#
# spec file for package systemd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor mini%{nil}

%if 0%{?_build_in_place}
# Allow users to specify the version and the release when building the rpm in
# place. When not provided we look for the version in meson.version (introduced
# in v256).
%define systemd_version    %{?version_override}%{!?version_override:%(cat meson.version)}
%define systemd_release    %{?release_override}%{!?release_override:0}
%define archive_version    %{nil}
%endif

# Enable this feature if the package version is set by obs-service-set_version.
%bcond_with obs_service_set_version

%if %{without obs_service_set_version}
%define systemd_version    257.6
%define systemd_release    0
%define archive_version    +suse.12.gc929295b4c
%endif

%define _testsuitedir %{_systemd_util_dir}/tests
%define xinitconfdir  %{?_distconfdir}%{!?_distconfdir:%{_sysconfdir}}/X11/xinit

# Similar to 'with' macro but return true/false. The value when the condition is
# verified can be redefined when a second parameter is passed.
%define __when_1() %{expand:%%{?with_%{1}:true}%%{!?with_%{1}:false}}
%define __when_2() %{expand:%%{?with_%{1}:%{2}}%%{!?with_%{1}:false}}
%define when()     %{expand:%%__when_%# %{*}}

%define __when_not_1() %{expand:%%{?with_%{1}:false}%%{!?with_%{1}:true}}
%define __when_not_2() %{expand:%%{?with_%{1}:false}%%{!?with_%{1}:%{2}}}
%define when_not()     %{expand:%%__when_not_%# %{*}}

# Same as above but return enabled/disabled instead.
%define disabled_with()  %{expand:%%{?with_%{1}:disabled}%%{!?with_%{1}:enabled}}
%define enabled_with()   %{expand:%%{?with_%{1}:enabled}%%{!?with_%{1}:disabled}}

%if "%{flavor}" == "mini"
%global mini -mini
%global with_bootstrap 1
%else
%global mini %nil
%bcond_without  apparmor
%bcond_without  homed
%bcond_without  importd
%bcond_without  journal_remote
%bcond_without  machined
%bcond_without  networkd
%bcond_without  portabled
%bcond_without  resolved
%ifarch %{ix86} x86_64 aarch64
%bcond_without  sd_boot
%else
%bcond_with     sd_boot
%endif
%bcond_without  selinux
%bcond_without  sysvcompat
%bcond_without  experimental
%bcond_without  testsuite
%endif

%bcond_with upstream

# The following features are kept to ease migrations toward SLE. Their default
# value is independent of the build flavor.
%bcond_without  filetriggers

Name:           systemd%{?mini}
URL:            http://www.freedesktop.org/wiki/Software/systemd
Version:        %{?systemd_version}
Release:        1.1
Summary:        A System and Session Manager
License:        LGPL-2.1-or-later
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{without bootstrap}
BuildRequires:  bpftool
BuildRequires:  clang
BuildRequires:  docbook-xsl-stylesheets
%if %{with apparmor}
BuildRequires:  libapparmor-devel
%endif
BuildRequires:  libgcrypt-devel
BuildRequires:  libxslt-tools
BuildRequires:  polkit
# python is only required for generating systemd.directives.xml
BuildRequires:  python3-base
BuildRequires:  python3-lxml
BuildRequires:  pkgconfig(audit)
BuildRequires:  pkgconfig(libbpf)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libiptc)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libseccomp) >= 2.3.1
%if %{with selinux}
BuildRequires:  pkgconfig(libselinux) >= 2.1.9
%endif
BuildRequires:  pkgconfig(libzstd)
%endif
BuildRequires:  fdupes
BuildRequires:  gperf
BuildRequires:  libacl-devel
BuildRequires:  libcap-devel
BuildRequires:  libmount-devel >= 2.27.1
BuildRequires:  meson >= 0.53.2
BuildRequires:  pam-devel
BuildRequires:  python3-Jinja2
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(blkid) >= 2.26
# The following packages are only required by the execution of the unit tests
# during the 'check' section.
BuildRequires:  acl
BuildRequires:  distribution-release
BuildRequires:  python3-pefile
BuildRequires:  timezone

%if %{with bootstrap}
#!BuildIgnore:  dbus-1
Provides:       systemd = %{version}-%{release}
Conflicts:      systemd
# Don't consider the mini flavors when building kiwi medias. This conflict is
# automatically inherited by sub-packages requiring systemd (such as udev).
Conflicts:      kiwi
# This dependency is used to ensure that the mini flavors are selected only
# inside OBS builds (where this dependency is ignored) and don't get installed
# on real systems.
Requires:       this-is-only-for-build-envs
%else
# the buildignore is important for bootstrapping
#!BuildIgnore:  udev
Requires:       aaa_base >= 13.2
Requires:       dbus-1 >= 1.4.0
Requires:       kbd
Requires:       netcfg >= 11.5
Requires:       systemd-default-settings-branding
Requires:       systemd-presets-branding
Requires:       util-linux >= 2.27.1
Requires(post): coreutils
Requires(post): findutils
Requires(post): systemd-presets-branding
Requires(post): pam-config >= 0.79-5
# See bsc#1228659
OrderWithRequires(post): udev
OrderWithRequires(post): systemd-boot
# These weak dependencies because some features are optional and enabled at
# runtime with the presence of the relevant libs.
Recommends:     libpcre2-8-0
Recommends:     libbpf1
%endif
Provides:       group(systemd-journal)
Conflicts:      filesystem < 11.5
Provides:       sbin_init
Provides:       sysvinit:/sbin/init
Conflicts:      sbin_init
Conflicts:      sysvinit
Obsoletes:      nss-systemd < %{version}-%{release}
Provides:       nss-systemd = %{version}-%{release}
Obsoletes:      nss-myhostname < %{version}-%{release}
Provides:       nss-myhostname = %{version}-%{release}
Provides:       systemd-coredump = %{version}-%{release}
Obsoletes:      systemd-coredump < %{version}-%{release}
Provides:       systemd-logger = %{version}-%{release}
Obsoletes:      systemd-logger < %{version}-%{release}
Provides:       systemd-analyze = %{version}-%{release}
Obsoletes:      pm-utils <= 1.4.1
Obsoletes:      suspend <= 1.0
Obsoletes:      systemd-analyze < 201
Source0:        systemd-%{version}%{?archive_version}.tar.xz
Source1:        systemd-rpmlintrc
Source3:        systemd-update-helper
%if %{with sysvcompat}
Source4:        systemd-sysv-install
%endif
Source5:        tmpfiles-suse.conf
Source6:        baselibs.conf
Source7:        triggers.systemd
Source8:        pam.systemd-user
Source9:        pam.systemd-run0
Source14:       kbd-model-map.legacy

Source100:      fixlet-container-post.sh
Source101:      fixlet-systemd-post.sh

Source200:      files.systemd
Source201:      files.udev
Source202:      files.container
Source203:      files.networkd
Source204:      files.devel
Source205:      files.sysvcompat
Source206:      files.uefi-boot
Source207:      files.experimental
Source208:      files.resolved
Source209:      files.homed
Source210:      files.lang
Source211:      files.journal-remote
Source212:      files.portable
Source213:      files.devel-doc

#
# All changes backported from upstream are tracked by the git repository, which
# can be found at:  https://github.com/openSUSE/systemd.
#
# The patches listed below are specific to openSUSE and should be kept to a
# minimum.  We strive to push our changes upstream, but sometimes they are only
# relevant for SUSE distributions. Special rewards for those who manage to
# eliminate any of them!
#
# Upstream CI builds run from latest upstream main, and as such patches will not
# apply due to fuzz, so skip all of them. Ensure all patches are always listed
# inside the following if block.
#
%if %{without upstream}
Patch:          0001-Drop-support-for-efivar-SystemdOptions.patch
%if %{with sysvcompat}
Patch:          0002-rc-local-fix-ordering-startup-for-etc-init.d-boot.lo.patch
Patch:          0008-sysv-generator-translate-Required-Start-into-a-Wants.patch
%endif
Patch:          0009-pid1-handle-console-specificities-weirdness-for-s390.patch
# The patches listed below are in quarantine. Normally, all changes must be
# pushed to upstream first and then cherry-picked into the SUSE git
# repository. However, in few cases, some issues might take too much time to be
# solved by upstream. In these cases, these patches are temporarily added here
# and will be removed as soon as a proper fix is merged by upstream.
Patch:          5001-Revert-udev-update-devlink-with-the-newer-device-nod.patch
Patch:          5002-Revert-udev-revert-workarounds-for-issues-caused-by-.patch
%endif

%description
Systemd is a system and service manager, compatible with SysV and LSB
init scripts for Linux. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system state,
maintains mount and automount points and implements an elaborate
transactional dependency-based service control logic. It can work as a
drop-in replacement for sysvinit.

%package devel
Summary:        Development files for libsystemd and libudev
License:        LGPL-2.1-or-later
Requires:       libsystemd0%{?mini} = %{version}-%{release}
Requires:       libudev%{?mini}1 = %{version}-%{release}
Requires:       systemd-rpm-macros
Provides:       libudev%{?mini}-devel = %{version}-%{release}
Obsoletes:      libudev%{?mini}-devel < %{version}-%{release}
%if %{with bootstrap}
Provides:       systemd-devel = %{version}-%{release}
Conflicts:      systemd-devel
Provides:       libudev-devel = %{version}-%{release}
Conflicts:      libudev-devel
%endif

%description devel
Development headers and files for libsystemd and libudev libraries for
developing and building applications linking to these libraries.

%if %{with sysvcompat}
%package sysvcompat
Summary:        SySV and LSB init script support for systemd (deprecated)
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
Provides:       systemd-sysvinit = %{version}-%{release}
Obsoletes:      systemd-sysvinit < %{version}-%{release}

%description sysvcompat
This package ships the necessary files that enable minimal SysV and LSB init
scripts support in systemd. It also contains the obsolete SysV init tools
telinit(8) and runlevel(8). You should consider using systemctl(1) instead.

Unless you have a 3rd party application installed on your system that still
relies on such scripts, this package should not be needed at all.

Please note that the content of this package is considered as deprecated.
%endif

%package -n libsystemd0%{?mini}
Summary:        Component library for systemd
License:        LGPL-2.1-or-later
%if %{with bootstrap}
Conflicts:      kiwi
Conflicts:      libsystemd0
Provides:       libsystemd0 = %{version}-%{release}
Requires:       this-is-only-for-build-envs
%endif

%description -n libsystemd0%{?mini}
This library provides several of the systemd C APIs:

* sd-bus implements an alternative D-Bus client library that is
  relatively easy to use, very efficient and supports both classic
  D-Bus as well as kdbus as transport backend.

* sd-daemon(3): for system services (daemons) to report their status
  to systemd and to make easy use of socket-based activation logic

* sd-event is a generic event loop abstraction that is built around
  Linux epoll, but adds features such as event prioritization or
  efficient timer handling.

* sd-id128(3): generation and processing of 128-bit IDs

* sd-journal(3): API to submit and query journal log entries

* sd-login(3): APIs to introspect and monitor seat, login session and
  user status information on the local system.

%package -n udev%{?mini}
Summary:        A rule-based device node and kernel event manager
License:        GPL-2.0-only
URL:            http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev.html
Requires:       %{name} = %{version}-%{release}
%systemd_requires
Requires:       filesystem
%if %{without bootstrap}
# kmod executable is needed by kmod-static-nodes.service
Requires:       kmod
# By v256 libkmod will be dlopen()ed.
Requires:       libkmod2
%endif
Requires:       system-group-hardware
Requires:       group(kvm)
Requires:       group(lp)
# The next dependency is also needed with file-triggers enabled due to the way
# the libzypp default transaction backend works.
Requires(pre):  group(kvm)
Requires(post): sed
Requires(post): coreutils
Requires(postun): coreutils
# 'regenerate_initrd_post' macro is expanded during build, hence this BR.
BuildRequires:  suse-module-tools
%if %{without bootstrap}
# fdisk is a build requirement for repart
BuildRequires:  pkgconfig(fdisk)
BuildRequires:  pkgconfig(libcryptsetup) >= 1.6.0
BuildRequires:  pkgconfig(libkmod) >= 15
# Enable fido2 and tpm supports in systemd-cryptsetup, systemd-enroll. However
# these tools are not linked against the libs directly but instead are
# dlopen()ed at runtime to avoid hard dependencies. Hence the use of soft
# dependencies.
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libfido2)
BuildRequires:  pkgconfig(tss2-esys)
BuildRequires:  pkgconfig(tss2-mu)
BuildRequires:  pkgconfig(tss2-rc)
Recommends:     libarchive13
Recommends:     libfido2
Recommends:     libtss2-esys0
Recommends:     libtss2-mu0
Recommends:     libtss2-rc0
%endif
Conflicts:      ConsoleKit < 0.4.1
Conflicts:      dracut < 059
Conflicts:      filesystem < 11.5
Conflicts:      util-linux < 2.16
%if %{with bootstrap}
Conflicts:      udev
Provides:       udev = %{version}-%{release}
%endif
%if %{with upstream}
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(xencontrol)
BuildRequires:  pkgconfig(xkbcommon)
Recommends:     libxkbcommon0
%endif

%description -n udev%{?mini}
This package provides systemd-udevd. The udev daemon receives device uevents
directly from the kernel whenever it adds or removes a device from the system in
/dev, or it changes its state. When udev receives a device event, it matches its
configured set of rules, located in %{_udevrulesdir}/, against various device
attributes to identify the device. Rules that match may adjust device node
permissions, create meaningful symlink names or provide additional device
information to be stored in the udev database.

The udev daemon may also rename network interfaces and perform various network
device configurations, see systemd.link(5) for more details.

This package also provides various tools and services that operate on devices
exclusively. For example it contains systemd-cryptsetup to manage encrypted
block devices as well as systemd-growfs to instruct the kernel to grow the
mounted filesystem to full size of the underlying block device.

This package shouldn't be necessary in containers.

%package -n libudev%{?mini}1
Summary:        Dynamic library to access udev device information
License:        LGPL-2.1-or-later
%if %{with bootstrap}
Conflicts:      kiwi
Conflicts:      libudev1
Provides:       libudev1 = %{version}-%{release}
Requires:       this-is-only-for-build-envs
%endif

%description -n libudev%{?mini}1
This package contains the dynamic library libudev, which provides
access to udev device information

%if %{with sd_boot}
%package boot
Summary:        A simple UEFI boot manager
License:        LGPL-2.1-or-later
BuildRequires:  pesign-obs-integration
BuildRequires:  python3-pyelftools

%description boot
This package provides systemd-boot (short: sd-boot), which is a simple UEFI boot
manager. It provides a textual menu to select the entry to boot and an editor
for the kernel command line. systemd-boot supports systems with UEFI firmware
only.

This package also contains bootctl(1) and services to manage boot loaders that
implement the Boot Loader Specification[1] and the Boot Loader Interface[2] on
EFI systems, such as systemd-boot.

Note that systemd-boot is not fully integrated in openSUSE distributions yet
hence its installation requires special care and manual steps when used on
systems supporting secure boot or snapshots. For more details, visit:
https://en.opensuse.org/Systemd-boot

[1] https://uapi-group.org/specifications/specs/boot_loader_specification/
[2] https://systemd.io/BOOT_LOADER_INTERFACE/
%endif

%package container
Summary:        Systemd tools for container management
License:        LGPL-2.1-or-later
%if %{with importd}
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
%endif
Requires:       %{name} = %{version}-%{release}
# import-tar needs tar and gpg
Requires:       /usr/bin/tar
Requires:       /usr/bin/gpg
%systemd_requires
Obsoletes:      nss-mymachines < %{version}-%{release}
Provides:       nss-mymachines = %{version}-%{release}
Provides:       systemd-container = %{version}-%{release}
Provides:       systemd:%{_bindir}/systemd-nspawn
%if %{with bootstrap}
Conflicts:      systemd-container
Provides:       systemd-container = %{version}-%{release}
%endif

%description container
Systemd tools to spawn and manage containers and virtual machines.

In addition, it also contains a plugin for the Name Service Switch (NSS),
providing host name resolution for all local containers and virtual machines
using network namespacing and registered with systemd-machined. It also maps
UID/GIDs ranges used by containers to useful names.

To activate this NSS module, you will need to include it in /etc/nsswitch.conf,
see nss-mymachines(8) manpage for more details.

%if %{with networkd}
%package networkd
Summary:        Systemd Network Manager
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
%systemd_requires
Obsoletes:      systemd-network < %{version}-%{release}
Provides:       systemd-network = %{version}-%{release}
Provides:       systemd-network:/usr/lib/systemd/systemd-networkd
# Workaround for bsc#1241513: ensure systemd-resolved is always installed before
# systemd-network when the latter is replaced by both systemd-resolved and
# systemd-networkd. The systemd-update-helper script logic depends on that.
Suggests:       systemd-resolved

%description networkd
systemd-networkd is a system service that manages networks. It detects and
configures network devices as they appear, as well as manages network addresses
and routes for any link for which it finds a .network file, see
systemd.network(5). It can also create virtual network devices based on their
description given by systemd.netdev(5) files. It may be controlle by
networkctl(1).
%endif

%if %{with resolved}
%package resolved
Summary:        Systemd Network Name Resolution Manager
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
%systemd_requires
# This Recommends because some symbols of libidn2 are dlopen()ed by resolved
Recommends:     pkgconfig(libidn2)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(openssl)
Obsoletes:      nss-resolve < %{version}-%{release}
Provides:       nss-resolve = %{version}-%{release}
Provides:       systemd-network:/usr/lib/systemd/systemd-resolved

%description resolved
systemd-resolved is a system service that provides network name resolution to
local applications. It implements a caching and validating DNS/DNSSEC stub
resolver, as well as an LLMNR and MulticastDNS resolver and responder. It may be
controlled by resolvectl(1).

Addtionally, this package also contains a plug-in module for the Name Service
Switch (NSS), which enables hostname resolutions by contacting
systemd-resolved(8). It replaces the nss-dns plug-in module that traditionally
resolves hostnames via DNS.

To activate this NSS module, you will need to include it in /etc/nsswitch.conf,
see nss-resolve(8) manpage for more details.
%endif

%if %{with homed}
%package homed
Summary:        Home Area/User Account Manager
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
%systemd_requires
BuildRequires:  pkgconfig(fdisk)
BuildRequires:  pkgconfig(libcryptsetup)
BuildRequires:  pkgconfig(libfido2)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pwquality)
# These Recommends because some symbols of these libs are dlopen()ed by homed
Recommends:     libcryptsetup12
Recommends:     libfido2
Recommends:     libpwquality1
Recommends:     libqrencode4

%description homed
This package contains systemd-homed.service, a system service that manages home
directories of users. The home directories managed are self-contained, and thus
include the user's full metadata record in the home's data storage itself,
making them easy to migrate between machines; the user account and home
directory becoming the same concept.

This package also includes homectl(1), a tool to interact with systemd-homed and
PAM module to automatically mount home directories on user login.

See homectl(1) man page for instructions to create a new user account.

A description of the various storage mechanisms implemented by systemd-homed can
be found at https://systemd.io/HOME_DIRECTORY/.

Note that nss-systemd has still not been integrated into nsswitch and therefore
needs to be added manually into /etc/nsswitch.conf, see nss-systemd(8) man page
for an example on how to do that.
%endif

%if %{with portabled}
%package portable
Summary:        Systemd tools for portable services
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
%systemd_requires

%description portable
Systemd tools to manage portable services. The feature is still considered
experimental so the package might change or vanish.  Use at own risk.

More information can be found online:

http://0pointer.net/blog/walkthrough-for-portable-services.html
https://systemd.io/PORTABLE_SERVICES
%endif

%if %{with journal_remote}
%package journal-remote
Summary:        Gateway for serving journal events over the network using HTTP
License:        LGPL-2.1-or-later
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmicrohttpd) >= 0.9.33
Requires:       %{name} = %{version}-%{release}
%systemd_requires

%description journal-remote
This extends the journal functionality to keep a copy of logs on a
remote server by providing programs to forward journal entries over
the network, using encrypted HTTP, and to write journal files from
serialized journal contents.

This package contains systemd-journal-gatewayd,
systemd-journal-remote, and systemd-journal-upload.
%endif

%if %{with testsuite}
%package testsuite
Summary:        Testsuite for systemd
License:        LGPL-2.1-or-later
Recommends:     python3
Recommends:     python3-colorama
# Optional dep for mkfs.vfat needed by test-loop-block (otherwise skipped)
Recommends:     dosfstools
# Optional deps needed by TEST-70-TPM2 (otherwise skipped)
Recommends:     swtpm
Recommends:     tpm2.0-tools
%if %{with resolved}
# Optional dep for knot needed by TEST-75-RESOLVED
Recommends:     knot
%endif
%if %{with selinux}
# Optional deps needed by TEST-06-SELINUX (otherwise skipped)
Recommends:     selinux-policy-devel
Recommends:     selinux-policy-targeted
%endif
Requires:       %{name} = %{version}-%{release}
Requires:       attr
Requires:       binutils
Requires:       busybox-static
Requires:       cryptsetup
Requires:       dhcp-client
Requires:       dosfstools
Requires:       iproute2
Requires:       jq
Requires:       libcap-progs
Requires:       lz4
Requires:       make
Requires:       mtools
Requires:       python3-pexpect
Requires:       qemu
Requires:       quota
Requires:       socat
Requires:       squashfs
Requires:       stress-ng
Requires:       systemd-container
# System users/groups that some tests rely on.
Requires:       group(bin)
Requires:       group(daemon)
Requires:       group(games)
Requires:       group(nobody)
Requires:       user(bin)
Requires:       user(daemon)
Requires:       user(games)
Requires:       user(nobody)
# The following deps on libs are for test-dlopen-so whereas the pkgconfig ones
# are used by test-funtions to find the libs on the host and install them in the
# image, see install_missing_libraries() for details.
Requires:       pkgconfig(libarchive)
Requires:       pkgconfig(libfido2)
Requires:       pkgconfig(libidn2)
Requires:       pkgconfig(libkmod)
%if %{with experimental}
Requires:       pkgconfig(libqrencode)
Requires:       pkgconfig(pwquality)
%endif
Requires:       pkgconfig(tss2-esys)
Requires:       pkgconfig(tss2-mu)
Requires:       pkgconfig(tss2-rc)
%if %{with sd_boot}
Requires:       systemd-boot
%endif
%if %{with experimental}
Requires:       systemd-experimental
%endif
%if %{with homed}
Requires:       systemd-homed
%endif
%if %{with journal_remote}
Requires:       systemd-journal-remote
%endif
%if %{with networkd}
Requires:       systemd-networkd
%endif
%if %{with portabled}
Requires:       systemd-portable
%endif
Requires:       xz

%description testsuite
This package contains the unit tests as well as the extended testsuite. The unit
tests are used to check various internal functions used by systemd whereas the
extended testsuite is used to test various functionalities of systemd and all
its components.

Note that you need root privileges to run the extended testsuite.

Run the following python script to run all unit tests at once:
$ %{_testsuitedir}/run-unit-tests.py

To run the full extended testsuite do the following:
$ NO_BUILD=1 TEST_NESTED_VM=1 %{_testsuitedir}/integration-tests/run-integration-tests.sh

Or to run one specific integration test:
$ NO_BUILD=1 TEST_NESTED_VM=1 make -C %{_testsuitedir}/integration-tests/TEST-01-BASIC clean setup run

For more details on the available options to run the extended testsuite, please
refer to %{_testsuitedir}/integration-tests/README.testsuite.
%endif

%if %{with experimental}
%package experimental
Summary:        Experimental systemd features
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}-%{release}
%systemd_requires

%description experimental
This package contains optional extra services that are considered as previews
and are provided so users can do early experiments with the new features or
technologies without waiting for them to be fully supported by both upstream
and openSUSE.

Please note that the material shipped by this package should be considered in
development phase and as such their behaviors, unit files, option names,
etc... are subject to change without the usual backwards-compatibility promises.

Components that turn out to be stable and considered as fully supported will be
merged into the main package or moved into a dedicated package.

Currently this package contains the following features : bsod, oomd, measure,
pcrextend, pcrlock, run0, ssh-generator, storagetm, systemd-vmspawn, sysupdate,
tpm2-setup, userwork and ukify.

Have fun (at your own risk).
%endif

%if %{without bootstrap}
%lang_package

%package doc
Summary:        Additional documentation or doc formats for systemd
License:        LGPL-2.1-or-later
BuildArch:      noarch

%description doc
A HTML version of the systemd documentation, plus the manual pages
for the C APIs.
%endif

%prep
%autosetup -p1 -n systemd-%{version}%{?archive_version}

# When building on OBS with version substitution, systemd_version is not
# defined, and the "Version:" field contains the base version plus the archive
# version. Therefore, recompute the base version so it can be used seamlessly to
# name the private shared libraries.
%global base_version %(v=%{version}; echo ${v%%+*})

%build
%meson \
        -Dmode=release \
        -Dversion-tag=%{version}%{?archive_version} \
        -Dshared-lib-tag=%{base_version}-%{release} \
        -Ddocdir=%{_docdir}/systemd \
        -Dconfigfiledir=/usr/lib \
        -Dsplit-bin=true \
        -Dsystem-uid-max=499 \
        -Dsystem-gid-max=499 \
        -Dclock-valid-range-usec-max=946728000000000 \
        -Dadm-group=false \
        -Dwheel-group=false \
        -Dgroup-render-mode=0660 \
        -Dutmp=false \
        -Ddefault-kill-user-processes=false \
        -Dpamconfdir=no \
        -Dpamlibdir=%{_pam_moduledir} \
        -Dshellprofiledir=%{_distconfdir}/profile.d \
        -Dxinitrcdir=%{xinitconfdir}/xinitrc.d \
        -Drpmmacrosdir=no \
        -Dcertificate-root=%{_sysconfdir}/pki/systemd \
%if %{with bootstrap}
        -Dbashcompletiondir=no \
        -Dzshcompletiondir=no \
%endif
%if %{without sysvcompat}
        -Dsysvinit-path= \
        -Dsysvrcnd-path= \
%else
        -Drc-local=/etc/init.d/boot.local \
%endif
        -Dcreate-log-dirs=false \
        -Ddebug-shell=/bin/bash \
        \
        -Dbump-proc-sys-fs-nr-open=false \
        -Ddbus=disabled \
        -Ddefault-mountfsd-trusted-directories=false \
        -Ddefault-network=false \
        -Dglib=disabled \
        -Dgshadow=false \
        -Dldconfig=false \
        -Dlibidn=disabled \
        -Dsmack=false \
        -Dvmlinux-h=disabled \
        -Dxenctrl=disabled \
        -Dxkbcommon=disabled \
        \
        -Dpstore=true \
        \
        -Daudit=%{disabled_with bootstrap} \
        -Dbpf-framework=%{disabled_with bootstrap} \
        -Dbzip2=%{enabled_with importd} \
        -Delfutils=%{disabled_with bootstrap} \
        -Dfdisk=%{disabled_with bootstrap} \
        -Dgcrypt=%{disabled_with bootstrap} \
        -Dgnutls=%{disabled_with bootstrap} \
        -Dhtml=%{disabled_with bootstrap} \
        -Dima=%{when_not bootstrap} \
        -Dkernel-install=%{when_not bootstrap} \
        -Dlibarchive=%{disabled_with bootstrap} \
        -Dlibfido2=%{disabled_with bootstrap} \
        -Dlibidn2=%{enabled_with resolved} \
        -Dlibiptc=%{disabled_with bootstrap} \
        -Dlz4=%{disabled_with bootstrap} \
        -Dqrencode=%{disabled_with bootstrap} \
        -Dkmod=%{disabled_with bootstrap} \
        -Dlibcryptsetup=%{disabled_with bootstrap} \
        -Dlibcryptsetup-plugins=%{disabled_with bootstrap} \
        -Dlibcurl=%{disabled_with bootstrap} \
        -Dman=%{disabled_with bootstrap} \
        -Dmountfsd=%{when_not bootstrap} \
        -Dnsresourced=%{when_not bootstrap} \
        -Dmicrohttpd=%{enabled_with journal_remote} \
        -Dnss-myhostname=%{when_not bootstrap} \
        -Dnss-mymachines=%{enabled_with machined} \
        -Dnss-resolve=%{enabled_with resolved} \
        -Dnss-systemd=%{when_not bootstrap} \
        -Dopenssl=%{disabled_with bootstrap} \
        -Dp11kit=%{disabled_with bootstrap} \
        -Dpasswdqc=%{disabled_with bootstrap} \
        -Dpwquality=%{disabled_with bootstrap} \
        -Dseccomp=%{disabled_with bootstrap} \
        -Drepart=%{disabled_with bootstrap} \
        -Dstoragetm=%{when_not bootstrap} \
        -Dtpm=%{when_not bootstrap} \
        -Dtpm2=%{disabled_with bootstrap} \
        -Dtranslations=%{when_not bootstrap} \
        -Duserdb=%{when_not bootstrap} \
        -Dxz=%{disabled_with bootstrap} \
        -Dzlib=%{enabled_with importd} \
        -Dzstd=%{disabled_with bootstrap} \
        \
        -Dapparmor=%{enabled_with apparmor} \
        -Dcoredump=%{when_not bootstrap} \
        -Dhomed=%{enabled_with homed} \
        -Dimportd=%{enabled_with importd} \
        -Dmachined=%{when machined} \
        -Dnetworkd=%{when networkd} \
        -Dportabled=%{when portabled} \
        -Dremote=%{enabled_with journal_remote} \
        -Dselinux=%{enabled_with selinux} \
        \
        -Dbootloader=%{enabled_with sd_boot} \
        -Defi=%{when sd_boot} \
        -Defi-color-highlight="black,green" \
        \
        -Dsbat-distro="%{?sbat_distro}" \
        -Dsbat-distro-summary="%{?sbat_distro_summary}" \
        -Dsbat-distro-url="%{?sbat_distro_url}" \
        \
        -Dsbat-distro-pkgname="%{name}" \
        -Dsbat-distro-version="%{version}%[%{without upstream}?"-%{release}":""]" \
        \
        -Ddefault-dnssec=no \
        -Ddns-servers='' \
        -Ddns-over-tls=%{when resolved openssl} \
        -Dresolve=%{when resolved} \
        \
        -Doomd=%{when experimental} \
%if %{with experimental}
        -Dsshdconfdir=%{_distconfdir}/ssh/sshd_config.d \
        -Dsshconfdir=%{_distconfdir}/ssh/ssh_config.d \
        -Dukify=%{enabled_with sd_boot} \
%else
        -Dsshdconfdir=no \
        -Dsshconfdir=no \
        -Dukify=disabled \
%endif
        -Dsshdprivsepdir=no \
        -Dsysupdate=%{enabled_with experimental} \
        -Dsysupdated=%{enabled_with experimental} \
        -Dvmspawn=%{enabled_with experimental} \
        \
        -Dtests=%{when testsuite unsafe} \
        -Dinstall-tests=%{when testsuite} \
        \
        %{?meson_extra_configure_options}

%meson_build

%install
%meson_install

%if %{with sd_boot}
%ifarch x86_64
export BRP_PESIGN_FILES="%{_systemd_util_dir}/boot/efi/systemd-bootx64.efi"
%endif
%if %{with upstream}
%ifarch aarch64
export BRP_PESIGN_FILES="%{_systemd_util_dir}/boot/efi/systemd-bootaa64.efi"
%endif
%endif
%endif

# Don't ship resolvconf symlink for now as it conflicts with the binary shipped
# by openresolv and provides limited compatibility only.
%if %{with resolved}
rm %{buildroot}%{_sbindir}/resolvconf
rm %{buildroot}%{_mandir}/man1/resolvconf.1*
%endif

install -m0755 -D %{SOURCE3} %{buildroot}/%{_systemd_util_dir}/systemd-update-helper
%if %{with sysvcompat}
install -m0755 -D %{SOURCE4} %{buildroot}/%{_systemd_util_dir}/systemd-sysv-install
%endif

# Install the fixlets
mkdir -p %{buildroot}%{_systemd_util_dir}/rpm
%if %{with machined}
install -m0755 %{SOURCE100} %{buildroot}%{_systemd_util_dir}/rpm/
%endif
install -m0755 %{SOURCE101} %{buildroot}%{_systemd_util_dir}/rpm/

# Make sure /usr/lib/modules-load.d exists in udev(-mini)?, so other
# packages can install modules without worry
mkdir -p %{buildroot}%{_modulesloaddir}

# Make sure we don't ship static enablement symlinks in /etc during
# installation, presets should be honoured instead.
rm -rf %{buildroot}%{_sysconfdir}/systemd/system/*.target.{requires,wants}
rm -f %{buildroot}%{_sysconfdir}/systemd/system/default.target

# Replace upstream PAM configuration files with openSUSE ones.
install -m0644 -D %{SOURCE8} %{buildroot}%{_pam_vendordir}/systemd-user
%if %{with experimental}
install -m0644 -D %{SOURCE9} %{buildroot}%{_pam_vendordir}/systemd-run0
%endif

# Don't enable wall ask password service, it spams every console (bnc#747783).
rm %{buildroot}%{_unitdir}/multi-user.target.wants/systemd-ask-password-wall.path

# do not ship sysctl defaults in systemd package, will be part of aaa_base (in
# procps for now).
rm -f %{buildroot}%{_sysctldir}/50-default.conf
rm -f %{buildroot}%{_sysctldir}/50-pid-max.conf

# Make sure systemd-network polkit rules file starts with a suitable number
# prefix so it takes precedence over our polkit-default-privs.
%if %{with networkd}
mv %{buildroot}%{_datadir}/polkit-1/rules.d/systemd-networkd.rules \
        %{buildroot}%{_datadir}/polkit-1/rules.d/60-systemd-networkd.rules
%endif

# Since v207 /etc/sysctl.conf is no longer parsed (commit 04bf3c1a60d82791),
# however backward compatibility is provided by the following symlink.
ln -s ../../../etc/sysctl.conf %{buildroot}%{_sysctldir}/99-sysctl.conf
touch %{buildroot}%{_sysconfdir}/sysctl.conf

# The definitions of the basic users/groups are given by system-user package on
# SUSE (bsc#1006978).
rm -f %{buildroot}%{_sysusersdir}/basic.conf

# systemd-user PAM module relies on pam_env(8) to import the environment defined
# in /etc/environment (which is part of the environment configuration files of
# pam_env(8) anyways).
rm -f %{buildroot}%{_environmentdir}/99-environment.conf

# Remove README file in init.d as (SUSE) rpm requires executable files in this
# directory... oh well.
rm -f %{buildroot}%{_sysconfdir}/init.d/README

# Create *.conf.d/ directories to encourage users to create drop-ins when they
# need to customize some setting defaults.
mkdir -p %{buildroot}%{_sysconfdir}/systemd/coredump.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/journald.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/journal-remote.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/journal-upload.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/logind.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/networkd.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/oomd.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/pstore.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/resolved.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/sleep.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/system.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/timesyncd.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/systemd/user.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/udev/iocost.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/udev/udev.conf.d

mkdir -p %{buildroot}%{_sysconfdir}/systemd/network
mkdir -p %{buildroot}%{_sysconfdir}/systemd/nspawn

mkdir -p %{buildroot}%{_sysconfdir}/sysusers.d/

# This dir must be owned (and thus created) by systemd otherwise the build
# system will complain. This is odd since we simply own a ghost file in it...
mkdir -p %{buildroot}%{_sysconfdir}/X11/xorg.conf.d

# Make sure directories in /var exist.
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/coredump
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/catalog
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/rpm

# Make sure the NTP units dir exists.
mkdir -p %{buildroot}%{_ntpunitsdir}

# Make sure the shutdown/sleep drop-in dirs exist.
mkdir -p %{buildroot}%{_systemd_util_dir}/system-shutdown/
mkdir -p %{buildroot}%{_systemd_util_dir}/system-sleep/

# Make sure these directories are properly owned.
mkdir -p %{buildroot}%{_unitdir}/basic.target.wants
mkdir -p %{buildroot}%{_unitdir}/default.target.wants
mkdir -p %{buildroot}%{_unitdir}/dbus.target.wants
mkdir -p %{buildroot}%{_unitdir}/graphical.target.wants
mkdir -p %{buildroot}%{_unitdir}/halt.target.wants
mkdir -p %{buildroot}%{_unitdir}/initrd-root-device.target.wants
mkdir -p %{buildroot}%{_unitdir}/initrd-root-fs.target.wants
mkdir -p %{buildroot}%{_unitdir}/kexec.target.wants
mkdir -p %{buildroot}%{_unitdir}/poweroff.target.wants
mkdir -p %{buildroot}%{_unitdir}/reboot.target.wants
mkdir -p %{buildroot}%{_unitdir}/remote-fs.target.wants
mkdir -p %{buildroot}%{_unitdir}/rescue.target.wants
mkdir -p %{buildroot}%{_unitdir}/shutdown.target.wants

# Make sure the generator directories are created and properly owned.
mkdir -p %{buildroot}%{_systemdgeneratordir}
mkdir -p %{buildroot}%{_systemdusergeneratordir}
mkdir -p %{buildroot}%{_presetdir}
mkdir -p %{buildroot}%{_userpresetdir}
mkdir -p %{buildroot}%{_systemd_system_env_generator_dir}
mkdir -p %{buildroot}%{_systemd_user_env_generator_dir}

# ghost directories with default permissions.
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/backlight

# ghost files with default permisssions.
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
touch %{buildroot}%{_sysconfdir}/vconsole.conf
touch %{buildroot}%{_sysconfdir}/locale.conf
touch %{buildroot}%{_sysconfdir}/machine-info
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database

%fdupes -s %{buildroot}%{_mandir}

# Make sure to disable all services by default. The branding presets package
# takes care of defining the SUSE policies.
rm -f %{buildroot}%{_presetdir}/*.preset
echo 'disable *' >%{buildroot}%{_presetdir}/99-default.preset
echo 'disable *' >%{buildroot}%{_userpresetdir}/99-default.preset

# Most of the entries for the generic paths are defined by filesystem package as
# the definitions used by SUSE distros diverged from the ones defined by
# systemd. For lack of a better place some (deprecated) paths are still shipped
# along with the systemd package.
rm -f %{buildroot}%{_tmpfilesdir}/{etc,home,legacy,tmp,var}.conf
install -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/systemd-suse.conf

# These 2 following file are useless because on SUSE distros ssh can parse
# drop-ins in /usr.
rm -f %{buildroot}%{_tmpfilesdir}/20-systemd-ssh-generator.conf
rm -f %{buildroot}%{_tmpfilesdir}/20-systemd-userdb.conf

# The content of the files shipped by systemd doesn't match the
# defaults used by SUSE. Don't ship those files but leave the decision
# to use the mechanism to the individual packages that actually
# consume those configs (like glibc or pam), see bsc#1170146.
rm -fr %{buildroot}%{_datadir}/factory/*

# kbd-model-map.legacy is used to provide mapping for legacy keymaps, which may
# still be used by yast.
cat %{SOURCE14} >>%{buildroot}%{_datarootdir}/systemd/kbd-model-map

%if %{with testsuite}
# -Dinstall_test took care of installing the unit tests only (those in
# src/tests) and testdata directory. Here we copy the integration tests
# including also all related scripts used to prepare and run the integration
# tests in dedicated VMs.
mkdir -p %{buildroot}%{_testsuitedir}/integration-tests
tar -cO \
    --exclude-vcs  \
    --exclude-vcs-ignores \
    -C test/integration-tests/ . | tar -xC %{buildroot}%{_testsuitedir}/integration-tests/
%endif

%if %{without bootstrap}
%find_lang systemd
%else
rm -f  %{buildroot}%{_journalcatalogdir}/*
rm -fr %{buildroot}%{_docdir}/systemd
rm -f %{buildroot}%{_bindir}/run0
rm -f %{buildroot}%{_systemdgeneratordir}/systemd-ssh-generator
rm -f %{buildroot}%{_systemdgeneratordir}/systemd-tpm2-generator
rm -f %{buildroot}%{_unitdir}/systemd-nspawn@.service
rm -f %{buildroot}%{_systemd_util_dir}/systemd-ssh-proxy
%endif

# Don't drop the following 'pre' section even if it becomes empty: the build
# process of installation images uses a hardcoded list of packages with a 'pre'
# section that needs to be run during the build and complains if it can't find
# one.
%pre
# We don't really need to enable these units explicitely since during
# installation `systemctl preset-all` is executed at the end of the install
# transaction by the branding preset package. However it might be needed when
# upgrading from a previous version of systemd that didn't ship one of these
# units.
%systemd_pre remote-fs.target
%systemd_pre getty@.service
%systemd_pre systemd-journald-audit.socket
%systemd_pre systemd-userdbd.service

%check
%if %{with upstream}
# Run the unit tests.
%meson_test
%endif

%post
if [ $1 -eq 1 ]; then
        # Make /etc/machine-id an empty file during package installation. On the
        # first boot, machine-id is initialized and either committed (if /etc/
        # is writable) or the system/image runs with a transient machine ID,
        # that changes on each boot (if the image is read-only). This is
        # important for appliance builds to avoid an identical machine ID in all
        # images.
        touch     %{_sysconfdir}/machine-id
        chmod 444 %{_sysconfdir}/machine-id

        # Persistent journal is the default
        mkdir -p %{_localstatedir}/log/journal
fi

%if %{without bootstrap}
pam-config --add --systemd || :
# Run ldconfig for nss-systemd and nss-myhostname NSS modules.
%ldconfig
%endif

systemctl daemon-reexec || :
# Reexecute the user managers (if any)
%{_systemd_util_dir}/systemd-update-helper user-reexec || :

%if %{without filetriggers}
# During package installation, the followings are for config files shipped by
# packages that got installed before systemd and by the systemd main package
# itself. During update they deal with files that could have been introduced by
# new versions of systemd.
systemd-sysusers || :
systemd-tmpfiles --create || :
journalctl --update-catalog || :
%endif

# See the comment in the 'pre' section about why we need to call 'systemd_pre'
# macro.
%systemd_post remote-fs.target
%systemd_post getty@.service
%systemd_post systemd-journald-audit.socket
%systemd_post systemd-userdbd.service

# Run the hacks/fixups to clean up the old stuff left by (very) old versions of
# systemd.
%{_systemd_util_dir}/rpm/fixlet-systemd-post.sh $1 || :

%postun
# Avoid restarting logind until fixed upstream (issue #1163)
%systemd_postun_with_restart systemd-hostnamed.service
%systemd_postun_with_restart systemd-journald.service
%systemd_postun_with_restart systemd-localed.service
%systemd_postun_with_restart systemd-timedated.service
%systemd_postun_with_restart systemd-userdbd.service

%pretrans -p <lua>
if posix.access("%{_systemd_util_dir}/systemd-update-helper") then
   rpm.execute("%{_systemd_util_dir}/systemd-update-helper", "clean-state")
end

%posttrans -p <lua>
rpm.execute("%{_systemd_util_dir}/systemd-update-helper", "clean-state")

%pre -n udev%{?mini}
%systemd_pre remote-cryptsetup.target
%systemd_pre systemd-pstore.service
%systemd_pre systemd-timesyncd.service

# New installations uses the last compat symlink generation number (currently at
# 2), which basically disables all compat symlinks. On old systems, the file
# doesn't exist. This is equivalent to generation #1, which enables the creation
# of all compat symlinks.
if [ $1 -eq 1 ]; then
        echo "COMPAT_SYMLINK_GENERATION=2" >/usr/lib/udev/compat-symlink-generation
fi

%post -n udev%{?mini}
%regenerate_initrd_post
%if %{without filetriggers}
%udev_hwdb_update
%tmpfiles_create systemd-pstore.conf
%sysusers_create systemd-timesync.conf
%endif
%systemd_post remote-cryptsetup.target
%systemd_post systemd-pstore.service
%systemd_post systemd-timesyncd.service

%preun -n udev%{?mini}
%systemd_preun systemd-udevd.service systemd-udevd-{control,kernel}.socket
%systemd_preun systemd-pstore.service
%systemd_preun systemd-timesyncd.service

%postun -n udev%{?mini}
%regenerate_initrd_post
# Restarting udev socket units along with udevd is not safe (bsc#1228809).
%systemd_postun_with_restart systemd-udevd.service
%systemd_postun_with_restart systemd-timesyncd.service
%systemd_postun systemd-pstore.service

%posttrans -n udev%{?mini}
%regenerate_initrd_posttrans

%ldconfig_scriptlets -n libsystemd0%{?mini}
%ldconfig_scriptlets -n libudev%{?mini}1

%pre container
%systemd_pre systemd-mountfsd.socket
%systemd_pre systemd-nsresourced.socket
%if %{with machined}
%systemd_pre machines.target
%endif

%preun container
%systemd_preun systemd-mountfsd.socket
%systemd_preun systemd-nsresourced.socket
%if %{with machined}
%systemd_preun machines.target
%endif

%postun container
%systemd_postun systemd-mountfsd.socket
%systemd_postun systemd-nsresourced.socket
%if %{with machined}
%ldconfig
%systemd_postun machines.target
%endif

%post container
%if %{with machined}
%ldconfig
%if %{without filetriggers}
%tmpfiles_create systemd-nspawn.conf
%endif
%systemd_post systemd-mountfsd.socket
%systemd_post systemd-nsresourced.socket
%systemd_post machines.target
%{_systemd_util_dir}/rpm/fixlet-container-post.sh $1 || :
%endif

%if %{with journal_remote}
%pre journal-remote
%systemd_pre systemd-journal-gatewayd.service
%systemd_pre systemd-journal-remote.service
%systemd_pre systemd-journal-upload.service

%post journal-remote
# Assume that all files shipped by systemd-journal-remove are owned by root.
%if %{without filetriggers}
%sysusers_create systemd-remote.conf
%endif
%systemd_post systemd-journal-gatewayd.service
%systemd_post systemd-journal-remote.service
%systemd_post systemd-journal-upload.service

%preun journal-remote
%systemd_preun systemd-journal-gatewayd.service
%systemd_preun systemd-journal-remote.service
%systemd_preun systemd-journal-upload.service

%postun journal-remote
%systemd_postun_with_restart systemd-journal-gatewayd.service
%systemd_postun_with_restart systemd-journal-remote.service
%systemd_postun_with_restart systemd-journal-upload.service
%endif

%if %{with networkd}
%pre networkd
%systemd_pre systemd-networkd.service
%systemd_pre systemd-networkd-wait-online.service

%post networkd
%if %{without filetriggers}
%sysusers_create systemd-network.conf
%tmpfiles_create systemd-network.conf
%endif
%systemd_post systemd-networkd.service
%systemd_post systemd-networkd-wait-online.service

%preun networkd
%systemd_preun systemd-networkd.service
%systemd_preun systemd-networkd-wait-online.service

%postun networkd
%systemd_postun systemd-networkd.service
%systemd_postun systemd-networkd-wait-online.service
%endif

%if %{with resolved}
%pre resolved
%systemd_pre systemd-resolved.service

%post resolved
%ldconfig
%if %{without filetriggers}
%sysusers_create systemd-resolve.conf
%tmpfiles_create systemd-resolve.conf
%endif
%systemd_post systemd-resolved.service

%preun resolved
%systemd_preun systemd-resolved.service

%postun resolved
%ldconfig
%systemd_postun systemd-resolved.service
%endif

%if %{with homed}
%pre homed
%systemd_pre systemd-homed.service

%post homed
if [ $1 -eq 1 ]; then
        pam-config --add --systemd_home || :
fi
%systemd_post systemd-homed.service

%preun homed
%systemd_preun systemd-homed.service
if [ $1 -eq 0 ]; then
        pam-config --delete --systemd_home || :
fi

%postun homed
%systemd_postun_with_restart systemd-homed.service
%endif

%if %{with portabled}
%pre portable
%systemd_pre systemd-portabled.service

%post portable
%if %{without filetriggers}
%tmpfiles_create portables.conf
%endif
%systemd_post systemd-portabled.service

%preun portable
%systemd_preun systemd-portabled.service

%postun portable
%systemd_postun_with_restart systemd-portabled.service
%endif

%if %{with experimental}
%pre experimental
%systemd_pre systemd-oomd.service systemd-oomd.socket

%post experimental
%if %{without filetriggers}
%sysusers_create systemd-oom.conf
%endif
%systemd_post systemd-oomd.service systemd-oomd.socket

%preun experimental
%systemd_preun systemd-oomd.service systemd-oomd.socket

%postun experimental
%systemd_postun systemd-oomd.service systemd-oomd.socket
%endif

# Keep the clean section until the following issue is solved:
# https://github.com/rpm-software-management/rpm/issues/3658
%clean
rm -rf \
    $RPM_BUILD_ROOT \
    %{name}.lang \
    debugfiles.list \
    debuglinks.list \
    debugsourcefiles.list \
    debugsources.list \
    elfbins.list

# File trigger definitions
%if %{with filetriggers}
%include %{SOURCE7}
%endif

%files
%include %{SOURCE200}

%files -n udev%{?mini}
%include %{SOURCE201}

%if %{with sd_boot}
%files boot
%include %{SOURCE206}
%endif

%files container
%include %{SOURCE202}

%if %{with networkd}
%files networkd
%include %{SOURCE203}
%endif

%if %{with resolved}
%files resolved
%include %{SOURCE208}
%endif

%files devel
%license LICENSE.LGPL2.1
%include %{SOURCE204}

%if %{with sysvcompat}
%files sysvcompat
%include %{SOURCE205}
%endif

%files -n libsystemd0%{?mini}
%license LICENSE.LGPL2.1
%{_libdir}/libsystemd.so.0
%{_libdir}/libsystemd.so.0.*.0

%files -n libudev%{?mini}1
%license LICENSE.LGPL2.1
%{_libdir}/libudev.so.1
%{_libdir}/libudev.so.1.7.*

%if %{without bootstrap}
%files lang -f systemd.lang
%include %{SOURCE210}

%files doc
%{_docdir}/systemd/
%include %{SOURCE213}
%endif

%if %{with journal_remote}
%files journal-remote
%include %{SOURCE211}
%endif

%if %{with homed}
%files homed
%include %{SOURCE209}
%endif

%if %{with portabled}
%files portable
%include %{SOURCE212}
%endif

%if %{with testsuite}
%files testsuite
%doc %{_testsuitedir}/integration-tests/README.md
%{_testsuitedir}
%endif

%if %{with experimental}
%files experimental
%include %{SOURCE207}
%endif

%changelog
* Mon Jun  2 2025 Franck Bui <fbui@suse.com>
- Import commit c929295b4c1fb3cd6b9963bc7588fbc3e597ab86 (merge of v257.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8e9840a2897e36ae3f926f8d10a2b0d7e4102c67...c929295b4c1fb3cd6b9963bc7588fbc3e597ab86
* Fri May 16 2025 Franck Bui <fbui@suse.com>
- Import commit 8e9840a2897e36ae3f926f8d10a2b0d7e4102c67 (bsc#1243280)
  8e9840a289 bless-boot: never try to rename an entry file onto itself
  5b5cde8866 bless-boot: in "status" output report bad state from prev boot as "dirty"
  49949fa9fb bless-boot: switch from last_path_component() to path_find_last_component()
* Thu May 15 2025 Fabian Vogt <fvogt@suse.com>
- systemd-update-helper: Fix invalid use of "break" in case statement
* Tue Apr 22 2025 Franck Bui <fbui@suse.com>
- systemd-update-helper: do not stop or disable services when they are migrated
  to other packages. This can occur during package renaming or splitting.
* Wed Apr 16 2025 Franck Bui <fbui@suse.com>
- Split systemd-network into two new sub-packages: systemd-networkd and
  systemd-resolved (bsc#1224386 jsc#PED-12669)
* Fri Apr  4 2025 Franck Bui <fbui@suse.com>
- Import commit c10a66fb4dd34b86d42fa92501bd88db63df479a (merge of v257.5)
  This merge includes the following fix:
    9b52c10986 test-network: replace symlink to 99-default.link with a copy
    d7577221b8 man/pstore.conf: pstore.conf template is not always installed in /etc
    62071a984d man: coredump.conf template is not always installed in /etc (bsc#1237496)
    18dde3dd2a umount: do not move busy network mounts (bsc#1236177)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/f133e5974e69708d7491d4823780690c913f7bda...c10a66fb4dd34b86d42fa92501bd88db63df479a
* Wed Mar 12 2025 Franck Bui <fbui@suse.com>
- triggers.systemd: more posix.fork() conversion (bsc#1238566)
* Wed Mar 12 2025 Franck Bui <fbui@suse.com>
- Import commit f133e5974e69708d7491d4823780690c913f7bda (merge of v257.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/e03ffd74c4a30c1c75e05874ce18d31e503437b7...f133e5974e69708d7491d4823780690c913f7bda
* Mon Mar  3 2025 Franck Bui <fbui@suse.com>
- Name libsystemd-{shared,core} based on the major version of systemd and the
  package release number (bsc#1228081)
  This way, both the old and new versions of these shared libraries will be
  present during the update. This should prevent issues during package updates
  when incompatible changes are introduced in the new versions of these shared
  libraries.
  Note: these libraries are private so only binaries shipped by systemd and its
  sub-packages can be linked against them.
* Wed Feb 26 2025 Luca Boccassi <luca.boccassi@gmail.com>
- Move 20-systemd-stub.conf tmpfiles.d from the systemd-boot
  package to the systemd main package, as it is needed in the
  initrd to copy stuff from /.extra to /run/systemd/stub.
  Installing systemd-boot in the initrd is not the right approach,
  as that pulls in the bootloader and other files that have no use
  in the initrd and just take up space. The main package is always
  in the initrd, so it's the right place to ensure that, if
  systemd-boot is used, the snippet is present, and it will be a
  no-op otherwise.
* Fri Feb 14 2025 Franck Bui <fbui@suse.com>
- Import commit e03ffd74c4a30c1c75e05874ce18d31e503437b7 (merge of v257.3)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/47794646786ae4ddb6d3deb2030e2761447999ec...e03ffd74c4a30c1c75e05874ce18d31e503437b7
* Wed Feb 12 2025 Thorsten Kukuk <kukuk@suse.com>
- Enable systemd-sysupdated and updatectl as experimental subpackage
* Fri Feb  7 2025 Franck Bui <fbui@suse.com>
- Import commit 47794646786ae4ddb6d3deb2030e2761447999ec
  4779464678 import-pubring.gpg: add openSUSE build key (bsc#1236751)
  2c8382881f systemd-pull: support .asc and .sha256.* signature (bsc#1236887)
* Tue Feb  4 2025 Franck Bui <fbui@suse.com>
- triggers.systemd: convert posix.fork() and posix.exec() to rpm.execute() (bsc#1236741)
* Tue Feb  4 2025 Franck Bui <fbui@suse.com>
- Update 0009-pid1-handle-console-specificities-weirdness-for-s390.patch to not
  warn when "conmode=" is not specified on s390x (bsc#1236725).
* Tue Feb  4 2025 Franck Bui <fbui@suse.com>
- Move systemd-userwork from the experimental sub-package to the main package (bsc#1236643)
  It is likely an oversight from when systemd-userdb was migrated from the
  experimental package to the main one.
* Thu Jan 30 2025 Michal Koutný <mkoutny@suse.com>
- Drop 5004-disable-session-freeze.patch since the kernel fix commit
  d96c77bd4eeba ("KVM: x86: switch hugepage recovery thread to vhost_task")
  v6.13-rc1~97^2~3 is in Tumbleweed kernel
* Wed Jan  8 2025 Franck Bui <fbui@suse.com>
- Import commit 7fa3b5018bfffa176c77a2a5794dce792eebadcb (merge of v257.2)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/47eea9ee9f46537bc18d6a64fa21fd9c50538e13...7fa3b5018bfffa176c77a2a5794dce792eebadcb
* Thu Dec 26 2024 Franck Bui <fbui@suse.com>
- systemd-update-helper: backport commit 2d0af8bc354f4a1429ce
  Since user@.service has `Type=notify-reload` (making the reloading process
  synchronous) and reloading implies reexecuting with `ReloadSignal=RTMIN+25`,
  reexecuting user managers synchronously can be achieved with `systemctl reload
  user@*.service" now.
* Thu Dec 26 2024 Franck Bui <fbui@suse.com>
- Upgrade to v257.1 (commit 47eea9ee9f46537bc18d6a64fa21fd9c50538e13)
  See https://github.com/openSUSE/systemd/blob/SUSE/v257/NEWS for details.
  - This upgrade includes the following bug fixes:
  - commit 9258e27f4a1ddf2834d0cadd66770ad65e55e066 (boo#1233752, bsc#1234313)
  - commit 423de11f046cc2c9b6904e4eff71d6a48cd661c9 (boo#1233752, bsc#1234313)
  - commit 2ae79a31b7c7947e2c16e18eb85ac5607ebc40b6 (bsc#1232844)
- Drop 5006-tpm2-util-Also-retry-unsealing-after-policy_pcr-retu.patch and
  5005-Revert-boot-Make-initrd_prepare-semantically-equival.patch
  These two patches have bee merged upstream and are included in v257.1, see
  above.
- Our testsuite sub-package has been broken by upstream after they decided to
  remove the bash test runner, see https://github.com/systemd/systemd/pull/34271
  for details. For running the testsuite, the systemd git repository has to be
  cloned for now. We'll try to adapt the testsuite sub-package these changes.
* Sun Dec 22 2024 Franck Bui <fbui@suse.com>
- Import commit f962392e1e0d5683a2adebf09698b5fda02f9cfc (merge of v256.10)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/290170c8550bf2de4b5085ecdf7f056769944444...f962392e1e0d5683a2adebf09698b5fda02f9cfc
* Mon Dec 16 2024 Fabian Vogt <fvogt@suse.com>
- Add 5006-tpm2-util-Also-retry-unsealing-after-policy_pcr-retu.patch
  Backport of https://github.com/systemd/systemd/pull/35657, which fixes
  https://github.com/systemd/systemd/issues/35490 (boo#1233752, bsc#1234313).
* Tue Dec  3 2024 Franck Bui <fbui@suse.com>
- Add 5005-Revert-boot-Make-initrd_prepare-semantically-equival.patch
  Revert commit d64193a2a652b15db9cb9ed10c6b77a17ca46cd2 until the regression it
  caused, reported at https://github.com/systemd/systemd/issues/35439, is fixed
  (see also bsc#1233752 for its downstream counterpart).
* Tue Dec  3 2024 Franck Bui <fbui@suse.com>
- Disable EFI support on architectures that are not EFI-compliant
* Tue Dec  3 2024 Franck Bui <fbui@suse.com>
- Import commit 290170c8550bf2de4b5085ecdf7f056769944444 (merge of v256.9)
  This merge includes the following fix:
    cf7b3cc182 pid1: make clear that $WATCHDOG_USEC is set for the shutdown binary, noone else (bsc#1232227)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/c7671762b39ead7f8f9e70064256f5efaccedeca...290170c8550bf2de4b5085ecdf7f056769944444
* Mon Nov  4 2024 Franck Bui <fbui@suse.com>
- Import commit aee28e4c20a053ea27f8be69f2ea981e43bcb0b6
  aee28e4c20 udev-builtin-path_id: SAS wide ports must have num_phys > 1 (bsc#1231610)
  280989cfa4 core: when switching root remove /run/systemd before executing the binary specified by init= (bsc#1227580)
- Drop 5003-core-when-switching-root-remove-run-systemd-before-e.patch, this
  patch has been integrated in branch 'SUSE/v256', see above.
* Tue Oct  8 2024 Franck Bui <fbui@suse.com>
- Import commit c7671762b39ead7f8f9e70064256f5efaccedeca (merge of v256.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8a0ae4d90aff1d067a125ff9366eafc7dd5d4701...c7671762b39ead7f8f9e70064256f5efaccedeca
* Wed Oct  2 2024 Franck Bui <fbui@suse.com>
- Clean up some remnants from when homed was in the experimental sub-package (bsc#1231048)
* Wed Sep 18 2024 Franck Bui <fbui@suse.com>
- Import commit 8a0ae4d90aff1d067a125ff9366eafc7dd5d4701 (merge of v256.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/bef0958f4db1b774c23505e93537ffe16f1b3894...8a0ae4d90aff1d067a125ff9366eafc7dd5d4701
* Tue Aug 27 2024 Franck Bui <fbui@suse.com>
- Don't try to restart the udev socket units anymore (bsc#1228809)
  There's currently no way to restart a socket activable service and its socket
  units "atomically" and safely.
* Mon Aug 26 2024 Franck Bui <fbui@suse.com>
- Move 80-container-host0.network back to the network sub-package (bsc#1229098)
  Rev 428 mistakenly moved it to the container sub-package.
* Mon Aug 19 2024 Franck Bui <fbui@suse.com>
- Import commit bef0958f4db1b774c23505e93537ffe16f1b3894 (merge of v256.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/5bba1ebe17564b606cc5d1c07b14123c305019a7...bef0958f4db1b774c23505e93537ffe16f1b3894
* Mon Aug 19 2024 Franck Bui <fbui@suse.com>
- Make the 32bit version of libudev.so available again (bsc#1228223)
  The symlink for building 32bit applications was mistakenly dropped when the
  content of libudev-devel was merged into systemd-devel.
  Provide the 32bit flavor of systemd-devel again, which should restore the plug
  and play support in Wine for 32bit windows applications.
* Fri Aug  2 2024 Antonio Feijoo <antonio.feijoo@suse.com>
- Order the update of udev and systemd-boot right after systemd (bsc#1228659)
* Wed Jul 24 2024 Franck Bui <fbui@suse.com>
- Import commit 5bba1ebe17564b606cc5d1c07b14123c305019a7 (merge of v256.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/bd8b5ee3cf0466b6b78e167967468cf6f93ec807...5bba1ebe17564b606cc5d1c07b14123c305019a7
* Wed Jul 24 2024 Michal Koutný <mkoutny@suse.com>
- Add 5004-disable-session-freeze.patch as a temporary workaround for
  https://github.com/systemd/systemd/issues/33083
* Mon Jul 22 2024 Franck Bui <fbui@suse.com>
- Add temporarily 5003-core-when-switching-root-remove-run-systemd-before-e.patch (bsc#1227580)
* Mon Jul 22 2024 Franck Bui <fbui@suse.com>
- Don't mention any rpm macros inside comments, even if escaped (bsc#1228091)
  Otherwise pesign-obs-integration ends up re-packaging systemd with all macros
  inside comments unescaped leading to unpredictable behavior. Now why rpm
  expands rpm macros inside comments is the question...
* Tue Jul 16 2024 Franck Bui <fbui@suse.com>
- Skip running the test units in %%check for now.
  Some tests don't appreciate to run inside the build environment of OBS
  currently and some of them take an unexpected long time to execute on both
  risc and s390x architectures.
* Thu Jul 11 2024 Franck Bui <fbui@suse.com>
- Make sure systemd-sysvcompat replaces systemd-sysvinit on upgrades (bsc#1218110)
* Mon Jul  8 2024 Franck Bui <fbui@suse.com>
- Import commit bd8b5ee3cf0466b6b78e167967468cf6f93ec807 (merge of v256.2)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/dd15bf4f6430d8646e546ee0b980448c7d0c9699...bd8b5ee3cf0466b6b78e167967468cf6f93ec807
* Thu Jul  4 2024 Franck Bui <fbui@suse.com>
- varlinkctl is no more considered as experimental and has been moved to the
  main package.
* Thu Jul  4 2024 Franck Bui <fbui@suse.com>
- Upgrade to v256.1 (commit dd15bf4f6430d8646e546ee0b980448c7d0c9699)
  See https://github.com/openSUSE/systemd/blob/SUSE/v256/NEWS for details.
  - This includes the following bug fixes:
  - commit 3b2e7dc5a285edbbb1bf6aed2d88b889d801613f (bsc#1234015)
  - commit c072860593329293e19580b337504adb52248462 (bsc#1229518)
  - commit cfbf7538d87023840c5574fa5b0452e5b0f42149 (bsc#1229228)
  - commit 3c85d3fda50f71755aa276cfa60807c315bfc04b (bsc#1236886)
  - Added pam.systemd-run0
* Mon Jul  1 2024 Franck Bui <fbui@suse.com>
- Import commit 5a8eadd0c021758337a020c423f25a353bdb9b3c (merge of v255.8)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/603cd1d4d81147d4f2eccd5e352064a4215119b4...5a8eadd0c021758337a020c423f25a353bdb9b3c
- Drop 5003-Revert-run-pass-the-pty-slave-fd-to-transient-servic.patch as v255.8
  contains the workaround (commit 639c922ede9485) for the broken commit
  28459ba1f4df.
* Mon Jun 24 2024 Franck Bui <fbui@suse.com>
- Don't automatically clean unmodified config files up (bsc#1226415)
  Relying on the presence of .rpmsave for detecting unmodified main config files
  couldn't work as it created a time window in which some of the systemd
  services were restarted with no config file. That had the bad side effect to
  restart them with the upstream defaults, ignoring any user's customization.
* Tue Jun 18 2024 Franck Bui <fbui@suse.com>
- testsuite: move a misplaced %%endif
* Tue Jun 18 2024 Franck Bui <fbui@suse.com>
- Merge systemd-coredump back into the main package (bsc#1091684)
* Tue Jun 18 2024 Franck Bui <fbui@suse.com>
- testsuite: only require the devel packages when pulling the dlopen'd
  dependencies (the libraries are dependencies of the devel packages).
* Thu Jun  6 2024 Franck Bui <fbui@suse.com>
- Add 5003-Revert-run-pass-the-pty-slave-fd-to-transient-servic.patch
  This revert the backport of the broken commit 28459ba1f4df until a fix is
  released in the v255-stable tree (see pr#33216).
* Fri May 31 2024 Franck Bui <fbui@suse.com>
- Rename PAM config file 'systemd-user' into 'pam.systemd-user'.
* Fri May 31 2024 Franck Bui <fbui@suse.com>
- Import commit 603cd1d4d81147d4f2eccd5e352064a4215119b4 (merge of v255.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/b9c17562f612ab2cd8cfee1960714c58d0a6c593...603cd1d4d81147d4f2eccd5e352064a4215119b4
* Fri May 31 2024 Franck Bui <fbui@suse.com>
- Import commit b9c17562f612ab2cd8cfee1960714c58d0a6c593
  b9c17562f6 99-systemd.rules: rework SYSTEMD_READY logic for device mapper
  c5003fc15e pcrlock: add make_pcrlock_record_from_stream
* Wed May 22 2024 Franck Bui <fbui@suse.com>
- systemd.spec: introduce %%{meson_extra_configure_options} to allow passing
  extra meson configure options.
* Thu May 16 2024 Radoslav Kolev <radoslav.kolev@suse.com>
- systemd.spec: enable unit tests during build
* Thu May 16 2024 Franck Bui <fbui@suse.com>
- Import commit 3ea0e1dff3d7ca74c072cdcc8b371034125803d6
  3ea0e1dff3 test/test-rpm-macros.sh: add build directory to pkg-config search path
  1cbf1c82b5 libsystemd-network: skip dhcp server test in case of EAFNOSUPPORT
  38f7ac60db sd-event: increase test-event timeout to 120s
* Wed May 15 2024 Franck Bui <fbui@suse.com>
- systemd.spec: update the minimal required version of dracut. Also drop
  conflicts with mkinitrd: this package has been removed since quite some time
  now.
* Tue May 14 2024 Franck Bui <fbui@suse.com>
- systemd.spec: some of the meson options have been converted to meson features.
* Mon May 13 2024 Franck Bui <fbui@suse.com>
- Import commit a3dccacb97e94ed91f1c41ce82ef13bfe8fa1a79 (merge of v255.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/49fb09fa18a7b81f6b3c3c15aca47fd00940430e...a3dccacb97e94ed91f1c41ce82ef13bfe8fa1a79
* Tue May  7 2024 Franck Bui <fbui@suse.com>
- Import commit 49fb09fa18a7b81f6b3c3c15aca47fd00940430e (merge of v255.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/23b15deb203780580cbfad095ae1071bd2133220...49fb09fa18a7b81f6b3c3c15aca47fd00940430e
* Tue May  7 2024 Franck Bui <fbui@suse.com>
- Import commit 23b15deb203780580cbfad095ae1071bd2133220
  23b15deb20 gpt-auto-generator: be more defensive when checking the presence of ESP in fstab (bsc#1218671)
  7ed2979654 journalctl: explicitly check < 0 for error
  fc5e25d0a0 journalctl: make --until work again with --after-cursor and --lines (bsc#1221906)
* Thu Apr 25 2024 Franck Bui <fbui@suse.com>
- Update 0008-sysv-generator-translate-Required-Start-into-a-Wants.patch to
  adapt sysv-generator-test to the SUSE's specificity brought by this patch.
* Thu Apr 25 2024 Franck Bui <fbui@suse.com>
- systemd-testsuite: some of the integration tests depend on the bin, daemon,
  games and nobody users/groups.
* Mon Apr 22 2024 Franck Bui <fbui@suse.com>
- Drop _FORTIFY_SOURCE=2 workaround. Since commit 7929e180aa (v253) it shouldn't
  be needed anymore.
* Mon Apr  8 2024 Franck Bui <fbui@suse.com>
- systemd.spec: preparation for the next version of systemd (i.e. v256), libkmod2
  will be dlopened hence explicitly require it now as it doesn't hurt with the
  current version. However don't recommend it from systemd by assuming that when
  module loading from PID1 is needed, udev is installed.
- Make systemd-doc subpackage noarch.
* Wed Apr  3 2024 Franck Bui <fbui@suse.com>
- Move systemd-repart from experimental to udev.
* Fri Mar 22 2024 Franck Bui <fbui@suse.com>
- Add 0001-Drop-support-for-efivar-SystemdOptions.patch (bsc#1220338)
  Upstream deprecated it and plan to drop it in the future.
  Let's get ahead and drop it now as this feature is unlikely to be used on SUSE
  distros and it might be used to gain access to encrypted SLEM systems with
  unattended disk unlock and with secure boot disabled.
* Thu Mar 21 2024 Franck Bui <fbui@suse.com>
- The following patches have been merged into SUSE/v255 branch hence removed
  from the OBS project.
  5006-cgroup-Add-EffectiveMemoryMax-EffectiveMemoryHigh-an.patch
  5007-test-Convert-rlimit-test-to-subtest-of-generic-limit.patch
  5008-test-Add-effective-cgroup-limits-testing.patch
  5009-cgroup-Restrict-effective-limits-with-global-resourc.patch
  5010-cgroup-Rename-effective-limits-internal-table.patch
- Import commit 56b53b17bcd8311dfb53f05b359b2812593883ab
  56b53b17bc cgroup: Rename effective limits internal table (jsc#PED-5659)
  7c9202317c cgroup: Restrict effective limits with global resource provision (jsc#PED-5659)
  da858e68eb test: Add effective cgroup limits testing (jsc#PED-5659)
  2f013357a5 test: Convert rlimit test to subtest of generic limit testing (jsc#PED-5659)
  0a3ea7f367 cgroup: Add EffectiveMemoryMax=, EffectiveMemoryHigh= and EffectiveTasksMax= properties (jsc#PED-5659)
* Wed Mar 20 2024 Franck Bui <fbui@suse.com>
- Drop split_usr build conditional since both split-usr and unmerged-usr
  supports have been removed since v255.
- Don't use the "Patch:" directive with a suffix number as since the suffix
  doesn't serve any purpose.
* Mon Mar 18 2024 Franck Bui <fbui@suse.com>
- Import commit be772961ada05afab21a72e225d28c26ef9fb1ea (merge of v255.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/3986ed5117e1563adfce3f5a8e088a77016c0aee...be772961ada05afab21a72e225d28c26ef9fb1ea
* Mon Mar 18 2024 Franck Bui <fbui@suse.com>
- Import commit 3986ed5117e1563adfce3f5a8e088a77016c0aee
  3986ed5117 test: drop route from test-functions
* Mon Mar 18 2024 Daan De Meyer <daan.j.demeyer@gmail.com>
- Account for upstream changes to the quotaon and quotacheck services
* Mon Mar 18 2024 Michal Vyskocil <mvyskocil@opensuse.org>
- Create /etc/sysusers.d as expected by sysusers.d(5)
* Fri Mar  1 2024 Jan Engelhardt <jengelh@inai.de>
- Move C API manual pages to systemd-doc, this saves buildroots
  770+ files and time (mandb is run in %%posttrans).
- Delete supplements on base-documentation from that.
- Courtesy of spec formatters, remove redundant %%defattr.
* Mon Feb 26 2024 Antonio Feijoo <antonio.feijoo@suse.com>
- Fix syntax required for OBS source validator
* Fri Feb 23 2024 Franck Bui <fbui@suse.com>
- Upgrade to v255.3 (commit 96edf7ad1866172b994cafb4df49e27d68ce8e87)
  See https://github.com/openSUSE/systemd/blob/SUSE/v255/NEWS for details.
  - This includes the following bug fixes:
  - commit 6e10405aa25fe5e76b740d9ec59730e3f4470c7a (bsc#1219766)
  - The following patches have been rebased:
  - 0002-rc-local-fix-ordering-startup-for-etc-init.d-boot.lo.patch
  - 0008-sysv-generator-translate-Required-Start-into-a-Wants.patch
  - 0009-pid1-handle-console-specificities-weirdness-for-s390.patch
  - 5001-Revert-udev-update-devlink-with-the-newer-device-nod.patch
  - 5002-Revert-udev-revert-workarounds-for-issues-caused-by-.patch
  - The following patches have been removed since they're part of v255:
  - 5003-cgroup-rename-TasksMax-structure-to-CGroupTasksMax.patch
  - 5004-bus-print-properties-ignore-CGROUP_LIMIT_MAX-for-Mem.patch
  - 5005-bus-print-properties-prettify-more-unset-properties.patch
  - systemd-boot has been added to the list of the dependencies of the
    systemd-testsuite package as the installation of the bootloader is now
    tested.
  - the following patches have been backported on top of v255.3:
    96edf7ad18 service: Demote log level of NotifyAccess= messages to debug (bsc#1210113 jsc#PED-6214)
    fdde7f26d6 vconsole-setup: don't fail if the only found vc is already used by plymouth (bsc#1218618)
    f96c587d41 rules: set up tty permissions and group for /dev/hvc* nodes (bsc#1218137)
    63a41b8899 vconsole-setup: remember the correct error value when open_terminal() fails
    f51a2e038c vconsole-setup: handle the case where the vc is in KD_GRAPHICS mode more gracefully (bsc#1215282)
    15025a04c4 test: make sure to install the filesystem package in the test image on SUSE
    06fecfb635 test: make sure that sd-boot is installed before testing bootctl
    1e8788ea68 test: install systemd-boot in openSUSE test images
    6e2875ad43 test/test-shutdown.py: optionally display the test I/Os in a dedicated log file
    4be1a801b4 test-69: send SIGTERM to ask systemd-nspawn to properly stop the container
    7bdab7b7c7 man: Document ranges for distributions config files and local config files
    3f12a6c22f test: systemd-update-utmp is optional
    1911c7fd95 man: conditionalize sd-pcrlock and sd-measure on the same variable as their binaries
    352f76f734 man: always install bootctl
    b48a18c464 meson: fix installation of html doc aliases
- bootctl has been moved to the udev package since some of its commands work on
  non UEFI systems too.
* Fri Feb 23 2024 Franck Bui <fbui@suse.com>
- When building systemd rpms in place (i.e. rpmbuild --build-in-place), the
  version of systemd is now retrieved from the file "meson.version" by
  default. This file is supposed to contain a string that described the full
  version of the systemd project.
- Overriding of %%systemd_version/%%systemd_release is now limited to builds of
  rpms in place cases.
* Thu Feb 22 2024 Franck Bui <fbui@suse.com>
- Import commit 31f1148f75a1155d3eb37fd1a450096d669ec65b
  31f1148f75 seccomp: include `fchmodat2` in `@file-system` (bsc#1219766)
  001f349c57 service: Demote log level of NotifyAccess= messages to debug (bsc#1210113 jsc#PED-6214)
* Tue Feb 20 2024 Daan De Meyer <daan.j.demeyer@gmail.com>
- Add a new %%upstream macro to support building from upstream sources. This
  will allow upstream to build systemd rpms using the opensuse systemd packaging
  specs. These rpms will be built and used in upstream's mkosi based hacking and
  testing environment to test changes and in the future to run integration tests
  as well. By building the rpms using the opensuse packaging specs, the idea is
  to catch more issues ahead of time as the mkosi environment will behave more
  like a regular opensuse system.
- Add new %%version_override and %%version_release macros to allow overriding the
  version and release of the rpm respectively.
* Mon Feb 19 2024 Franck Bui <fbui@suse.com>
- Import commit 53e2aaaf9d69fb1c8f6ae2c9f8a99b02d70d318f
  53e2aaaf9d vconsole-setup: don't fail if the only found vc is already used by plymouth (bsc#1218618)
  22c4878430 vconsole-setup: port to main-func.h boilerplate
* Mon Feb 19 2024 Franck Bui <fbui@suse.com>
- systemd-testsuite: depend on "qemu" instead of "qemu-kvm", the latter is
  obsolete. (bsc#1218684)
* Wed Feb 14 2024 Franck Bui <fbui@suse.com>
- Import commit fbf9f32eb774ba6ec54e0d5d53b36baaf3e6b146
  fbf9f32eb7 test/test-shutdown.py: optionally display the test I/Os in a dedicated log file
  cd012774df test-69: send SIGTERM to ask systemd-nspawn to properly stop the container
  d883b83244 man: Document ranges for distributions config files and local config files
* Wed Feb 14 2024 Franck Bui <fbui@suse.com>
- Import commit fa94ab006d09686cef121aaa3baa10cf5ca95e19 (merge of v254.9)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/67a5ac1043417d900bf417a884372ae14a96ef69...fa94ab006d09686cef121aaa3baa10cf5ca95e19
* Tue Feb 13 2024 Franck Bui <fbui@suse.com>
- Update the version of libbpf dlopened by systemd (weak dependency) (bsc#1219440)
* Tue Feb  6 2024 Franck Bui <fbui@suse.com>
- Drop python3-pefile dependency from the experimental package. MicroOs is fond
  of the experimental stuff but OTOH it doesn't ship python3. Let's drop the
  dependency for now, users of ukify are invited to install python3-pe manually.
* Tue Feb  6 2024 Franck Bui <fbui@suse.com>
- Move systemd-reboot.service from udev to the main package as this service is
  useful in containers.
* Tue Jan 23 2024 Franck Bui <fbui@suse.com>
- Add patches that implement [jsc#PED-5659]
  5003-cgroup-rename-TasksMax-structure-to-CGroupTasksMax.patch
  5004-bus-print-properties-ignore-CGROUP_LIMIT_MAX-for-Mem.patch
  5005-bus-print-properties-prettify-more-unset-properties.patch
  5006-cgroup-Add-EffectiveMemoryMax-EffectiveMemoryHigh-an.patch
  5007-test-Convert-rlimit-test-to-subtest-of-generic-limit.patch
  5008-test-Add-effective-cgroup-limits-testing.patch
  5009-cgroup-Restrict-effective-limits-with-global-resourc.patch
  5010-cgroup-Rename-effective-limits-internal-table.patch
  They are temporarily put in quarantine to get broader testing but should be
  eventually moved to the git repo.
* Sat Jan 20 2024 Giacomo Comes <gcomes.obs@gmail.com>
- remove pam-config call from post scriptlet of systemd-32bit
  * the full package already does that
* Fri Jan 12 2024 Franck Bui <fbui@suse.com>
- Add 5001-Revert-udev-update-devlink-with-the-newer-device-nod.patch
    5002-Revert-udev-revert-workarounds-for-issues-caused-by-.patch
  It seems that systemd upstream has a dubious way to fix broken code these
  days... let's revert these hacks until a final decision is taken to solve
  https://github.com/systemd/systemd/issues/28141. See also
  https://github.com/systemd/systemd/pull/30075.
* Fri Jan 12 2024 Franck Bui <fbui@suse.com>
- Import commit 67a5ac1043417d900bf417a884372ae14a96ef69 (merge of v254.8)
  It includes the following fix:
    029272750f resolved: actually check authenticated flag of SOA transaction (bsc#1218297 CVE-2023-7008)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/071ac409a0564863657d8f8a5a35e6a4f914695f...67a5ac1043417d900bf417a884372ae14a96ef69
* Thu Dec 21 2023 Dominique Leuenberger <dimstar@opensuse.org>
- udev(-mini)?: ensure %%_modulesloaddir exists and is owned
  properly. Allows other packages to install modules without worry
  of the parent directory. We do not ensure /etc/modules-load.d
  exists in the -mini flavor, as that directory is not meant to be
  used by packages.
* Wed Dec 20 2023 Dominique Leuenberger <dimstar@opensuse.org>
- udev: only require kmod in the full flavor. udev-mini is only
  used inside OBS in a strictly defined setup and udev will never
  have to load device drivers there.
* Wed Dec 20 2023 Franck Bui <fbui@suse.com>
- Import commit 071ac409a0564863657d8f8a5a35e6a4f914695f
  071ac409a0 rules: set up tty permissions and group for /dev/hvc* nodes (bsc#1218137)
  f693b3ed8a vconsole-setup: remember the correct error value when open_terminal() fails
  963d838bad vconsole-setup: handle the case where the vc is in KD_GRAPHICS mode more gracefully (bsc#1215282)
  6f53f71d2d vconsole-setup: simplify error handling
* Tue Dec 12 2023 Franck Bui <fbui@suse.com>
- Explicitely provide 'group(systemd-journal)' from the main package (bsc#1217852)
* Tue Dec 12 2023 Franck Bui <fbui@suse.com>
- Import commit ce08cd5f66e1a661c2b9ed764ad7036decd76503
  ce08cd5f66 man/standard-conf: directory paths should end with '/'
  8324cbfde7 config files: update their header to reflect that they can be installed in /usr
  bc36846ad2 Reflect the fact that main config files can be installed in /usr
  e304a11f33 config files: more recommendations of `systemd-analyze cat-config`
  c45cecf279 meson: add build option for install path of main config files
  cc61b052c6 vconsole-setup: use a consistent log level when setfont fails with EX_OSERR (bsc#1212970)
  4fe3653dab tmpfiles: ignore EINVAL with --graceful (bsc#1216628)
* Tue Nov 21 2023 Wolfgang Frisch <wolfgang.frisch@suse.com>
- udev: Tighten permissions for DRM render nodes (bsc#1217118). Note that this
  implicitly enables `uaccess`, so any logged-in user still gets access
  regardless of group membership. Some use cases, e.g. remote access via ssh,
  might require you to add the desired user to the `render` group.
  See:
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/thread/3S3HAWVODHC2FQI4E76IFGCSRVRJ63KG/
* Thu Nov  2 2023 Franck Bui <fbui@suse.com>
- Disable utmp support
  The announcement can be found at:
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/thread/MYIWGQEE54VJDBYXMQCEY7XKEAIUFLAU/
  The user visible consequence of it is that /run/utmp file is no more created.
  systemd itself doesn't depend on utmp anymore since "shared/wall: use logind
  if build without utmp support" has been backported.
* Mon Oct 30 2023 Franck Bui <fbui@suse.com>
- Fix typo in /etc/systemd/user.confd.d (bsc#1216676)
* Tue Oct 24 2023 Franck Bui <fbui@suse.com>
- Import commit b53f364c264cd598d4210b64285a55d362b47b89
  b53f364c26 test: install af_packet kernel module on openSUSE
  86b7521a3c shared/wall: use logind if build without utmp support
  65aac5858f errno-util: allow ERRNO_IS_* to accept types wider than int
  8f93b89db4 basic/errno-util: add wrappers which only accept negative errno
  1b815b3e76 Introduce RET_GATHER and use it in src/shared/
* Fri Oct 20 2023 Franck Bui <fbui@suse.com>
- Drop 0001-conf-parser-introduce-early-drop-ins.patch
  The usage of drop-ins is now the official way for configuring systemd and its
  various daemons on Factory/ALP.
  See: https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/thread/KWRBTAVQ6MGHVAHKDZZ6GIRX4RMHKHQ6/
* Thu Oct 19 2023 Franck Bui <fbui@suse.com>
- Ship the main configuration files in /usr/lib/
  Besides the fact that shipping files in /etc is not recommended anymore, this
  change will hopefully encourage users to customize the defaults via the mean
  of drop-ins hence removing the risk of conflicts with downstream
  customization.
  In contrary, shipping empty directories *.conf.d/ in /etc is not a concern and
  should suggest users to create drop-ins (bsc#1207056).
* Thu Oct 19 2023 Franck Bui <fbui@suse.com>
- systemd.spec: add files.portable and files.journal-remote
* Fri Oct 13 2023 Franck Bui <fbui@suse.com>
- Don't include entries listed in kbd-model-map.xkb-generated (provided by kbd
  package) in kbd-model-map anymore. Yast, the only user of these entries,
  directly parses kbd-model-map.xkb-generated now (bsc#1211104).
* Fri Oct 13 2023 Franck Bui <fbui@suse.com>
- tmpfiles-suse.conf: drop entries for /run/lock and /var/log/wtmp
  /run/lock is now defined by filesystem package and wtmp has been replaced by
  wtmpdb on TW.
* Thu Oct  5 2023 Franck Bui <fbui@suse.com>
- rpmlintrc: allow systemd-network and systemd-container sub-packages to ship
  shared libs. These are actually NSS plugins and are not really subject to
  shlib policy.
* Wed Oct  4 2023 Franck Bui <fbui@suse.com>
- Drop 5000-core-manager-run-generators-directly-when-we-are-in-.patch
  Since dracut-059+suse.447.g9d1fc722, this workaround is not needed anymore.
* Wed Sep 27 2023 Franck Bui <fbui@suse.com>
- Import commit 9674bb256205e6c643feadbcccfd1ee8feeee684 (merge of v254.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/6ed5b11298005e07509832881a0c5ff1a80bf225...9674bb256205e6c643feadbcccfd1ee8feeee684
* Wed Sep 27 2023 Franck Bui <fbui@suse.com>
- Make sure to call %%sysusers_create only when transfiletrigger is disabled.
* Wed Sep 27 2023 Franck Bui <fbui@suse.com>
- systemd.spec: switch to %%ldconfig_scriptlets
* Wed Sep 27 2023 Franck Bui <fbui@suse.com>
- systemd.spec: add `%%tmpfiles_create systemd-resolve`
  It's only needed by SLE distros since systemd packages rely on
  transtriggerfiles in Factory.
* Mon Sep 25 2023 Franck Bui <fbui@suse.com>
- Import commit 6ed5b11298005e07509832881a0c5ff1a80bf225 (merge of v254.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/b6b4e5a8a82d1f13f265a4ef170f2d13be82789a...6ed5b11298005e07509832881a0c5ff1a80bf225
* Fri Sep 22 2023 Franck Bui <fbui@suse.com>
- systemd.spec: during package updates, restart localed, timedated and hostnamed
  if they're running.
* Fri Sep 22 2023 Franck Bui <fbui@suse.com>
- systemd.spec: when enabling units prefer enabling service units over socket
  ones for socket activable services. The services shipped by systemd
  automatically redirect the enablement request to the socket unit.
* Thu Sep 14 2023 Franck Bui <fbui@suse.com>
- systemd.spec: %%regenerate_initrd_post is only used by udev sub-package hence
  move the build requirement pulling this macro in in the list of udev BRs.
* Tue Sep 12 2023 Franck Bui <fbui@suse.com>
- Don't ship after-local.service anymore. This was mostly a hack for people
  wanting to execute any random things once the boot was finished. We shouldn't
  encourage such practice and it actually conflicts with the sysv-generator
  which believes that /etc/init.d/after.local is SysV init script that needs to
  be converted into a native unit file.
  We still install a copy of this service in /etc if the user is relying on
  it, for backward compatibility.
* Tue Sep 12 2023 Franck Bui <fbui@suse.com>
- fixlet-systemd-post.sh: fix invalid use of rpm macro %%{_localstatedir}
* Mon Sep 11 2023 Franck Bui <fbui@suse.com>
- Import commit b6b4e5a8a82d1f13f265a4ef170f2d13be82789a (merge of v254.3)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/1f73719d67b9300c6bb75232d695d03410991098...b6b4e5a8a82d1f13f265a4ef170f2d13be82789a
* Thu Aug 24 2023 Thorsten Kukuk <kukuk@suse.com>
- Make utmp support per project configureable [jsc#PED-3144]
- Make apparmor and selinux per project configureable [jsc#PED-2736]
* Thu Aug 24 2023 Franck Bui <fbui@suse.com>
- systemd.spec: don't use build conditionals (%%bcond_with/%%bcond_without) with
  the mini flavor to make sure that all the features remain disabled for this
  flavor regardless of what is enabled in the prjconf.
* Fri Aug 18 2023 Franck Bui <fbui@suse.com>
- Don't build systemd-doc with the mini flavor
* Fri Aug 18 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Explicitly require group(lp) by udev: this used to be provided by
  system-group-hardware, but with the introduction of
  system-user-lp (and systemd-users auto-generating groups) is now
  actually provided by system-user-lp. Latest versions of
  system-group-hardware clean this up and no longer also provide
  this group.
* Fri Aug 18 2023 Franck Bui <fbui@suse.com>
- Fix incorrect option name when calling pam-config for systemd-homed
* Thu Aug 17 2023 Johannes Segitz <jsegitz@suse.com>
- testsuite: Recommend selinux-policy-devel instead of requiring it in line with
  other tests. Add Recommends for selinux-policy-targeted as this is also
  required to run the test (in general any SELinux policy should do)
* Wed Aug 16 2023 Ludwig Nussel <lnussel@suse.de>
- systemd.spec: add journal translations to lang package
* Wed Aug 16 2023 Franck Bui <fbui@suse.com>
- Import commmit 1f73719d67b9300c6bb75232d695d03410991098
  1f73719d67 test-mountpoint-util: /root might be mounted
  a391ba4a8f test: testsuite-35.sh needs manual/test-session-properties to be installed on SUSE
* Wed Aug 16 2023 Franck Bui <fbui@suse.com>
- Upgrade to v254.1 (commit 208a21833b6953a2517a6c3f8f4849c6664b01be)
  See https://github.com/openSUSE/systemd/blob/SUSE/v254/NEWS for details.
  This includes the following bug fixes:
  - upstream commit 331aa7aa15ee5dd12b369b276f575d521435eb52 (bsc#1181192 bsc#1184238 bsc#1184254 bsc#1184859 bsc#1185828 bsc#1203141)
  - upstream commit 529ba8a1a3968564b67049a077f213e3a0d53070 (bsc#1209340)
  - upstream commit f1f331a252d22c15f37d03524cce967664358c5c (bsc#1186606)
  - upstream commit df1dccd25547b430258bd42ec60428fc9aff1370 (bsc#1213185)
  - upstream commit 000680a68dbdb07d77807868df0b4f978180e4cd (bsc#1211725)
  - upstream commit 2067a7ec7f4c8a353b8e2ece15a6a997e50808b0 (bsc#1211576)
  * Drop 5001-Revert-core-propagate-stop-too-if-restart-is-issued.patch. A fix
    for https://github.com/systemd/systemd/issues/26839 has been integrated in
    v254.
  * Drop 5002-Revert-core-service-when-resetting-PID-also-reset-kn.patch, it's
    part of v254.
  * Drop 0001-restore-var-run-and-var-lock-bind-mount-if-they-aren.patch, it's
    no more needed these days.
  * Rebase 0001-conf-parser-introduce-early-drop-ins.patch
* Fri Aug 11 2023 Franck Bui <fbui@suse.com>
- Import commit fcdb2dd2c921db3c6b7c28465dbda314f4469d17 (merge of v253.8)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/2dac0aff9ced1eca0cd11c24e264b33095ee5a5e...fcdb2dd2c921db3c6b7c28465dbda314f4469d17
* Fri Jul 28 2023 Franck Bui <fbui@suse.com>
- Drop 0003-strip-the-domain-part-from-etc-hostname-when-setting.patch
  /etc/hostname is supposed to contain the static host name of the system. This
  patch was used to work around cases where users incorrectly save the FQDN
  instead. However this is incorrect and not consistent with what
  systemd-hostnamed does and what other distributions do. Also assuming that
  /etc/hostname will contain the system host name only removes any ambiguities
  since the host name can contain a period.
  /etc/hosts is usually where one sets the domain name by aliasing the host name
  to the FQDN.
  Note that the installer used to save the FQDN in /etc/hostname but this has
  been fixed since several years now (bsc#972463).
* Tue Jul 25 2023 Franck Bui <fbui@suse.com>
- systemd-homed is no more considered as experimental
  It's been moved to its own dedicated sub-package "systemd-homed".
* Mon Jul 24 2023 Franck Bui <fbui@suse.com>
- systemd-userdb is no more considered as experimental (jsc#PED-2668)
  As such it's been moved to the main package.
* Tue Jul 18 2023 Franck Bui <fbui@suse.com>
- Import commit 2dac0aff9ced1eca0cd11c24e264b33095ee5a5e (merge of v253.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/6458c066547eaadf0e9709e441ea36ad03faa860...2dac0aff9ced1eca0cd11c24e264b33095ee5a5e
* Tue Jul 11 2023 Franck Bui <fbui@suse.com>
- Import commit 6458c066547eaadf0e9709e441ea36ad03faa860 (merge of v253.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/07bb12a282b0ea378850934c4a76008b448b8bad...6458c066547eaadf0e9709e441ea36ad03faa860
- Drop 5002-Revert-core-service-when-resetting-PID-also-reset-kn.patch, it's
  been backported to v253.6.
* Tue Jul 11 2023 Franck Bui <fbui@suse.com>
- Move a bunch of files from systemd to udev. These are pretty useless without
  block devices.
* Mon Jul  3 2023 Franck Bui <fbui@suse.com>
- Split off sd-boot into separate "systemd-boot" subpackage
* Tue Jun 27 2023 Franck Bui <fbui@suse.com>
- Change the group owner of /run/lock from "lock" to "root" (bsc#1212674)
  This allows to drop the dependency "Requires: group(lock)" that was introduced
  previously to make sure that the "lock" group will be kept around. This
  dependency introduced a dependency cycle.
* Mon Jun 26 2023 Franck Bui <fbui@suse.com>
- file-triggers: fix a typo that sneaked in the script dealing with tmpfiles
  (bsc#1212733)
* Wed Jun 21 2023 Franck Bui <fbui@suse.com>
- Make sure to keep the groups systemd and udev rely on installed. Theoretically
  with only "Requires(pre): group(x)", rpm is allowed to drop group 'x' at the
  end of the package installations.
  Note: this is also needed when (trans)file-triggers are enabled due to the
  current limitation of the default libzypp transaction backend.
* Wed Jun 21 2023 Franck Bui <fbui@suse.com>
- file-triggers: fix lua trigger priority for sysusers (bsc#1212376)
  A single digit in the priority used for sysusers got dropped somehow and
  upstream commit cd621954ed643c6ee0d869132293e26056a48826 forgot to restore it
  in the lua implementation.
* Tue Jun 20 2023 Franck Bui <fbui@suse.com>
- file-triggers: skip the call to systemd-tmpfiles in chroot too. That way we
  ensure that packages that really need the tmpfiles in advance use the right
  API which is %%tmpfiles_create_package.
- file-triggers: to be consistent with what we already does with tmpfiles, we
  skip the call to systemd-sysusers and delay system user creations until the
  next reboot.
* Tue Jun 20 2023 Franck Bui <fbui@suse.com>
- Temporarily add
  5002-Revert-core-service-when-resetting-PID-also-reset-kn.patch until it's
  backported to the next stable release
  See https://github.com/systemd/systemd/pull/28000
* Fri Jun 16 2023 Franck Bui <fbui@suse.com>
- file-triggers: make sure to skip the call to systemd-tmpfile in the
  file-triggers when running on transaction systems (bsc#1212449)
  systemd-tmpfiles usually modifies paths that are not supposed to change during
  transactional updates (e.g. /var, /run). On transaction systems changes will
  happen on the next reboot.
* Thu Jun  1 2023 Franck Bui <fbui@suse.com>
- Import commit 07bb12a282b0ea378850934c4a76008b448b8bad (merge of v253.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/25aec157888f7aa9a36726962fcbbf2c74ead440...07bb12a282b0ea378850934c4a76008b448b8bad
* Thu Jun  1 2023 Franck Bui <fbui@suse.com>
- Reexecute user managers on package updates.
  For now we send signal to user instances to trigger their reexecution. It's
  asynchronous but it shouldn't cause any problem in practice and it's probably
  safer than triggering reexecution with "systemctl --user -M 1000@
  daemon-reexec" command. The latter command creates a new PAM session behind
  the scene bringing with it the known issue (upstream issue #8598) with
  "(sd-pam)" helper process when the PAM session is being closed.
* Tue May  9 2023 Franck Bui <fbui@suse.com>
- Move more packaging fixups in the fixlet script.
* Tue May  9 2023 Franck Bui <fbui@suse.com>
- Provide (Lua-based) file triggers and adapt systemd.spec accordingly (boo#1133764)
  More specifically, file triggers handle automatically installations or updates
  of files for sysusers, tmpfiles, hwdb, journal catalog, udev rules, sysctl and
  binfmt.
  Therefore it makes a bunch of systemd rpm macros (such as %%udev_hwdb_update,
  %%udev_rules_update, %%journal_catalog_update, %%tmpfiles_create,
  %%sysusers_create and so on) not needed anymore. However before considering
  simplifying your spec files beware that these changes are not available in SLE
  yet and will probably never reach the current releases (latest one being
  SLE15-SP5 as of this writing).
  Macros dealing with unit restart/enabling (such as %%systemd_pre,
  %%service_add_pre, %%service_del_postun, ...) are still needed though. However
  reloading of systemd instances (and thus restarting of units) are delayed
  until the very end of the package install/update transaction and is now done
  only once.
  Nevertheless to fully take advantage of file triggers, users have to activate
  a specific zypper transaction backend which is still considered as
  experimental, see bsc#1041742 for details.
- Provide a (slighlty) customized version of systemd-update-helper. Some of the
  systemd rpm macros rely now on the helper and delegate their work to it. Hence
  we don't need to rebuild all packages anymore when the content of the rpm
  macros must be updated/fixed.
* Tue May  9 2023 Franck Bui <fbui@suse.com>
- Drop an old fix for the persistent net rules (only needed on SLE). Factory
  (fortunately) dropped the persistent net rule generator long time ago.
* Thu May  4 2023 Franck Bui <fbui@suse.com>
- Rather than having one script per fix, use a single script (or "fixlet") per
  (sub) package that contains all the fixups relative to a (sub) package. This
  has the advantage to limit the number of scripts but more importantly it will
  ease the sharing of the spec file between TW and SLE. We should also be able
  to compare the fixlets of two distros even if the spec files have diverged.
  Note that all the fixups are run just once now.
* Thu May  4 2023 Franck Bui <fbui@suse.com>
- Make use of %%_systemd_util_dir in the spec file.
- Rename the SUSE specific scripts used to fix up the system where systemd is
  installed on. Also rename the directory where these scripts are stored.
* Thu May  4 2023 Franck Bui <fbui@suse.com>
- kbd-model-map.legacy: drop entry for 'ruwin_alt-UTF-8' as yast doesn't rely on
  it anymore, see https://github.com/yast/yast-country/pull/307
* Wed May  3 2023 Franck Bui <fbui@suse.com>
- Import commit 25aec157888f7aa9a36726962fcbbf2c74ead440 (merge of v253.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/3ce9610975b5239a21c0c886cb893bb172966de7...25aec157888f7aa9a36726962fcbbf2c74ead440
* Wed May  3 2023 Franck Bui <fbui@suse.com>
- Import commit 3ce9610975b5239a21c0c886cb893bb172966de7
  3ce9610975 test: dont use anchor char '$' to match a part of a string
  03ede3eaa2 locale: when no xvariant match select the entry with an empty xvariant
  f08017efd5 locale: convert generated vconsole keymap to x11 layout automatically
  e8cf56459b localed-util: make use of strdupcspn()
  821c684440 test: use kbd-mode-map we ship in TEST-73-LOCALE
* Tue May  2 2023 Franck Bui <fbui@suse.com>
- Revert changes that dropped calls to %%systemd_{pre,post} in the main package
  Until we switch to filetriggers these calls are needed when a new version of
  systemd introduced a new config file during an update.
- We also introduce a new build conditional "%%filetriggers" to identify easily
  which parts of the code will become obsolete when we'll switch to file
  triggers (WIP). This is important as this is unlikely to happen on SLE.
* Fri Apr 28 2023 Franck Bui <fbui@suse.com>
- Re-add back 'arabic' keymap mapping as YaST needs more time than expected to
  cope with this change.
* Thu Apr 27 2023 Franck Bui <fbui@suse.com>
- systemd.spec: don't call %%systemd_{pre,post} on units shipped by the main
  package since they don't have any effect during installation (systemctl is not
  yet installed when %%pre script is executed). This is actually the reason why
  it's handled by the %%%%posttrans scripts of systemd-presets-common-SUSE.
* Thu Apr 27 2023 Franck Bui <fbui@suse.com>
- kbd-model-map.legacy: 'arabic' vc keymap has been renamed 'ara' (bsc#1210702)
* Wed Apr 19 2023 Ludwig Nussel <lnussel@suse.de>
- add some green to systemd-boot menu
* Tue Apr 18 2023 Martin Vidner <mvidner@suse.com>
- kbd-model-map.legacy: drop some entries no longer needed
  by YaST (related to bsc#1194609)
* Wed Apr 12 2023 Thorsten Kukuk <kukuk@suse.com>
- tmpfiles-suse.conf (jsc#PED-3144):
  - Remove lastlog entry, replaced by lastlog2
  - Remove btmp entry, not Y2038 safe
* Wed Apr  5 2023 Franck Bui <fbui@suse.com>
- testsuite: TEST-75-RESOLVED needs knot DNS server
* Wed Apr  5 2023 Franck Bui <fbui@suse.com>
- Import commit 66f3a8a47d5bf6aea3f6fb181c01550a1a54406e (merge of v253.3)
  This merge also includes the following fix, which is not part of the stable
  release:
    d2413cec02 test/test-functions: fix typo in install_suse_systemd()
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/03cfbe767327d01d5a71131d91bf06fdc0047ca1...66f3a8a47d5bf6aea3f6fb181c01550a1a54406e
* Mon Apr  3 2023 Franck Bui <fbui@suse.com>
- Import commit 03cfbe767327d01d5a71131d91bf06fdc0047ca1
  03cfbe7673 test: use setpriv instead of su for user switch from root
  857843834c test: wrap mkfs.*/mksquashfs/mkswap binaries when running w/ ASan
  be7388f8c5 test: do not remove state directory on failure
  1b2885bd16 test: fix regexp in testsuite-74.mount.sh
  41142f8013 test: drop extraneous bracket in testsuite-74.mount.sh
* Mon Apr  3 2023 Franck Bui <fbui@suse.com>
- systemd.spec: add files.coredump
* Fri Mar 31 2023 Franck Bui <fbui@suse.com>
- Import commit b63f58661b08037d8cb04ed97b5e39d9bf415fdc (merge of v253.2)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8b01686dd20124efc300d21ef38d85c1f75c372f...b63f58661b08037d8cb04ed97b5e39d9bf415fdc
- Move systemd-fsck stuff to udev sub-package.
* Fri Mar 31 2023 Franck Bui <fbui@suse.com>
- Include pam_keyinit.so in our systemd-user PAM service (bsc#1209741)
  That way "systemd --user" instances get their own session keyring instead of
  the user default session keyring. For some reasons cifscreds refuses to work
  with the latter. That's what is expected for every PAM session anyway.
* Tue Mar 28 2023 Franck Bui <fbui@suse.com>
- Import commit 8b01686dd20124efc300d21ef38d85c1f75c372f
  8b01686dd2 test: don't export $TOOLS_DIR
  7a56b1b2f0 test: clean up $STATEDIR too
  324bb19eb8 test: $STATEDIR should not point to /usr/lib/systemd/tests when NO_BUILD=1
  2251735482 test: install symlinks with valid targets on SUSE and Debian
  c30905a269 test: on openSUSE install the collection of unit test binaries in the target only for TEST-02-UNITTESTS
  797ced15d8 meson: make sure the unit test scripts find testdata/ even if they are not installed in the same directory
  04dc5b44b7 meson: define testdata_dir globally
  69643c6c96 test: install unit tests in a dedicated subdirectory below '$testsdir'
* Thu Mar 23 2023 Franck Bui <fbui@suse.com>
- Import commit d914e29c33c0248226a01112a3e03181ef17b06b
  d914e29c33 Revert "hwdb: fix swapped buttons for Logitech Lift left" (bsc#1209618)
  8360811d23 udev-rules: fix nvme symlink creation on namespace changes (bsc#1207410)
  b77c13a130 systemctl: explicitly cast the constants to uint64_t (bsc#1209305)
  51011f280d test: assume run-unit-tests.py and unit tests are installed in the same directory
  d86e346f6b tests: don't use absolute paths when installing binaries in TEST-58-REPART
  97e886c1f4 tests: fix inverted condition in testsuite-58.sh
- Drop 5002-systemctl-explicitly-cast-the-constants-to-uint64_t.patch, it's been
  merged in 'SUSE/v253', see above.
* Tue Mar 21 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Add python3-pefile as requires for experimental, needed for the
  ukify tool.
* Mon Mar 20 2023 Franck Bui <fbui@suse.com>
- Drop 0005-udev-create-default-symlinks-for-primary-cd_dvd-driv.patch
  These obsolete symlinks were kept because several years ago VLC was still
  relying on some of them. However it's been a long a time ago that it's been
  fixed and cdrom or similar devices are discovered in a better way.
* Mon Mar 20 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Enable that systemd can load the IMA policy from
  /etc/ima/ima-policy.  This is used to complement dracut-ima when
  using SELinux, as the SELinux policy should not be loaded in the
  initrd (https://github.com/openSUSE/microos-tools/pull/14)
* Thu Mar 16 2023 Franck Bui <fbui@suse.com>
- Add 5002-systemctl-explicitly-cast-the-constants-to-uint64_t.patch (bsc#1209305)
  Added temporarily until it's merged in either the stable v253 branch or in the
  SUSE git repo.
* Thu Mar 16 2023 Franck Bui <fbui@suse.com>
- Add 5001-Revert-core-propagate-stop-too-if-restart-is-issued.patch until
  https://github.com/systemd/systemd/issues/26839 is fixed properly.
* Mon Mar 13 2023 Franck Bui <fbui@suse.com>
- testsuite: mtools is required by TEST-58-REPART
* Mon Mar 13 2023 Franck Bui <fbui@suse.com>
- testsuite: swtpm and tpm2.0-tools are needed by TEST-70-TPM2
* Thu Mar  9 2023 Franck Bui <fbui@suse.com>
- Add 5000-core-manager-run-generators-directly-when-we-are-in-.patch, a
  temporary workaround until https://github.com/dracutdevs/dracut/issues/2211 is
  fixed in dracut.
* Mon Mar  6 2023 Franck Bui <fbui@suse.com>
- Upgrade to v253.1 (commit 6c327d74aa0d350482e82a247d7018559699798d)
  See https://github.com/openSUSE/systemd/blob/SUSE/v253/NEWS for details.
  This includes the following bug fixes:
  - upstream commit 3022916b4d2483452c3ddbbac9ee7c4372b1cb46 (bsc#1215241)
  * Rebased 0001-conf-parser-introduce-early-drop-ins.patch
  * Ship systemd-journald-audit.socket again: it can now be disabled via the
    usual "systemctl disable" mechanism to stop collection of audit
    messages. Note that it's handled by the preset logic, which turns it off by
    default.
  * TEST_06_SELINUX needs selinux-policy-devel.
* Mon Mar  6 2023 Franck Bui <fbui@suse.com>
- Import commit d447802feee7752cd1756f8fa86ce2a6314ba24f (merge of v252.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8e0a8094b8bbc442d262795b85ac57a37264c5fe...d447802feee7752cd1756f8fa86ce2a6314ba24f
* Tue Feb 28 2023 Lidong Zhong <lidong.zhong@suse.com>
- Fix return non-zero value when disabling SysVinit service(bsc#1208432)
* Mon Feb 27 2023 Franck Bui <fbui@suse.com>
- Import commit 8e0a8094b8bbc442d262795b85ac57a37264c5fe (merge of v252.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/d87834a33444b7163e741e1089e82b44af663808...8e0a8094b8bbc442d262795b85ac57a37264c5fe
- Drop 5000-rules-add-missing-line-continuation.patch, it's part of v252.6.
- aaa_base has stop providing /etc/sysctl.conf, cope with this change so the
  compat symlink we provide is not dangling during the build.
* Thu Feb 23 2023 Callum Farmer <gmbr3@opensuse.org>
- Correct BR from python3-jinja2 to python3-Jinja2, fixes
  dependency resolving on older distros
* Fri Feb 17 2023 Franck Bui <fbui@suse.com>
- Drop build requirement on libpci, it's not more needed since udev hwdb was
  introduced 11 years ago.
* Tue Feb  7 2023 Franck Bui <fbui@suse.com>
- Conditionalize the use of /lib/modprobe.d only on systems with split usr
  support enabled (i.e. SLE).
* Mon Jan 30 2023 Franck Bui <fbui@suse.com>
- Import commit d87834a33444b7163e741e1089e82b44af663808 (merge of v252.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/5a506d73bde7ba9261985f8e9ce084044a519432...d87834a33444b7163e741e1089e82b44af663808
* Thu Jan 26 2023 Franck Bui <fbui@suse.com>
- Move the bash completion support for systemd-cryptenroll in udev.
* Thu Jan 26 2023 Franck Bui <fbui@suse.com>
- systemd-testsuite: move the integration tests in a dedicated sub directory.
* Thu Jan 26 2023 Franck Bui <fbui@suse.com>
- machines.target belongs to systemd-container, do its init/cleanup steps from
  the scriptlets of this sub-package.
* Tue Jan 24 2023 Franck Bui <fbui@suse.com>
- Drop 1000-Revert-getty-Pass-tty-to-use-by-agetty-via-stdin.patch
  It's no more necessary since util-linux 2.38 has been released in Factory.
* Mon Jan 23 2023 Franck Bui <fbui@suse.com>
- Make sure we apply the presets on units shipped by systemd package
* Fri Jan  6 2023 Franck Bui <fbui@suse.com>
- Add 5000-rules-add-missing-line-continuation.patch until commit
  de8409ac43f6e4596de4cecce8dbbb5f1f2a18b1 is backported to the v252 stable
  tree.
* Wed Dec 21 2022 Franck Bui <fbui@suse.com>
- Import commit 5a506d73bde7ba9261985f8e9ce084044a519432 (merge of v252.4)
  It includes the following fixes:
    9b75a3d050 coredump: do not allow user to access coredumps with changed uid/gid/capabilities (bsc#1205000 CVE-2022-4415)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/bf3fef99886bd977a1c7a51d20087bc8977fff44...5a506d73bde7ba9261985f8e9ce084044a519432
  Additionally, it also includes the following backports:
  - 20ca3155c5 localed: reload PID1 configuration after modifying /etc/locale.conf
  - 3538c202fd test: update TEST-73-LOCALE to define several locale settings in initial PID1 environment
- Drop 5000-coredump-adjust-whitespace.patch
    5001-coredump-do-not-allow-user-to-access-coredumps-with-.patch
  They are part of v252.4.
* Mon Dec 19 2022 Franck Bui <fbui@suse.com>
- Fix systemd-coredump to not allow user to access coredumps with changed
  uid/gid/capabilities (bsc#1205000 CVE-2022-4415)
  Add 5000-coredump-adjust-whitespace.patch
  Add 5001-coredump-do-not-allow-user-to-access-coredumps-with-.patch
* Fri Dec  9 2022 Franck Bui <fbui@suse.com>
- Import commit bf3fef99886bd977a1c7a51d20087bc8977fff44
  6372fb0cc4 btrfs-util: convert O_PATH if necessary, in btrfs quota call (bsc#1205560)
  12e68eb0e5 blockdev-util: move O_PATH fd conversion into btrfs_get_block_device_fd() to shorten things
  bb2bafdc9d btrfs-util: convert to fd_reopen_condition()
  1323232948 fd-util: add new helper fd_reopen_conditional()
- Drop 6000-Revert-tmpfiles-whenever-creating-an-inode-immediate.patch
  It's no more needed as a fix for bsc#1205560 has been queued, see above.
* Fri Dec  9 2022 Franck Bui <fbui@suse.com>
- Import commit 82898a14f5b0a965ba9c1efc1913fcdf29d446a8 (merge of v252.3)
  It includes the following fixes:
    9410eb20eb cryptsetup: retry TPM2 unseal operation if it fails with TPM2_RC_PCR_CHANGED (bsc#1204944)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/e7e931b07edd786dc6ca1dae6c23ff7b785f8efd...82898a14f5b0a965ba9c1efc1913fcdf29d446a8
  Additionally, it also includes the following backports:
  - 17b2f9f196 utmp-wtmp: fix error in case isatty() fails
  - 8d5c487c87 sd-bus: handle -EINTR return from bus_poll() (bsc#1201982)
  - 2dd217c8b5 tree-wide: modernizations with RET_NERRNO()
* Fri Dec  2 2022 Franck Bui <fbui@suse.com>
- Don't ship symlink /usr/lib/environment.d/99-environment.conf
  anymore. /etc/environment is owned and parsed (among other config files) by
  pam_env(8), which is included by 'systemd-user' PAM service anyway.
* Fri Nov 25 2022 Franck Bui <fbui@suse.com>
- Import commit e7e931b07edd786dc6ca1dae6c23ff7b785f8efd (merge of v252.2)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/64dc546913525e33e734500055a62ed0e963c227...e7e931b07edd786dc6ca1dae6c23ff7b785f8efd
- Rebase 6000-Revert-tmpfiles-whenever-creating-an-inode-immediate.patch
* Tue Nov 22 2022 Franck Bui <fbui@suse.com>
- Import commit 3bd3e4e6c1efe0d6df776107efde47e15e58fe96
  d28e81d65c test: fix the default timeout values described in README.testsuite
  d921c83f53 meson: install test-kernel-install only when -Dkernel-install=true
  c3b6c4b584 tests: update install_suse_systemd()
  3c77335b19 tests: install dmi-sysfs module on openSUSE
  df632130cd tests: install systemd-resolved on openSUSE
- Add 6000-Revert-tmpfiles-whenever-creating-an-inode-immediate.patch until
  upstream issue #25468 is fixed.
- Drop 6000-meson-install-test-kernel-install-only-when-Dkernel-.patch, the
  patch has been merged in the SUSE git repo.
* Fri Nov 18 2022 Franck Bui <fbui@suse.com>
- Reenable build of sd_boot, it was mistakenly disabled during the integration
  of v252.
* Mon Nov 14 2022 Franck Bui <fbui@suse.com>
- Upgrade to v252.1 (commit 64dc546913525e33e734500055a62ed0e963c227)
  See https://github.com/openSUSE/systemd/blob/SUSE/v252/NEWS for details.
  This includes the following bug fixes:
  - upstream commit 67c3e1f63a5221b47a8fea85ae421671f29f3b7e (bsc#1200723)
  - upstream commit 9102c625a673a3246d7e73d8737f3494446bad4e (bsc#1204968 CVE-2022-3821)
  - upstream commit efbd4b3ca84c0426b6ff98d6352f82f3b7c090b2 (bsc#1213873)
  - upstream commit f562abe2963bad241d34e0b308e48cf114672c84 (bsc#1226414)
  * Rebased 0001-conf-parser-introduce-early-drop-ins.patch
    1000-Revert-getty-Pass-tty-to-use-by-agetty-via-stdin.patch
  * The new tools systemd-measure and systemd-pcrphase have been added to the
    experimental sub-package for now.
  * Add temporarly
    6000-meson-install-test-kernel-install-only-when-Dkernel-.patch until this
    patch is mainstreamed.
* Tue Nov  8 2022 Franck Bui <fbui@suse.com>
- Import commit 9cdd78585069b133bebcd479f3a204057ad25d76 (merge of v251.8)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/c212388f7de8d22a3f7c22b19553548ccc0cdd15...9cdd78585069b133bebcd479f3a204057ad25d76
- Force _FORTIFY_SOURCE=2 as systemd (ab)use of malloc_usable_size() leads to
  build issues with FS=3 (bsc#1200819).
* Tue Oct 25 2022 Franck Bui <fbui@suse.com>
- Import commit c212388f7de8d22a3f7c22b19553548ccc0cdd15 (merge of v251.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/f78bba8d037cc26c09bbdd167625b2d7fe1f5a30...c212388f7de8d22a3f7c22b19553548ccc0cdd15
* Tue Oct 25 2022 Franck Bui <fbui@suse.com>
- specfile: reindent comments
* Fri Oct 21 2022 Franck Bui <fbui@suse.com>
- Import commit f78bba8d037cc26c09bbdd167625b2d7fe1f5a30 (merge of v251.6)
  Beside the merge of v251.6, it also includes the following backport:
  - 07aaa898bd pstore: do not try to load all known pstore modules
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/07aa29e3942fb46b0aed5405c88e8d3179ca958f...f78bba8d037cc26c09bbdd167625b2d7fe1f5a30
* Wed Oct 19 2022 Franck Bui <fbui@suse.com>
- Don't create /var/lib/systemd/random-seed in %%post (bsc#1181458)
  To make sure that the same seed is not replicated when installing from a
  'golden' image.
  For regular installations the random seed file is initialized by the installer
  itself (bsc#1174964). Even if it didn't, the random seed file would be created
  on first boot anyway.
* Wed Oct 12 2022 Dirk Müller <dmueller@suse.com>
- Avoid expanding of macro in comment which leads to an error on installation
  (workaround for bsc#1203847)
* Tue Oct  4 2022 Franck Bui <fbui@suse.com>
- Import commit 07aa29e3942fb46b0aed5405c88e8d3179ca958f (merge of v251.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/532faa39ebaa6f56e493cc938a91a40df082b74f...07aa29e3942fb46b0aed5405c88e8d3179ca958f
* Wed Sep 21 2022 Franck Bui <fbui@suse.com>
- Drop the old band aid used during the breakage introduced by the switch of
  /tmp to tmpfs
  This was done to address the regression reported in boo#1175779 but shouldn't
  be necessary anymore since the (few) affected users should have updated
  systemd during the last 2 years.
* Wed Sep 21 2022 Franck Bui <fbui@suse.com>
- Move nss-systemd and nss-myhostname NSS modules into the main package
* Tue Sep 20 2022 Franck Bui <fbui@suse.com>
- Give the instructions to create a home directory with systemd-homed in the
  description of the systemd-experimental sub-package
* Mon Sep  5 2022 Franck Bui <fbui@suse.com>
- rc-local.service.8 belongs to the systemd-sysvcompat sub-package (bsc#1203053)
* Fri Sep  2 2022 Bob Haley <fawz@use.startmail.com>
- Enable building and include libcryptsetup-plugins provided by systemd
  Now that dracut 057 has been released we can enable building libcryptsetup
  plugins. These can be used by cryptsetup to extend functionality including
  fido2, pkcs11 and tpm2 support.
* Mon Aug 29 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Let systemd trust the RTC for 30 years after the last update instead of 15 (bsc#1202356)
  To allow for our systems to be used in edge locations without systemd updates
  for a long time.
* Tue Aug 16 2022 Franck Bui <fbui@suse.com>
- Import commit 532faa39ebaa6f56e493cc938a91a40df082b74f (merge of v251.4)
  It includes the following fixes:
  - 739d7130cb home: drop conflicted headers (bsc#1202221)
  - 8fe0c12178 glibc: Remove #include <linux/fs.h> to resolve fsconfig_command/mount_attr conflict with glibc 2.36 (bsc#1202221)
  - 0c5b7ee318 udev: allow to execute longer command line (bsc#1201766)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8cd784e9250b38d20d8e14fccbfb211010283c79...532faa39ebaa6f56e493cc938a91a40df082b74f
- Drop 1001-statx.patch, it's no more needed.
* Mon Aug 15 2022 Dr. Werner Fink <werner@suse.de>
- Add patch 1001-statx.patch based on commit 3657d3a0
  * to resolve conflicts with glibc 2.36 with <linux/fs.h>
  * add dirty hack to get in src/basic/chattr-util.h,
    src/home/homework.h, src/home/homework-fscrypt.c,
    src/home/homed-manager.c, and src/home/homework-mount.c as well
    to avoid that <linux/fs.h> does include <linux/mount.h>
* Tue Jul 19 2022 Franck Bui <fbui@suse.com>
- Enable oomd (bsc#1200456)
  It's part of the experimental sub-package for now.
* Tue Jul 19 2022 Franck Bui <fbui@suse.com>
- Import commit 8cd784e9250b38d20d8e14fccbfb211010283c79 (merge of v251.3)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/32912879062bb1595d8498b6f9c77d5acd1dc66a...8cd784e9250b38d20d8e14fccbfb211010283c79
* Tue Jul 19 2022 Franck Bui <fbui@suse.com>
- Import commit 32912879062bb1595d8498b6f9c77d5acd1dc66a
  111b96ca86 logind: don't delay login for root even if systemd-user-sessions.service is not activated yet (bsc#1195059)
* Tue Jul 19 2022 Franck Bui <fbui@suse.com>
- Enable bpf framework
* Mon Jul 18 2022 Franck Bui <fbui@suse.com>
- When systemd-container is installed install tar/gpg too
  So `machinectl import-tar` always works flawlessly. systemd-container already
  is an optional package and both tar and gpg are rather basic anyway so no harm
  should be done by requiring them.
- Move the systemd sysupdate stuff from the main package to the experimental
  sub-package while it's still time. The method used (currently) for updating
  openSUSE distro is rpm, not systemd-sysupdate.
* Tue Jul 12 2022 Franck Bui <fbui@suse.com>
- systemd.spec: add files.experimental
* Fri Jul  8 2022 Franck Bui <fbui@suse.com>
- Make {/etc,/usr/lib}/systemd/network owned by both udev and systemd-network (bsc#1201276)
  This configuration files put in these directories are read by both udevd and
  systemd-networkd.
* Tue Jun 21 2022 Franck Bui <fbui@suse.com>
- Import commit 69abca7794ed06d823bc0a9bb55daf822adcc632
  f29b146685 pstore: Run after modules are loaded
* Tue Jun 21 2022 Franck Bui <fbui@suse.com>
- pstore is no more considered as an experimental feature: move it to udev
  package (bsc#1197802 jsc#PED-2663)
* Tue Jun 21 2022 Franck Bui <fbui@suse.com>
- Adjust rpmlintrc for shlib-policy-name-error/multibuild case so that it's not
  only for x86_64.
* Tue Jun 21 2022 Franck Bui <fbui@suse.com>
- spec: %%suse_version rpm macro is already reserved and has a special meaning in
  openSUSE distros so rename it to %%archive_version instead.
* Wed Jun  8 2022 Franck Bui <fbui@suse.com>
- Import commit e9fc337d97539fcab23078ab3e06f6b2ce3a3c8d
  ca0b29521f sha256: fix compilation on efi-ia32
  1bbbac6a7e test: enable virtio-rng device for QEMU guests
* Wed Jun  1 2022 Franck Bui <fbui@suse.com>
- Upgrade to v251.2 (commit 949d6bb7201dd48167ee9716ed6278764d1f4c0f)
  See https://github.com/openSUSE/systemd/blob/SUSE/v251/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit e6b169418369abbc88c8f622e02e1d704a23d4ef (bsc#1137373 bsc#1181658 bsc#1194708 bsc#1195157 bsc#1197570)
  - upstream commit 3a3b022d2cc112803ea7b9beea98bbcad110368a (bsc#1212434 bsc#1213575)
  - upstream commit e92a3d8fa3c554f807ddbcd7fc00821868fd8a62 (bsc#1195529)
  - upstream commit 1d0727e76fd5e9a07cc9991ec9a10ea1d78a99c7 (bsc#1208194)
  - upstream commit 55fabe92e2efb1a907d4c3c93dc63b96ff5b6860 (bsc#1191502)
  * Rebased 0001-conf-parser-introduce-early-drop-ins.patch
  * systemd-testsuite now requires python3-pexpect due to TEST-69-SHUTDOWN
    relying on this module.
  * sysusers.d/systemd-network.conf has been moved to systemd-network
    sub-package since the tmpfiles configuration snippets for networkd has also
    been moved to this sub-package.
* Tue May 31 2022 Franck Bui <fbui@suse.com>
- Import commit 4dbc543953eabd4c578da67ce6e2970d6f96c406 (merge of v250.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/0d950479e58dd3af007eb3780d600a5446aac519...4dbc543953eabd4c578da67ce6e2970d6f96c406
* Fri May 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update rpmlintrc for shlib-policy-name-error/multibuild case.
* Fri May  6 2022 Franck Bui <fbui@suse.com>
- Import commit 0d950479e58dd3af007eb3780d600a5446aac519 (merge of v250.5)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/736db5a59f1ab1317ef64ec6e7dc394250178146...0d950479e58dd3af007eb3780d600a5446aac519
* Fri Apr 29 2022 Franck Bui <fbui@suse.com>
- Call pam_loginuid when creating user@.service (bsc#1198507)
  It's a backport of upstream commit 1000522a60ceade446773c67031b47a566d4a70d.
* Wed Apr 20 2022 Ludwig Nussel <lnussel@suse.de>
- spec: add sbat (boo#1198589)
* Wed Apr 20 2022 Ludwig Nussel <lnussel@suse.de>
- spec: sign the systemd-boot efi binary (boo#1198586)
* Tue Apr 19 2022 Franck Bui <fbui@suse.com>
- Drop 0011-core-disable-session-keyring-per-system-sevice-entir.patch
  Since bsc#1081947 has been addressed, we can attempt to re-enable private
  session kernel keyring for each system service hence each service gets a
  session keyring that is specific to the service.
* Tue Apr 19 2022 Franck Bui <fbui@suse.com>
- Import commit 736db5a59f1ab1317ef64ec6e7dc394250178146
  98bc28d824 tmpfiles: constify item_compatible() parameters
  3faf1a2648 test: adapt install_pam() for openSUSE
  b7ca34fa28 test: add test checking tmpfiles conf file precedence
  2713693d93 test tmpfiles: add a test for 'w+'
  ce2cbefe38 tmpfiles.d: only 'w+' can have multiple lines for the same path (bsc#1198090)
  769f5a0cbe Support -D_FORTIFY_SOURCE=3 by using __builtin_dynamic_object_size.
* Sat Apr  9 2022 Andreas Schwab <schwab@suse.de>
- libseccomp is needed everywhere
* Thu Apr  7 2022 Franck Bui <fbui@suse.com>
- Move coredumpctl completion files into systemd-coredump sub-package.
* Wed Apr  6 2022 Franck Bui <fbui@suse.com>
- Import commit e43a1b018899266b764ab81afb9c30fb417675c6
  1c229f8fc1 cryptsetup: fall back to traditional unlocking if any TPM2 operation fails
  8881f21539 cryptsetup: fix typo
  5882148902 journald: make use of CLAMP() in cache_space_refresh()
  6ee0601f73 journald: make sure journal_file_open() doesn't leave a corrupted file around after failing (bsc#1198114)
  fe928f3d49 fs-util: make sure openat_report_new() initializes return param also on shortcut
  3881af1806 fs-util: fix typos in comments
  96060b73ba journal-file: port journal_file_open() to openat_report_new()
  611d9955bb fs-util: add openat_report_new() wrapper around openat()
  f16edb41d4 network: ignore all errors in loading .network files (bsc#1197968)
  5422730a7b meson: build kernel-install man page when necessary
  45c627cfc2 build: include status of TPM2 in the feature string show by --version
- Drop 0001-meson-build-kernel-install-man-page-when-necessary.patch
  It's been merged in the SUSE git repo.
* Mon Apr  4 2022 Franck Bui <fbui@suse.com>
- spec: define %%bootstrap with %%bcond_with so it can be used with %%when. Also
  re-order the meson options a bit.
* Mon Apr  4 2022 Franck Bui <fbui@suse.com>
- spec: make sure /lib exists when installing conf files in /lib/modprobe.d
* Thu Mar 31 2022 Franck Bui <fbui@suse.com>
- Temporarily disable 'libcryptsetup plugins until dracut 056 is merged in
  Factory
* Thu Mar 31 2022 Franck Bui <fbui@suse.com>
- Add 0001-meson-build-kernel-install-man-page-when-necessary.patch
  Submitted to upstream: https://github.com/systemd/systemd/pull/22918
* Mon Mar 28 2022 Franck Bui <fbui@suse.com>
- Move systemd-boot and all components managing (secure) UEFI boot into udev
  sub-package: they may deserve a dedicated sub-package in the future but for
  now move them to udev so they aren't installed in systemd based containers.
- Move a bunch of components operating on (mainly block) devices into udev as
  without udev they're most likely useless.
* Mon Mar 28 2022 Franck Bui <fbui@suse.com>
- spec: enable 'efi' support regardless of whether sd_boot is enabled or not
  We should support EFI systems even if systemd-boot is not enabled.
* Wed Mar 23 2022 Franck Bui <fbui@suse.com>
- spec: cope with %%{_modprobedir} being /lib/modprobe.d on SLE
* Thu Mar 17 2022 Franck Bui <fbui@suse.com>
- Add 1000-Revert-getty-Pass-tty-to-use-by-agetty-via-stdin.patch
  A temporary workaround until bsc#1197178 is resolved.
* Wed Mar 16 2022 Franck Bui <fbui@suse.com>
- Import commit 8ef8dfd5401ba18caec59e54a05af9f2e0d7ac65 (merge of v250.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/ca89b1d1fd1ae86cc1e763d2d01ec2806f3a4d3a...8ef8dfd5401ba18caec59e54a05af9f2e0d7ac65
* Wed Mar 16 2022 Franck Bui <fbui@suse.com>
- Import commit ca89b1d1fd1ae86cc1e763d2d01ec2806f3a4d3a
  37b683c832 journal: preserve acls when rotating user journals with NOCOW attribute set
  d043fabebc journal: when copying journal file to undo NOCOW flag, go via fd
  78c2766689 journal-file: explicitly handle file systems that do not support hole punching
  7ecfb4b098 journal-file: fix error handling of pread() in journald_file_punch_holes()
  c4946a412c journal-file: don't use pread() when determining where to append, use mmap as before
  d3fbd20628 journal: various fixes to journal_file_read_object()
  5897a8e8d4 shared: Handle filesystems that don't support hole punching in COPY_HOLES
  27746408e2 journal: Truncate file instead of punching hole in final object
  59b6130030 shared: Ensure COPY_HOLES copies trailing holes
  ac9ccba73f journal: stat journal file after truncating
  0257283444 journal: Copy holes when archiving BTRFS journal files
  26c2a9952d shared: Copy holes in sparse files in copy_bytes_full()
  6c7191dece copy: fix wrong argument passed to S_ISREG() in copy_file_fd_full()
  af0a43024d udev: 60-persistent-storage-tape.rules: handle duplicate device ID (bsc#1195529)
* Sat Mar 12 2022 Callum Farmer <gmbr3@opensuse.org>
- Update Supplements to new format in baselibs.conf
- Fix libsystemd-shared exclusion in baselibs.conf
- Exclude new cryptsetup libraries in baselibs.conf
* Tue Mar  8 2022 Franck Bui <fbui@suse.com>
- systemd.spec: minor simplification by assuming that %%{bootstrap} is always
  defined.
* Tue Mar  8 2022 Franck Bui <fbui@suse.com>
- Make sure to create 'systemd-coredump' system user when systemd-coredump is
  installed (follow-up for the split of the sysusers config files).
* Tue Mar  8 2022 Franck Bui <fbui@suse.com>
- Upgrade to v250.3 (commit dbd8bd2b9fd827ca89ed18034b60703c95798e01)
  See https://github.com/openSUSE/systemd/blob/SUSE/v250/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit 34357545590d4791d1acbbeb07ae8f7636e187cb (bsc#1198093)
  * Rebased 0001-conf-parser-introduce-early-drop-ins.patch
    0001-restore-var-run-and-var-lock-bind-mount-if-they-aren.patch
- Dropped 0007-networkd-make-network.service-an-alias-of-systemd-ne.patch
  The alias makes little sense as soon as multiple network managers are used in
  parallel.
* Tue Mar  8 2022 Franck Bui <fbui@suse.com>
- Fix the default target when it's been incorrectly set to one of the runlevel
  targets (bsc#1196567)
  The script 'upgrade-from-pre-210.sh' used to initialize the default target
  during migration from sysvinit to systemd. However it created symlinks to
  runlevel targets, which are deprecated and might be missing when
  systemd-sysvcompat package is not installed. If such symlinks are found the
  script now renames them to point to 'true' systemd target units.
- When migrating from sysvinit to systemd (it probably won't happen anymore),
  let's use the default systemd target, which is the graphical.target one. In
  most cases it will do the right thing anyway.
* Thu Feb 24 2022 Franck Bui <fbui@suse.com>
- Fix a regression caused by the split of the sysusers config files shipped by
  systemd (bsc#1196322)
  Calls to %%sysusers_create were not updated accordingly.
* Wed Feb 23 2022 Franck Bui <fbui@suse.com>
- spec: fix dependencies for mini variants (follow-up)
  systemd-mini-container is one of the sub-package that relies systemd-mini to
  conflict with kiwi and to not be installed on real systems.
* Tue Feb 22 2022 Franck Bui <fbui@suse.com>
- Import commit 0bb1977021be2fc9ebfae10d766dff0b1a457f88 (merge of v249.10)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/b9b83c5d11e686178ddd545862a00b33c6fdfabb...0bb1977021be2fc9ebfae10d766dff0b1a457f88
* Tue Feb 22 2022 Franck Bui <fbui@suse.com>
- Import commit b9b83c5d11e686178ddd545862a00b33c6fdfabb
  8973cb2462 systemd-coredump: allow setting external core size to infinity (bsc#1195899 jsc#SLE-23866)
* Mon Feb 21 2022 Fabian Vogt <fvogt@suse.com>
- Fix build if %%_distconfdir is not defined (see bsc#1195679)
* Thu Feb 17 2022 Franck Bui <fbui@suse.com>
- Drop enablement symlink migration support of SysV init scripts
  And let's finish reducing the support of SysV init scripts to its minimum.
* Thu Feb 17 2022 Franck Bui <fbui@suse.com>
- Don't rely on %%{_distconfdir}, it's broken on SLE (bsc#1195998)
* Mon Feb 14 2022 Franck Bui <fbui@suse.com>
- spec: fix dependencies for mini variants
  Make sure that all mini variants won't be installed in real systems and won't
  be involved when building medias with kiwi. Note that sub-packages that
  requires systemd (such as udev) don't need any special treatment since the
  specific deps are inherited from the main (mini) package.
- spec: simplify systemd-mini-doc dependencies by assuming that the doc
  sub-package can't be a build requirement for other packages.
- spec: libsystemd-mini and libudev-mini need to provide libsystemd and libudev
  respectively
* Mon Feb 14 2022 Franck Bui <fbui@suse.com>
- Rename systemd-sysvinit into systemd-sysvcompat
  systemd-sysvinit was probably provided to allow systems to switch from
  sysvinit to systemd by overwriting /sbin/init with a link to systemd. But this
  isn't very useful anymore due to the fact that sysvinit is not supported since
  several years. Therefore the subpackage contains now the files needed to keep
  backward compatibility with SysV init scripts (most notably sysv-generator)
  and has been renamed accordingly. The few files that are not specific to
  sysvinit (such as /bin/init) have been moved to the main package.
  Normally this new subpackage shouldn't be needed (since all packages use
  systemd unit files) unless a 3rd party application is installed and still
  relies on SysV init scripts.
* Mon Feb 14 2022 Franck Bui <fbui@suse.com>
- systemd.spec: explicitely turn on/off build options
  Hence a feature can't be accidentally turned on/off because its dep is pulled
  in or removed due to another feature being turned on/off.
* Fri Feb  4 2022 Franck Bui <fbui@suse.com>
- Always create systemd-network system user, even if systemd-networkd is not
  installed (bsc#1195559)
* Wed Feb  2 2022 Franck Bui <fbui@suse.com>
- Make more use of %%{_unitdir} in files.{systemd,container}
* Tue Feb  1 2022 Franck Bui <fbui@suse.com>
- Installation of libnss_mymachines.so depended on %%{bootstrap} but it is
  actually installed when %%{with machined} is true.
- Call ldconfig when container subpackage is installed since it ships
  nss-mymachines NSS plug-in module.
* Mon Jan 31 2022 Franck Bui <fbui@suse.com>
- Import commit 117bd7f14aa7834d85a4306cd380d292bec04108
  1395c74be7 udevadm: cleanup-db: don't delete information for kept db entries (bsc#1194912)
  bbafc8092a udevadm: cleanup_dir: use dot_or_dot_dot()
* Mon Jan 31 2022 Franck Bui <fbui@suse.com>
- Drop 0006-sysv-generator-add-back-support-for-SysV-scripts-for.patch
    0009-sysv-add-back-support-for-all-virtual-facility-and-f.patch
  Given the fact that Factory no more ship SysV init scripts since several
  months, only scripts coming from 3rd party applications should remain which
  are unlikely to rely on the SUSE specifities implemented by these
  patches. This change was announced on the Factory mailing list:
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/thread/3ERUP5ZZJ6PPA36L3HVN46BH6U6JL74O/
* Mon Jan 31 2022 Franck Bui <fbui@suse.com>
- Import commit 885e0b9126bd2cf1e3f6b147c45ec58a5550c75c
  41334be59e meson: minor cleanup
  3db0c28462 sysusers: split up systemd.conf
- Drop 0012-resolved-create-etc-resolv.conf-symlink-at-runtime.patch (bsc#1195153)
  Since v241, the patch isn't useful anymore because resolved is no more able to
  create /etc/resolv.conf symlink by itself,it runs as 'systemd-resolve'
  user. The symlink is now handled by a tmpfiles config file which is only
  installed when systemd-resolved is. The tmpfiles config file has currently a
  lower priority than the one shipped by netconfig.
* Mon Jan 31 2022 Franck Bui <fbui@suse.com>
- Make use of %%ldconfig_scriptlets
* Fri Jan 28 2022 Franck Bui <fbui@suse.com>
- Merge nss-resolved and nss-mymachines NSS plug-in modules into systemd-network
  and systemd-container respectively.
  These modules are plug-in modules hence the shared library packaging policy
  doesn't apply for them. Moreover they're pretty useless alone without their
  respective systemd services, Hence let's reduce the number of sub-packages as
  the list keeps increasing.
* Thu Jan 27 2022 Franck Bui <fbui@suse.com>
- Merge libudev-devel into systemd-devel
* Thu Jan 27 2022 Franck Bui <fbui@suse.com>
- Make sure that libopenssl-devel is installed when building resolved. Openssl
  was implictly pulled in by systemd-experimental subpackage but could be
  missing if the build of this subpackage was disabled.
* Wed Jan 26 2022 Franck Bui <fbui@suse.com>
- resolved: disable fallback DNS servers and fail when no DNS server info could
  be obtained from the links. It's better to let the sysadmin know that
  something is likely misconfigured rather than silently handing over the DNS
  queries to Google or Cloudflare.
* Wed Jan 26 2022 Franck Bui <fbui@suse.com>
- resolved: disable DNSSEC until the following issue is solved:
  https://github.com/systemd/systemd/issues/10579
- Replace '%%setup+%%autopatch' with '%%autosetup'
* Mon Jan 24 2022 Franck Bui <fbui@suse.com>
- systemd.spec: explicitely list all files for each main (sub) packages
  Using glob patterns in %%files section to reduce the number of listed files was
  error-prone as some introduced files could silently be placed in the wrong
  subpackage. The sections were also hard to read and many files needed to be
  excluded from the main package making the point of glob pattern usage moot.
  systemd, udev, systemd-container and systemd-network packages have now their
  list of files described in a dedicated file. The lists are kept sorted to make
  them easy to parse. The size of the files, especially the one for the main
  package, is still reasonable and much easier to read now.
  During this rework, a couple of cleanups happened: more use of
  %%{_systemd_util_dir}, some files was incorrectly owned by the main package and
  have been moved to the correct sub-package, etc...
  Note: the rest of the subpackages might be addressed later but let's find how
  it goes for now.
* Wed Jan 19 2022 Franck Bui <fbui@suse.com>
- Move the whole content of /usr/share/doc/packages/systemd in doc subpackage
* Wed Jan 19 2022 Franck Bui <fbui@suse.com>
- Move the systemd-network-generator stuff in udev package
  This generator can generate .link files and is mainly used in initrd where
  udev is mandatory.
* Tue Jan 18 2022 Franck Bui <fbui@suse.com>
- Restore /sbin/udevadm and /bin/systemctl (obsolete) paths when split_usr is
  true (bsc#1194519)
* Mon Jan 17 2022 Franck Bui <fbui@suse.com>
- Import commit 3743acbce3bd44208af453fc6dc384a1236dc83c (merge of v249.9)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/e2ca79dd775d1f7d39861d57f23c43f6cd85a872...3743acbce3bd44208af453fc6dc384a1236dc83c
* Fri Jan 14 2022 Franck Bui <fbui@suse.com>
- Extract bits from 0008-sysv-generator-translate-Required-Start-into-a-Wants.patch
  which are not specific to the handling of 'Required-Start:' and move them into a
  new patch 0009-sysv-add-back-support-for-all-virtual-facility-and-f.patch
* Thu Jan 13 2022 Franck Bui <fbui@suse.com>
- Import commit e2ca79dd775d1f7d39861d57f23c43f6cd85a872 (merge of v249.8)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/458220239c69b8e5fe7be480929348daeccb70d1...e2ca79dd775d1f7d39861d57f23c43f6cd85a872
* Thu Jan 13 2022 Franck Bui <fbui@suse.com>
- Import commit 458220239c69b8e5fe7be480929348daeccb70d1
  e95df40b09 shared/rm-rf: loop over nested directories instead of instead of recursing (CVE-2021-3997 bsc#1194178)
  078e04305d shared/rm_rf: refactor rm_rf() to shorten code a bit
  6d560d0aca shared/rm_rf: refactor rm_rf_children_inner() to shorten code a bit
  6666ff056c localectl: don't omit keymaps files that are symlinks (bsc#1191826)
- Drop the following patches as they have been merged into SUSE/v249 branch:
  5000-shared-rm_rf-refactor-rm_rf_children_inner-to-shorte.patch
  5001-shared-rm_rf-refactor-rm_rf-to-shorten-code-a-bit.patch
  5002-shared-rm-rf-loop-over-nested-directories-instead-of.patch
* Tue Jan 11 2022 Franck Bui <fbui@suse.com>
- Added patches to fix CVE-2021-3997 (bsc#1194178)
  5000-shared-rm_rf-refactor-rm_rf_children_inner-to-shorte.patch
  5001-shared-rm_rf-refactor-rm_rf-to-shorten-code-a-bit.patch
  5002-shared-rm-rf-loop-over-nested-directories-instead-of.patch
  These patches will be dropped and cherry-picked from upstream once upstream
  will commit them in their main branch.
* Thu Jan  6 2022 Franck Bui <fbui@suse.com>
- Import commit a54f80116ccf105dff11aef5d18dd110ebd3e8ee
  30cbebc56f tmpfiles: 'st' may have been used uninitialized
  5443654ec0 macro: add new helper RET_NERRNO()
  8d90ecc435 rm-rf: optionally fsync() after removing directory tree
  591344010d rm-rf: refactor rm_rf_children(), split out body of directory iteration loop
  8c7762c4f1 Bump the max number of inodes for /dev to a million (bsc#1192858)
  dc9476c881 journal: don't remove the flushed flag when journald is stopped
  29efc29efd TEST-10: don't attempt to write a byte to the socket
  773fb785b6 Bump the max number of inodes for /dev to 128k (bsc#1192858)
* Tue Jan  4 2022 Franck Bui <fbui@suse.com>
- Update systemd-user PAM service again
  Change the default implementation of pam_setcred() again, previously
  customized to run the full "auth" PAM stack and only call pam_deny.so which is
  basically the SUSE default behavior without pam_warn.so.
  This is considered safer, especially on SLE where a regression was spotted by
  QA.
* Tue Dec  7 2021 Ludwig Nussel <lnussel@suse.de>
- move files related to static nodes to udev
* Wed Nov 24 2021 Ludwig Nussel <lnussel@suse.com>
- Replace S:$n references with SOURCE$n. Makes vim * search work.
* Mon Nov 22 2021 Franck Bui <fbui@suse.com>
- Import commit 523f32df573d459551760b072cb62906f4a2cf23 (merge of v249.7)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/c34c98712600bc206919ec6ed136195f75ac1967...523f32df573d459551760b072cb62906f4a2cf23
- Import commit c34c98712600bc206919ec6ed136195f75ac1967
  f99aa40c6e TEST-12: make sure 'adm' group exist
  6c7194ff99 TEST-08: don't force ext4 for /
  dd1814b8f9 test: use kbd-mode-map we ship in one more test case
  94c5febf2a test: fix TEST-10-ISSUE-2467
* Mon Nov 22 2021 Franck Bui <fbui@suse.com>
- Update the dependencies of the systemd-testsuite sub-package.
* Mon Nov 15 2021 Franck Bui <fbui@suse.com>
- Import commit 61c79e68381801428c0bc00a56b9e2e9cfa68373 (merge of v249.6)
  bcdeee7b4c virt: Support detection for ARM64 Hyper-V guests (bsc#1186071)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/8521f8d22fd44400289fcea03493ebd7f8b1487d...61c79e68381801428c0bc00a56b9e2e9cfa68373
- Drop 0001-Revert-core-Check-unit-start-rate-limiting-earlier.patch
  It's part of v249.6.
* Tue Nov  2 2021 Franck Bui <fbui@suse.com>
- Add 0001-Revert-core-Check-unit-start-rate-limiting-earlier.patch
  Temporarly revert commit ed8fbbf1745c6a2dc0b8cd560ac8a3353f72e979
  until the regression it introduced [1] is addressed by upstream and
  a fix is released via the stable tree.
  [1] https://github.com/systemd/systemd/issues/21025
* Tue Oct 19 2021 Franck Bui <fbui@suse.com>
- Disable nss-systemd and translations features for the mini flavour
* Mon Oct 18 2021 Franck Bui <fbui@suse.com>
- Really enable libiptc for masquerading support (bsc#1191651)
  Currently used by systemd-nspawn and systemd-networkd.
* Mon Oct 18 2021 Franck Bui <fbui@suse.com>
- Convert systemd package to multibuild
* Fri Oct 15 2021 Franck Bui <fbui@suse.com>
- Import commit 8521f8d22fd44400289fcea03493ebd7f8b1487d (merge of v249.5)
  8de173ff93 mount-util: fix fd_is_mount_point() when both the parent and directory are network fs (bsc#1190984)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/355e113ce193e5e2d195278c57d47f9a1b00ae46...8521f8d22fd44400289fcea03493ebd7f8b1487d
* Fri Oct 15 2021 Franck Bui <fbui@suse.com>
- Import commit 355e113ce193e5e2d195278c57d47f9a1b00ae46
  3b4a005095 meson: add missing include directory when using xkbcommon
  4c4e642712 meson: allow extra net naming schemes to be defined during configuration (jsc#SLE-18514)
  78466e4464 meson: drop the list of valid net naming schemes
  b9a2098f9d netif-naming: inline one iterator variable
  d7fbbc5e74 Add remaining supported schemes as options for default-net-naming-scheme
* Fri Oct 15 2021 Franck Bui <fbui@suse.com>
- Rename %%{gnu-efi} into %%{sd_boot}
  Build conditionals (%%bcond_with and %%bcond_without) are used to
  define a specific feature of systemd. "gnu-efi" is rather an
  implemenation detail. Also not really sure what "efi" option alone
  is useful for since systemd-boot & co depends on "gnu-efi".
- Enable sd_boot support for aarch64
* Fri Oct 15 2021 Franck Bui <fbui@suse.com>
- Ghost own directories /var/log/journal and /var/log/journal/remote again
  rpmlint no more complain about the setgid bit, see sr#923496.
* Fri Oct  8 2021 Franck Bui <fbui@suse.com>
- Overwriting rootprefix= is only required when split-usr is enabled
* Fri Oct  8 2021 Franck Bui <fbui@suse.com>
- Rename %%usrmerged into %%split_usr
* Wed Oct  6 2021 Franck Bui <fbui@suse.com>
- Suppress PAM warning when the credentials for user@.service service
  are established (bsc#1190515)
  systemd-user PAM service needs to define a default implementation of
  pam_setcred() otherwise the fallback (defined by /etc/pam.d/other)
  is used, which consists of pam_warn.so + pam_deny.so, and will throw
  a warning each time a user logs in.
* Mon Oct  4 2021 Franck Bui <fbui@suse.com>
- No need to install upstream pam configuration file "systemd-user"
  It's overwritten by the SUSE version anyway.
* Wed Sep 29 2021 Franck Bui <fbui@suse.com>
- Work around rpmlint complaining about /var/log/journal shipped with setgid bit
  This setgid bit has been already reviewed in the past and wasn't a
  concern. However we want the mode/ownership adjusted by tmpfiles and
  avoid the duplication of these info in rpm.
- Don't ghost own any directories created dynamically by tmpfiles
  Again rpmlint complains but it doesn't seem to make sense to try to
  track all paths (including theirs perms, ownerships...) created
  dynamically. And 'rpm -V' is likely to report issues later with
  these paths anyway.
  This effectively partially reverts the two previous commits.
* Fri Sep 24 2021 Franck Bui <fbui@suse.com>
- Make sure the build process won't create /var/log/journal
- /var/log/journal/remote is owned by systemd-journal-remote
* Fri Sep 24 2021 Franck Bui <fbui@suse.com>
- systemd.spec: fix a bunch of rpmlint errors/warnings
* Fri Sep 24 2021 Franck Bui <fbui@suse.com>
- Drop systemd-logger
  This sub package was introduced in order to configure persistent
  journal and also to make sure that another syslog provider (such as
  rsyslog) couldn't be installed at the same time: each syslog
  provider conflicts with each others.
  However this mechanism didn't work since uninstalling systemd-logger
  wasn't magically turning off persistent logging because
  /var/log/journal is likely to be populated hence not removed.
  Moreover using a subpackage to configure the mode of journald was
  overkill and the usual ways (main conf file or drop-ins) should be
  preferred.
* Wed Sep 22 2021 Franck Bui <fbui@suse.com>
- Import commit 7a5801342fe2f53e5c2a8578d6db132c0eca2d97
  8d65ec4a66 test: wc is needed by test/units/testsuite-50.sh
  1527bcc5dd test: make the installation of the debug tools optional in the image
  f4e6bf0b37 journalctl: never fail at flushing when the flushed flag is set (bsc#1188588)
* Wed Sep 22 2021 Franck Bui <fbui@suse.com>
- Update the dependencies of the testsuite package
  The debug tools are optional thus no more required.
  OTOH strip(1) is needed when building the test image and nc(1) is
  needed by some tests.
* Fri Sep 10 2021 Franck Bui <fbui@suse.com>
- Drop git internal files from the testsuite sub-package
* Fri Sep 10 2021 Franck Bui <fbui@suse.com>
- Adjust pam macros
* Wed Sep  8 2021 Franck Bui <fbui@suse.com>
- Don't reexecute user manager instances on package update yet
  This can't be done until users have their user instance updated to
  the new version that supports reexecuting with SIGRTMIN+25 because
  this signal terminates the user managers for the previous versions.
* Wed Sep  8 2021 Franck Bui <fbui@suse.com>
- Import commit ec72db9ee0f8ce061f83624d7148ff38a5993b11
  3b1aa2f79f manager: reexecute on SIGRTMIN+25, user instances only
  fd46c81922 test: make sure to include all haveged unit files
- systemd.spec: reexec user manager instances on package updates
* Fri Sep  3 2021 Franck Bui <fbui@suse.com>
- Make sure the versions of both udev and systemd packages are always the same (bsc#1189480)
* Thu Sep  2 2021 Franck Bui <fbui@suse.com>
- Drop dependency on m4 (replaced by Jinja2)
* Wed Sep  1 2021 Franck Bui <fbui@suse.com>
- Configure split-usr=true only when %%usrmerged is not defined
* Wed Sep  1 2021 Franck Bui <fbui@suse.com>
- Import commit 40bda18e346ff45132ccd6f8f8e96de78dcf3470 (merge of v249.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/7f23815a706cf2b2df3eac2eb2f8220736b8f427...40bda18e346ff45132ccd6f8f8e96de78dcf3470
* Mon Aug 23 2021 Franck Bui <fbui@suse.com>
- Rework the test (sub)package:
  - it's been renamed into 'systemd-testsuite'
  - it includes the extended tests too
  - the relevant commits have been backported to SUSE/v249 so no SUSE
    specific patch is needed to run the extended tests (see below)
  - the deps needed by the extended tests have been added
- Import commit 7f23815a706cf2b2df3eac2eb2f8220736b8f427
  ad216581b6 test: if haveged is part of initrd it needs to be installed in the image too
  088fbb71d0 test: adapt install_pam() for openSUSE
  4d631c1f0c Revert "test: adapt TEST-13-NSPAWN-SMOKE for SUSE"
  ef956eb8a2 test: on openSUSE the static linked version of busybox is named "busybox-static"
  6f7ce633b0 TEST-13-*: in busybox container sleep(1) takes a delay in seconds only
  278baaa3ec test: don't try to find BUILD_DIR when NO_BUILD is set
  3bba2f876a test: add support for NO_BUILD=1 on openSUSE
  d77cbc1b64 test: make busybox TEST-13-only dependency
* Mon Aug  2 2021 Franck Bui <fbui@suse.com>
- Upgrade to v249.2 (commit c0bb2fcbc26f6aacde574656159504f263916719)
  See https://github.com/openSUSE/systemd/blob/SUSE/v249/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit 6fb61918ccdd0610b425d5b0e5417751f8f8f783 (bsc#1182870)
  - upstream commit 6fe2a70b9160e35fdeed9d37bd31727c2d46a8b2 (jsc#SLE-17798)
  - Rebased 0002-rc-local-fix-ordering-startup-for-etc-init.d-boot.lo.patch
    0012-resolved-create-etc-resolv.conf-symlink-at-runtime.patch
* Thu Jul 29 2021 Franck Bui <fbui@suse.com>
- Avoid the error message when udev is updated due to udev being
  already active when the sockets are started again (bsc#1188291)
* Mon Jul 26 2021 Franck Bui <fbui@suse.com>
- Import commit 73e9e6fb847513c6d62f2fb445778ef5bc0fe516 (merge of v248.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/cb29bcc5ef2c0ee659686c5d229646a6ba98ec50...73e9e6fb847513c6d62f2fb445778ef5bc0fe516
* Tue Jul 20 2021 Franck Bui <fbui@suse.com>
- Drop 0001-Revert-core-prevent-excessive-proc-self-mountinfo-pa.patch
  Commit 81107b8419c39f726fd2805517a5b9faab204e59 fixes
  https://github.com/systemd/systemd/issues/19464 which makes the
  aforementioned patch not needed anymore.
* Tue Jul 20 2021 Franck Bui <fbui@suse.com>
- Drop 1003-basic-unit-name-adjust-comments.patch
  It's been merged in SUSE/v248 branch
* Tue Jul 20 2021 Franck Bui <fbui@suse.com>
- Import commit cb29bcc5ef2c0ee659686c5d229646a6ba98ec50 (merge of v248.5)
  4a1c5f34bd basic/unit-name: do not use strdupa() on a path (bsc#1188063 CVE-2021-33910)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/94efce2ee59fca15a48ff9c232c8dd7cf930c0a0...cb29bcc5ef2c0ee659686c5d229646a6ba98ec50
- Drop 1002-basic-unit-name-do-not-use-strdupa-on-a-path.patch as it
  was merged in v248.5.
* Tue Jul 20 2021 Franck Bui <fbui@suse.com>
- Import commit 94efce2ee59fca15a48ff9c232c8dd7cf930c0a0 (merge of v248.4)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/c0aecee593511e49638579cb2b9ac8aaf1f8e6c8...94efce2ee59fca15a48ff9c232c8dd7cf930c0a0
- Drop 1001-unit-name-generate-a-clear-error-code-when-convertin.patch
  as it was merged in v248.4.
* Tue Jul 20 2021 Franck Bui <fbui@suse.com>
- Import commit c0aecee593511e49638579cb2b9ac8aaf1f8e6c8
  42ec1d537a login: use a hwdb entry for tagging Parallels' fb devices with 'master-of-seat' tag
  ecc7c7b462 login: use a hwdb entry for tagging HyperV's fb devices with 'master-of-seat' tag
  a4cfd70476 login: XGI Z7/Z9 (XG20 core) graphic chip requires master-of-seat to be set (bsc#1187154)
  ef553e0199 sd-dhcp-client: tentatively ignore FORCERENEW command (bsc#1185972 CVE-2020-13529)
  aae6c575fc sd-dhcp-client: logs when dhcp client unexpectedly gains a new lease
  258a3d2043 sd-dhcp-client: shorten code a bit
  0a80303114 sd-dhcp-client: check error earlier and reduce indentation
* Thu Jul  8 2021 Franck Bui <fbui@suse.com>
- Added patches to fix CVE-2021-33910 (bsc#1188063)
  Added 1001-unit-name-generate-a-clear-error-code-when-convertin.patch
  Added 1002-basic-unit-name-do-not-use-strdupa-on-a-path.patch
  Added 1003-basic-unit-name-adjust-comments.patch
  These patches will be moved to the git repo once the bug will become
  public.
* Mon Jul  5 2021 Franck Bui <fbui@suse.com>
- systemd-hwdb-update.service should be shipped by the udev package
* Thu Jul  1 2021 Franck Bui <fbui@suse.com>
- Finally don't create /run/lock/subsys anymore
  This effectively reverts the fix for bsc#1187292 made earlier. This
  directory is specific to RH sysvinit and since we're going to fade
  the support of SysV init script away the directory has no future.
* Mon Jun 28 2021 Franck Bui <fbui@suse.com>
- Import commit e9a23d9e064c2e7ac21a1b984d116bcf15327e63
  8dd19c6ee3 sd-device: allow to read sysattr which contains embedded NUL
  d52409e5fe pid1: only add a Wants= type dependency on /tmp when PrivateTmp=yes (bsc#1181970
* Mon Jun 28 2021 Fabian Vogt <fvogt@suse.com>
- Enable TPM2 support
* Thu Jun 24 2021 Franck Bui <fbui@suse.com>
- Import commit fcdb8dce591db2f5fc3c1e3eeb7abe9a2090b401
  aa2d840a3b compat-rules: fix warning: "label ‘out’ defined but not used" in path_id_compat.c
- Restore 61-persistent-storage-compat.rules that was mistakenly
  dropped during the merge of v248.
* Fri Jun 18 2021 Franck Bui <fbui@suse.com>
- Create /run/lock/subsys again (bsc#1187292)
  The creation of this directory was mistakenly dropped when
  'filesystem' package took the initialization of the generic paths
  over.
  Paths under /run/lock are still managed by systemd for lack of
  better place.
* Fri Jun  4 2021 Franck Bui <fbui@suse.com>
- Drop systemd's dependency on udev (jsc#PM-2677)
  In some environments (i.e. containers) udev is usually not necessary
  but pulls in unnecessary packages.
* Fri Jun  4 2021 Franck Bui <fbui@suse.com>
- Now that chkconfig/insserv are history, let's implement the strict
  minimum in systemd-sysv-install to enable/disable SysV init scripts
  (bsc#1186595 bsc#1186359)
  Indeed there's no much point in dropping SysV support completely
  until upstream will do especially since 3rd party applications such
  as vmware still rely on it, see bsc#1186359).
* Tue May 25 2021 Franck Bui <fbui@suse.com>
- Allow the sysusers config files shipped by systemd rpms to be
  overriden during system installation (bsc#1171962)
- While at it, add a comment to explain why we don't use
  %%sysusers_create in %%pre and why it should be safe in %%post.
* Thu May 20 2021 Franck Bui <fbui@suse.com>
- udev requires systemd in its %%post (bsc#1185958)
  udevadm, called in udev's %%post, requires libsystemd-shared-248.so.
* Thu May 20 2021 Franck Bui <fbui@suse.com>
- Restore all "License:" tags
  udev uses a different license (GPL-2.0-only) than the main package
  and "osc service localrun format_spec_file" has the good taste to
  restore the license tags for all other subpackages if one of the
  subpackage tag differs.
* Thu May 20 2021 Franck Bui <fbui@suse.com>
- Expect 644 permissions for /usr/lib/udev/compat-symlink-generation (bsc#1185807)
* Wed May 19 2021 Franck Bui <fbui@suse.com>
- Spec file minor cleanups:
  - Drop all "Group:" tags as they are deprecated.
  - Drop "License:" tags from all subpackages and make it inherited
    from the main package.
  - Drop "%%bcond_with parentpathid" as it's not used.
* Tue May 18 2021 Franck Bui <fbui@suse.com>
- Introduce subpackage systemd-tests
  This subpackage is mainly used before submitting a new version of
  the systemd packages. As such it's not intended for regular users
  hence can be removed/renamed at any time. One might wonder why the
  unit tests are not executed during package builds (%%check)... the
  reason is that the environment used to build package (chroot) is too
  limited and therefore only a subset of the unit tests would be
  executed in this environment.
  To disable the build of the subpackage, use "--without=tests".
* Tue May 18 2021 Franck Bui <fbui@suse.com>
- Add 0001-Revert-core-prevent-excessive-proc-self-mountinfo-pa.patch
  A temporary patch until
  https://github.com/systemd/systemd/issues/19464 is solved.
* Tue May 18 2021 Franck Bui <fbui@suse.com>
- Import commit bc08011f04ac4f12569ec05965149f665a0b110b (merge of v248.3)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/6f5c11b28f5739b901390f22c2bf4c003cadedaa...bc08011f04ac4f12569ec05965149f665a0b110b
* Mon May 10 2021 Franck Bui <fbui@suse.com>
- Import commit 6f5c11b28f5739b901390f22c2bf4c003cadedaa (merge of v248.2)
  2c8ec0095e udev/net_id: don't generate slot based names if multiple devices might claim the same slot (bsc#1192637)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/e5f93c9d2e9e26dd0dff430c4c072a547357ae7d...6f5c11b28f5739b901390f22c2bf4c003cadedaa
* Mon Apr 26 2021 Franck Bui <fbui@suse.com>
- Upgrade to v248 (commit 5d3d934a5c2f4593207497db94e6f313348e89e7)
  See https://github.com/openSUSE/systemd/blob/SUSE/v248/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit 4327574fc1093513badc2177f71cede2fc88c13c (bsc#1166028)
  - upstream commit 3573e032f26724949e86626eace058d006b8bf70 (bsc#1186411)
  - upstream commit 30927a24848c4d727f7619cc74b878f098cdd724 (bsc#1200170)
  - A couple runtime dependencies on libraries are now tracked
    manually (with Recommends:) due to the fact that some symbols of
    these libs are dynamically loaded with dlopen() (heck!)
  - oomd is left disablde for now
  - pam configuration file 'systemd-user' is now shipped in
    /usr/etc/pam.d
  - Rebased 0001-conf-parser-introduce-early-drop-ins.patch
    0003-strip-the-domain-part-from-etc-hostname-when-setting.patch
    0006-sysv-generator-add-back-support-for-SysV-scripts-for.patch
  - Dropped 0004-tmpfiles-support-exclude-statements-based-on-file-ow.patch
    as it is SLE specific.
- Clean systemd-experimental up:
  - Enclose "%%package/%%descriptoin experimental" within a "%%if
    %%experimental/%%endif" block condition
  - List the build requirements in the sub-package instead of listing
    them in the main package.
  - Enable support for fido2, pwquality and qrencode in the home
    stuff
  - Improve the package description
* Wed Apr  7 2021 Franck Bui <fbui@suse.com>
- systemd.spec: clean some of the build deps up:
  - libpcre is redundant with libpcre2 (only required by the full
    build) and the mini variant needs none of them. Hence drop the ref
    to libpcre.
  - normally libidn2 is needed by some optional features in
    systemd-network (only). But it's implicitly pulled in by libgnutls
    (required by the main package). Let's make sure the related
    features won't be disabled inadvertently in the future by making
    the dep explicit.
* Tue Mar 30 2021 Franck Bui <fbui@suse.com>
- Import commit 14581e01203df7aa63c7c8383a12e6ebe258476f (merge of v246.13)
  423b1e759c Revert "resolved: gracefully handle with packets with too large RR count" (bsc#1183745)
  4723778738 meson.build: make xinitrcdir configurable (bsc#1183408)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/9753d1c17545a5d46530696cb14254f5f12024f1...14581e01203df7aa63c7c8383a12e6ebe258476f
- Drop 0001-Revert-resolved-gracefully-handle-with-packets-with-.patch
  as it's part of v246.13.
- Make use of the new build option to ship xinitrc in
  /usr/etc/X11/xinit/xinitrc.d (bsc#1183408)
* Wed Mar 24 2021 Franck Bui <fbui@suse.com>
- Add 0001-Revert-resolved-gracefully-handle-with-packets-with-.patch
  Temporary workaround for bsc#1183745 (upstream issue 18917) until an
  actual fix is found.
* Tue Mar 23 2021 Ludwig Nussel <lnussel@suse.de>
- enable libiptc for masquerading support in networkd
* Mon Mar 22 2021 Neal Gompa <ngompa13@gmail.com>
- Default to the "unified" cgroup hierarchy. At this point, most
  users of cgroup (such as docker, libvirt, kubernetes) should be
  ready for this change. It's still possible to switch back to the
  old "hybrid" hierarchy by passing "systemd.unified_cgroup_hierarchy=0"
  option to the kernel command line.
* Mon Mar 15 2021 Franck Bui <fbui@suse.com>
- Import commit 9753d1c17545a5d46530696cb14254f5f12024f1 (merge of v246.11)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/134cf1c8bc3e361a2641161aa11ac2b5b990480b...9753d1c17545a5d46530696cb14254f5f12024f1
- Rebase 0001-conf-parser-introduce-early-drop-ins.patch
* Mon Mar 15 2021 Franck Bui <fbui@suse.com>
- Import commit 13bc08870147b35f87cefb074aec22e767b7ac04
  846d61e0a1 boot: Move console declarations to missing_efi.h
  171a37228b boot: Add startswith() and endswith() functions with no_case variants
  0fad9f309a boot: Drop unnecessary braces
  c38bbb0874 boot: Fix void pointer arithmetic warning
  438210924b boot: Replace raw efivar gets with typed variants
  e46cb3e4a0 boot: Add  efivar_get/set_uint64_le() functions
  e16bee35c8 boot: Rename efivar_get/set_int() to efivar_get/set_uint_string()
  2808d0e9a3 boot: Tighten scope of variables used in loops
  d3f3d57743 boot: Add efivar_get_boolean_u8()
  0551ecce71 boot: Make all efivar util functions take the guid as an argument
  8376ba3b9f boot: Turn all guid constants into C99 compound initializers
  166fc2dad2 boot: Enable C99
  c87d66e261 boot: Move Secure Boot logic to new file
  da7bba9438 udev: fix memleak
  e06139117c nspawn: make rootfs relative to oci bundle path (bsc#1182598)
  8ba587d46c PATCH] Always free deserialized_subscribed on reload (bsc#1180020)
* Thu Mar 11 2021 Ludwig Nussel <lnussel@suse.de>
- create subpackage systemd-experimental to host pstore, repart,
  userdb and homed
* Thu Mar 11 2021 Franck Bui <fbui@suse.com>
- Make sure the udev socket units are reloaded during udev package updates
* Wed Mar 10 2021 Franck Bui <fbui@suse.com>
- fix-machines-btrfs-subvol.sh is only shipped when machined is built
* Mon Feb 22 2021 Franck Bui <fbui@suse.com>
- systemd requires aaa_base >= 13.2
  This dependency is required because 'systemctl
  {is-enabled,enable,disable} <initscript>" ends up calling
  systemd-sysv-install which in its turn calls "chkconfig
  - -no-systemctl".
  aaa_base package has a weird versioning but the '--no-systemctl'
  option has been introduced starting from SLE12-SP2-GA, which shipped
  version "13.2+git20140911.61c1681".
  Spotted in bsc#1180083.
* Fri Feb 19 2021 Franck Bui <fbui@suse.com>
- Add 0001-conf-parser-introduce-early-drop-ins.patch
  Introduce early configuration drop-in file. This type of drop-ins
  are reserved for vendor own purposes only and should never been used
  by users. It might be removed in the future without any notice.
* Wed Feb 17 2021 Franck Bui <fbui@suse.com>
- Drop use of %%systemd_postun in %%postun
  This macro is supposed to operate on units but it was used without
  passing any parameters. This call was probably used for issuing a
  daemon-reload but the following calls to
  %%systemd_postun_with_restart imply that already. So let's simply
  drop it.
* Fri Feb  5 2021 Franck Bui <fbui@suse.com>
- systemd-sysv-convert: handle the case when services are migrated
  from SysV scripts to systemd units and are renamed at the same
  time (bsc#1181788)
  The list of such services is hard coded and contains only the
  'ntp->ntpd' translation.
* Wed Feb  3 2021 Franck Bui <fbui@suse.com>
- Import commit 134cf1c8bc3e361a2641161aa11ac2b5b990480b (merge of v246.10)
  25f220eafb sysusers: flush nscd's caches whenever /etc/{passwd,group} are modified (bsc#1181121)
  4a543f0257 journal: send journald logs to kmsg again
  26df96473f busctl: add a timestamp to the output of the busctl monitor command (bsc#1180225)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/520e53b6d85087b05892ee637ae93f1b269e7e52...134cf1c8bc3e361a2641161aa11ac2b5b990480b
* Wed Jan 13 2021 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
  * don't install legacy symlinks to /
  * use %%_pamdir to install pam modules
  * leave nss files in /usr/lib*, glibc loads them from there just
    fine independent of usrmerge
* Fri Dec 18 2020 Franck Bui <fbui@suse.com>
- Import commit 520e53b6d85087b05892ee637ae93f1b269e7e52 (merge of v246.9)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/2401461e5f0e32922823d954c56106f96344070e...520e53b6d85087b05892ee637ae93f1b269e7e52
* Fri Dec 18 2020 Franck Bui <fbui@suse.com>
- Import commit 2401461e5f0e32922823d954c56106f96344070e
  6131548b0f udev: link_update() should fail if the entry in symlink dir couldn't have been created
  f6cb8c7d79 udev: make algorithm that selects highest priority devlink less susceptible to race conditions (bsc#1084748)
  fc64e47291 basic/stat-util: make mtime check stricter and use entire timestamp
  ae91d45d3d test/sys-script.py: add missing DEVNAME entries to uevents
  09e3473a7a test/udev_test.pl: add "expected good" count
  fc89379b5b test/udev-test.pl: suppress umount error message at startup
  d9e114f10d test/sd-script.py: new helper script for udev testing
  f2672eae66 test/udev-test.pl: generator for large list of block devices
  42b68e43e2 test/udev-test.pl: add repeat count
  eec8ec375a tests/udev-test.pl: add multiple device test
  73b8f3cf93 test/udev-test.pl: count "good" results
  ee04d70bb6 test/udev-test.pl: merge import parent tests into one
  03942c8fbc test/udev-test.pl: merge "space and var with space" tests
  ec95546189 test/udev-test.pl: remove bogus rules from magic subsys test
  f704429217 test/udev-test.pl: Make some tests a little harder
  ce1a877dc0 test/udev-test.pl: last_rule is unsupported
  913c72ff2d test/udev-test.pl: fix wrong test descriptions
  eeb25a1be6 test/udev-test.pl: allow checking multiple symlinks
  00ab4292da test/udev-test.pl: test correctness of symlink targets
  5b71ee2911 test/udev-test.pl: use computed devnode name
  2e04bb9ae8 test/udev-test.pl: allow concurrent additions and removals
  8816dd593c test/udev-test.pl: create rules only once
  214418632d test/udev-test.pl: allow multiple devices per test
  1eb6b23f27 udev-test: do not rely on "mail" group being defined
  4a0a4dcf10 udev: Fix sound.target dependency (bsc#1179363)
* Wed Dec 16 2020 Franck Bui <fbui@suse.com>
- Enable support for zstd compression
  systemd-journald will now use zstd for compressing large fields in
  journal files. systemd-coredump will also use this algorithm to
  compress coredump files.
  Please note that systemd older than v246 won't be able to read new
  journal files as zstd algorithm is not supported by these versions.
  This incompatible change was actually not the only one introduced by
  v246 since the hash tables in journal files have been hardened
  against hash collisions too in an incompatible way with older
  versions.
* Mon Dec 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Explicitly require group(kvm) by udev: the group used to be
  created by system-users-hardware, but has been split/moved to
  qemu/kvm, where it is more logical. The file
  /usr/lib/udev/rules.d/50-udev-default.rules references this
  group, thus we should make sure the group exists. Otherwise there
  are errors in the journal in the form of:
  /usr/lib/udev/rules.d/50-udev-default.rules:86 Unknown group 'kvm', ignoring
* Wed Dec  9 2020 Franck Bui <fbui@suse.com>
- Import commit d5e7958d35dc7758fe2e87e0a8193b93ce1a1b15 (merge of v246.7)
  450792497e sd-event: fix delays assert brain-o (#17790)
  1040a19d08 udevadm: rename option '--log-priority' into '--log-level'
  a7b41e19bd udev: rename kernel option 'log_priority' into 'log_level'
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/f6104ea5f554233e34b94ffd92da8332c3bd7d8f...d5e7958d35dc7758fe2e87e0a8193b93ce1a1b15
* Tue Dec  1 2020 Franck Bui <fbui@suse.com>
- Import commit f6104ea5f554233e34b94ffd92da8332c3bd7d8f
  617aed9236 scope: on unified, make sure to unwatch all PIDs once they've been moved to the cgroup scope
* Tue Nov 24 2020 Franck Bui <fbui@suse.com>
- Don't post-require systemd-default-settings-branding anymore
  This is actually not needed now that the branding package issues a
  PID1 reloading every times it's being updated.
* Mon Nov 23 2020 Franck Bui <fbui@suse.com>
- Import commit 49caf8e37aba04841e5493ccc25e7edab462d95b
  f8f7286527 units: restore sysfs conditions in sys-fs-fuse-connections.mount and sys-kernel-config.mount
  e9c7158dc7 units: wait until some fs modules are entirely loaded before mounting their corresponding filesystem (bsc#1178631)
  ac7ddc4201 Revert "units: skip modprobe@.service if the unit appears to be already loaded"
  17310a1d19 core: serialize u->pids until the processes have been moved to the scope cgroup (bsc#1174436)
  1416965614 meson: add option to skip installing to $sysconfdir
  f71a1ef5d0 systemctl: give a nice hint about org.freedesktop.LogControl1 when applicable
  20a3f9fd95 systemctl: immediately reject invalid log levels
  9f67d2e57b systemctl: merge log_target(), log_level(), service_log_setting()
  ddf7cf4872 systemctl: add service-log-{level,target} verbs
  026d7d156d systemctl: list unit introspection verbs first, modification second
* Fri Nov 20 2020 Franck Bui <fbui@suse.com>
- systemd-default-settings is needed by %%post scriptlet
* Tue Nov 17 2020 Franck Bui <fbui@suse.com>
- Revert the change that dropped %%{release} from the package version
  constraints used in Requires:
  The release number is actually relevant since it can be increased
  when some patches, which might touch multiple sub-packages of
  systemd, are added/modified.
  However the %%{release} is still no more used in conflicts.
* Fri Nov  6 2020 Franck Bui <fbui@suse.com>
- Import commit fdce77ce2067f9dd90d816bad28b51efed0b6dc1
  05fff5bd02 generator: use kmsg in system-level generators, journal otherwise
  ecc07954de log: normalize log target condition check
  d32ceea42b log: update comment
  2ebad02b60 basic/virt: Detect PowerVM hypervisor (bsc#1176800)
* Mon Nov  2 2020 Franck Bui <fbui@suse.com>
- Simplify systemd-sysv-convert
  - the previous code incorrectly assumed that the sysv init scripts
    were uninstalled before %%post get executed. It therefore save the
    enablement state in %%pre and restore it in %%post. Now all is done
    in %%post (making --save option useless) and there's no more need
    to remember the enablement state.
  - "--save" option is a NOP but is still kept for backward
    compatibility.
  - the previous simplifcation made /var/lib/systemd/migrated no more
    used.
  - we do not search for units in /lib/systemd anymore, this shouldn't
    be needed anymore these days especially since this path was only
    used when systemd was introduced in openSUSE and it was never used
    in SLE (checked SLE12-GA).
  - the option --show has been dropped. It's never been used even
    internally.
  - the DB is populated only once even if the script was enabled at
    multiple runlevels. The runlevel info was never used. A dummy
    value is still added to keep the same format just in case.
* Wed Oct 21 2020 Franck Bui <fbui@suse.com>
- No more need to clean the journal-upload stuff with --without=journal_remote
  Since -Dremote build option has been introduced with meson, this
  workaround is no more needed.
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Move journal-{remote,upload}.conf.5.gz man pages into systemd-journal_remote sub package
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Explicitly list files in /usr/lib/sysusers.d shipped by the main package
  Currently only one config file is shipped in this directory and we
  want to check any new files that may be added in the future.
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Use %%{_modulesloaddir}, %%{_environmentdir} and %%{_modprobedir} wherever appropriate
* Tue Oct 13 2020 Franck Bui <fbui@suse.com>
- Do not include %%{release} in a few places where we explicitly mention package versions
  It's usually not a good idea especially when used with conflicts.
* Tue Oct 13 2020 Franck Bui <fbui@suse.com>
- Rely on systemd-default-settings for overriding system default settings (bsc#1172517)
  The new branding packages now ships the drop-ins to customize
  systemd either for an openSUSE or a SLE ditro.
* Wed Sep 30 2020 Franck Bui <fbui@suse.com>
- Import commit d7b5ac76dc95ddf30e707d26998e36303e9f52a7 (merge of v246.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/1cab0d44584687ace92d1df30eadf264231e3b65...d7b5ac76dc95ddf30e707d26998e36303e9f52a7
* Tue Sep 29 2020 Franck Bui <fbui@suse.com>
- Ship {/usr/lib,/etc}/systemd/network directories in the main package
  These directories can be used by both udevd and networkd.
* Thu Sep 17 2020 Franck Bui <fbui@suse.com>
- Remove dangling symlink
  /usr/lib/systemd/system/sockets.target.wants/systemd-journald-audit.socket
  Otherwise the build system complains.
* Thu Sep 17 2020 Franck Bui <fbui@suse.com>
- Import commit 1cab0d44584687ace92d1df30eadf264231e3b65 (include v246.5)
  304ec2c7ab fstab-generator: add 'nofail' when  NFS 'bg' option is used (bsc#1176513)
  6ae277fb37 test: adapt TEST-21-SYSUSERS for SUSE
  acd8bfd2cc test: adapt TEST-13-NSPAWN-SMOKE for SUSE
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/a4e393eecb9dbe140a6c7d57419c291d786155cf...1cab0d44584687ace92d1df30eadf264231e3b65
* Wed Sep 16 2020 Franck Bui <fbui@suse.com>
- Drop 0001-udev-temporarly-restore-the-creation-a-few-symlinks-.patch
  linuxrc has already been fixed.
* Wed Sep 16 2020 Franck Bui <fbui@suse.com>
- Add 0001-udev-temporarly-restore-the-creation-a-few-symlinks-.patch
  A temporary patch until the installer environment is updated to
  create some of the symlinks that udevd used to create during its
  startup but now udevd relies on the init system to do so.
* Thu Sep 10 2020 Franck Bui <fbui@suse.com>
- Rework how we prevent journald from both enabling auditd and
  recording audit messages
  journald.conf gained a new setting Audit= to control whether
  journald enables audit during the boot process. So let's use it and
  make sure it's disabled by default by shipping a drop-in that
  overrides upstream default.
  Also we used to patch systemd to prevent journald from reading the
  audit messages. There's still no way for downstream to configure
  that properly (we would need to mask systemd-journald-audit.socket
  meaning shipping a symlink in /etc) but I think dropping
  systemd-journald-audit.socket from the package is a nicer way to do
  that as some users might choose to reenable this setting (by
  reintroducing the socket unit in /etc).
* Thu Sep 10 2020 Franck Bui <fbui@suse.com>
- Enable audit support (bsc#1175883)
  Enabling audit support in systemd will only make PID1 (and some of
  its services) to generate some audit records for certain events. But
  it doesn't affect journald, which has been prevented from recording
  audit messages in the journal (SUSE specific behavior).
* Wed Sep  2 2020 Franck Bui <fbui@suse.com>
- Upgrade to v246.4 (commit f1344d5b7f31e98aedb01e606f41d74d3caaf446)
  See https://github.com/openSUSE/systemd/blob/SUSE/v246/NEWS for
  details.
  Now that the number of SUSE specific patches has been shrinked and
  is pretty low (12 at the time of this writing), they are no more
  tracked by the git repo and are now handled at the package
  level. Hence It is easier to maintain and identify them. This
  effectively means that SUSE/v246 will contain upstream commits only.
  Added 0001-restore-var-run-and-var-lock-bind-mount-if-they-aren.patch
  Added 0002-rc-local-fix-ordering-startup-for-etc-init.d-boot.lo.patch
  Added 0003-strip-the-domain-part-from-etc-hostname-when-setting.patch
  Added 0004-tmpfiles-support-exclude-statements-based-on-file-ow.patch
  Added 0005-udev-create-default-symlinks-for-primary-cd_dvd-driv.patch
  Added 0006-sysv-generator-add-back-support-for-SysV-scripts-for.patch
  Added 0007-networkd-make-network.service-an-alias-of-systemd-ne.patch
  Added 0008-sysv-generator-translate-Required-Start-into-a-Wants.patch
  Added 0009-pid1-handle-console-specificities-weirdness-for-s390.patch
  Added 0010-journald-disable-audit-support-completely-from-the-j.patch
  Added 0011-core-disable-session-keyring-per-system-sevice-entir.patch
  Added 0012-resolved-create-etc-resolv.conf-symlink-at-runtime.patch
* Thu Aug 27 2020 Fabian Vogt <fvogt@suse.com>
- Adjust %%pre and %%post for the restoration of upstream tmp.mount (boo#1175779)
* Wed Aug 26 2020 Franck Bui <fbui@suse.com>
- Import commit a4e393eecb9dbe140a6c7d57419c291d786155cf
  d8e3bd4e22 Revert "core: don't send SIGKILL to user@.service immediatly during shutdown"
* Tue Aug 25 2020 Franck Bui <fbui@suse.com>
- Drop requirement on 'sysvinit-tools'
  It was used to workaround bug #886599 by explicitly calling
  vhangup(8) from getty@.service so when this service was stopped a
  virtually hangup on the specified terminal when were stopped to give
  the shell a few seconds to save its history.
  But this workaround was dropped since it had no effect (SLE12-GM was
  released with it but was still suffering from the bug) and was
  replaced by commit e9db43d5910717a108, which was released from v226
  and backported to SLE12/SLE12-SP1.
* Thu Aug 20 2020 Franck Bui <fbui@suse.com>
- Import commit 6d6d92930acad63f9b9029c305a672c32c550d2d (include merge of v245.7)
  797ad47d3e vconsole-setup: downgrade log message when setting font fails on dummy console (bsc#1172195 bsc#1173539)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/b12cd8b89b4bccfcf972b47153a2b01cd7775932...6d6d92930acad63f9b9029c305a672c32c550d2d
- Drop 0001-Revert-job-Don-t-mark-as-redundant-if-deps-are-relev.patch
  Upstream finally reverted it and it's part of both v245.7 and master.
* Tue Jul 28 2020 Richard Brown <rbrown@suse.com>
- Restore default upstream tmp.mount (/tmp as tmpfs) behaviour (boo#1173461)
* Wed Jun 24 2020 Franck Bui <fbui@suse.com>
- migrate-sysconfig-i18n.sh: fix marker handling  (bsc#1173229)
  The marker is used to make sure the script is run only once. Instead
  of storing it in /usr, use /var which is more appropriate for such
  file.
  Also make it owned by systemd package.
* Tue Jun 23 2020 Franck Bui <fbui@suse.com>
- Fix inconsistent file modes for some ghost files (bsc#1173227)
  Ghost files are assumed by rpm to have mode 000 by default which is
  not consistent with file permissions set at runtime.
  Also /var/lib/systemd/random-seed was tracked wrongly as a
  directory.
  Also don't track (ghost) /etc/systemd/system/runlevel*.target
  aliases since we're not supposed to track units or aliases user
  might define/override.
* Fri Jun 19 2020 Franck Bui <fbui@suse.com>
- Include in the package version the stable minor (if any).
  Also update the version shown by various command such as 'systemctl
  - -version' to show the stable number.
* Wed Jun 17 2020 Franck Bui <fbui@suse.com>
- Don't restart udevd sockets during package update
  Otherwise we might miss kernel events as the daemon need to be
  stopped as well.
* Wed Jun 17 2020 Franck Bui <fbui@suse.com>
- Import commit b12cd8b89b4bccfcf972b47153a2b01cd7775932 (include merge of v245.6)
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/a6d31d1a02c2718a064bbbc40d003668acf72769...b12cd8b89b4bccfcf972b47153a2b01cd7775932
* Thu Jun  4 2020 matthias.gerstner@suse.com
- no longer explicitly package setgid directory /var/log/journal (bsc#1172550).
  The bit will be set during %%post by way of the systemd-tmpfiles invocation.
  This avoids a conflict with the permissions package and an rpmlint error
  popping up.
* Fri May 29 2020 Franck Bui <fbui@suse.com>
- Fix build when resolved is disabled
  While at it sort the build conditionals.
* Thu May 28 2020 Franck Bui <fbui@suse.com>
- Import commit a6d31d1a02c2718a064bbbc40d003668acf72769
  bb6e2f7906 pid1: update manager settings on reload too (bsc#1163109)
  e9e8907b06 watchdog: reduce watchdog pings in timeout interval
  385a8f9846 udev: rename the persistent link for ATA devices (bsc#1164538)
  66018a12ae tmpfiles: remove unnecessary assert (bsc#1171145)
* Mon May 25 2020 Franck Bui <fbui@suse.com>
- Disable bump of /proc/sys/fs/nr-open
  Hopefully a _temporary_ workaround until bsc#1165351 is fixed
  otherwise user instances crashes the system is using NIS (and the
  nscd cache is empty).
* Mon Apr 27 2020 Franck Bui <fbui@suse.com>
- Drop legacy /sbin/{udevd,udevadm) symlinks hopefully for good
  Since boo#1160890 has been fixed since a couple of months now.
* Mon Apr 27 2020 Franck Bui <fbui@suse.com>
- Drop content of /usr/share/factory/ (bsc#1170146)
  systemd ships several files in /usr/share/factory/etc that are
  copied to /etc in case those files are missing there. Unfortunately
  the content does not match the openSUSE defaults.
* Mon Apr 27 2020 Franck Bui <fbui@suse.com>
- Drop most of the tmpfiles that deal with generic paths (bsc#1078466 bsc#1181831)
  They are problematic because some of them conflict with SUSE
  defaults. Therefore it seems better to let the revelant packages
  owning these paths to provide their own definitions instead.
  Meanwhile we still keep the homeless definitions in suse.conf until
  a better place is found for them.
  Drop 0001-Fix-run-lock-group-to-follow-openSUSE-policy.patch
  Drop 0001-SUSE-policy-do-not-clean-tmp-by-default.patch
* Fri Apr 24 2020 Franck Bui <fbui@suse.com>
- Drop %%tmpfiles_create portables.conf from %%post of networkd sub-package
  It was probably mistakenly added because systemd-portable served as
  template for systemd-network.
* Thu Apr 23 2020 Franck Bui <fbui@suse.com>
- Import commit 08cd65ac385c884ed6e4bd71128a0796f56ecd17 (include merge of v245.5)
  1ceedf8535 meson: fix build of udev 'path_id_compat' builtin with meson 0.54
  e61569d4a9 pid1: by default make user units inherit their umask from the user manager (bsc#1162698)
  64fdacd5f1 user-util: rework how we validate user names (bsc#1170272)
  [...]
  For a complete list of changes, visit:
  https://github.com/openSUSE/systemd/compare/c5aa158173ced05201182d1cc18632a25cf43b94...08cd65ac385c884ed6e4bd71128a0796f56ecd17
* Thu Apr 23 2020 Franck Bui <fbui@suse.com>
- Drop 0001-meson-fix-build-of-udev-path_id_compat-builtin-with-.patch
  It's been merged in 'openSUSE-Factory' branch otherwise this branch
  won't build anymore since meson has been upgraded to version 0.54 in
  Factory.
* Wed Apr 15 2020 Franck Bui <fbui@suse.com>
- Switch back to the hybrid hierarchy
  Unfortunately Kubernetes and runc are not yet ready for
  cgroupsv2. Let's reconsider the unified hierarchy in a couple of
  months.
* Mon Apr  6 2020 Franck Bui <fbui@suse.com>
- Import commit c5aa158173ced05201182d1cc18632a25cf43b94 (merge v245.4)
* Mon Apr  6 2020 Franck Bui <fbui@suse.com>
- Add 0001-meson-fix-build-of-udev-path_id_compat-builtin-with-.patch
* Thu Mar 19 2020 Franck Bui <fbui@suse.com>
- Import commit 31f82b39c811b4f731c80c2c2e7c56a0ca924a5b (merge v245.2)
  d1d3f2aa15 docs: Add syntax for templated units to systemd.preset man page
  3c69813c69 man: add a tiny bit of markup
  bf595e788c home: fix segfault when parsing arguments in PAM module
  e110f4dacb test: wait a bit after starting the test service
  e8df08cfdb fix journalctl regression (#15099)
  eb3a38cc23 NEWS: add late note about job trimming issue
  405f0fcfdd systemctl: hide the 'glyph' column when --no-legend is requested
  1c7de81f89 format-table: allow hiding a specific column
  b7f2308bda core: transition to FINAL_SIGTERM state after ExecStopPost=
  2867dfbf70 journalctl: show duplicate entries if they are from the same file (#14898)
  [...]
* Wed Mar 18 2020 Franck Bui <fbui@suse.com>
- Upgrade to v245 (commit 74e2e834b4282c9bbdc12014f6ccf8d86e542b8d)
  See https://github.com/openSUSE/systemd/blob/SUSE/v245/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit 7f56982289275ce84e20f0554475864953e6aaab (CVE-2020-1712)
  - upstream commit 66a19d85a533b15ed32f4066ec880b5a8c06babd (bsc#1157315)
  - upstream commit 7f56982289275ce84e20f0554475864953e6aaab (bsc#1162108)
  The new tools provided by systemd repart, userdb, homed, fdisk,
  pwquality, p11kit feature have been disabled for now as they require
  reviews first.
  Default to the "unified" cgroup hierarchy. Indeed most prominent
  users of cgroup (such as libvirt, kubic) should be ready for such
  change. It's still possible to switch back to the old "hybrid"
  hierarchy by passing "systemd.unified_cgroup_hierarchy=0" option to
  the kernel command line though.
  Added 0001-Revert-job-Don-t-mark-as-redundant-if-deps-are-relev.patch:
  upstream commit 097537f07a2fab3cb73aef7bc59f2a66aa93f533 has been
  reverted for now on as it introduced a behavior change which has
  impacted plymouth at least.
* Fri Mar 13 2020 Elisei Roca <eroca@suse.com>
- add systemd-network-generator.service file together with systemd-network-generator binary
* Wed Feb 19 2020 Ludwig Nussel <lnussel@suse.de>
- move html documentation to sparate package to save space
- move networkd and resolved binaries into correct subpackage
* Thu Feb  6 2020 Franck Bui <fbui@suse.com>
- Import commit f8adabc2b1f3e3ad150e7a3bfa88341eda5a8a57 (merge v244.2)
  77c04ce5c2 hwdb: update to v245-rc1
  b4eb884824 Fix typo in function name
  e2d4cb9843 polkit: when authorizing via PK let's re-resolve callback/userdata instead of caching it
  83bfc0d8dd sd-bus: introduce API for re-enqueuing incoming messages
  5926f9f172 polkit: use structured initialization
  0697d0d972 polkit: on async pk requests, re-validate action/details
  2589995acd polkit: reuse some common bus message appending code
  5b2442d5c3 bus-polkit: rename return error parameter to ret_error
  0a19ff7004 shared: split out polkit stuff from bus-util.c → bus-polkit.c
  1325dfb577 test: adapt to the new capsh format
  3538fafb47 meson: update efi path detection to gnu-efi-3.0.11
  3034855a5b presets: "disable" all passive targets by default
  c2e3046819 shared/sysctl-util: normalize repeated slashes or dots to a single value
  6f4364046f dhcp6: do not use T1 and T2 longer than one provided by the lease
  0ed6cda28d network: fix implicit type conversion warning by GCC-10
  f6a5c02d26 bootspec: parse random-seed-mode line in loader.conf
  ddc5dca8a7 sd-boot: fix typo
  2bbbe9ae41 test: Synchronize journal before reading from it
  072485d661 sd-bus: fix introspection bug in signal parameter names
  80af3cf5e3 efi: fix build.
  [...]
* Mon Feb  3 2020 Franck Bui <fbui@suse.com>
- Use suse.pool.ntp.org server pool on SLE (jsc#SLE-7683)
* Tue Jan 21 2020 Franck Bui <fbui@suse.com>
- Drop scripts-udev-convert-lib-udev-path.sh
  Nobody should need it these days.
* Tue Jan 14 2020 Franck Bui <fbui@suse.com>
- Temporarily restore /sbin/{udevd,udevadm) obsolete symlinks
  They're restored until YaST stop using them (see boo#1160890)
* Tue Jan 14 2020 Franck Bui <fbui@suse.com>
- Import commit 8254b8d9646f3e0f5f8057d1ffb5d6c20f079aaa (merge v244.1)
  639dc9f4bf network: set ipv6 mtu after link-up or device mtu change
  cbced49daa man: fix typo in net-naming-scheme man page
  7dd04c99b0 network: tc: drop unused element
  bf4b7d07ba man: fix typos (#14304)
  1ba2e7a730 ipv4ll: do not reset conflict counter on restart
  49806bb310 macro: avoid subtraction overflow in ALIGN_POWER2()
  c4c1600689 test-network: add a test case for SendOption=
  6f15b45949 network: fix segfault in parsing SendOption=
  2e531b830d seccomp: real syscall numbers are >= 0
  f7616ed52b network: fix copy and paste mistake
  e8b53300c4 network: do not drop foreign config if interface is in initialized state
  00f05813bf seccomp: mmap test results depend on kernel/libseccomp/glibc
  4de1909e61 seccomp: use per arch shmat_syscall
  d83010521d seccomp: ensure rules are loaded in seccomp_memory_deny_write_execute
  2c6568221a seccomp: fix multiplexed system calls
  bcf0aa02bf Fix typo (duplicate "or")
  96d7083c54 network: if /sys is rw, then udev should be around
  e874419902 nspawn: do not fail if udev is not running
  29c9144655 Create parent directories when creating systemd-private subdirs
  9cbb8b5254 network: do not return error but return UINT64_MAX if speed meter is disabled
  c08429ae33 core: swap priority can be negative
  f25c0be335 networkctl: fix to show BSSID
  65fd2fce59 systemctl: enhance message about kexec missing kernel
  bdd0af5f81 Fixup typo in NEWS
* Wed Dec 11 2019 Franck Bui <fbui@suse.com>
- Manually set system-uid-max and system-gid-max to 499
  It used to be detected automatically by meson but it's been broken
  by the migration of login.defs from /etc to /usr/etc.
* Wed Dec 11 2019 Franck Bui <fbui@suse.com>
- Import commit d8f6a204858bff68b8e0e7be86b418c36087ab2e
  6c5e492a65 cryptsetup: umount encrypted devices before detaching it during shutdown
* Thu Dec  5 2019 Franck Bui <fbui@suse.com>
- Upgrade to v244 (commit 090da85161ceb1ba0b4c208963c7156a8fdf10c6)
  See https://github.com/openSUSE/systemd/blob/SUSE/v244/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit b49e14d5f3081dfcd363d8199a14c0924ae9152f (bsc#1139459)
  - upstream commit 22683674716fd0e5b016ce5a7d8fd90df5f9f9e7 (bsc#1151377)
  - upstream commit faf205de3ba9a11b0ba17682123d7f3fedc7da24 (bsc#1151377)
  - upstream commit 27c3112dcbd1b5f171c36c32550d9c6331375b0b (bsc#1155574)
  - upstream commit 21b40f16622f171a9969dc334d74fb5eb2f575c2 (bsc#1159814)
  - upstream commit 9b88bb5023dfa3cea406c14fdaa3d8e3e320907a (jsc#SLE-7689)
  - upstream commit bc9ecd484f1ebfe0de8b567c90f6cd867fbd5894 (bsc#1141597)
  Legacy and obsolete symlinks have been finally dropped.
  Dropped 0001-logind-keep-backward-compatibility-with-UserTasksMax.patch.
  Users were notified about the deprecation of UserTasksMax option and
  how to move to the new mechanism. The dropin replacement for
  UserTasksMax is therefore no more generated but its use still
  produces a warning.
  Added 0001-SUSE-policy-do-not-clean-tmp-by-default.patch and
  0001-Fix-run-lock-group-to-follow-openSUSE-policy.patch.
  These patches were extracted from the git repo because it's not
  clear where the SUSE tmpfiles specificities should be located.
* Tue Dec  3 2019 Franck Bui <fbui@suse.com>
- Import commit dbb1d4734daffa62e0eddecfa4f784c84a9d8e76
  1439d72a72 udevd: don't use monitor after manager_exit()
  99288dd778 Revert "udevd: fix crash when workers time out after exit is signal caught"
  152577d6d0 udevd: fix crash when workers time out after exit is signal caught
  f854991504 udevd: wait for workers to finish when exiting (bsc#1106383)
  Changes from the v243-stable (84 commits):
  e51d9bf9e5 man: add entry about SpeedMeter=
  aa1fc791c7 udev: silence warning about PROGRAM+= or IMPORT+= rules
  b9a619bb67 udevadm: ignore EROFS and return earlier
  1ec5b9f80c basic: add vmware hypervisor detection from device-tree
  7fa7080248 umount: be happy if /proc/swaps doesn't exist
  [...]
  47d0e23d26 udev: fix memleak caused by wrong cleanup function
  a6fb0542c5 parse_hwdb: fix compatibility with pyparsing 2.4.*
  cb1d892f17 parse_hwdb: process files in order
* Tue Nov 12 2019 Franck Bui <fbui@suse.com>
- Import commit 0b715187a87907e18edf98eab9d0a50fced4a424
  9dbdbc2f10 logind: fix (again) the race that might happen when logind restores VT (bsc#1101591 bsc#1140081)
  c848bec110 libblkid: open device in nonblock mode. (bsc#1084671)
  b70ad6c927 resolved: check for IP in certificate when using DoT with GnuTLS (bsc#1155539 CVE-2018-21029)
  bbedf3d557 resolved: require at least version 3.6.0 of GnuTLS for DNS-over-TLS
  eb732c2e29 resolved: fix connection failures with TLS 1.3 and GnuTLS
  4e45084ac5 shared/install: failing with -ELOOP can be due to the use of an alias in install_error()
  2e297f0d87 shared/install: fix error codes returned by install_context_apply()
  dd29d70d32 man: alias names can't be used with enable command
* Tue Nov  5 2019 Franck Bui <fbui@suse.com>
- Fix %%{_libexecdir} misuses of /usr/lib
* Thu Oct 31 2019 Franck Bui <fbui@suse.com>
- Drop 0001-compat-rules-escape-when-used-for-shell-expansion.patch
  It's part of the previous import.
* Thu Oct 31 2019 Franck Bui <fbui@suse.com>
- Import commit b7467b7b553d6d0d6f92758d966b69f1a88b6b42
  441f44f371 fileio: introduce read_full_virtual_file() for reading virtual files in sysfs, procfs (bsc#1133495)
  8a1bb5c66b swap: do not make swap units wanted by its device unit anymore
* Tue Oct 29 2019 Franck Bui <fbui@suse.com>
- Import commit 5df9000899ef7d45ddbcacd0fdf73afa07a40f6b
  f0ed7237e4 udev/cdrom_id: Do not open CD-rom in exclusive mode. (bsc#1154256)
  b37054aa5a compat-rules: escape '$' when used for shell expansion
  Changes from the v243-stable:
  ef677436aa test: Pass personality test even when i686 userland runs on x86_64 kernel
  3f6398c450 docs: fix inadvertent change in uid range
  25bb377a73 cgroup: fix typo in BPF firewall support warning message
  6d97aca0d5 fix build with compilers with default stack-protector enabled
  fbad077cec nspawn: surrender controlling terminal to PID2 when using the PID1 stub
  0553c3c668 pid1: fix DefaultTasksMax initialization
  f406a691a7 src/core/automount: use DirectoryMode when calling mkdir -p
  20438f96c3 udevadm trigger: do not propagate EACCES and ENODEV
  6480630bc3 hwdb: Correct WWWW Pattern In Documentation Comment
  9d8e889810 nspawn: consistenly fail if parsing the environment fails
  40e169b304 nspawn: default to unified hierarchy if --as-pid2 is used
  b5df1037a0 cgroup: Mark memory protections as explicitly set in transient units
  f14e3e02cc cgroup: Respect DefaultMemoryMin when setting memory.min
  ea248e53bf cgroup: Check ancestor memory min for unified memory config
  de1d25a506 cgroup: docs: memory.high doc fixups
  2ab45f38d8 cgroup: docs: Mention unbounded protection for memory.{low,min}
  19a43dc38a Consider smb3 as remote filesystem
  5c0224c7bf Handle d_type == DT_UNKNOWN correctly
  8282bc61df util-lib: Don't propagate EACCES from find_binary PATH lookup to caller
  9d0ae987a6 network: drop noisy log message
  f67f0e4ec4 Updated log message when the timesync happens for the first time (#13624)
  e151bf4674 units: make systemd-binfmt.service easier to work with no autofs
  2b8e574d82 Corect man page reference in systemd-nologin.conf comments
  a0577353f1 man: Add a missing space in machinectl(1)
  693e983988 log: Add missing "%%" in "%%m" log format strings
  ea7151b8c4 pid1: do not warn if /run/systemd/relabel-extra.d/ doesn't exist
  b90549290e man: fix typo
* Tue Oct 22 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove intltool BuildRequires, not needed since v237
- Use python3-base BuildRequires instead of full python3
* Mon Oct 21 2019 Franck Bui <fbui@suse.com>
- Add 0001-compat-rules-escape-when-used-for-shell-expansion.patch (bsc#1153648)
  Added to the quaratine area to avoid uploading a new tar ball just
  for that single change. It will be dropped during the next import.
* Mon Oct 21 2019 Ludwig Nussel <lnussel@suse.de>
- don't package locales in -mini package
* Fri Oct  4 2019 Franck Bui <fbui@suse.com>
- Import commit 428b937f917ae177f2315e8469800941885e441a
  0026b58744 pid1: fix DefaultTasksMax initialization
* Mon Sep 30 2019 Franck Bui <fbui@suse.com>
- Import commit ed81f69153488279957268e247a5c81b678da491 (changes from v243-stable)
  fab6f010ac dhcp6: use unaligned_read_be32()
  f2d9af4322 dhcp6: add missing option length check
  ccf797511e ndisc: make first solicit delayed randomly
  f2275b6e12 dhcp6: read OPTION_INFORMATION_REFRESH_TIME option
  6dfbe58ee7 l10n: update Czech Translation
  d4cd0e9d32 sd-radv: if lifetime < SD_RADV_DEFAULT_MAX_TIMEOUT_USEC, adjust timeout (#13491)
  dbefe59259 polkit: fix typo
  a321507476 sd-netlink: fix invalid assertion
  45dca7fe86 network: do not enter failed state if device's sysfs entry does not exist yet
  dd83d58796 network: add missing link->network checks
  b294305888 path: stop watching path specs once we triggered the target unit
  2cd636c437 hwdb: add Medion Akoya E2292 (#13498)
  d133bdd1fa po: update Brazilian Portuguese translation
  530e09b594 po: update Polish translation
  0c5c3e34c1 polkit: change "revert settings" to "reset settings"
  73e0f372d8 man: fix description of ARPIntervalSec= units
  5412cc54a1 hwdb: axis override for Dell 9360 touchpad
  9d4e658529 test: drop the missed || exit 1 expression
  7ed7ea82f6 udevadm: use usec_add()
  477bf86c91 udevadm: missing initialization of descriptor
  19ac31c989 networkd: unbreak routing_policy_rule_compare_func()
  a20a2157a8 core: coldplug possible nop_job
  eb55241742 tty-ask-pwd-agent: fix message forwarded to wall(1)
  1a3c53c06c core: Fix setting StatusUnitFormat from config files
  91db81e4dd network DHCP4: Dont mislead the logs.
  6af590838b Update m4 for selective utmp support.	modified:   tmpfiles.d/systemd.conf.m4
  6823c907cf core: restore initialization of u->source_mtime
  29308bcc13 mount-setup: relabel items mentioned directly in relabel-extra.d
  8ca1e56165 Call getgroups() to know size of supplementary groups array to allocate
  5d84a7ad1c test: add test cases for empty string match
  1536348cc8 udev: fix multi match
  3ccafef0ad man: move TimeoutCleanSec= entry from .service to .exec
  8c0c30a820 zsh: udpate bootctl completions
  0556c247a2 resolved: fix abort when recv() returns 0
  9a25d75520 man: remove repeated words
  be3be29347 hwdb: Also mark lis3lv02d sensors in "HP" laptops as being in the base
  4b92ffccaa udev: also logs file permission
  75a2845e5a udev: add missing flag for OPTIONS=static_node
  19e9fc4262 network: do not abort execution when a config file cannot be loaded
  3e1267cf50 fileio: update warning message
  1b3156edd2 pstore: fix use after free
  f500d2fa81 journal: Make the output of --update-catalog deterministic
  64d0f7042d travis: protect the systemd organization on Fuzzit from forks
  4247938ee1 hwdb: Mark lis3lv02d sensors in HP laptops as being in the base
  379158684a po: update Japanese translation
  31e1bbd1ca docs: fix push recipe in RELEASE.md
  f06530d86b man/systemctl.xml: fix missing "not"
  22aba2b969 docs: fix typo in boot loader doc
  000e08ca70 pstore: fix typo in error message - directoy -> directory
  f7f9c69ac5 Fix typo in comment: overide -> override
  ca8ba8f8c0 po: update Polish translation
* Mon Sep 23 2019 Franck Bui <fbui@suse.com>
- Some files related to the portable stuff were missing some %%exclude
* Thu Sep 19 2019 Martin Vidner <mvidner@suse.com>
- Allow YaST to select Iranian (Persian, Farsi) keyboard layout
  (bsc#1092920)
* Wed Sep 18 2019 Ludwig Nussel <lnussel@suse.de>
- split off networkd and resolved into separate network subpackage
- use separate lang package for translations
* Wed Sep 18 2019 Franck Bui <fbui@suse.com>
- Import commit 9e41d7ec3572d8d5ea1e00f683e9fbf8108e85b4
  fb1b9d54f9 tty-ask-pwd-agent: fix message forwarded to wall(1)
  dd14da3bb6 core: restore initialization of u->source_mtime
  d62f30f647 resolved: create /etc/resolv.conf symlink at runtime
* Wed Sep 18 2019 Franck Bui <fbui@suse.com>
- Slighly rework (mostly reorganization) the portable stuff
* Fri Sep  6 2019 Franck Bui <fbui@suse.com>
- Track 0001-resolved-create-etc-resolv.conf-symlink-at-runtime.patch
  in the git repo
  This patch has been in the quarantine area long enough, so let's
  move it in the git repo.
* Tue Sep  3 2019 Franck Bui <fbui@suse.com>
- Upgrade to v243 (commit e0b24c4356aa0c1c56ff274ff72228f33482a5be)
  See https://github.com/openSUSE/systemd/blob/SUSE/v243/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit b2774a3ae692113e1f47a336a6c09bac9cfb49ad (CVE-2019-20386 bsc#1161436)
  - upstream commit 5406c36844b35504a64e9f05fc74b8e5e5a09143 (bsc#1132400)
  - upstream commit 83a32ea7b03d6707b8e5bb90a0b3a6eb868ef633 (bsc#1132721)
  - upstream commit 7cc5ef5f1811c539ae7f20255c2a093f413cc64f (bsc#1172824 bsc#1142733)
  - upstream commit 83cb24ac20baf19f7834931dcf6e03486b4c9c30 (bsc#1156213)
  - upstream commit a2dcb1d78737d3daa301ee63fbdd02837acb71a8 (bsc#1158485)
  - upstream commit 08185cff19efcb1d7d9fb7b546e7f516ab6dae91 (bsc#1165011)
  - upstream commit 59c55e73eaee345e1ee67c23eace8895ed499693 (bsc#1177510)
  Drop 0001-Revert-insserv.conf-generator.patch as it's been dropped
  from branch SUSE/v243 while we were rebasing.
  Drop 0001-rc-local-generator-deprecate-halt.local-support.patch as
  this functionality had been deprecated during the previous release
  and now have been dropped by upstream.
* Wed Aug 14 2019 Ludwig Nussel <lnussel@suse.de>
- Enable systemd-portabled (jsc#SLE-21695)
* Wed Jul 31 2019 Franck Bui <fbui@suse.com>
- systemd-container creates and owns /etc/systemd/nspawn now
* Mon Jul 22 2019 Franck Bui <fbui@suse.com>
- Import commit 0f9271c1336c5c9055e75389732a44745d796851 (changes from v242-stable)
  07f0549ffe network: do not send ipv6 token to kernel
  9d34e79ae8 systemd-mount: don't check for non-normalized WHAT for network FS
  5af677680c core: set fs.file-max sysctl to LONG_MAX rather than ULONG_MAX (bsc#1142099)
  29dda7597a random-util: eat up bad RDRAND values seen on AMD CPUs
  eb6c17c178 util-lib: fix a typo in rdrand
  829c20dc8e random-util: rename "err" to "success"
  5442366fbf man: rework the description of Aliases and .wants/.requires directories
  ae71c6f634 docs: typo in arg name replace-irreversible -> replace-irreversibly
  09774a5fcb meson: make nologin path build time configurable
  69ffeeb0b1 man: add note about systemctl stop return value
  4cf14b5513 shared/conf-parser: say "key name" not "lvalue", add dot
  4481ca7f86 shared/conf-parser: emit a nicer warning for something like "======"
  46f3db894b shared/conf-parser: be nice and ignore lines without "="
  7d928995f7 nspawn: fix memleak in argument parsing
  7727e6c0ae resolve: fix memleak
  7f32a81976 journal: properly read unaligned le64 integers
  fa419099e5 activate: move array allocation to heap
  815a9fef2a systemctl: print non-elapsing timers as "n/a" not "(null)"
  a4fc3c88f1 factory: include pam_keyinit.so in PAM factory configuration
  a453d63315 factory: add comment to PAM file, explaining that the defaults are not useful
  d9a5a70a59 factory: tighten PAM configuration
  5e2d3bf80b test: make sure colors don't confuse our test
  5fe3be1334 wait-online: change log level
  c49b6959d5 systemctl: emit warning when we get an invalid process entry from pid1 and continue
  3c9f43eb03 systemctl: do not suggest passing --all if the user passed --state=
  5964d1474e man: offline-updates: make dependence on system-update.target explicit
  a04dd26e03 alloc-util: drop _alloc_ decorator from memdup_suffix0()
  7c46a694ca man: add example for setting multiple properties at once
  1d72789271 man: CPUShares= is so 2015
  45da304673 man: document that WakeSystem= requires privs
  bed58a06e4 man: document that "systemd-analyze blame/critical-chain" is not useful to track down job latency
  c5461f31b3 man: be more explicit that Type=oneshot services are not "active" after starting
  455ee07abe man: document that the supplementary groups list is initialized from User='s database entry
  5f0cb2616a alloc-util: drop _alloc_(2, 3) decorator from memdup_suffix0_multiply()
  7bc336794d generator: downgrade Requires= → Wants= of fsck from /usr mount unit
  66465c4381 systemctl: allow "cat" on units with bad settings
  ca937b49da pid1: fix serialization/deserialization of commmands with spaces
  4bb3113023 growfs: call crypt_set_debug_level() correctly, skip if not needed
  0db716771e cryptsetup: enable libcryptsetup debug logging if we want it
  c8b9b3956f cryptsetup: set libcryptsetup global log callback too
  679b3f6b7f basic/log: fix SYSTEMD_LOG_* parsing error messages
  8d6b5158aa units: add SystemCallErrorNumber=EPERM to systemd-portabled.service
  6681fcd445 network: fix the initial value of the counter for brvlan
  853ec5f458 man: Add some notes about variable $prefix for StateDirectory=
  e6d23358e9 sd-netlink: fix inverted log message
  6feb862407 blockdev: filter out invalid block devices early
  9f7c0dbc75 blockdev-util: propagate actual error
  3f5355bcb9 man: document tmpfiles.d/ user/group resolvability needs
  c15b92cd98 man: fix wrong udev property name
  9768a900d6 meson: drop duplicated source
  15194f22ed cryptsetup-generator: fix luks-* entry parsing from crypttab
  c2475390b4 core: skip whitespace after "|" and "!" in the condition parser
  fdc754aeb7 shared/condition: fix printing of ConditionNull=
  572385e135 test: add testcase for issue #12883
  9aa1edddb0 conf-parser: fix continuation handling
  8fbc72f45f networkd: fix link_up() (#12505)
* Mon Jul  1 2019 Franck Bui <fbui@suse.com>
- State directory of systemd-timesync might become inaccessible after upgrading to v240+ (bsc#1137341)
  This happens for users who had previously used systemd-timesync with
  DynamicUser=true, ie the ones who upgraded from a systemd version
  between v235 and v239 to systemd v240 and later (v240 was the
  version where DynamicUser was switched back to OFF).
* Tue May 28 2019 Franck Bui <fbui@suse.com>
- Import commit eaa7b8b148927d471609de75e542dffcc1b36df4
  7e58b89136 udevd: change the default value of udev.children-max (again) (bsc#1107617)
* Tue May 28 2019 Franck Bui <fbui@suse.com>
- Add 0001-rc-local-generator-deprecate-halt.local-support.patch
  /etc/init.d/halt.local support will removed from the next systemd
  version (v243) so for now on warn (hopefully the few) users who rely
  on this script so they have a chance to switch to systemd-shutdown
  interface.
* Mon May 27 2019 Franck Bui <fbui@suse.com>
- Add 0001-Revert-insserv.conf-generator.patch (bsc#1052837)
  All remaining packages have been fixed so they don't rely on the
  insser-generator to generate proper deps. So let's drop it as all
  services should carry the proper dependencies itself.
* Mon May 27 2019 Franck Bui <fbui@suse.com>
- Drop debug-only-remove-new-policies.patch
  The new DBUS methods have been reviewed by the security team.
* Tue May 14 2019 Franck Bui <fbui@suse.com>
- Import commit 9984a86d0d2259d54c7060f9c09f214202b4efa7
  f2459bf373 random-util: eat up bad RDRAND values seen on AMD CPUs
  c90a2e9793 util-lib: fix a typo in rdrand
  4db1cc9d46 random-util: rename "err" to "success"
  981a62a102 random-util: hash AT_RANDOM getauxval() value before using it
  64a9c3d918 random-util: use gcc's bit_RDRND definition if it exists
  c5d6ecfdca random-util: rename RANDOM_DONT_DRAIN → RANDOM_MAY_FAIL
  298d13df7e network: remove redunant link name in message
  77cbde31f2 hwdb: Align airplane mode toggle key mapping for all Acer series
  460f03794e Revert "hwdb: Apply Acer mappings to all Gateway and Packard Bell models"
  fe9271ad84 test: return a non-zero return code when 'nobody' user doesn't exist
  29d355e755 fstab-generator: Prevent double free of reused FILE*
  f30f1adc11 meson: make source files including nspawn-settings.h depend on libseccomp
  84bab914b8 alloc-util: don't use malloc_usable_size() to determine allocated size
  5240972d8d units: drop reference to sushell man page
  0a26de5e33 codespell: fix spelling errors
  582de105c8 nspawn-expose-ports: fix a typo in error message
* Mon May 13 2019 Franck Bui <fbui@suse.com>
- Buildrequire polkit so /usr/share/polkit-1/rules.d has an owner (bsc#1145023)
  Otherwise the "post build checks" would complain and would force
  systemd to own this directory. The owner should still be "polkit"
  and the perms should be in sync with the perm set by polkit
  itself.
* Thu May  9 2019 Franck Bui <fbui@suse.com>
- Add debug-only-remove-new-policies.patch
  A temporary patch to suppress the new DBUS methods introduced by
  v242 until they are reviewed and whitelisted by the secteam.
* Thu May  9 2019 Franck Bui <fbui@suse.com>
- Add a comment explaining why static enablement symlinks in /etc are suppressed
  Also remove any /etc/systemd/system/*.requires/ symlinks for the
  same reason.
* Thu May  2 2019 Franck Bui <fbui@suse.com>
- preset remote-cryptsetup.target during package installation
  This target is supposed to be part of the targets that should be
  enabled (or not depending on the presets) at package installation.
* Thu May  2 2019 Franck Bui <fbui@suse.com>
- Upgrade to v242 (commit 071c380dcc434dca2a0c8b6de0519cc9e816c6d6)
  See https://github.com/openSUSE/systemd/blob/SUSE/v242/NEWS for
  details.
  This includes the following bug fixes:
  - upstream commit bf65b7e0c9fc215897b676ab9a7c9d1c688143ba (CVE-2019-3843)
  - upstream commit bf65b7e0c9fc215897b676ab9a7c9d1c688143ba (CVE-2019-3844)
  - upstream commit 37ed15d7edaf59a1fc7c9e3552cd93a83f3814ef (bsc#1124122)
  - upstream commit bf65b7e0c9fc215897b676ab9a7c9d1c688143ba (bsc#1133506)
  - upstream commit bf65b7e0c9fc215897b676ab9a7c9d1c688143ba (bsc#1133509)
  - upstream commit 1f82f5bb4237ed5f015daf93f818e9db95e764b8 (bsc#1150595)
  - upstream commit e55bdf9b6c5f72475b258a7a4585a0480551cb60 (bsc#1173422)
* Wed Apr 24 2019 Franck Bui <fbui@suse.com>
- Drop "BuildRequires:  -post-build-checks" from the specfile (bsc#1130230)
  The syntax of this directive is obsolete and should be replaced by
  "#!BuildIgnore: post-build-checks".
  However there's no good reasons to disable these SUSE extra checks,
  so let's re-enable them and fix the few errors it detected.
* Fri Apr 12 2019 Franck Bui <fbui@suse.com>
- Import commit 4e6e66ea94cf5125f9044f0869939a86801ed2d8
  430877e794 pam-systemd: use secure_getenv() rather than getenv() (bsc#1132348 CVE-2019-3842)
  3cff2e6514 man: document that if the main process exits after SIGTERM we go directly to SIGKILL
  26c4f7191c bus: fix memleak on invalid message
* Tue Mar 19 2019 Franck Bui <fbui@suse.com>
- systemd-coredump: generate a stack trace of all core dumps (bsc#1128832 jsc#SLE-5933)
  This stack trace is logged to the journal.
* Mon Mar 11 2019 Franck Bui <fbui@suse.com>
- Stop installing macros.systemd
  There're no points in installing this file if we remove it right
  after.
* Mon Mar 11 2019 Franck Bui <fbui@suse.com>
- Make sure systemd-network.rules take precedence over our polkit-default-privs (bsc#1125438)
* Thu Mar  7 2019 Franck Bui <fbui@suse.com>
- Include the SUSE version along with the major version of systemd
  $ systemctl --version
  systemd 241 (+suse.42.g15a1b4d58)
  Note that the SUSE version format maybe subject to change and as
  such scripts should not try to parse it.
* Wed Mar  6 2019 Franck Bui <fbui@suse.com>
- systemd-mini: explicitly disable some of the systemd components
  For some reasons, some build requirements get pulled in for the mini
  variant now, enabling some parts of the code that were expected to
  be turned OFF.
* Tue Mar  5 2019 Franck Bui <fbui@suse.com>
- Upgrade to v241 (commit 15a1b4d58f1d2bc9c21c7cbab6fe63b58e48bda1)
  This includes the following bug fixes:
  - upstream commit c0d76959080e3ba6534bce1c7053c750668e8b55 (bsc#1160595)
  - upstream commit 7334ade4a7e103b1a01d1c8fe1ea7c7a854a1c31 (bsc#1123892)
  - upstream commit c7e93c4d15019323973baf12daa76357c83892c4 (boo#1111498)
  This also includes the following bug fixes released in v240:
  - upstream commit 2675747f3cdd6f1e6236bbb2f79abfa53fb307f1 (boo#1111498)
  - upstream commit 9eb0fc32d6cb63e71f2cfc1e7dd34c3ede4b48a3 (bsc#1140631)
  - upstream commit 1432d2dbdfa90963272a9b581dc4b55dd3ac514f (bsc#1155574)
  - upstream commit 26e35b164b8d0603629b3d394554cfa728e8c3e4 (bsc#1169488)
  - upstream commit a9fc640671ef60ac949f1ace6fa687ff242fc233 (fate#325697)
* Tue Feb 19 2019 Franck Bui <fbui@suse.com>
- Import commit a1d86af7ed49dacef671e8ec8dae9472a8fa47f5
  92d860fc12 sysctl: Don't pass null directive argument to '%%s' (bsc#1121563)
  1379e30d59 Allocate temporary strings to hold dbus paths on the heap (bsc#1125352 CVE-2019-6454)
  b5569a03ae Refuse dbus message paths longer than BUS_PATH_SIZE_MAX limit. (bsc#1125352 CVE-2019-6454)
* Fri Feb 15 2019 Franck Bui <fbui@suse.com>
- Import commit 01b4746d3c6f6cbf969fa2176c77ac3f616a7eda
  7af53e005b sd-bus: if we receive an invalid dbus message, ignore and proceeed
  92dcbfdd7f bus: move BUS_DONT_DESTROY calls after asserts
  a83e7b3b43 automount: don't pass non-blocking pipe to kernel.
  726127ea1d units: make sure initrd-cleanup.service terminates before switching to rootfs (bsc#1123333)
  a6347a3cb6 core: Fix use after free case in load_from_path() (bsc#1121563)
  22e2550222 strv: rework FOREACH_STRING() macro (bsc#1121563)
  2ddd38f41a test,systemctl,nspawn: use "const char*" instead of "char*" as iterator for FOREACH_STRING()
  c2c8333e0b strv: add new macro STARTSWITH_SET()
  1db243a601 Update systemd-system.conf.xml (bsc#1122000)
* Tue Jan 15 2019 Franck Bui <fbui@suse.com>
- Import commit ad34cc45f63720ced69960dc66b47bddb146176d
  Import a bunch of fixes from stable/v239-stable:
  c8293f5af4 Revert "network: set DynamicUser= to systemd-networkd.service"
  7f605592e6 Revert "resolve: enable DynamicUser= for systemd-resolved.service"
  5a48e92e06 test: Fix networkd test for an already running service
  36eae1688b Revert "timesyncd: enable DynamicUser="
  3a11f24cf0 Revert "unit: drop After=systemd-sysusers.service from timesyncd"
  23cfd15ce9 machinectl: fix verbosity of import-raw or friends
  ba037daf29 Make bzip2 an optional dependency for systemd-importd
  fb609d2721 pull: initialize libgcrypt before calling any functions provided by libgcrypt
  c50857bc6b hwdb: remove stray 'i' in hwdb match string for the HP Spectre (#9571)
  9a12fd17f5 man: Mention that paths in unit files must be fully normalized.
  76fc2ab4a6 tree-wide: use  instead of #ifdef for HAVE_*
  fcc699c093 network: update log message
  a4f497b2cd Use #if instead of #ifdef for ENABLE_GSHADOW
  121c662eb8 man: add missing option for system.conf
  564341146e core: add missing option and drop nonexistent option in system.conf
  7082a3599f journal: add missing option in journald.conf
  3c15efa9c1 basic: add missing comma in raw_clone assembly for sparc
  4c210b6dce cryptsetup: Add dependency on loopback setup to generated units
  c777fbbe3e journal-gateway: use localStorage["cursor"] only when it has valid value
  c5b1bef639 journal-gateway: explicitly declare local variables
  2361522ca6 analyze: actually select longest activated-time of services
  3e810d92d9 sd-bus: fix implicit downcast of bitfield reported by LGTM
  aef660a4cf resolvconf: fixes for the compatibility interface
  06b3f54f50 install: fix error handling in is_symlink_with_known_name()
  f70ab9a468 portable: fix error handling
  d2c40d4e80 resolve: fix return value type of dns_answer_has_dname_for_cname()
  6f684e0670 resolve: dns_scope_network_good() does not returns negative errno
  15d83e1138 bus-util: fix error handling
  ba0a1f3384 core: free lines after reading them
* Thu Jan 10 2019 Franck Bui <fbui@suse.com>
- Import commit 3bece8a25ae11e8ec132cdecc7e72a00ee790994
  89a9721a47 Revert "logind: become the controlling terminal process before restoring VT" (bsc#1120836)
  c3a8dc821b pam_systemd: reword message about not creating a session
  0ba0f5b3ef pam_systemd: suppress LOG_DEBUG log messages if debugging is off
* Thu Jan 10 2019 Franck Bui <fbui@suse.com>
- Import commit a3b059a8c60622e4ec30aabda93c6b41d0953dc4
  9dbe9f12ec journal-remote: set a limit on the number of fields in a message (CVE-2018-16865 bsc#1120323)
  61d569ab1b journal-remote: verify entry length from header
  a08760b26c µhttpd: use a cleanup function to call MHD_destroy_response
  43f46a1a3d journal-gateway: use _cleanup_ attribute to stop microhttpd daemon
  437b0b2d01 journald: lower the maximum entry size limit to ½ for non-sealed fds
  ac9e209710 journald: when processing a native message, bail more quickly on overbig messages
  ce103705b9 journald: set a limit on the number of fields (1k) (CVE-2018-16865 bsc#1120323)
  35538171c2 coredump: fix message when we fail to save a journald coredump
  cfe247b555 basic/process-util: limit command line lengths to _SC_ARG_MAX
  9d59e6f6ee journald: do not store the iovec entry for process commandline on stack (CVE-2018-16864 bsc#1120323)
  8d650a68d4 journald: remove unnecessary {}
  b608f532a4 coredump: remove duplicate MESSAGE= prefix from message
  0dbb2dc066 vconsole-setup: fonts copy will fail if the current terminal is in graphical mode (bsc#1114933)
  e501d65540 Revert "systemctl: when removing enablement or mask symlinks, cover both /run and /etc"
  d3ea69961f fs-util: rename safe_transition() into unsafe_transition()
  338470fdc9 tmpfiles: use CHASE_WARN in addition to CHASE_SAFE
  d9ae1b30da fs-util: make chase_symlink() returns -ENOLINK when unsafe transitions are met
  8b76594d1f fs-util: add new CHASE_WARN flag to chase_symlinks()
* Tue Dec  4 2018 Franck Bui <fbui@suse.com>
- Import commit 8ae56af7802ef8f91fac64fa244d62a4468fbbd5
  4474878178 udev-builtin-kmod: adjust logging
  805534aff5 core: use the generic module_load() function
  ac7e902530 shared/module-util: fix preexisting mixup with errno sign
  415aa40793 udev-builtin-kmod: use the generic module_load() function
  8a36b4bac6 Move module-util.h to src/shared/ and load_module() to libshared
  999b910752 core/kmod-setup: restore comments
  1f2b822a21 logind: stop managing VT switches if no sessions are registered on that VT
  5ad8d374c5 terminal-util: introduce vt_release() helper
  145d492490 logind: become the controlling terminal process before restoring VT (bsc#1101591)
  d4b5dbc033 terminal-util: introduce vt_restore() helper
  2e8af185f0 logind: make session_restore_vt() static
  ff3048364f udev: downgrade message when we fail to set inotify watch up (bsc#1005023)
* Fri Nov 23 2018 Franck Bui <fbui@suse.com>
- Fix the test for figuring out if /etc/machine-id is writable in %%post (bsc#1117063)
  "test -w" always returns true for root user even if the writable
  mode bits are not set. Fix this by testing the file mode bit value
  instead.
* Fri Nov 23 2018 Franck Bui <fbui@suse.com>
- Move systemd-sysv-convert from /usr/sbin to /usr/lib/systemd
  This tool is not supposed to be run by users.
* Fri Nov 16 2018 Franck Bui <fbui@suse.com>
- Import commit 69f9f79e1b03e3d23df25b61cbcc9304af3e358f (bsc#1080919 CVE-2018-6954)
  f3615ce49 tmpfiles: don't adjust qgroups on existing subvolumes (bsc#1093753)
  7165e92f4 tmpfiles: use fd_get_path() even less excessively
  c2c531c1d test: make TEST-22 easier to debug, by outputting to /dev/console
  621b78317 test: don't use "nobody:nogroup" for tests
  1f9c7acad tmpfiles: return correct error variable after fd_reopen()
  2236280c1 tmpfiles: reindent one comment less weirdly
  f6bdfb889 tmpfiles: use correct error variable
  bc75127cd tmpfiles: clarify that we ignore file attribute setting errors
  621c8b1fe tmpfiles: add log message where we previously failed silently
  bc9229630 tmpfiles: use fd_get_path() less excessively
  5a1106039 tmpfiles: add more tests
  c974086cc tmpfiles: don't follow unsafe transitions in path_set_*()
  e64a510eb fs-util: add new CHASE_NOFOLLOW flag to chase_symlinks()
  7480154d0 tmpfiles: make create_fifo() safe
  eb890962c fs-util: introduce mkfifoat_atomic() helper
  653bb81af fileio: make tempfn_random_child() accept empty string as path
  2b1e12bfe tmpfiles: introduce create_fifo()
  6dd80f289 tmpfiles: introduce empty_directory()
  f2c137edf tmpfiles: introduce create_directory() and create_subvolume() and make them safe
  6a76f6dfb basic/stat-util: introduce is_dir_fd()
  38a7f2e81 btrfs-util: unfuck tmpfiles' subvol creation
  26e19b6fe btrfs-util: introduce btrfs_subvol_make_fd()
  5fb5bdf5d basic/label: introduce mkdirat_label()/mkdirat_errno_wrapper() helpers
  390b767da selinux: introduce mac_selinux_create_file_prepare_at()
  0f72fadba smack: introduce mac_smack_fix_at()
  f2838154b tmpfiles: introduce create_directory_or_subvolume()
  2de697fb8 tmpfiles: make create_device() safe
  558c5fec7 tmpfiles: introduce create_device()
  dee986b1d tmpfiles: make copy_files() safe
  cacb14d3f tmpfiles: introduce copy_files() routine
  81c85ce17 tmpfiles: make write_one_file() safe
  9ec6b92ab tmpfiles: make truncate_file() safe
  8dde36e03 tmpfiles: introduce truncate_file() which deals with 'F' exclusively
  481134a93 tmpfiles: introduce create_file() which deals with 'f'/'F' exclusively
  057861560 tmpfiles: make the stat struct parameter in fd_set_*() optional
  f37caffda tmpfiles: stat file in item_do() rather than in its callers
  86f1362d4 tmpfiles: set only default acls to folders #9545 (#9599)
* Fri Nov  9 2018 Franck Bui <fbui@suse.com>
- Make systemd-mini-sysvinit provides systemd-sysvinit
  Some packages (such as shepherd-bins) want to conflicts with
  systemd-sysvinit: they should also conflict with
  systemd-mini-sysvinit.
* Wed Nov  7 2018 Franck Bui <fbui@suse.com>
- Add 0001-logind-keep-backward-compatibility-with-UserTasksMax.patch
  We have to keep support for UserTasksMax= for a while before
  dropping it. This patch is supposed to do that and also to make
  users aware of this change. It also hints how to configure that
  differently.
* Wed Nov  7 2018 Franck Bui <fbui@suse.com>
- Import commit f39674d6d114d999c50672c7bea8cad21e1eaed9
  7d1e04e85 units: use =yes rather than =true everywhere
  185ce0d34 units: assign user-runtime-dir@.service to user-%%i.slice
  a051f5e41 units: make sure user-runtime-dir@.service is Type=oneshot
  30c6842c3 units: set StopWhenUnneeded= for the user slice units too
  e74de046e login: fix typo in log message
* Mon Nov  5 2018 Franck Bui <fbui@suse.com>
- Own %%{_libexecdir}/modules-load.d (again)
  This was incorrectly dropped during the split of the SUSE specific
  configurations.
* Fri Nov  2 2018 Franck Bui <fbui@suse.com>
- Drop a Conflicts: in systemd-coredump
  It not needed anymore since the mini variant of systemd-coredump is
  not built anymore.
* Fri Nov  2 2018 Franck Bui <fbui@suse.com>
- Import commit b54f5d7a8b41898ce98f43cd1a6cc92c0071806d
  5def29d24 coredump: only install coredump.conf when ENABLED_COREDUMP=true
  9133e2d6e dhcp6: make sure we have enough space for the DHCP6 option header (bsc#1113632 CVE-2018-15688)
  ebc3fa418 dhcp6: split assert_return() to be more debuggable when hit
  51eefb6ac chown-recursive: let's rework the recursive logic to use O_PATH (bsc#1113666 CVE-2018-15687)
  e1e1aa237 core: skip unit deserialization and move to the next one when unit_deserialize() fails
  1c726c87d core: when deserializing state always use read_line(…, LONG_LINE_MAX, …) (bsc#1113665 CVE-2018-15686)
  4cd7d11ac core: don't create Requires for workdir if "missing ok" (bsc#1113083)
* Fri Nov  2 2018 Franck Bui <fbui@suse.com>
- Make systemd-coredump sub-package optional
  and don't build the mini variant.
* Fri Nov  2 2018 Franck Bui <fbui@suse.com>
- Drop duplicated %%{?mini} suffix for systemd-{container,coredump} subpackages
  "-mini" is already part of the name of the main package so there's
  no need to append it again for those sub packages. It's only needed
  when the name of a subpackage is completely redefined, IOW when '-n'
  option is used with the %%package directive.
* Fri Nov  2 2018 Franck Bui <fbui@suse.com>
- Dont ship /usr/sbin/resolvconf symlink for now
  It conflicts with the bin shipped by openresolv and provides
  limited compat only.
* Wed Oct 24 2018 Franck Bui <fbui@suse.com>
- Upgrade to v239 (commit 6d8584e7e8e5d13d2bab49b9e6f6d2ec39759978)
  This includes the following bug fixes:
  - upstream commit 0722b359342d2a9f9e0d453875624387a0ba1be2 (bsc#1045723)
  - upstream commit 2f2e14b251b9929e84e8b690d0187b766dfbae20 (bsc#1124122)
  - upstream commit c839b729c5f7b08f6d91bf9567d0b1f91d17e0f7 (bsc#1155207)
  - upstream commit 8eebb6a9e5e74ec0ef40902e2da53d24559b94a4 (bsc#1168076)
  This also includes the following bug fixes released in v238:
  - upstream commit e8a3144ec4ff332bd63644e468a98e1a7e06e7e4 (bsc#1112024)
  - upstream commit 4d219f5343b1924e7c519c2c178aeb5d1a5ab924 (bsc#1123727)
  - upstream commit 43b7f24b5e0dd048452112bfb344739764c58694 (bsc#1146991)
  - upstream commit bf443be99565e4327f1c8c12b79d98b4c1529cf1 (bsc#1156213)
* Mon Oct 15 2018 Franck Bui <fbui@suse.com>
- Ship systemd-sysv-install helper via the main package
  This script was part of systemd-sysvinit sub-package but it was
  wrong since systemd-sysv-install is a script used to redirect
  enable/disable operations to chkconfig when the unit targets are
  sysv init scripts. Therefore it's never been a SySV init tool.
  While at it, don't ship this script (as well as
  systemd-sysv-convert) when sysvcompat is not defined.
* Mon Oct 15 2018 Franck Bui <fbui@suse.com>
- Import commit 19b3868d32af20f1ecc86fe3c997144ff456fd65
  06c2284d64 core: introduce systemd.early_core_pattern= kernel cmdline option
  479b002083 core: add missing 'continue' statement
  c7fbccc62e journald: don't ship systemd-journald-audit.socket (bsc#1109252)
  f17a6c790c detect-virt: do not try to read all of /proc/cpuinfo (bsc#1109197)
  5a1aa84544 compat-rules: generate more compat by-id symlinks for NVMe devices (bsc#1095096)
* Fri Sep 28 2018 fbui@suse.com
- Import commit a67b516d49115a5be0f2ac27a2874cee6c59a7ae
  f8457adf9d emergency: make sure console password agents don't interfere with the emergency shell
  b8bbb50634 man: document that 'nofail' also has an effect on ordering
  a5410b2229 journald: take leading spaces into account in syslog_parse_identifier
  b793c312c7 journal: do not remove multiple spaces after identifier in syslog message
  f9595f0481 syslog: fix segfault in syslog_parse_priority()
  d464f06934 journal: fix syslog_parse_identifier()
  e70422883a socket-util: attempt SO_RCVBUFFORCE/SO_SNDBUFFORCE only if SO_RCVBUF/SO_SNDBUF fails (bsc#991901)
* Fri Sep 28 2018 Thomas.Blume@suse.com
- split off SUSE specific udev rules from systemd package (fate#325478)
  * remove 60-io-scheduler.rules
  * remove 80-hotplug-cpu-mem.rules
  * remove 99-wakeup-from-idle.rules
  * remove /usr/lib/modules-load.d/sg.conf (see bsc#1036463 for details)
  these are now maintained in the new package system-tuning-common-SUSE
* Fri Sep 14 2018 fbui@suse.com
- Enable or disable machines.target according to the presets (bsc#1107941)
* Fri Sep 14 2018 fbui@suse.com
- Import commit cc55f1ea9e1c1ccab5b9fb97e10e08830d02b282
  962b38aaf user@.service: don't kill user manager at runlevel switch (bsc#1091677)
  3986c4d82 units: make sure user@.service runs with dbus still up
  5e68aa0f2 Revert "udevd: increase maximum number of children" (bsc#1107617)
  099138fd9 fix race between daemon-reload and other commands (v237) (bsc#1105031)
* Tue Sep 11 2018 fbui@suse.com
- Import commit 6ac2232d88f4b64428511a4692a51bd00d610b32
  6247696db nspawn: always use mode 555 for /sys (bsc#1107640)
  72f558b57 cryptsetup: do not define arg_sector_size if libgcrypt is v1.x (#9990)
  cfcd97cf2 cryptsetup: add support for sector-size= option (#9936) (fate#325634)
* Wed Aug  8 2018 fbui@suse.com
- Import commit bb5a925bcefd4743873cae3f748ae1a426e92d44
  8983bd246 core: don't include libmount.h in a header file (#8580)
  3e4156a8f tmpfiles: don't adjust qgroups on existing subvolumes (bsc#1093753)
  42edc93ac core/service: rework the hold-off time over message
* Wed Aug  1 2018 fbui@suse.com
- Enable regexp matching support
  Currently only used by "journalctl --grep=xxx".
* Fri Jul 27 2018 fbui@suse.com
- Import commit 0350f62a8cf7f151951b6b78337fe3c198b8bf6a
  fbf43a697 core: don't freeze OnCalendar= timer units when the clock goes back a lot (bsc#1090944)
  4134ba8b6 man: SystemMaxUse= clarification in journald.conf(5) (bnc#1101040)
  78bb2a0c4 socket-util: fix getpeergroups() assert(fd) (#8080) (bsc#1096516)
  1753d0420 systemctl: mask always reports the same unit names when different unknown units are passed (bsc#1095973)
  50ebf79d7 scsi_id: Fixup prefix for pre-SPC inquiry reply (bsc#1039099)
  570f7655b locale-util: on overlayfs FTW_MOUNT causes nftw(3) to not list *any* files
* Mon Jun 25 2018 fbui@suse.com
- Drop runtime dependency on dracut (bsc#1098569)
  Otherwise systemd pulls in tools to generate the initrd even in
  container/chroot installations that don't have a kernel anyways.
  For environments where initrd matters, dracut should be pulled via a
  pattern.
* Wed Jun 13 2018 fbui@suse.com
- Import commit f63623c1fc0eb01b8efc2037d004f42ed8328356
  6a161916f device: make sure to always retroactively start device dependencies (take #2) (bsc#1088052)
  e4402648c Fix pattern to detect distribution
  ad59c7970 install: "user" and "global" scopes are equivalent for user presets (boo#1093851)
  b1876c81a rpm: remove confusing --user before --global
  00ea8a214 man: updated systemd-analyze blame description for service-units with Type=simple (#8834) (bsc#1091265)
  a9b587e2f fileio.c: fix incorrect mtime
* Tue Jun 12 2018 fbui@suse.com
- Add 0001-resolved-create-etc-resolv.conf-symlink-at-runtime.patch (boo#1024897)
- Ship systemd-resolved (but disabled by default) (bsc#1018387)
* Fri May 18 2018 fbui@suse.com
- Disable user units by default (bsc#1090785)
* Mon May 14 2018 fbui@suse.com
- Slight rewrite of the previous fix
* Tue May  8 2018 Thomas.Blume@suse.com
- align permissions of /etc/machine-id to upstream code (bsc#1092269)
  world writeable machine-id is a security issue
* Mon Apr 23 2018 fbui@suse.com
- Move 80-container-v[ez].network in systemd-container sub-package
- Move 80-container-host0.network from udev to systemd
* Mon Apr 23 2018 fbui@suse.com
- Import commit d8196805089566ecd846b7c627ff2f3c42588c50
  621b247f3 device: skip deserialization of device units when udevd is not running
  a7da5bdbc device: make sure to always retroactively start device dependencies (bsc#1088052)
  303624f6f systemd-udevd: limit children-max by available memory (#8668) (bsc#1086785 bsc#1066422)
  76acf3ae9 tmpfiles: fix directory removal with force symlink (#8619)
* Fri Apr 20 2018 fbui@suse.com
- Ship 99-sysctl.conf instead of creating it during package installation/update (bsc#1088769)
  Previously this symlink was created in /etc/sysctl.d during %%post
  which made the symlink not owned and more importantly it was created
  only if /etc/sysctl.conf is already installed which is not always
  the case during the installation process it seems.
  So ship the symlink unconditionally and put it in /usr/lib/sysctl.d
  instead since it's a distro default behavior that might be overriden
  by sysadmin later.
* Mon Apr  9 2018 fbui@suse.com
- Be consistent in 60-io-scheduler.rules
  And use "?*" when checking for the non empty string (instead of "*?").
* Wed Apr  4 2018 fbui@suse.com
- /usr/lib/systemd/systemd-coredump was missing from systemd-coredump sub-package (boo#1088057)
* Wed Mar 28 2018 fbui@suse.com
- Drop systemd-bash-completion sub-package
  Now we directly ship the completion scripts from the main package as
  we already do for zsh. I couldn't see any advantages in this split.
* Wed Mar 28 2018 fbui@suse.com
- Be more accurate when specifiying the tools version we provide
* Wed Mar 28 2018 fbui@suse.com
- Make sure rpm won't expand %%autopatch even if it's commented
* Wed Mar 28 2018 fbui@suse.com
- stat(1) as well as systemctl are not use in %%post section of udev
  So remove stat(1) from the list of dep and move systemctl to the
  requirements of %%postun since it's called from there.
* Wed Mar 28 2018 fbui@suse.com
- Import commit 14b3e00c3ccb8c1c82c8a2e99a9534750880a09e
  e0a8285e2 pid1: when creating service directories, don't chown existing files (#8181) (boo#1085971)
  fb25886b1 Fix format-truncation compile failure by typecasting USB IDs (#8250) (bsc#1084638)
  5a6e9c92e sysusers: make sure to reset errno before calling fget*ent()
  c2e1ee488 sysusers: also add support for NIS entries in /etc/shadow
  51cb94fa1 sysusers: do not append entries after the NIS ones (bsc#1085062 bsc#1045092)
  783f3d368 basic/macros: rename noreturn into _noreturn_ (#8456)
- Drop 0001-basic-macros-rename-noreturn-into-_noreturn_.patch
  It's been merged in the git repo.
* Wed Mar 28 2018 fbui@suse.com
- Rename the tarball (bsc#1087323)
  So it's clear that it contains some additional patches on top of the
  upstream version. Use the commit hash in the name so the exact
  version can easily be identified.
  Provide _service file which can be used to retrieve the tarball from
  the git repo (with "osc service disabledrun").
* Wed Mar 28 2018 fbui@suse.com
- Split systemd-coredump sub-package off (bsc#1083849)
* Tue Mar 27 2018 develop7@develop7.info
- Enhance IO scheduler tweaking rules to support blk-mq as well
  * Set optimal blk-mq schedulers (bfq and mq-deadline for HDD and
    SSD respectively)
  * Explicitly set CFQ for rotational disks when no `elevator`
    is specified
  * Verbose comments explaining what is going on
  * Rename the rules file since it is not ssd-only anymore
* Tue Mar 27 2018 fbui@suse.com
- Don't ship machines.target in systemd-container but in systemd main package
  machines.target is supposed to be a standard target for
  starting/stopping all containers. systemd-nspawn is the main user of
  it but other container managers could also make use of it.
* Sun Mar 25 2018 fbui@suse.com
- Build a mini variant of systemd-container
  So we don't have to manually track and remove all files that should
  be shipped by systemd-container in the case of a bootstrap build.
* Thu Mar 22 2018 fbui@suse.com
- Run migrate-sysconfig-i18n.sh also during package installation (bsc#1086164)
  This is needed when we upgrade from SLE11.
* Wed Mar 14 2018 fbui@suse.com
- Add 0001-basic-macros-rename-noreturn-into-_noreturn_.patch
  This fix a build error triggered by the introduction of the new
  version of libgpg-error package. Patch submitted to upsream:
  https://github.com/systemd/systemd/pull/8456
* Wed Mar 14 2018 fbui@suse.com
- Turn off the IP sandboxing for systemd-logind
  Since v235 logind run inside an IPv4/IPv6 sandbox by default. This
  creates incompatibilites for systems using NIS.
* Tue Mar 13 2018 fbui@suse.com
- Restore (maybe temporarly) "pam_config --add systemd"
  During its installation pam-config seems to overwrite the defaults
  shipped by "pam" for "some" reasons (see bsc#1084924)
  No idea why but since pam_systemd is not part of the "pam-config"
  defaults, we need to restore pam_systemd in common-session
  manually...
* Fri Mar  9 2018 fbui@suse.com
- Remove dropin that was used to turn delegation off for user instances
  Upstream now enables "memory" and "pids" controllers only which
  should have a very limited impact on performance compare to the
  "cpu" controller.
* Fri Mar  9 2018 fbui@suse.com
- Import commit 46d6bc9c4f1c05f3b4fcfca754cc59963bd86ce3
  2a79f4e78 units: delegate "memory" instead of "cpu" by default for user instances (#8320) (bsc#954765 bnc#953241 fate#320421)
  88174ae85 compat-rules: fix syntax errors spotted by test/rule-syntax-check.py
* Thu Mar  8 2018 fbui@suse.com
- Remove udev-remount-tmpfs script
  Complete the previous commit.
* Thu Mar  8 2018 fbui@suse.com
- Fix hotplug memory in 80-hotplug-cpu-mem.rules
  When new memory was hotplugged, the rule was supposed to call an
  external script (udev-remount-tmpfs) to remount all tmpfs. However
  the script was broken since its introduction (commit rev=715,
  14/07/2014) and had no effects... this makes me wonder if we
  shouldn't get rid of this...
* Wed Mar  7 2018 fbui@suse.com
- Make sure /var/lib/machines is created when systemd-container is installed
* Thu Mar  1 2018 fbui@suse.com
- BS forces us to own %%{_prefix}/lib/modprobe.d
  This seems wrong but that's how the SUSE BS works.
* Thu Mar  1 2018 fbui@suse.com
- Upgrade to v237 (commit 78221ca750a9c266f9f8497dda59d7ee44000a6c)
  Udev rules 60-ssd-scheduler.rules and 80-hotplug-cpu-mem.rules have
  been removed from the git repo and are now maintained at the package
  level. Those rules have been rejected by upstream as they seem to be
  written to workaround some kernel shortcomings...
  This includes the following bug fix:
  - upstream commit 3d083b2245b0b8e52f2d8ccc3e55246f41f1f544 (bsc#1102908)
  This also includes the following bug fixes released in v235:
  - upstream commit 2e64e8f46d726689a44d4084226fe3e0ea255c29 (bsc#1069239)
  - upstream commit 79873bc850177050baa0c5165b119adafeebb891 (bsc#1069239)
  - upstream commit 4bc5d27b942afa83cc3d95debd2ad48d42ac07a8 (bsc#1089376)
  - upstream commit e9ea4526a3a3b41eced29b8d742498cc36750424 (bsc#1089693)
  - upstream commit d75b31837c93dbb9b20067719026ad0fb7cdfadd (bsc#1117025)
  - upstream commit 0e8856d25ab71764a279c2377ae593c0f2460d8f (bsc#1117025)
  - upstream commit 048dd629c4590eefb2ebd6a316c7350ed3a6ff19 (bsc#1119971)
  - upstream commit 9b32afa9f241fe8febc0a754850f1e7331caf6e3 (bsc#1126056)
  - upstream commit e6dde451a51dc5aaa7f4d98d39b8fe735f73d2af (bsc#1137053)
  - upstream commit 0864d311766498563331f486909a0d950ba7de87 (bsc#1158336)
  - upstream commit d60cb656fc63c24b430421764b7d0322857d34fd (bsc#1161262)
  - upstream commit e2be442e791fa1150aa835c684acc6d7189de3e1 (bsc#1165011)
  - upstream commit 64a36ae4b1dd23474dd7ea261381ac437b24fac2 (bsc#1172072)
  - upstream commit b001ad61e91b6499897f0c977045c7608c233bfa (jsc#SLE-7687)
  - includes IP filtering feature (jsc#SLE-7743)
  This also includes the following bug fixes released in v236:
  - upstream commit b3b4ebab02395933cde554b5a5d5c363dae3920d (bsc#1083571)
  - upstream commit 3e3852b3c6c61506963112fd218a86b673fc61e6 (bsc#1110445)
  - upstream commit 4050e4797603d3644707d58edfd9742b5311c7cf (bsc#1124153)
  - upstream commit 8cb83266062b383cdd4a57301ef559d64b491c51 (bsc#1125604)
  - upstream commit 19a44dfe4525ab01caf593a9c2beada4b412910d (bsc#1156482)
* Wed Feb 28 2018 Thomas.Blume@suse.com
- add basic user space support for suspend to idle (fate#323814)
    add 99-wakeup-from-idle.rules
    Currently this only covers the power button and usb/AT keyboards
    as wakeup devices. It is planned to make that configurable in
    the future.
* Tue Feb 27 2018 fbui@suse.com
- Don't call "pam-config --systemd"
  pam_systemd.so has been integrated directly in the PAM stack since
  bsc#812462. So there's no need to call pam-config.
* Mon Feb 26 2018 fbui@suse.com
- Fix build errors due to the split-off of systemd-containe:
  found conflict of systemd-234-33.1.x86_64 with systemd-container-234-33.1.x86_64:
  - /usr/share/man/man5/systemd.nspawn.5.gz
  - /usr/share/man/man1/systemd-nspawn.1.gz
  found conflict of systemd-container-234-33.1.x86_64 with systemd-mini-container-234-33.1.x86_64:
  - /usr/bin/systemd-nspawn
  - /usr/lib/systemd/system/systemd-nspawn@.service
  - /usr/lib/tmpfiles.d/systemd-nspawn.conf
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Thu Feb 22 2018 fbui@suse.com
- Split systemd-container sub-package off (fate#325469)
  Other distros already do it and it seems a good idea to not install
  this stuff on new installations by default. At least
  /var/lib/machines subvol is not created anymore at boot even if it
  wasn't used at all.
* Mon Feb 19 2018 fbui@suse.com
- Import commit 295ead0f396beb2b5199abd99a17e274c2581f95
  f4f94ab2e meson: install rules/80-hotplug-cpu-mem.rules
  2901aa9b9 meson: install rules/60-ssd-scheduler.rules
  1293c0056 core: use id unit when retrieving unit file state (#8038) (bsc#1075801)
  596b2b241 Revert "vconsole-setup: add SUSE specific settings for font/keyboard in sysconfig"
  0b595da04 Revert "locale-setup: handle locale at boot time well"
* Mon Feb 19 2018 fbui@suse.com
- Re-enable systemd-firstboot
  It's used by the installer and also by JeOS.
* Mon Feb 19 2018 fbui@suse.com
- Use %%systemd_post in %%post
* Mon Feb 19 2018 fbui@suse.com
- Own /usr/lib/systemd/system-environment-generators directory
* Mon Feb 19 2018 fbui@suse.com
- More systemd rpm macro usages
* Tue Feb 13 2018 fbui@suse.com
- Disable systemd-firstboot
  I don't think there's any use case for it currently.
* Mon Feb 12 2018 fbui@suse.com
- Use systemd rpm macros in paths defined in the specfile
* Mon Feb 12 2018 fbui@suse.com
- Stop importing i18n settings from /etc/sysconfig (fate#319454)
  Bits taken from SLE15.
* Mon Feb 12 2018 fbui@suse.com
- Make systemd-timesyncd use the openSUSE NTP servers by default
  Previously systemd-timesyncd used the Google Public NTP servers
  time{1..4}.google.com
* Fri Feb  9 2018 fbui@suse.com
- Import commit 4a6a1e4f0b02e6cedf7eba93b85a6dd968f875c7
  db1d8eacd compat-rules: make path_id_compat build with meson
- Drop 0001-compat-rules-make-path_id_compat-build-with-meson.patch
  which is now part of the git repo (see above).
* Fri Feb  9 2018 fbui@suse.com
- Don't ship /usr/lib/systemd/system/tmp.mnt at all (bsc#1071224)
  The previous fix couldn't work on platforms using a RO
  rootfs. Therefore we don't ship /usr/lib/systemd/system/tmp.mnt but
  we still ship a copy in /usr/share/systemd.
  Users who want to use tmpfs on /tmp are supposed to add a symlink in
  /etc/ pointing to the copy shipped in /usr/share/systemd.
  To support the update path we automatically create the symlink if
  tmp.mount in use is located in /usr/lib/systemd.
* Tue Feb  6 2018 fbui@suse.com
- Don't build seccomp support in the mini package
* Tue Feb  6 2018 fbui@suse.com
- Switch to Meson build system
  Some rearrangement in the file list was also needed. That was
  probably due to the upgrade of rpm.
* Tue Feb  6 2018 fbui@suse.com
- Import commit 0a5600eb7f8263c7c79fec0d85cc159d54aba636
  2a181fc6f insserv-generator: make it build with meson
  7b0401da4 build-sys: don't build networkctl if networkd is disabled
* Tue Feb  6 2018 fbui@suse.com
- Don't build-require selinux for the mini package
* Tue Feb  6 2018 fbui@suse.com
- Drop libgcrypt.m4
  The mini package builds fine without it so it doesn't seem necessary
  anymore.
* Mon Feb  5 2018 fbui@suse.com
- Import commit 846d838c37865da60eba48090e570e959291399f
  b1e0a348d fileio: include sys/mman.h
  f1fa784cb meson: update header file to detect memfd_create()
  8838ba7ec meson: define _GNU_SOURCE to detect copy_file_range() (#7734)
  531a00c84 Restore "restore /var/run and /var/lock bind mount if they aren't symlink""
  (the 3 first commits make systemd build against glibc 2.27)
* Mon Feb  5 2018 fbui@suse.com
- Import commit 3f421e4fbf6fcb31d74caf729435868ba8824483
  7fb9ea39a Revert "restore /var/run and /var/lock bind mount if they aren't symlink"
  23ce1207a meson.build: make docdir configurable (#8068)
* Fri Feb  2 2018 fbui@suse.com
- Import commit 8ec9f58d334c76e736957812d9e57151502a6f63
  07c6ee3eb compat-rules: get rid of scsi_id when generating compat symlinks for NVMe devices (bsc#1051465)
  261a4ef38 compat-rules: generate compat by-id symlinks with 'nvme' prefix missing (bsc#1063249)
* Fri Feb  2 2018 fbui@suse.com
- Drop 0001-compat-rules-get-rid-of-scsi_id-when-generating-comp.patch
  It's been imported in branch "compats/udev-compat-symlinks" which
  has been merged in branch "openSUSE-Factory" in its turn.
* Fri Feb  2 2018 fbui@suse.com
- Import commit c516268845b0fd0683cef2e491b84077371e8f01
  37da1facb core: disable session keyring per system sevice entirely for now (bnc#1045886)
  8a1ae0449 strv: fix buffer size calculation in strv_join_quoted()
* Fri Feb  2 2018 fbui@suse.com
- Drop 0001-core-disable-session-keyring-per-system-sevice-entir.patch
  It's been merged in branch "SUSE/v234".
* Wed Jan 31 2018 fbui@suse.com
- Import commit 2087a80d56bb6f8c7fb74a19172259bc9d9af866
  2b8971b8a tmpfiles: refuse to chown()/chmod() files which are hardlinked, unless protected_hardlinks sysctl is on (bsc#1077925 CVE-2017-18078)
  8c2bcac25 tmpfiles: change ownership of symlinks too
* Mon Jan 29 2018 fbui@suse.com
- Do not optionally remove /usr/lib/systemd/system/tmp.mnt anymore (bsc#1071224)
  This was done to make sure that tmpfs wouldn't be used for /tmp by
  defaut in case the dir layout created by the installer did not
  create a customized tmp.mount.
  But it had the bad side effect to break "rpm -V systemd" and updates
  of systemd via delta-RPMs.
  Now instead of removing tmp.mount unit file, we mask it (still only
  if no other tmp.mount would override the default one). It's the
  official way to disable tmpfs on /tmp after all.
  Since we cannot rely on the presence of fstab during package
  installations, we introduced a service which is run once on the
  first boot and which figures out if tmpfs would be used. If so it
  masks the unit.
  We also handle the upgrade path and make sure to preserve admin's
  settings (if any).
  Another advantage of this is that we will only need to remove the
  introduced service the day when tmpfs will be the default for SUSE
  distros.
* Fri Jan 26 2018 fbui@suse.com
- Import commit 83067827cc891ddc90def200fdbe725917ec9fa3
  3d60486f7 core/timer: Prevent timer looping when unit cannot start (bsc#1068588)
  460bd0cd6 Revert "handle SYSTEMCTL_OPTIONS environment variable" (fate#323393)
* Tue Jan 16 2018 fbui@suse.com
- Import commit cc94ce8513221061898c83f57862544b16021f0e
  aa3eba828 delta: don't ignore PREFIX when the given argument is PREFIX/SUFFIX
  b1ea0173a delta: extend skip logic to work on full directory paths (prefix+suffix) (bsc#1070428)
  77c5065f9 delta: check if a prefix needs to be skipped only once
  db32866d1 Fix parsing of features in detect_vm_xen_dom0 (#7890) (bsc#1048510)
  11d40461a sd-bus: use -- when passing arguments to ssh (#6706)
  1148d99f6 tmpfiles: consider /etc uninitialized also when /etc/machine-id is present but empty (#7849) (bsc#1075179)
  3a95f69bf tmpfiles: downgrade warning about duplicate line
* Fri Jan 12 2018 rbrown@suse.com
- Edit scripts-systemd-fix-machines-btrfs-subvol.sh
  We shouldn't be creating a /var/lib/machines subvolume if /var is
  already a seperate partition or subvolume. /var/lib/machines will
  already be excluded from snapper & similar tooling in this case.
* Wed Jan 10 2018 fbui@suse.com
- Import commit 82dbe8a2ae56649231111eaadd4c302a2d2175ee
  8c7f0c449 service: Don't stop unneeded units needed by restarted service (bsc#1066156)
  869be64ce sysctl: use raw file descriptor in sysctl_write (#7753)
  0c2400810 sysctl: disable buffer while writing to /proc (bsc#1071558)
  9eb1f30b8 Use read_line() and LONG_LINE_MAX to read values configuration files. (bsc#1071558)
  4dbea654f def: add new constant LONG_LINE_MAX
  48f14cd71 fileio: add new helper call read_line() as bounded getline() replacement
  861e1a222 build-sys: udevadm should have LOG_REALM=LOG_REALM_UDEV
  8ed5cf3fb meson: libudev_core and udevadm should have LOG_REALM=LOG_REALM_UDEV (#7666)
  a9f93f1d0 virt: use XENFEAT_dom0 to detect the hardware domain (#6442, #6662) (#7581) (bsc#1048510)
  fe56abdf9 seccomp: arm64/x32 do not have _sysctl
  c9194fe37 seccomp: arm64 does not have mmap2
  31d9b3c32 fs-util: small tweak in chase_symlinks()
  9dd0bc7a3 meson: do not include man/meson.build if xsltproc not found
  7e29e2b07 analyze: replace --no-man with --man=no in the man page (bsc#1068251)
* Mon Dec  4 2017 pavlix@pavlix.net
- Add missing /etc/systemd/network directory
* Wed Nov 29 2017 fbui@suse.com
- Import commit e30f1b10e276fb18db10ea2463fbd7146ae778f6
  63481b24b firstboot: do not write vconsole.conf when arg_keymap is empty (bsc#1070124)
* Wed Nov 29 2017 fbui@suse.com
- Add 0001-compat-rules-get-rid-of-scsi_id-when-generating-comp.patch (bsc#1051465)
  This patch is not yet merged in the 'compats/udev-compat-symlinks'
  branch: we asked to upstream if it would be possible to introduce a
  new specifier that wouldn't strip trailing whitespaces , see
  https://github.com/systemd/systemd/issues/7462
  Also this allows to give the patch more testing before merging it in
  the git repo.
* Thu Nov 23 2017 fbui@suse.com
- Drop a useless rm(1) from the specfile
* Thu Nov 23 2017 kukuk@suse.de
- Remove requires for pwdutils, we don't need the shadow tools
  anymore [bsc#1069150]
* Fri Nov 17 2017 fbui@suse.com
- Import commit 4b9afa11f918796184e1264d618b4ff5d18e481b
  22dcb1d04 tmpfiles: when /etc is not fully initialized, some specifiers are expected to be unresolvable (#6860) (bsc#1055664)
  216beb768 tmpfiles: Allow create symlink on directories (#6039)
  baf85eb79 udev: net_setup_link: don't error out when we couldn't apply link config (#7328)
- Remove stderr redirection to /dev/null when calling %%tmpfiles_create
  since it's not needed anymore due to commit 22dcb1d04. Indeed the
  messages are no more emitted at LOG_WARN but LOG_NOTICE.
* Mon Nov 13 2017 fbui@suse.com
- Import commit b9a41367b6c1164318443491cc3dae0e8208e15c
  86804326f systemd-firstboot: add vconsole keymap support (#7035) (bsc#1046436)
  9b64225e9 resolved: fix loop on packets with pseudo dns types (bsc#1065276 CVE-2017-15908)
- Drop 0001-systemd-firstboot-add-vconsole-keymap-support.patch since
  it's been merged upstream and backported to SUSE/v234 (see above).
* Thu Oct 26 2017 fbui@suse.com
- Import commit e44237e76f6e133e62ff6c681d3fd06ebf12f66d
  a4e02c099 udev-rules: all values can contain escaped double quotes now (#6890)
  d2b767a76 tmpfiles: remove old ICE and X11 sockets at boot (#6979)
* Thu Oct 19 2017 fbui@suse.com
- Add 0001-systemd-firstboot-add-vconsole-keymap-support.patch (bsc#1046436)
  Temporary patch until it's been merged by upstream, see
  https://github.com/systemd/systemd/pull/7035
* Fri Oct  6 2017 fbui@suse.com
- Damn forgot to drop 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch in
  the spec file
* Fri Oct  6 2017 fbui@suse.com
- Import commit 6dea894131d78b20b9e0482f75afa6ee4dec8627
  1cdd944b0 unit: when JobTimeoutSec= is turned off, implicitly turn off JobRunningTimeoutSec= too (bsc#1004995)
  This make 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch
  not needed anymore.
* Thu Oct  5 2017 fbui@suse.com
- Import commit 93688f8e53b4e482a55a7d4aba2d927ddedebdde
  c53522be3 compat-rules: allow to specify the generation number through the kernel cmdline
* Wed Oct  4 2017 fbui@suse.com
- Import commit c1e8af7d1e8b09c2878a5b17f513bfc41ae46dc6
  982754275 build-sys: make sure 61-persitent-storage-compat.rules is installed with meson
  9ac2e8b9b udev: proc_cmdline_get_key() FTW! (#6925)
* Tue Sep 26 2017 fbui@suse.com
- Import commit 9e0985dc330b1cf04bc44049962343bdf4ba851a
  4fd7cd041 pam_logind: skip leading /dev/ from PAM_TTY field before passing it on
  dd6312828 logind: make sure we don't process the same method call twice (#6583)
* Tue Sep 26 2017 fbui@suse.com
- Update scripts-systemd-upgrade-from-pre-210.sh script
  - drop dependency on awk
  - fallback to runlevel #3 if something goes wrong
  Note: I'm not sure how this is supposed to work as /etc/inittab is
  likely to be missing in my understanding. Indeed this file is part
  of the aaa_base package which might be upgraded before systemd is
  installed...
* Tue Sep 26 2017 fbui@suse.com
- Drop macros.systemd.upstream as it's not used
* Thu Sep 14 2017 fbui@suse.com
- Import commit 58ea3c819cca1639ef8c922505c573ba5e262b3d
  334945091 shutdown: fix incorrect fscanf() result check (#6806)
  027202892 shutdown: don't remount,ro network filesystems. (#6588) (bsc#1035386)
  bc77b53a5 shutdown: don't be fooled when detaching DM devices with BTRFS (boo#1055641)
  d9d293847 util: make get_block_device() available
  421ce7382 tmpfiles: silently ignore any path that passes through autofs (#6506) (bsc#1045472)
  ca8f90e62 device: make sure to remove all device units sharing the same sysfs path (#6679)
* Thu Sep 14 2017 fbui@suse.com
- Make use of "%%tmpfiles_create" in %%post of the logger subpackage
* Thu Sep 14 2017 fbui@suse.com
- Add scripts-udev-convert-lib-udev-path.sh (bsc#1050152)
  This script takes care of converting /lib/udev into a symlink
  pointing to /usr/lib/udev when upgrading a distro using an old
  version of udev.
* Thu Sep 14 2017 fbui@suse.com
- Make use of "%%make_build" rpm macro
* Thu Sep 14 2017 fbui@suse.com
- Renumber scripts to start at index 100
* Thu Sep 14 2017 fbui@suse.com
- Introduce scripts-systemd-upgrade-from-pre-210.sh
  It collects all existing hacks done in %%post to fix old/deprecated
  settings in systemd older than 210. This includes hacks needed to
  fix system that are migrating from SysV.
  There shouldn't be any functional changes.
* Thu Sep 14 2017 fbui@suse.com
- Move scripts for packaging workaround/fixes in /usr/lib/systemd/scripts
  It also renames fix-machines-subvol-for-rollbacks.sh into
  scripts-systemd-fix-machines-btrfs-subvol.sh
  Note that the "scripts-systemd-" prefix is used for those scripts so
  we can gather them. Why not using a directory instead ? because osc
  doesn't allow that.
* Wed Aug 30 2017 fbui@suse.com
- Add 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch (bsc#1048605)
  It's a temporary but urgent fix for a regression discovered in bug
  1048605. The fix is still under discussion with upstream but we need
  to make progress here and limit the number of affected users.
  Consequently this fix reintroduces bsc#1004995 (the bug report has
  been re-opened) but this one is far less critical and a workaround
  was provided.
  The final solution will fix both bugs.
* Tue Aug 29 2017 fbui@suse.com
- Import commit 2bed4bf99cf7f24eafda490f778ed5e109f8d7f1
  7a4935268 compat-rules: drop the boggus 'import everything' rule (bsc#1046268)
* Tue Aug  1 2017 fbui@suse.com
- %%regenerate_initrd_post is suppsed to be used in %%post (not %%pre) section
* Fri Jul 28 2017 fbui@suse.com
- Import commit 6887cc21f23e33ac37801a01d76176e5c16fd8ea
  9dcc6c04e pid1: forward port console specificities handling for s390 arch to v234
* Fri Jul 28 2017 fbui@suse.com
- Import commit 986e98fd5a75470ba17e21fea12d7d4e966c1ecc
  4706ebc62 call chase_symlinks without the /sysroot prefix (#6411) (boo#1051172)
* Thu Jul 27 2017 fbui@suse.com
- Remove the unneeded hack forcing systemd-crypsetup binary to be linked against the just built libudev
  I don't remember why it was added but it looks unnecessary: most of
  all systemd components are linked againt libsystemd-shared.so which
  includes all the just built symbols.
  Also I don't see why it was done only for systemd-cryptsetup since
  all other binaries should have had suffered from the same issue.
* Wed Jul 26 2017 fbui@suse.com
- Import commit c5705e01800bdadd6a4fa7dc50d47b13eb697211
  8ea065d44 compat-rules: don't rely on ID_SERIAL when generating 'by-id' symlinks for NVMe devices (bsc#1048679)
* Wed Jul 26 2017 fbui@suse.com
- Import commit 06bed720274d9436405a7c27c8238d7d1aefca2b
  66fffdf12 build-sys: don't hook var-lib-machined.mount to remote-fs.target when machined is disabled
  96c232066 Revert "core: don't load dropin data multiple times for the same unit (#5139)"
* Wed Jul 26 2017 fbui@suse.com
- Drop support of compression from the mini package
  Hence remove the relevant build-requires from the mini package.
* Fri Jul 21 2017 fbui@suse.com
- Upgrade to v234 (commit 78af11131da1b2760778206806c0ebe8616a5284)
  - package /etc/systemd/system/dbus-org.freedesktop.network1.service
  - /usr/lib/systemd/resolv.conf is not installed if resolved is disabled
* Fri Jul  7 2017 jengelh@inai.de
- Edit pkgconfig(liblz4) dependency: liblz4 now uses 1.x *again*
* Thu Jul  6 2017 fbui@suse.com
- Added 0001-core-disable-session-keyring-per-system-sevice-entir.patch (bnc#1045886)
  Temporary patch to disable the session keyring stuff as it's
  currently broken and may introduce some security holes.
* Thu Jul  6 2017 fbui@suse.com
- Import commit 21827ea0875ff197e16e72003b2bfaa1c6e8daad
  1ad06735f core: fail when syntactically invalid values for User=/Group= fields are detected (bsc#1047023)
  d563972e2 timesyncd: don't use compiled-in list if FallbackNTP has been configured explicitly
  f4e0c16f5 gpt-auto-generator: fix the handling of the value returned by fstab_has_fstype() in add_swap() (#6280)
  e1345aac5 fix add_esp() in the gpt-auto-generator.c (#6251)
  c591ece9a automount: don't lstat(2) upon umount request (#6086) (bsc#1040968)
  643ab2eea gpt-auto-generator: disable gpt auto logic for swaps if at least one is defined in fstab
  f07d2022f fstab-util: introduce fstab_has_fstype() helper
  bf735bb35 fstab-util: don't eat up errors in fstab_is_mount_point()
  a4b40fbed resolved: simplify alloc size calculation (bsc#1045290 CVE-2017-9445)
  8b960bec0 only check signature job error if signature job exists (#6118) (boo#1043758)
  1418bfb5b job: Ensure JobRunningTimeoutSec= survives serialization (#6128) (bsc#1004995)
  19b6d5f08 udev: turn off -Wformat-nonliteral for one safe case
  717ace439 udev: net_id add support for platform bus (ACPI, mostly arm64) devices (#5933)
  a3bf2e6b5 core/mount: pass "-c" flag to /bin/umount (#6093)
* Wed Jul  5 2017 fbui@suse.com
- Add minimal support for boot.d/* scripts in systemd-sysv-convert (boo#1046750)
  While at it, the handling of the symlink priorities is also removed
  since it doesn't appear to be used at all.
* Thu Jun 22 2017 fbui@suse.com
- Don't try to restart networkd/resolved if they're disabled (boo#1045521)
  "systemctl try-restart/preset" wants the unit files exist.
* Thu Jun 22 2017 fbui@suse.com
- Stop shipping /usr/lib/sysusers.d/basic.conf (bsc#1006978)
  Ok looks like the previous change was the right thing to do and we
  continue to follow this path by relying on the new user/group scheme
  Therefore the basic system user/group are now managed and created by
  system-sysusers and udev also relies on this for the groups it uses
  in its rule files.
  Ideally we should have listed all of the groups in the deps (with
  "Requires: group(disk)" but the list of the groups is rather long
  and the risk for those groups to be re-organized is probably low, so
  currently we simply use "Requires: system-group-hardware" as a
  shortcut.
* Fri Jun 16 2017 fbui@suse.com
- Make sure "lock" group is created
  On SUSE distros, /run/lock must be owned by "lock" group (see
  boo#733523).
  This group was previously created by another package but since a
  recent changes it doesn't seem to be true anymore or at least this
  package isn't pulled in anymore when building the rescue system.
  For now make systemd creates the group by adding
  "Requires: group(lock)".
  I'm currently not sure why we don't use sysusers.d stuff for that
  purpose and if the "lock" group on /run/lock is still
  mandatory. This should be revisited later.
* Wed Jun  7 2017 fbui@suse.com
- Make sure dracut (if installed) will embed the new compat rule
  The new compat rule must be embedded in the initramfs so make sure
  that the installed dracut supports it.
* Wed May 24 2017 fbui@suse.com
- Upgrade to v233 (commit 330b55d5e28d17f361062dba66426e46fb7d7857)
  - package new systemd-umount binary
  - package new environment generator stuff
  - drop /dev/root symlink support
  - /etc/pam.d/systemd-user is not patched anymore but we ship a
    dedicated file for SUSE now.
  - manage compat symlink generation in a dedicated branch (bsc#1040153)
* Wed May 17 2017 fbui@suse.com
- Fix systemd-sysv-convert when a package starts shipping service units (bsc#982303)
  The database might be missing when upgrading a package which was
  shipping no sysv init scripts nor unit files (at the time --save was
  called) but the new version start shipping unit files.
* Wed May 17 2017 fbui@suse.com
- Fix indentation in systemd-sysv-convert
  While at it, strip trailing whitespaces.
  No functional changes.
* Thu May 11 2017 fbui@suse.com
- Disable group shadow support (bsc#1029516)
  The new configure option will be imported during the next tarball
  update.
* Tue May  2 2017 fbui@suse.com
- Ship /var/log/README
  Unfortunately it's not possible to also ship /etc/init.d/README
  because of rpm "sanity" checks that prevent executable in
  /etc/init.d
* Tue May  2 2017 fbui@suse.com
- Drop systemd-{journalctl,loginctl} legacy symlinks.
* Tue May  2 2017 fbui@suse.com
- Drop %%preun section
  Currently the only use of this section is to remove the symlinks
  enabling systemd services on package removal. Those symlinks were
  initially installed by the systemd package installation but could
  have been overriden by the sysadmin later. If so the symlinks
  shouldn't be uninstalled.
  Also in a near futur disabling services will install a symlink to
  /dev/null.
* Tue May  2 2017 fbui@suse.com
- Import commit 9e33c2ae69fbb705e8ad143536e419a231e93020
  04ef0eab8 importd: support SUSE style checksums supplementary (#5800)
  fb601ad9a importd: support SUSE style checksums (#5206) (fate#322054)
  b76b27c76 hwdb: fix warning "atkbd serio0: Unknown key pressed" (#5772) (boo#1010220)
  cb0d991f6 loginctl: fix typo causing ignoring multiple session IDs (#5732)
* Tue May  2 2017 fbui@suse.com
- Make use of %%systemd_postun()
* Tue May  2 2017 fbui@suse.com
- Restart a couple of systemd services on package update
  Those services (most notably journald) should support restarting
  these days. However logind still doesn't but that should be fixed
  pretty soon, well I hope :)
* Tue May  2 2017 fbui@suse.com
- Don't buildrequire pam-config, it's not used at this step.
  Also drop the use of it in %%postun as it can't realistically
  happen...
* Thu Apr 20 2017 fbui@suse.com
- Don't call /sbin/ldconfig in %%post of the main package
  systemd main package doesn't ship any shared libs so there's no
  point in calling ldconfig in %%post/%%postun
* Thu Apr 20 2017 fbui@suse.com
- Silent %%tmpfiles_create in %%post (bsc#1034938)
  Due to bsc#1024740, we stopped generating /etc/machine-id during
  systemd package installation making the specifier '%%m' unavailable
  in the tmpfiles.d configuration files at this time.
  Make it simple for now and silent %%tmpfiles_create, after all that's
  how the macro was implemented originally.
* Mon Apr 10 2017 fbui@suse.com
- Import commit f0325620d23a247682c629d28883a364e4a7a8c4
  327814841 core: when a unit's SourcePath points to API VFS pretend we are never out-of-date (#5487)
  f4b9fb58e units: move Before deps for quota services to remote-fs.target (#5627) (bsc#1028263)
  44b9d27f8 udev: net_id - support predictable ifnames on vio buses (#5675) (bnc#1029183)
  64f4761c9 units: apply plymouth warning fix to in rescue mode as well (#5615)
  77607b887 units: do not throw a warning in emergency mode if plymouth is not installed (#5528) (bsc#1025398)
  336d6016c core: downgrade "Time has been changed" to debug (#4906) (bsc#1028610)
* Wed Mar 22 2017 fbui@suse.com
- Consider chroot updates in fix-machines-subvol-for-rollbacks.sh (bsc#1030290)
* Tue Mar 14 2017 fbui@suse.com
- Initialize /etc/machine-id during the first boot (bsc#1024740)
  Previously that was done at package installation but it didn't fit
  well for appliance builds.
* Tue Mar  7 2017 fbui@suse.com
- Import commit 68fc0a749a83d16d4cde8471d5030bc6254ffd96
  76d4d05fb udev: fix variable assignment
  473df8cc4 udev-rules: perform whitespace replacement for symlink subst values (bsc#1025886)
  d6c3ff647 udev-event: add replace_whitespace param to udev_event_apply_format
  30ad15f7c libudev-util: change util_replace_whitespace to return number of chars in dest
* Fri Mar  3 2017 fbui@suse.com
- Import commit 103259b3226251d06f79ca627f7b0ba0bd49f4bc
  0ee7890dd automount: if an automount unit is masked, don't react to activation anymore (#5445)
  99865a181 core: make sure to destroy all name watching bus slots when we are kicked off the bus (#5294) (bsc#1006687)
  f34234c54 build-sys: add check for gperf lookup function signature (#5055)
  44e39538f sd-event: "when exiting no signal event are pending" is a wrong assertion (#5271) (boo#995936 bsc#1022014)
  471b26807 sd-event: when an event source fails, don't assume the type of it is still set
* Mon Feb 20 2017 fbui@suse.com
- Don't ship systemd-resolved for now (bsc#1024897)
  If resolved is enabled , systemd-tmpfiles creates a wrong symlink in
  /etc/resolv.conf which confuses the network manager actually used.
* Thu Feb  9 2017 fbui@suse.com
- More indentation cleanup (no functional changes)
* Wed Feb  8 2017 kukuk@suse.de
- Remove obsolete insserv requirements for udev again [bsc#999841]
* Mon Feb  6 2017 fbui@suse.com
- Import commit cd97d5d5fef79ab9d957bf6504d085c0faca6bfc
  e587b6ce0 disable RestrictAddressFamilies on all architectures but x86_64 one (bsc#1023460)
  c8ae05632 journald: don't flush to /var/log/journal before we get asked to (bsc#1004094)
  7261eaf3e sd-event: fix sd_event_source_get_priority() (#4712)
* Fri Feb  3 2017 fbui@suse.com
- Move fix for permission set on /var/lib/systemd/linger/* (no functional changes)
  Move that part after the fix on timer timestamp files otherwise the
  comment doesn't make sense.
* Wed Feb  1 2017 fbui@suse.com
- Import commit 028fd9b60580976dffb09b3576a2b652ee35137c
  cc2ca55ff build-sys: do not install ctrl-alt-del.target symlink twice
  ececae77a device: Avoid calling unit_free(NULL) in device setup logic (#4748)
* Wed Feb  1 2017 fbui@suse.com
- Ship systemd-resolved but it's disabled by default (bsc#1018387)
  The NSS plugin will also be disabled, users need to enable it
  manually.
* Wed Jan 25 2017 fbui@suse.com
- Don't ship ldconfig.service anymore
  This service was introduced to support stateless systems that
  support offline /usr updates properly.
  AFAIK we don't support any such system for now, so disable it. If
  it's wrong it's easy enough to restore it back.
  Related to bsc#1019470.
* Wed Jan 25 2017 fbui@suse.com
- Be more consistent with indentation (*no* functional changes)
  Indentation should use 8 spaces now (no tabs).
* Wed Jan 25 2017 fbui@suse.com
- Import commit 2559bc0c076b58f0a649056e79ca90fe5f1d556c
  9c4a759ab systemctl: 'show' don't exit with a failure status if the requested property does not exist [SUSE] (bsc#1021062)
  f9194193b systemctl: remove duplicate entries showed by list-dependencies (#5049) (bsc#1012266)
  2a6653335 rule: don't automatically online standby memory on s390x (bsc#997682)
* Wed Jan 25 2017 fbui@suse.com
- Fix permission set on /var/lib/systemd/linger/*
  Those files are created by logind which run with umask(0022), so
  they are not world writable and shouldn't be affected by
  bsc#1020601. But it's cleaner to not let files forever with their
  setuid bit set for no good reason.
* Wed Jan 25 2017 fbui@suse.com
- Fix permissions set on permanent timer timestamp files (bsc#1020601) (CVE-2016-10156)
  This change makes sure to fix the permissions of the timestamp files
  which could have been created by an affected version of systemd.
  Local unprivileged users could have run arbitrary code as root if
  systemd previously created world writable suid root files such as
  permanent timer stamp files.
* Tue Jan 10 2017 fbui@suse.com
- Import commit 3edb876e3b80437a95502aa5d31d454606ea94bd
  27b544224 core: make sure to not call device_is_bound_by_mounts() when dev is null (#5033) (bsc#1018399)
* Fri Jan  6 2017 fbui@suse.com
- Use the %%{resolved} build conditional for the nss-resolve subpackage
* Thu Jan  5 2017 fbui@suse.com
- /usr/bin/systemd-resolve was missing from the filelist
* Thu Jan  5 2017 fbui@suse.com
- Silent warnings emitted when udev socket units are restarted during package upgrade (bsc#1018214)
* Mon Dec 19 2016 fbui@suse.com
- Upgrade to v232, commit de62e96da6a62ac61a7dea45cc558f5fa4342032
  - a4dff165d nspawn: resolv.conf might not be created initially (#4799)
  - b543fe907 nspawn: fix condition for mounting resolv.conf (#4622)
  - 1aed89e55 core: make mount units from /proc/self/mountinfo possibly bind to a device (#4515) (boo#909418 bsc#912715 bsc#945340)
  - bfb54ecdc coredumpctl: let gdb handle the SIGINT signal (#4901) (bsc#1012591)
* Wed Dec 14 2016 fbui@suse.com
- Really include legacy kbd maps in kbd-model-map (bsc#1015515)
  Instead of fix-machines-subvol-for-rollbacks.sh...
* Thu Dec  8 2016 fbui@suse.com
- Enable lz4 (which becomes the default)
  It's much faster than xz and thus should be more appropriate to
  compress journals and coredumps.
  The LZ4 logic is now officially supported and no longer considered
  experimental.
  The new frame api was released in v125.
* Tue Dec  6 2016 fbui@suse.com
- Good by compatlibs support
  There's no longer need for enabling/disabling the support for the
  compatlibs as it's been dropped from the source code.
* Tue Nov 29 2016 fbui@suse.com
- Drop /usr/lib/systemd/libsystemd-shared-%%{version}.so from the 32bit package
  This shared library is not for public use, and is neither API nor
  ABI stable, but is likely to change with every new released
  update. Only systemd binaries are supposed to link against it.
  This also prevents from the 32bit package to conflit with the 64bit
  one if this lib was installed by both packages.
* Tue Nov 22 2016 fbui@suse.com
- Upgrade to v232, commit c5c3445825981e2a5c3ed71214127d5b1b9de802:
  - Dropped backported commits which has been merged
  - Forward-port Suse specific patches
  - Added --disable-lto option to ./configure
  - Added systemd-mount
  - Removed in %%file /usr/lib/systemd/user/*.socket: since
    798c486fbcdce3346cd86 units/systemd-bus-proxyd.socket has been
    removed.
  - Removed in %%file %%{_sysconfdir}/systemd/bootchart.conf
    since commit 232c84b2d22f2d96982b3c bootchart is not part of systemd
    anymore.
  - Backward compat libs have been disabled since it's been dropped from
    the source code.
  - Added /usr/bin/systemd-socket-activate in %%file
  - Added --without-kill-user-processes ./configure option
  - Bump libseccomp build require (>= 2.3.1) as described in README
  - Specifiy version of libmount as required in the README
* Fri Nov 18 2016 meissner@suse.com
- libudev-devel 32bit is needed for building 32bit wine now.
* Mon Nov 14 2016 fbui@suse.com
- specfile: conflict systemd-bash-completion and systemd-mini-bash-completion
  Otherwise the build system detects that systemd-bash-completion and
  its mini variant are conflicting at files level even though those
  packages can't be installed on the same system.
* Thu Nov 10 2016 fbui@suse.com
- specfile: clean up nss-* plugins descriptions and drop
  nss-myhostname-config script for now.
  Currently /etc/nsswitch.conf is supposed to be edited by the
  sysadmin to enable the modules. However for some reasons only
  nss-myhostname is removed from the conf file when the corresponding
  package is uninstalled. This is inconsistent so let's remove it.
  Actually I'm wondering if we shouldn't make those NSS plugins part
  of the main package and get rid of all those sub-packages...
* Thu Nov 10 2016 fbui@suse.com
- specfile: remove old comments and unneeded sed command
* Thu Nov 10 2016 fbui@suse.com
- specfile: no need to create systemd-update-utmp-runlevel.service symlinks anymore
  The symlinks in /usr/lib/systemd/system/<target>.target.wants/systemd-update-utmp-runlevel.service
  are created in Makefile.am since commit d5d8429a12c4b1.
  'reboot' and 'poweroff' targets initially had the symlinks but
  there's not point since the latter conflicts shutdown.target whereas
  the 2 targets pull it in.
  See: https://github.com/systemd/systemd/pull/4429
* Thu Nov 10 2016 fbui@suse.com
- specfile: remove the following warnings:
  [  256s] warning: File listed twice: /usr/lib/systemd/system/dbus.target.wants
  [  256s] warning: File listed twice: /usr/lib/systemd/system/default.target.wants
* Wed Oct 26 2016 fbui@suse.com
- Own a couple of directories even if they don't belong to systemd
  otherwise the build system will complain.
  Some directories (owned by others packages) are simply used by
  systemd to ship some scripts or config files to customize others
  * optional* components. Since thos components are not build required
  by systemd those directories are not owned by any packages and the
  BS complains...
* Wed Oct 26 2016 fbui@suse.com
- Import commit
  15ea716 journal-remote: change owner of /var/log/journal/remote and create /var/lib/systemd/journal-upload (bsc#1006372)
* Mon Oct 24 2016 fbui@suse.com
- %%sysusers_create and %%tmpfiles_create must be called in %%post
  Calling %%pre is broken since the respective conf files are not yet
  installed.
* Mon Oct 24 2016 fbui@suse.com
- %%{_libexecdir}/{tmpfiles.d,sysusers.d}/systemd-remote.conf are
  part of systemd-journal-remote package (only).
* Mon Oct 24 2016 fbui@suse.com
- systemd-journal-{gatewayd,remote,upload} units are only part of
  "systemd-journal-remote" package.
  So exclude them from the main package.
* Mon Oct 24 2016 fbui@suse.com
- Import commit a1c145e6ad6588555dca64402f9103fb1e02b1a0
  7f34037 man: explain that *KeyIgnoreInhibited only apply to a subset of locks
  df5798b Revert "logind: really handle *KeyIgnoreInhibited options in logind.conf" (bsc#1001790 bsc#1005404)
  f79fee7 Revert "kbd-model-map: add more mappings offered by Yast"
  3760c10 manager: tighten incoming notification message checks
  d6efd71 core: only warn on short reads on signal fd
  6eebd91 manager: be stricter with incomining notifications, warn properly about too large ones
  fdf2dc3 manager: don't ever busy loop when we get a notification message we can't process
* Thu Oct 20 2016 fbui@suse.com
- Rename kbd-model-map-extra into kbd-model-map.legacy
* Wed Oct 19 2016 fbui@suse.com
- Remove tcpd-devel build requirement.
  tcpwrap support has been removed since v212, see commit
  7f8aa67131cfc03ddcbd31c0420754864fc122f0
* Tue Oct 18 2016 fbui@suse.com
- remove all dummy "aliases" to /etc/init.d (as it was already done by
  factory more than 1 year ago).
  Even if a sysvinit script is still requiring one of those dummy
  symlinks this should not be an issue since this is requirement is
  translated into a weak dependency.
* Tue Oct 18 2016 fbui@suse.com
- specfile:
  - do not own /usr/share/zsh directory
  - do not own /etc/dbus-1 and /etc/dbus-1/system.d dirs
  - do not own /usr/share/dbus-1 dir
* Tue Oct 18 2016 fbui@suse.com
- specfile: %%{_prefix}/lib/systemd/system-preset was mentioned twice
  in %%files section.
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - use curly braces with rpm macros
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - %%ghost files doesn't need (anymore) to be created in %%builroot
  - do not own /etc/X11/xorg.conf.d and /etc/X11/xinit
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup: no need to protect the manpages with %%bootstrap
  condition in nss-myhostname package since the package itself is
  already protected.
* Tue Oct 18 2016 fbui@suse.com
- fix nss-resolve sub package:
  - add a %%files section
  - add a package description
  - libnss_resolve.so.2 is now part of this subpackage
  - add %%post and %%postun sections
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - reorganize some files in %%files by types
  - some config files were missing the "noreplace" attribute
* Tue Oct 18 2016 fbui@suse.com
- Use %%config(noreplace) for %%{_sysconfdir}/pam.d/systemd-user
* Tue Oct 18 2016 fbui@suse.com
- Rework systemd-gatewayd package:
  - some gateway's files were still in the main package
  - it now includes all progs dealing with remote journals
  - it can be turned off (SP2 does that currently)
  - it's been renamed systemd-journal-remote to reflect that
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - only specify once %%{_prefix}/lib/systemd/system-shutdown in %%file
  - no need to list the content of %%{_prefix}/lib/systemd/user-generators in %%file
  - machined is not built when %%bootstrap = 1
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - There's no point in listing all generators in %%file
    explicitly. The default is to include all of them and if for some
    reason one must be excluded then it should be done explicitly.
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - remove explicit call to make for building man pages. This is not
    needed and was maybe useful when generated doc was pre-built and
    shipped in the tarball.
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - break overly long and unreadable line using mkdir
  - gather directory creations
* Mon Oct 17 2016 fbui@suse.com
- Stop providing udevd.8
  systemd-udevd has replaced udevd for some time already and usage of
  udevd should be avoided. Therefore don't encourage this and stop
  documenting it.
* Mon Oct 17 2016 fbui@suse.com
- Import from factory:
  - Thu Feb  4 11:05:37 UTC 2016 - lnussel@suse.de
  - curl also causes building of journal-upload. That one has rather
    unusal certificate usage, set it's ca root to /etc/pki/systemd
    instead of the built-in default /etc/ssl as journal-remote and
    journal-upload think they can put stuff in /etc/ssl/certs then
    but that directory is managed by p11-kit and doesn't serve the
    purpose those programs think.
* Thu Oct 13 2016 fbui@suse.com
- Package rootsymlink-generator helper. It was forgotten when
  switching to the git repo but re-added back.
  That said this thing should be removed as it's broken as soon as
  there's no direct link between the root fs and its backend device
  node (i.e. BTRFS).
* Thu Oct 13 2016 fbui@suse.com
- Add kbd-model-map-extra file which contains the additional legacy
  keymaps needed by yast.
  This was previously directly patched in the systemd source code.
* Mon Oct 10 2016 fbui@suse.com
- Imported e251b8d7fb5c801fdfa3a023257ba0e4d514f3b0
  - Re-add back /dev/root symlink generation (although this must be
    deprecated and finally removed).
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  Third step:
  - Re-enable networkd (disabled by default in SLE12)
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  Second step:
  - Import the specfile
  - Import the tarball generated from the git repo
  - Import lastest changes for the different scripts
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  First step: drop all patches and drop the tar ball.
  The dropped patches are:
    fix-support-for-boot-prefixed-initscript-bnc-746506.patch
    set-and-use-default-logconsole.patch
    ensure-ask-password-wall-starts-after-getty-tty1.patch
    0001-rules-block-add-support-for-pmem-devices-3683.patch
    Fix-run-lock-directories-permissions-to-follow-openSUSE-po.patch
    1007-physical-hotplug-cpu-and-memory.patch
    1066-udev-add-compatibility-links-for-truncated-by-id-links.patch
    watch_resolv.conf_for_become_changed.patch
    0019-make-completion-smart-to-be-able-to-redirect.patch
    systemd-add-user-keep.patch
    0001-core-re-sync-bus-name-list-after-deserializing-durin.patch
    systemd-228-nspawn-make-journal-linking-non-fatal-in-try-and-auto.diff
    avoid-random-hangs-on-timeouts-due-lost-cwd.patch
    1037-udev-exclude-cd-dvd-from-block-device.patch
    0001-add-network-device-after-NFS-mount-units.patch
    journald-advice-about-use-of-memory.patch
    1011-64-btrfs.rules-skip-btrfs-check-if-devices-are-not-r.patch
    1006-udev-always-rename-network.patch
    handle-numlock-value-in-etc-sysconfig-keyboard.patch
    use-rndaddentropy-ioctl-to-load-random-seed.patch
    0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
    0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
    0001-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    0001-bnc888612-logind-polkit-acpi.patch
    avoid-divide-by-zero-sigtrap.patch
    1035-99-systemd.rules-Ignore-devices-with-SYSTEMD_READY-0.patch
    suse-sysv-bootd-support.diff
    ensure-shortname-is-set-as-hostname-bnc-820213.patch
    parse-crypttab-for-noauto-option.patch
    tty-ask-password-agent-on-console.patch
    0001-pid1-process-zero-length-notification-messages-again.patch
    handle-root_uses_lang-value-in-etc-sysconfig-language.patch
    0001-core-exclude-.slice-units-from-systemctl-isolate.patch
    vhangup-on-all-consoles.patch
    0001-systemctl-pid1-do-not-warn-about-missing-install-inf.patch
    apply-ACL-for-nvidia-device-nodes.patch
    make-emergency.service-conflict-with-syslog.socket.patch
    0001-journal-warn-when-we-fail-to-append-a-tag-to-a-journ.patch
    1096-new-udev-root-symlink-generator.patch
    1099-Add-default-rules-for-valve-steam-controller-to-work.patch
    0001-journal-set-STATE_ARCHIVED-as-part-of-offlining-2740.patch
    systemd-install-compat_pkgconfig-always.patch
    1012-Skip-persistent-device-link-creation-on-multipath-de.patch
    0001-avoid-abort-due-timeout-at-user-service.patch
    insserv-generator.patch
    apply-ACL-for-nvidia-uvm-device-node.patch
    restore-var-run-and-var-lock-bind-mount-if-they-aren-t-sym.patch
    systemd-pam_config.patch
    systemd-dbus-system-bus-address.patch
    let-linker-find-libudev-for-libdevmapper.patch
    1098-systemd-networkd-alias-network-service.patch
    0001-let-systemctl-completion-ignore-at-names.patch
    boot-local-start.patch
    1095-set-ssd-disk-to-use-deadline-scheduler.patch
    tomcat6-var-lock-subsys-legacy.patch
    let-vconsole-setup-get-properties-only-once-to-copy-them.patch
    plymouth-quit-and-wait-for-emergency-service.patch
    respect-nfs-bg-option.patch
    0001-If-the-notification-message-length-is-0-ignore-the-m.patch
    1062-rules-set-default-permissions-for-GenWQE-devices.patch
    rescue-emergency-target-conflicts.patch
    Correct_assert_on_unexpected_error_code.patch
    1097-udevd-increase-maximum-number-of-children.patch
    0001-core-fix-bus-name-synchronization-after-daemon-reloa.patch
    1005-create-default-links-for-primary-cd_dvd-drive.patch
    allow-multiple-sulogin-to-be-started.patch
    systemd-230-cgroup2-use-new-fstype-for-unified-hierarchy.patch
    0010-do-not-install-sulogin-unit-with-poweroff.patch
    1003-udev-netlink-null-rules.patch
    1002-rules-create-by-id-scsi-links-for-ATA-devices.patch
    0001-nss-mymachines-do-not-allow-overlong-machine-names.patch
    shut-up-rpmlint-on-var-log-journal.patch
    systemd-tmp-safe-defaults.patch
    portmap-wants-rpcbind-socket.patch
    hostname-NULL.patch
    0001-pid1-more-informative-error-message-for-ignored-noti.patch
    0001-journal-fix-HMAC-calculation-when-appending-a-data-o.patch
    handle-disable_caplock-and-compose_table-and-kbd_rate.patch
    kbd-model-map.patch
    systemctl-set-default-target.patch
    0014-journald-with-journaling-FS.patch
    0001-On_s390_con3270_disable_ANSI_colour_esc.patch
* Fri Sep 30 2016 fbui@suse.com
- Import a better fix from upstream for bsc#1001765
  - Added:
    0001-pid1-more-informative-error-message-for-ignored-noti.patch
    0001-pid1-process-zero-length-notification-messages-again.patch
  - Updated (no code changes, only patch metadata)
    0001-If-the-notification-message-length-is-0-ignore-the-m.patch
    0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
* Thu Sep 29 2016 fbui@suse.com
- Re add back "udev: don't require nsserv and fillup"
  Did this in the wrong project... it was a complicated day today ;)
* Thu Sep 29 2016 fbui@suse.com
- Added 2 patches to fix bsc#1001765
  0001-If-the-notification-message-length-is-0-ignore-the-m.patch
  0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
* Thu Sep 29 2016 fbui@suse.com
- Revert "udev: don't require nsserv and fillup"
  It's been judged too late for being part of SLE12 final release.
  Nevertheless it's part of Factory and will be reintroduced after the
  final release is out (ie through an update).
* Mon Sep 26 2016 fbui@suse.com
- systemd-sysv-convert: make sure that
  /var/lib/systemd/sysv-convert/database is always initialized (bsc#982211)
  If "--save" command was used and the sysv init script wasn't enabled
  at all the database file wasn't created at all. This makes the
  subsequent call to "--apply" fail even though this should not
  considered as an error.
* Mon Sep 26 2016 fbui@suse.com
- Added patches to fix journal with FSS protection enabled (bsc#1000435)
  0001-journal-fix-HMAC-calculation-when-appending-a-data-o.patch
  0001-journal-set-STATE_ARCHIVED-as-part-of-offlining-2740.patch
  0001-journal-warn-when-we-fail-to-append-a-tag-to-a-journ.patch
* Wed Sep 21 2016 fbui@suse.com
- udev: don't require nsserv and fillup (bsc#999841)
  udev has no LSB init scripts nor fillup templates anymore.
* Fri Sep 16 2016 fbui@suse.com
- Build require python and python-lxml in order to generate
  systemd.directives man page (bsc#986952)
* Fri Sep 16 2016 fbui@suse.com
- Add rules: block: add support for pmem devices (#3683) (bsc#988119)
  0001-rules-block-add-support-for-pmem-devices-3683.patch
* Tue Sep  6 2016 tbechtold@suse.com
- Fix is-enabled check in systemd-sysv-install (bsc#997268)
* Wed Aug 24 2016 dimstar@opensuse.org
- Only BuildRequire gnu-efi when building the 'real' systemd
  package.
* Tue Aug 23 2016 fbui@suse.com
- Add a script to fix /var/lib/machines to make it suitable for
  rollbacks (bsc#992573)
* Wed Aug 10 2016 meissner@suse.com
- reverted the systemctl split-off on request of Franck Bui.
* Fri Jul 29 2016 jengelh@inai.de
- Add sysusers to the new split "systemctl" subpackage
* Tue Jul 26 2016 jengelh@inai.de
- Split systemctl and tmpfiles into a separate package
* Tue Jul 19 2016 develop7@develop7.info
- Fix 1099-Add-default-rules-for-valve-steam-controller-to-work.patch
  to enable missing functionality of Steam Controller
* Sun Jul 17 2016 asarai@suse.com
- Backport unified_cgroup_hierarchy fix for Linux >= 4.4. boo#989276
  + systemd-230-cgroup2-use-new-fstype-for-unified-hierarchy.patch
* Sat Jun 18 2016 arvidjaar@gmail.com
- drop 1060-udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
  it breaks btrfs on multiple device-mapper devices (boo#984516). The problem
  it tried to fix is already fixed in rule shipped with btrfsprogs (see
  boo#912170).
* Wed May  4 2016 Thomas.Blume@suse.com
- fix warning about missing install info during preset (boo#970293)
  0001-systemctl-pid1-do-not-warn-about-missing-install-inf.patch
* Thu Apr  7 2016 schwab@suse.de
- Avoid bootstrap cycle with sg3_utils
* Tue Apr  5 2016 werner@suse.de
- Fix patch patch handle-numlock-value-in-etc-sysconfig-keyboard.patch
  that is do not close a file descriptor twice (boo#973907)
* Sat Mar 26 2016 jengelh@inai.de
- Add two patches which address logind/networkd disappearing from
  dbus (and busctl) even while the units and processes continue
  running.
  0001-core-fix-bus-name-synchronization-after-daemon-reloa.patch
  0001-core-re-sync-bus-name-list-after-deserializing-durin.patch
* Mon Mar 14 2016 fbui@suse.com
- drop all compiler/linker option customizations:
  - -pipe option is used by default since day 0
  - get rid of cflags() function which is not needed
  - --hash-size has no impact specially in runtime
  IOW, use the default options for the compiler and the linker,
  there's no point in making systemd different from other package in
  this regards.
* Mon Mar 14 2016 fbui@suse.com
- use %%make_build instead of 'make %%{?_smp_mflags}'
* Mon Mar 14 2016 fbui@suse.com
- be more strict on own lib version requirements
* Mon Mar 14 2016 fbui@suse.com
- systemd should require udev with the exact same version
* Thu Mar 10 2016 werner@suse.de
- Modify patch handle-numlock-value-in-etc-sysconfig-keyboard.patch
  to allow that open, seek, and read of /dev/mem may fail e.g.
  on XEN based virtual guests (bsc#961120)
* Tue Mar  1 2016 werner@suse.de
- Add upstream patch
  0001-core-exclude-.slice-units-from-systemctl-isolate.patch
  this fixes forced logouts on isolate target aka changing runlevel
  (boo#966535)
* Thu Feb  4 2016 lnussel@suse.de
- require curl and bzip2 to build importd
- curl also causes building of journal-upload. That one has rather
  unusal certificate usage, set it's ca root to /etc/pki/systemd
  instead of the built-in default /etc/ssl as journal-remote and
  journal-upload think they kan put stuff in /etc/ssl/certs then but
  that directory is managed by p11-kit and doesn't serve the purpose
  those programs think.
- /var/lib/systemd/random-seed is a file
- own /var/lib/machines
- add systemd-228-nspawn-make-journal-linking-non-fatal-in-try-and-auto.diff
* Sat Jan  9 2016 afaerber@suse.de
- systemd-sysv-install: Fix chkconfig argument for disable op
* Thu Jan  7 2016 olaf@aepfle.de
- Create groups adm,input,tape in fixed order (boo#944660)
* Mon Dec 21 2015 fbui@suse.com
- Make sure we don't use tmpfs on /tmp by default (bsc#940522)
* Mon Dec 21 2015 jengelh@inai.de
- Avoid enabling readahead services; they have been removed.
- In %%install, only process kbd-model-map.xkb-generated if it
  exists. Resolves a build failure in 13.2/42.1.
* Wed Dec  9 2015 crrodriguez@opensuse.org
- spec: update minimum kernel version to 3.11
- Update minimum util-linux version to 2.27.1
* Thu Dec  3 2015 tchvatal@suse.com
- Add patch to enable working steam controller:
  * 1099-Add-default-rules-for-valve-steam-controller-to-work.patch
* Mon Nov 30 2015 thomas.blume@suse.com
- fix CVE-2015-7510: Stack overflow in nss-mymachines (boo#956712)
  Add 0001-nss-mymachines-do-not-allow-overlong-machine-names.patch
* Wed Nov 18 2015 jengelh@inai.de
- Update to new upstream release 228
  * The various memory-related resource limit settings (such as
  LimitAS=) now understand the usual K, M, G, ... suffixes to
  the base of 1024 (IEC). Similar, the time-related settings
  understand the usual min, h, day, ... suffixes now.
  * CPUAffinity= now takes CPU index ranges in addition to just
  individual indexes.
  * A number of properties previously only settable in unit
  files are now also available as properties to set when
  creating transient units programmatically via the bus.
- Remove 0001-Make-sure-the-mount-units-pulled-by-RequiresMountsFo.patch
  (merged upstream)
* Fri Nov 13 2015 sor.alexei@meowr.ru
- Update to 227.
- Rebase systemd-pam_config.patch,
  handle-root_uses_lang-value-in-etc-sysconfig-language.patch,
  0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch,
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch,
  0014-journald-with-journaling-FS.patch,
  0019-make-completion-smart-to-be-able-to-redirect.patch,
  avoid-divide-by-zero-sigtrap.patch, systemd-add-user-keep.patch,
  set-and-use-default-logconsole.patch,
  tty-ask-password-agent-on-console.patch,
  0001-bnc888612-logind-polkit-acpi.patch,
  watch_resolv.conf_for_become_changed.patch,
  1097-udevd-increase-maximum-number-of-children.patch.
- Remove
  0002-units-enable-waiting-for-unit-termination-in-certain.patch,
  1001-re-enable-by_path-links-for-ata-devices.patch,
  rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch:
  fixed upstream.
* Thu Nov 12 2015 werner@suse.de
- Modify patch handle-root_uses_lang-value-in-etc-sysconfig-language.patch
  to handle locale at boot time well (boo#927250)
- Be able to use build service environments several times
* Tue Nov 10 2015 schwab@suse.de
- 1096-new-udev-root-symlink-generator.patch: fix substitution in
  ExecStart value
* Wed Oct 21 2015 dmueller@suse.com
- enable seccomp for aarch64 (fate#318444)
* Thu Oct 15 2015 fbui@suse.com
- Fix again UEFI for mini package
* Thu Oct 15 2015 jengelh@inai.de
- Drop one more undesirable Obsoletes/Provides. This should have
  been a Conflicts. (There was already a Conflicts, and since
  Conflicts go both ways, we won't need a second one.)
* Thu Oct 15 2015 werner@suse.de
- No UEFI for systemd-mini
* Mon Oct 12 2015 fbui@suse.com
- Add 2 upstream patches to fix boo#949574 and bsc#932284
  0001-Make-sure-the-mount-units-pulled-by-RequiresMountsFo.patch
  0002-units-enable-waiting-for-unit-termination-in-certain.patch
* Fri Oct  9 2015 fbui@suse.com
- Disable systemd-boot on aarch64 since it fails to build.
  Error while compiling src/boot/efi/util.o is:
  usr/include/efi/aarch64/efibind.h:2:20: fatal error: stdint.h: No such file or directory
* Fri Oct  9 2015 fbui@suse.com
- Fix UEFI detection logic: basically we let configure.ac figure out
  if UEFI is supported by the current build environment. No need to
  clutter the spec file with a new conditionnal %%has_efi.
- Provide systemd-bootx64.efi (aka gummiboot)
* Tue Oct  6 2015 werner@suse.de
- Modify patch tty-ask-password-agent-on-console.patch to reflect
  the changes done for pull request 1432
* Thu Oct  1 2015 jengelh@inai.de
- Undo Obsoletes/Provides (from Aug 11), creates too big a cycle.
- Provide systemd-sysv-install program/link [bnc#948353]
* Fri Sep 25 2015 werner@suse.de
- Fix patch tty-ask-password-agent-on-console.patch not to crash
  away but enable it to ask on all devices of /dev/console
* Wed Sep 23 2015 jengelh@inai.de
- Avoid "file not found /etc/udev/rules.d/70-persistent-net.rules"
  waring occurring in %%post
* Wed Sep 23 2015 werner@suse.de
- Add patch let-vconsole-setup-get-properties-only-once-to-copy-them.patch
  to avoid broken virtual console mapping due stressed ioctl API
  for the virtual consoles (boo#904214)
* Mon Sep  7 2015 werner@suse.de
- Fix last change that is use the new name for udev packages in %%pretrans.
* Mon Sep  7 2015 fbui@suse.com
- restore usage of LUA in %%pretrans.
* Mon Sep  7 2015 werner@suse.de
- Try to generate the systemd users and groups always in same order
  to avoid republish other packages (boo#944660)
* Fri Aug 21 2015 fbui@suse.com
- cleanup specfile by removing commands that were dealing with systemd
  pre-generated files: we're now using systemd tarball generated directly
  from the git repo which doesn't contain any of these files.
- there's no point in using LUA in %%pretrans
* Wed Aug 19 2015 fbui@suse.com
- Drop 0009-make-xsltproc-use-correct-ROFF-links.patch
  This patch was initialy added to workaround bsc#842844. But it
  appears that man(1) was fixed (included since 13.2 at least) to
  handle manual pages that consist only of a .so directive such as
  '.so <page>'.
* Thu Aug 13 2015 werner@suse.de
- Change use-rndaddentropy-ioctl-to-load-random-seed.patch to
  make it work on big endian
* Tue Aug 11 2015 jengelh@inai.de
- Use Obsolete/Provides strategy from
  windows:mingw:mingw64/mingw64-cross-gcc to do the bootstrap
  cycle and kick out -mini afterwards.
* Tue Aug 11 2015 jengelh@inai.de
- Update to new upstream release 224
  * systemd-networkd gained a number of new configuration options
  for DHCP, tunnels and bridges
  * systemd-efi-boot-generator functionality was merged into
  systemd-gpt-auto-generator.
* Mon Aug 10 2015 sndirsch@suse.com
- /usr/share/systemd/kbd-model-map: added entries for
  xkeyboard-config converted keymaps; mappings, which already
  exist in original systemd mapping table are being ignored
  though, i.e. not overwritten; needs kbd in buildrequires
  (FATE#318426)
* Wed Jul 29 2015 meissner@suse.com
- hostname-NULL.patch: Work around a crash on XEN hosts
  in OBS. /etc/hostname is not present and systemd then does
  strchr(hostname,soemthing) with hostname NULL.
* Wed Jul 29 2015 werner@suse.de
- Add Correct_assert_on_unexpected_error_code.patch to work around
  a problem of an assert on ENODEV for closing fd on an input
  event device (boo#939571)
* Mon Jul 13 2015 jengelh@inai.de
- Remove udev-generate-rules.sh, apparently not used by anything in
  the systemd nor udev-persistent-ifnames package.
* Wed Jul  8 2015 crrodriguez@opensuse.org
- Systemd v222, bugfix release.
- Drop upstream patches
  0006-pam_systemd-Properly-check-kdbus-availability.patch
  0023-core-fix-reversed-dependency-check-in-unit_check_unn.patch
  0031-install-fix-bad-memory-access.patch
  1032-ata_id-unbotch-format-specifier.patch
- Drop SUSE patch 1013-no-runtime-PM-for-IBM-consoles.patch
  udev does no longer enable USB HID power management at all.
- The udev accelerometer helper was removed, obsoleted by
  iio-sensor-proxy package.
- networkd gained a new configuration option IPv6PrivacyExtensions.
- udev does not longer support the WAIT_FOR_SYSFS= key in udev
  rules. There are no known issues with current sysfs,
  and udev does not need or should be used to work around such bugs.
* Tue Jul  7 2015 jengelh@inai.de
- Avoid restarting logind [bnc#934901]
- Do not suppress errors in any case, even if they are ignored
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Fix devel package requires (both mini and real required real libsystemd0)
* Fri Jul  3 2015 werner@suse.de
- Rework patch  tty-ask-password-agent-on-console.patch to fit the
  requisition of https://bugs.freedesktop.org/show_bug.cgi?id=82004
* Wed Jul  1 2015 jengelh@inai.de
- Rework "-mini" package logic to not conflict with itself and
  then add libsystemd0 to mini.
* Wed Jul  1 2015 crrodriguez@opensuse.org
- remove SysVStartPriority= from after-local.service,
  unsupported since v218.
  Note that this option was only parsed and that's it. the logic
  to give "start priority" was never implemented.
* Wed Jul  1 2015 crrodriguez@opensuse.org
- change the default fallback ntp servers to the opensuse
  pool.ntp.org vendor zone.
- We still need to run systemd-sysctl.service after local-fs.target
  otherwise it works only when /boot is in the root filesystem but
  not when it is a separate partition.
* Fri Jun 26 2015 sbrabec@suse.com
- Obsolete pm-utils and suspend (boo#925873).
- Remove pm-utils support
  (remove Forward-suspend-hibernate-calls-to-pm-utils.patch).
* Thu Jun 25 2015 crrodriguez@opensuse.org
- remove patch sysctl-handle-boot-sysctl.conf-kernel_release.patch
  from the filelist.
* Thu Jun 25 2015 crrodriguez@opensuse.org
- libpcre, glib2 and libusb are not used by systemd, remove
  from buildrequires.
* Thu Jun 25 2015 crrodriguez@opensuse.org
- 1032-ata_id-unbotch-format-specifier.patch: fix udev ata_id
  output.
- 0023-core-fix-reversed-dependency-check-in-unit_check_unn.patch
  fix StopWhenUnneeded=true in combination with a Requisite=
  dependency.
- 0031-install-fix-bad-memory-access.patch: Fix Bad memory access
-  0006-pam_systemd-Properly-check-kdbus-availability.patch: if
  kdbus is enabled (i.e boot with kdbus=1) DBUS_SESSION_BUS_ADDRESS
  must not be exported.
- spec: add a min_kernel_version macro to ensure the package
  conflicts with kernel versions in which systemd cannot run.
* Wed Jun 24 2015 crrodriguez@opensuse.org
- sysctl-handle-boot-sysctl.conf-kernel_release.patch dropped,
  replaced by a tmpfiles.d snippet "current-kernel-sysctl.conf"
  (feature implemented in v220 just for our usecase)
* Wed Jun 24 2015 crrodriguez@opensuse.org
- fix build when resolved is enabled
- remove fsck -l test in spec file, systemd requires util-linux
  2.26 or later where this feature is already available.
* Wed Jun 24 2015 hrvoje.senjan@gmail.com
- Fix bootstrap build by guarding filelists (man pages don't get
  built in bootstrap mode)
- Drop commented sections from baselibs.conf, allows format_spec_file
  to have a successful run
* Wed Jun 24 2015 mpluskal@suse.com
- Install 50-coredump.conf as coredumpctl is now installed by
  default and does not use journal anymore as default storage
* Fri Jun 19 2015 jengelh@inai.de
- Update to new upstream release 221
  * From 220:
  * libgudev was moved into a package of its own
  * Runlevels 2, 3 and 4 are no longer distinct, they all map to
  multi-user.target.
  * The EFI System Partition mounted to /boot will be unmounted
  2 minutes after boot.
  * systemd does not support direct live-upgrades (via `systemctl
  daemon-reexec`) from versions older than v44 anymore.
  * systemd-nspawn may now be called as part of a shell pipeline.
  * systemd-shutdownd has been removed. This service was
  previously responsible for implementing scheduled shutdowns
  as exposed in /usr/bin/shutdown's time parameter. This
  functionality has now been moved into systemd-logind and is
  accessible via a bus interface.
  * udev will no longer call blkid and create symlinks for all
  block devices, but merely those from a whitelist
  (cf. 60-persistent-storage.rules).
  * /usr/lib/os-release gained a new optional field VARIANT=
  * Details at
  http://lists.freedesktop.org/archives/systemd-devel/2015-May/032147.html
  * From 221:
  * New sd-bus and sd-event APIs in libsystemd
  * If there is both a systemd unit and a SysV init script for the
  same service name, and `systemctl enable` or other operation is
  run, both will now be enabled (or execute the related operation
  on both), not just the unit.
- Split libsystemd0 to support systemd-less nspawn containers
- Redo manpage file lists without %%exclude, tends to hide
  unpackaged files.
- hwdb belongs to udev
- Resolve memory leak and add missing _cleanup_free_ to
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
- Remove systemd-powerd-initctl-support.patch
  (no longer builds because shutdownd is gone)
- Remove quilt-patches/0001-core-rework-device-state-logic.patch,
  0001-Let-some-boolean-survive-a-daemon-reload.patch
  (merged upstream),
  0001-Let-some-boolean-survive-a-daemon-reload.patch
  (obsolete)
* Thu Jun 11 2015 werner@suse.de
- Remove libudev0 from baselibs.conf
* Thu Jun 11 2015 werner@suse.de
- Drop 1055-let-9719859c07aa13539ed2cd4b31972cd30f678543-apply.patch
  as now upstream code
- Add 0001-Let-some-boolean-survive-a-daemon-reload.patch to fix
  bsc#933365 and boo#934077
* Tue Jun  2 2015 pwieczorkiewicz@suse.com
- Add 1098-systemd-networkd-alias-network-service.patch to alias
  network.service the same way NetworkManager and wicked does.
  This is needed by yast2 and other parts of the system. boo#933092
* Mon May 18 2015 werner@suse.de
- Modify patch 1021-udev-re-add-persistent-net-rules.patch to use
  the new return values of proc_cmdline() in enable_name_policy()
  this should fix boo#931165
* Mon May 18 2015 jengelh@inai.de
- Drop 1021-udev-re-add-persistent-net-rules.patch,
  1036-rules-disable-usage-of-dev_id-in-persistent-rules.patch,
  1040-re-enable-dev_id-conditionally-in-persistent-rules.patch,
  1046-fix-duplicated-rules-with-layer3-interfaces.patch,
  1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch,
  1051-check-if-NAME-has-a-value.patch,
  1053-better-checks-in-write_net_rules.patch,
  1088-drop-renaming-of-virtual-interfaces-in-guest.patch.
  1021 originally broke parsing of net.ifnames=0 [bnc#931165],
  and given that neither the kernel command line needs to be
  touched nor the source be patched to reach the unpredictable
  naming setup for SLE, all these parts are moved to a separate
  package.
* Mon Mar 16 2015 werner@suse.de
- Add upstream patch
  0001-core-don-t-change-removed-devices-to-state-tentative.patch
  to fix the fix of the last backport (bsc#921898)
* Thu Mar  5 2015 jengelh@inai.de
- Reenable networkd which was silently disabled on Feb 18
* Tue Mar  3 2015 jengelh@inai.de
- Add 0001-core-rework-device-state-logic.patch to fix spurious
  automated umount after mount.
* Wed Feb 18 2015 meissner@suse.com
- mark more subpackages as !bootstrap for systemd-mini usage.
* Wed Feb 18 2015 crrodriguez@opensuse.org
- spec : remove --with-firmware-path, firmware loader was removed in v217
- spec: remove --disable-multi-seat-x, gone.(fixed in xorg)
- spec: Do not enable systemd-readahead-collect.service and
  systemd-readahead-replay.service as these do not exist anymore.
- spec: drop timedate-add-support-for-openSUSE-version-of-etc-sysconfig.patch
  Yast was fixed to write all timezone changes exactly how timedated expects
  things to be done.
- spec: remove handle-etc-HOSTNAME.patch, since late 2014 the netcfg
  package handles the migration from /etc/HOSTNAME to /etc/hostname
  and owns both files.
-spec: remove boot.udev and systemd-journald.init as they currently
  serve no purpose.
- suse-sysv-bootd-support.diff: Remove HAVE_SYSVINIT conditions, we
  are in sysvcompat-only codepath, also remove the code targetting other
  distributions, never compiled as the TARGET_$DISTRO macros are never defined.
- systemd-powerd-initctl-support.patch guard with HAVE_SYSV_COMPAT
- set-and-use-default-logconsole.patch: fix HAVE_SYSV_COMPAT guards
- insserv-generator.patch: Only build when sysvcompat is enabled
- vhangup-on-all-consoles.patch add a comment indicating this is a workaround
  for a kernel bug.
- spec: Add option to allow disabling sysvinit compat at build time.
- spec: Add option to enable resolved at build time.
- spec: Remove all %%ifs for !factory products, current systemd releases can
  neither be built nor installed in older products without upgrading
  several components of the base system.
  (removed: 1008-add-msft-compability-rules.patch was only for =< 13.1)
- spec: remove all dummy "aliases" to /etc/init.d, that made sense only when
  those init scripts still existed. (dummy localfs.service source: gone)
- systemd-sleep-grub: moved to the grub2 package where it belongs as a
  suspend/resume hook (SR#286533) (drops prepare-suspend-to-disk.patch)
- remove LFS_CFLAGS from CFLAGS, never needed in systemd as it force feds
  config.h everywhere in the preprocessor cmdline.
* Mon Feb 16 2015 jengelh@inai.de
- Update to new upstream release 219
  * systemd units can now be "unsupported" (like, for example,
  .device in a containers), similar to the "skipped" state in
  SUSE's prior sysvinit scripts.
  * tmpfiles gained the 'v' type for creating btrfs subvolumes.
  * tmpfiles gained the 'a' type for setting ACLs.
  * systemd-nspawn gained new switches: --ephemeral, --template
  * The /var/lib/containers location is deprecated and replaced by
  /var/lib/machines.
  * machinectl gained the copy-from and copy-to commands.
  * machinectl now knows a "bind" command (for use with nspawn)
  * new "systemd-importd" daemon to download container images and run
  them as nspawn containers.
  * networkd collects LLDP network announcements, if available, and
  so shown in networkctl.
  * The fallback terminal type was changed from "vt102" to "vt220",
  allowing PgUp/PgDn keys to work.
  * Pressing Ctrl-Alt-Del 7x in 2 seconds forces a umount+reboot now,
  useful should the regular shutdown hang.
  * Removing storage will cause systemd to unmount the associated
  mountpoints so that they don't linger around.
* Mon Feb 16 2015 jengelh@inai.de
- Add suse-sysv-bootd-support.diff (reinstate old
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch)
* Mon Feb 16 2015 jengelh@inai.de
- Update to systemd v218-1050-g38ab096
- Remove patches
  use-usr-sbin-sulogin-for-emergency-service.patch (upstream fixed it)
- Reinstate and improve (remove huge indents from)
  tty-ask-password-agent-on-console.patch,
  0014-journald-with-journaling-FS.patch, rootsymlink_generator.
* Mon Feb 16 2015 meissner@suse.com
- disable systemd-resolved for now as it interacts not well with
  our methods and security has concerns regarding spoofing. bsc#917781
* Tue Jan 20 2015 werner@suse.de
- Add patch kbd-model-map.patch to add missed keyboard layouts
  which are offered by YaST2 (bsc#910643 and boo#897803)
* Fri Jan  9 2015 jengelh@inai.de
- Update to new upstream release 218
  * New utilities: systemd-timesyncd (SNTP client),
  systemd-resolved, systemd-networkd, networkctl,
  systemd-sysusers
  * machinectl gained a "poweroff" command for clean container shutdown
  * The udev hwdb now contains DPI information for mice.
  * Userspace firmware loading support has been removed and
  the minimum supported kernel version is thus bumped to 3.7.
- Remove patches:
  G=gone locally, is upstream;
  D=dropped: no longer needed;
  N=no longer applies to source nor is it deemed needed;
  K=killed: no longer applicable and too complex to resolve:
  - ---
  G 0002-rfkill-rework-how-we-generate-file-names-from-rfkill.patch
  G avoid-assertion-if-invalid-address-familily-is-passed-to-g.patch
  K service-flags-sysv-service-with-detected-pid-as-RemainAfte.patch
  K remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch
  K handle-SYSTEMCTL_OPTIONS-environment-variable.patch
  K 0018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  K log-target-null-instead-kmsg.patch
  K tty-ask-password-agent-on-console.patch
  K 513-nspawn-veth.patch
  K 1087-infinit-timeout-for-kmod-loaded-modules.patch
  D module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  D avoid-leaking-socket-descriptors.patch
  D 0001-make-fortify-happy-with-ppoll.patch
  N fix-owner-of-var-log-btmp.patch
  N disable-nss-myhostname-warning-bnc-783841.patch
  N Revert-service-drop-support-for-SysV-scripts-for-the-early.patch
  N 0001-make-209-working-on-older-dist.patch
  N 0001-Don-t-snprintf-a-potentially-NULL-pointer.patch
  N tmpfiles-do-not-clean-for-mandb-index-files.patch
  G 0001-sd-bus-don-t-look-for-a-64bit-value-when-we-only-hav.patch
  G avoid-assertion-if-invalid-address-familily-is-passed-to-g.patc
  G optionally-warn-if-nss-myhostname-is-called.patch
  G 0001-units-systemd-sysctl.service.in-run-after-load-modul.patch
  G 0004-getty-generator-properly-escape-instance-names.patch
  G rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  G 0008-Reset-signal-mask-on-re-exec-to-init.patch
  G 0001-login-fix-pos-array-allocation.patch
  G 0002-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  G 0003-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  G 0004-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  G 0005-Replace-var-run-with-run-in-remaining-places.patch
  G 0006-Revert-back-to-var-run-at-a-couple-of-problems.patch
  G 0007-README-document-that-var-run-must-be-a-symlink-run.patch
  G 0008-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  G 0009-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  G 0010-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  G 0011-logs-show-fix-corrupt-output-with-empty-messages.patch
  G 0012-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  G 0014-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  G 0001-Fix-systemd-stdio-bridge-symlink.patch
  G 0002-execute-free-directory-path-if-we-fail-to-remove-it-.patch
  G 0003-Do-not-print-invalid-UTF-8-in-error-messages.patch
  G 0004-man-document-missing-options-of-systemd-run.patch
  G 0005-systemd-run-add-some-extra-safety-checks.patch
  G 0006-journal-assume-that-next-entry-is-after-previous-ent.patch
  G 0007-journal-forget-file-after-encountering-an-error.patch
  G 0008-core-correctly-unregister-PIDs-from-PID-hashtables.patch
  G 0009-logind-fix-reference-to-systemd-user-sessions.servic.patch
  G 0010-man-update-link-to-LSB.patch
  G 0011-man-systemd-bootchart-fix-spacing-in-command.patch
  G 0012-man-add-missing-comma.patch
  G 0013-units-Do-not-unescape-instance-name-in-systemd-backl.patch
  G 0001-core-busname-add-lookup-string-for-BUSNAME_FAILURE_S.patch
  G 0002-manager-flush-memory-stream-before-using-the-buffer.patch
  G 0003-busname-don-t-drop-service-from-the-result-string.patch
  G 0004-fix-off-by-one-error-in-array-index-assertion.patch
  G 0005-logind-fix-policykit-checks.patch
  G 0006-rules-mark-loop-device-as-SYSTEMD_READY-0-if-no-file.patch
  G 0008-man-multiple-sleep-modes-are-to-be-separated-by-whit.patch
  G 0001-gpt-auto-generator-don-t-return-OOM-on-parentless-de.patch
  G 0002-bus-fix-memory-leak-when-kdbus-is-not-enabled.patch
  G 0006-Do-not-return-1-EINVAL-on-allocation-error.patch
  G 0007-networkd-fix-typo.patch
  G 0008-sd-bus-don-t-access-invalid-memory-if-a-signal-match.patch
  G 0009-sd-bus-don-t-choke-if-somebody-sends-us-a-message-wi.patch
  G 0012-journald-remove-stray-reset-of-error-return-value.patch
  G 0013-core-libsystemd-systemd-timedate-udev-spelling-fixes.patch
  G 0001-cgroup-it-s-not-OK-to-invoke-alloca-in-loops.patch
  G 0002-machined-fix-Kill-bus-call-on-machine-objects-when-w.patch
  G 0003-sd-bus-don-t-use-assert_return-to-check-for-disconne.patch
  G 0004-core-don-t-try-to-relabel-mounts-before-we-loaded-th.patch
  G 0005-sd-daemon-fix-incorrect-variable-access.patch
  G 0006-sd-event-initialization-perturbation-value-right-bef.patch
  G 0007-sd-event-don-t-accidentally-turn-of-watchdog-timer-e.patch
  G 0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
  G 0009-ask-password-when-the-user-types-a-overly-long-passw.patch
  G 0001-journal-fix-export-of-messages-containing-newlines.patch
  G 0002-systemctl-update-NAME-to-PATTERN-in-help.patch
  G 0003-tty-ask-password-agent-return-negative-errno.patch
  G 0004-systemd-python-use-.hex-instead-of-.get_hex.patch
  G 0005-systemd-python-fix-failing-assert.patch
  G 0007-dbus-suppress-duplicate-and-misleading-messages.patch
  G 0001-reduce-the-amount-of-messages-logged-to-dev-kmsg-whe.patch
  G 0001-bash-completion-fix-__get_startable_units.patch
  G 0002-sysctl-replaces-some-slashes-with-dots.patch
  G 0003-delta-do-not-use-unicode-chars-in-C-locale.patch
  G 0004-implement-a-union-to-pad-out-file_handle.patch
  G shut-up-annoying-assertion-monotonic-clock-message.patch
  G 0001-sd-rtnl-message-append-fix-uninitialized-memory.patch
  G 0001-tmpfiles-fix-permissions-on-new-journal-files.patch
  G 0001-errno-make-sure-to-handle-the-3-errnos-that-are-alia.patch
  G 0003-analyze-fix-plot-with-bad-y-size.patch
  G 0004-job-add-waiting-jobs-to-run-queue-in-unit_coldplug.patch
  G 0005-job-always-add-waiting-jobs-to-run-queue-during-cold.patch
  G 0001-backlight-Avoid-restoring-brightness-to-an-unreadabl.patch
  G 0002-backlight-do-nothing-if-max_brightness-is-0.patch
  G 0003-backlight-unify-error-messages.patch
  G 0004-backlight-warn-if-kernel-exposes-backlight-device-wi.patch
  G 0005-backlight-handle-saved-brightness-exceeding-max-brig.patch
  G 0001-replace-more-dup-by-F_DUPFD_CLOEXEC.patch
  G 0002-pam_systemd-use-F_DUPFD_CLOEXEC-when-dupping-session.patch
  G 0001-core-close-socket-fds-asynchronously.patch
  G 0002-logind-bring-polkit-policy-for-hibernate-in-line-wit.patch
  G 0003-core-make-sure-to-serialize-jobs-for-all-units.patch
  G 0001-logind-ignore-lid-switch-if-more-than-1-display-is-c.patch
  G 0002-logind-fix-printf-format.patch
  G 0003-logind-ignore-lid-switch-events-for-30s-after-each-s.patch
  G 0004-logind-Do-not-fail-display-count-if-a-device-has-no-.patch
  G 0005-logind-move-lid-switch-handling-from-logind-main-to-.patch
  G 0006-man-clarify-that-the-ExecReload-command-should-be-sy.patch
  G 0007-man-readahead-fix-cmdline-switch-inconsistency-betwe.patch
  G 0008-man-update-journald-rate-limit-defaults.patch
  G 0009-nspawn-properly-format-container_uuid-in-UUID-format.patch
  G 0010-logind-allow-suspending-if-there-are-no-displays.patch
  G 0001-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0002-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0003-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0004-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0005-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-conf-parser-silently-ignore-sections-starting-with-X.patch
  G 0002-man-note-that-entire-sections-can-now-be-ignored.patch
  G 0004-machined-make-sure-GetMachineAddresses-is-available-.patch
  G 0005-core-Filter-by-state-behind-the-D-Bus-API-not-in-the.patch
  G 0006-login-add-mir-to-the-list-of-session-types.patch
  G 0007-logind-fix-Display-property-of-user-objects.patch
  G 0001-hwdb-update.patch
  G 0002-hwdb-update.patch
  G 0003-hwdb-PCI-include-primary-model-string-in-subsystem-m.patch
  G 0004-hwdb-update.patch
  G 0005-hwdb-update.patch
  G 0001-journal-cleanup-up-error-handling-in-update_catalog.patch
  G 0002-journal-properly-detect-language-specified-in-line.patch
  G 0003-man-mention-XDG_CONFIG_HOME-in-systemd.unit.patch
  G 0001-keymap-Add-Lenovo-Enhanced-USB-Keyboard.patch
  G 0002-keymap-Asus-EeePC-touchpad-toggle-key.patch
  G 0001-nspawn-allow-to-bind-mount-journal-on-top-of-a-non-e.patch
  G 0002-nspawn-restore-journal-directory-is-empty-check.patch
  G 0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  G 0004-socket-properly-handle-if-our-service-vanished-durin.patch
  G 0001-Do-not-unescape-unit-names-in-Install-section.patch
  G 0002-analyze-run-use-bus_open_transport_systemd-instead-o.patch
  G 0001-virt-rework-container-detection-logic.patch
  G 0002-fsck-include-device-name-in-the-message-about-missin.patch
  G 0003-units-use-KillMode-mixed-for-systemd-nspawn-.service.patch
  G 0004-util-ignore_file-should-not-allow-files-ending-with.patch
  G 0006-tty-ask-password-agent-Do-tell-what-directory-we-fai.patch
  G 0007-keyboard-add-Plantronics-.Audio-mute-button.patch
  G 0001-build-sys-use-glibc-s-xattr-support-instead-of-requi.patch
  G 0001-hwdb-fix-case-sensitive-match.patch
  G 0001-sd-event-restore-correct-timeout-behaviour.patch
  G 0002-bus-make-use-of-sd_bus_try_close-in-exit-on-idle-ser.patch
  G 0001-umount-modernizations.patch
  G 0002-namespace-when-setting-up-an-inaccessible-mount-poin.patch
  G 0003-core-allow-transient-mount-units.patch
  G 0004-systemd-detect-virt-only-discover-Xen-domU.patch
  G 0005-backlight-Do-not-clamp-brightness-for-LEDs.patch
  G 0006-log-honour-the-kernel-s-quiet-cmdline-argument.patch
  G 0001-core-fix-invalid-free-in-killall.patch
  G 0003-install-fix-invalid-free-in-unit_file_mask.patch
  G 0001-systemd-detect-virt-detect-s390-virtualization.patch
  G 0001-core-sysvcompat-network-should-be-equivalent-to-netw.patch
  G 0002-units-add-missing-caps-so-that-GetAddresses-can-work.patch
  G 0003-units-order-systemd-tmpfiles-clean.service-after-tim.patch
  G 0005-po-add-Greek-translation.patch
  G 0006-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0007-po-add-German-translation.patch
  G 0009-core-clean-up-signal-reset-logic-when-reexec.patch
  G 0010-util-treat-fuse.sshfs-as-a-network-filesystem.patch
  G 0011-build-sys-add-pthread-flag-for-libsystemd-shared.patch
  G 0012-core-transaction-avoid-misleading-error-message-when.patch
  G 0001-vconsole-also-copy-character-maps-not-just-fonts-fro.patch
  G 0002-core-make-sure-Environment-fields-passed-in-for-tran.patch
  G 0003-core-You-can-not-put-the-cached-result-of-use_smack-.patch
  G 0004-cryptsetup-don-t-add-unit-dependency-on-dev-null-dev.patch
  G 0005-man-fix-path-in-crypttab-5.patch
  G 0001-units-order-network-online.target-after-network.targ.patch
  G 0001-core-use-correct-format-string-for-UIDs.patch
  G 0002-core-transaction-fix-cycle-break-attempts-outside-tr.patch
  G 0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
  G 0001-main-uid_to_name-might-fail-due-to-OOM-protect-again.patch
  G 0002-journald-make-MaxFileSec-really-default-to-1month.patch
  G 0003-units-remove-RefuseManualStart-from-units-which-are-.patch
  G 0004-util-refuse-considering-UID-0xFFFF-and-0xFFFFFFFF-va.patch
  G 0005-nspawn-block-open_by_handle_at-and-others-via-seccom.patch
  G 0006-tmpfiles-don-t-do-automatic-cleanup-in-XDG_RUNTIME_D.patch
  G 0007-units-skip-mounting-tmp-if-it-is-a-symlink.patch
  G 0001-parse_uid-return-ENXIO-for-1-uids.patch
  G 0002-util-when-unescaping-strings-don-t-allow-smuggling-i.patch
  G 0003-localed-consider-an-unset-model-as-a-wildcard.patch
  G 0004-sd-bus-when-an-event-loop-terminates-explicitly-clos.patch
  G 0005-bus-close-a-bus-that-failed-to-connect.patch
  G 0006-hwdb-update.patch
  G 0007-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-architecture-Add-tilegx.patch
  G 0002-architecture-Add-cris.patch
  G 0003-arch-add-crisv32-to-uname-check.patch
  G 0004-architecture-remove-cris-from-uname-list.patch
  G 0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch
  G 0002-namespace-fix-uninitialized-memory-access.patch
  G 0001-machine-don-t-return-uninitialized-variable.patch
  G 0002-vconsole-setup-run-setfont-before-loadkeys.patch
  G 0001-util-consider-0x7F-a-control-chracter-which-it-is-DE.patch
  G 0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  G 0003-architecture-add-string-table-entries-for-mips-le-ar.patch
  G 0004-core-Added-support-for-ERRNO-NOTIFY_SOCKET-message-p.patch
  G 0005-service-don-t-accept-negative-ERRNO-notification-mes.patch
  G 0006-systemctl-show-StatusErrno-value-in-systemctl-status.patch
  G 0007-service-flush-status-text-and-errno-values-each-time.patch
  G 0001-journal-compress-return-early-in-uncompress_startswi.patch
  G 0002-journal-compress-improve-xz-compression-performance.patch
  G 0001-logind-allow-switching-to-unused-VTs-via-SwitchTo.patch
  G 0002-hostnamed-add-a-new-chassis-type-for-watches.patch
  G 0001-units-make-ExecStopPost-action-part-of-ExecStart.patch
  G 0001-event-pull-in-sd-event.h-from-event-util.h.patch
  G 0002-util-fix-has-cc-check-and-add-test.patch
  G 0003-sd-event-always-call-epoll_ctl-on-mask-updates-if-ed.patch
  G 0004-fileio-quote-more-shell-characters-in-envfiles.patch
  G 0001-Clear-up-confusion-wrt.-ENTRY_SIZE_MAX-and-DATA_SIZE.patch
  G 0002-units-serial-getty-.service-use-the-default-RestartS.patch
  G 0001-po-add-Ukrainian-translation.patch
  G 0002-man-document-yearly-and-annually-in-systemd.time-7.patch
  G 0003-core-nicer-message-when-inotify-watches-are-exhauste.patch
  G 0001-detect-virt-Fix-Xen-domU-discovery.patch
  G 0002-Be-more-verbose-when-bind-or-listen-fails.patch
  G 0003-Add-quotes-to-warning-message.patch
  G 0004-systemd-return-the-first-error-from-manager_startup.patch
  G 0001-bash-completion-p-option-for-journalctl.patch
  G 0002-journalctl-man-allow-only-between-terms.patch
  G 0003-systemd-use-pager-for-test-and-help.patch
  G 0001-bus-proxyd-fix-incorrect-comparison.patch
  G 0002-shell-completion-prevent-mangling-unit-names.patch
  G 0003-Always-check-asprintf-return-code.patch
  G 0004-bash-completion-use-list-unit-files-to-get-all-units.patch
  G 0005-core-only-set-the-kernel-s-timezone-when-the-RTC-run.patch
  G 0006-parse_boolean-require-exact-matches.patch
  G 0007-drop_duplicates-copy-full-BindMount-struct.patch
  G 0008-shell-completion-prevent-mangling-unit-names-bash.patch
  G 0009-journald-always-add-syslog-facility-for-messages-com.patch
  G 0001-sysv-order-initscripts-which-provide-network-before-.patch
  G 0002-keymap-Add-microphone-mute-keymap-for-Dell-Latitude.patch
  G 0003-keymap-Annotate-all-micmute-workarounds.patch
  G 0007-hwdb-update.patch
  G 0001-nspawn-fix-truncation-of-machine-names-in-interface-.patch
  G 0002-switch-root-umount-the-old-root-correctly.patch
  G 0003-bootchart-it-s-not-OK-to-return-1-from-a-main-progra.patch
  G 0004-login-set_controller-should-fail-if-prepare_vt-fails.patch
  G 0005-sd-resolve-fix-allocation-if-query-ids-never-reuse-t.patch
  G 0006-login-share-VT-signal-handler-between-sessions.patch
  G 0007-journald-also-increase-the-SendBuffer-of-dev-log-to-.patch
  G 0008-mount-setup-fix-counting-of-early-mounts-without-SMA.patch
  G 0009-journald-Fix-off-by-one-error-in-Missed-X-kernel-mes.patch
  G 0010-machine_kill-Don-t-kill-the-unit-when-killing-the-le.patch
  G 0011-units-fix-BindsTo-logic-when-applied-relative-to-ser.patch
  G 0012-util-try-to-be-a-bit-more-NFS-compatible-when-checki.patch
  G 0001-hwdb-keymaps-for-Samsung-900X3E-900X3F.patch
  G 0002-Add-hwdb-entry-for-Samsung-Series-7-Ultra.patch
  G 0003-keymap-Fix-HP-Pavillon-DV7.patch
  G 0004-hwdb-update-format-description-and-document-reloadin.patch
  G 0008-hwdb-update.patch
  G 0001-systemctl-Correct-error-message-printed-when-bus_pro.patch
  G 0002-units-order-systemd-fsck-.service-after-local-fs-pre.patch
  G 0003-keymap-Adjust-for-more-Samsung-900X4-series.patch
  G 0001-login-fix-memory-leak-on-DropController.patch
  G 0002-util-fix-minimal-race-where-we-might-miss-SIGTERMs-w.patch
  G 0003-sd-journal-properly-convert-object-size-on-big-endia.patch
  G 0004-sd-journal-verify-that-object-start-with-the-field-n.patch
  G 0001-nspawn-fix-network-interface.patch
  G 0001-completion-filter-templates-from-restartable-units.patch
  G 0002-systemd-fix-error-message.patch
  G 0003-Quote-unit-names-in-suggested-systemctl-commandlines.patch
  G 0004-config-parser-fix-mem-leak.patch
  G 0005-login-fix-mem-leak.patch
  G 0001-login-simplify-controller-handling.patch
  G 0001-initrd-parse-etc.service-ignore-return-code-of-daemo.patch
  G 0008-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0009-hwdb-update.patch
  G 0001-systemctl-allow-to-change-the-default-target-without.patch
  G 0001-activate-fix-fd-leak-in-do_accept.patch
  G 0002-analyze-avoid-a-null-dereference.patch
  G 0003-analyze-fix-mem-leak.patch
  G 0004-backlight-Avoid-error-when-state-restore-is-disabled.patch
  G 0005-bus-avoid-using-m-kdbus-after-freeing-it.patch
  G 0006-bus-unref-buscreds-on-failure.patch
  G 0007-core-fix-a-potential-mem-leak.patch
  G 0008-core-smack-setup-Actually-allow-for-succesfully-load.patch
  G 0009-journal-do-not-leak-mmaps-on-OOM.patch
  G 0010-manager-use-correct-cleanup-function.patch
  G 0001-core-fix-resource-leak-in-manager_environment_add.patch
  G 0002-util-remove-a-unnecessary-check.patch
  G 0003-udev-event-explicitly-don-t-read-from-invalid-fd.patch
  G 0004-shared-conf-parser.patch
  G 0005-logind-fix-typo.patch
  G 0006-systemctl-fix-resource-leak-CID-1237747.patch
  G 0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  G 0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patch
  G 0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
  G 0001-journal-Do-not-count-on-the-compiler-initializing-fo.patch
  G 0002-include-fcntl.h-rather-than-sys-fcntl.h.patch
  G 0003-mount-order-options-before-other-arguments-to-mount.patch
  G 0004-shared-wtmp-utmp-don-t-clear-store_wtmp-in-utmp_put_.patch
  G 0005-shared-label.h-add-missing-stdio.h-include.patch
  G 0006-shared-sparse-endian.h-add-missing-byteswap.h-includ.patch
  G 0001-login-pause-devices-before-acknowledging-VT-switches.patch
  G 0001-nspawn-don-t-try-to-create-veth-link-with-too-long-i.patch
  G 0001-socket-introduce-SELinuxContextFromNet-option.patch
  G 0002-util-avoid-non-portable-__WORDSIZE.patch
  G 0001-Fix-warning-about-unused-variable-with-SELINUX.patch
  G 0002-bus-remove-unused-check.patch
  G 0001-systemd-tmpfiles-Fix-IGNORE_DIRECTORY_PATH-age-handl.patch
  G 0001-logind-add-support-for-Triton2-Power-Button.patch
  G 0002-logind-add-support-for-TPS65217-Power-Button.patch
  G 0001-shutdownd-clean-up-initialization-of-struct.patch
  G 0003-bootchart-parse-userinput-with-safe_atoi.patch
  G 0004-bootchart-check-return-of-strftime.patch
  G 0005-bootchart-Do-not-try-to-access-data-for-non-existing.patch
  G 0001-journalctl-do-not-output-reboot-markers-when-running.patch
  G 0002-udev-hwdb-New-Entry-for-Dell-XPS12-9Q33-keyboard.patch
  G 0001-core-swap-only-make-configured-units-part-of-swap.ta.patch
  G 0009-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-virt-detect-that-we-are-running-inside-the-docker-co.patch
  G 0002-bootchart-use-n-a-if-PRETTY_NAME-is-not-found.patch
  G 0003-fileio-label-return-error-when-writing-fails.patch
  G 0001-sd-event-don-t-require-a-signal-event-source-to-be-e.patch
  G 0004-sd-event-check-the-value-of-received-signal.patch
  G 0005-sd-id128-do-stricter-checking-of-random-boot-id.patch
  G 0001-keymap-Fix-touchpad-toggle-on-Toshiba-Satellite-P75-.patch
  G 0001-units-introduce-network-pre.target-as-place-to-hook-.patch
  G 0002-keymap-Fix-touchpad-toggle-key-on-Asus-laptops.patch
  G 0003-sd-bus-check-return-value-of-vasprintf.patch
  G 0004-core-map-the-rescue-argument-to-rescue.target.patch
  G 0005-util-avoid-double-close-of-fd.patch
  G 0001-systemctl-when-mangle-unit-names-for-the-isolate-suf.patch
  G 0001-tmpfiles-compare-return-against-correct-errno.patch
  G 0001-shell-completion-fix-completion-of-inactive-units.patch
  G 0002-shell-completion-propose-templates-for-disable-re-en.patch
  G 0003-man-we-don-t-have-Wanted-dependency.patch
  G 0004-selinux-fix-potential-double-free-crash-in-child-pro.patch
  G 0001-systemd-continue-switch-root-even-if-umount-fails.patch
  G 0002-systemd-try-harder-to-bind-to-notify-socket.patch
  G 0001-strv-add-an-additional-overflow-check-when-enlarging.patch
  G 0002-hwdb-Add-mapping-for-special-keys-on-compaq-ku-0133-.patch
  G 0003-journald-add-CAP_MAC_OVERRIDE-in-journald-for-SMACK-.patch
  G 0004-journal-do-server_vacuum-for-sigusr1.patch
  G 0005-cryptsetup-fix-an-OOM-check.patch
  G 0002-shutdown-pass-own-argv-to-run-initramfs-shutdown.patch
  G 0001-manager-Linux-on-hppa-has-fewer-rtsigs-hence-avoid-u.patch
  G 0002-time-also-support-infinity-syntax-in-parse_nsec.patch
  G 0003-time-earlier-exit-from-format_timestamp_relative-on-.patch
  G 0004-sd-bus-if-we-don-t-manage-to-properly-allocate-the-e.patch
  G 0005-journalctl-correct-help-text-for-until.patch
  G 0006-calendarspec-fix-typo-in-annually.patch
  G 0007-systemctl-do-not-ignore-errors-in-symlink-removal.patch
  G 0008-util-introduce-sethostname_idempotent.patch
  G 0009-util-fix-copy-paste-error-and-actually-set-the-new-h.patch
  G 0010-shutdown-do-final-unmounting-only-if-not-running-ins.patch
  G 0011-selinux-make-sure-we-do-not-try-to-print-missing-fie.patch
  G 0012-manager-do-not-print-anything-while-passwords-are-be.patch
  G 0001-sd-bus-properly-handle-removals-of-non-existing-matc.patch
  G 0002-keymap-Ignore-brightness-keys-on-Dell-Inspiron-1520-.patch
  G 0001-core-don-t-allow-enabling-if-unit-is-masked.patch
  G 0002-snapshot-return-error-when-snapshot-exists.patch
  G 0003-shared-install-avoid-prematurely-rejecting-missing-u.patch
  G 0004-Raise-level-of-Found-dependency.-lines.patch
  G 0005-units-order-sd-journal-flush-after-sd-remount-fs.patch
  G 0006-journald-fix-minor-memory-leak.patch
  G 0007-journald-also-check-journal-file-size-to-deduce-if-i.patch
  G 0008-journald-fix-memory-leak-on-error-path.patch
  G 0009-units-make-systemd-journald.service-Type-notify.patch
  G 0010-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-login-rerun-vconsole-setup-when-switching-from-vgaco.patch
  G 0002-shutdown-fix-arguments-to-run-initramfs-shutdown.patch
  G 0003-utf8-when-looking-at-the-next-unichar-honour-the-siz.patch
  G 0001-keymap-Add-support-for-IBM-ThinkPad-X41-Tablet.patch
  G 0002-keymap-Fix-special-keys-on-ThinkPad-X60-X61-Tablet.patch
  G 0001-systemctl-let-list-units-unit-files-honour-type.patch
  G 0002-systemctl-obey-state-in-list-unit-files.patch
  G 0002-core-watchdog-bus-properties-cannot-be-both-writable.patch
  G 0003-sd-bus-refuse-properties-that-claim-to-be-both-writa.patch
  G 0001-units-make-sure-rfkill-service-is-bount-to-the-actua.patch
  G 0001-selinux-access-fix-broken-ternary-operator.patch
  G 0002-systemctl-show-BindsTo-BoundBy-in-list-dependencies.patch
  G 0003-cryptsetup-default-to-no-hash-when-keyfile-is-specif.patch
  G 0004-core-fix-transaction-destructiveness-check-once-more.patch
  G 0001-units-tmpfiles-setup-dev-allow-unsafe-file-creation-.patch
  G 0002-man-tmpfiles.d-recommend-using-b-and-c.patch
  G 1009-cdrom_id-use-the-old-MMC-fallback.patch
  G 1010-udev-increase-result-size-for-programs.patch
  G 1014-udev-update-net_id-comments.patch
  G 1015-udev-persistent-naming-we-cannot-use-virtio-numbers-.patch
  G 1016-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  G 1017-udev-serialize-synchronize-block-device-event-handli.patch
  G 1018-udev-do-not-skip-the-execution-of-RUN-when-renaming-.patch
  G 1019-udev-avoid-use-of-uninitialized-err.patch
  G 1020-udev-keyboard-also-hook-into-change-events.patch
  G 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
  G 1023-udev-builtin-keyboard-do-tell-on-which-device-EVIOCS.patch
  G 1024-udev-always-close-lock-file-descriptor.patch
  G 1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
  G 1026-udevd-inotify-modernizations.patch
  G 1027-udev-synthesize-change-events-for-partitions-when-to.patch
  G 1028-udev-link-config-fix-mem-leak.patch
  G 1029-udev-try-first-re-reading-the-partition-table.patch
  G 1030-udev-guard-REREADP-logic-with-open-O_ECXL.patch
  G 1031-udev-make-sure-we-always-get-change-for-the-disk.patch
  G 1032-udev-guard-REREADPT-by-exclusive-lock-instead-of-O_E.patch
  G 1033-udev-really-exclude-device-mapper-from-block-device.patch
  G 1034-udev-check-the-return-value-from-udev_enumerate_scan.patch
  G 1038-udev-fix-invalid-free-in-enable_name_policy.patch
  G 1039-udevadm-settle-fixed-return-code-for-empty-queue.patch
  G 1041-libudev-fix-udev_queue_get_queue_is_empty-logic.patch
  G 1042-libudev-queue-provide-file-descriptor-to-watch-busy-.patch
  G 1043-libudev-queue-watch-entire-directory-to-allow-the-re.patch
  G 1044-rules-update-qemu-hid-rules.patch
  G 1045-rules-don-t-enable-usb-pm-for-Avocent-devices.patch
  G 1047-udev-net_setup_link-builtin-should-print-the-reason-.patch
  G 1048-udev-net_setup_link-add-a-bit-more-logging.patch
  G 1049-udev-link_config-ignore-errors-due-to-missing-MAC-ad.patch
  G 1052-rules-uaccess-add-ID_SOFTWARE_RADIO.patch
  G 1054-udev-exclude-MD-from-block-device-ownership-event-lo.patch
  G 1056-udevd-add-event-timeout-commandline-option.patch
  G 1057-udev-unify-event-timeout-handling.patch
  G 1058-udev-unify-event-timeout-handling.patch
  G 1059-udev-fixup-commit-dd5eddd28a74a49607a8fffcaf960040db.patch
  G 1061-rules-allow-systemd-to-manage-loop-device-partitions.patch
  G 1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patch
  G 1064-udev-hwdb-do-not-look-at-usb_device-parents.patch
  G 1065-udev-bump-event-timeout-to-60-seconds.patch
  G 1067-udev-always-resolve-correctly-database-names-on-chan.patch
  G 1068-udev-net_setup_link-export-the-.link-filename-applie.patch
  G 1069-rules-net-setup-link-preserve-ID_NET_LINK_FILE-and-I.patch
  G 1070-rules-net-setup-link-remove-stray-linebreak.patch
  G 1071-udev-import-the-full-db-on-MOVE-events-for-devices-w.patch
  G 1072-udev-netif_rename-don-t-log-to-kmsg.patch
  G 1073-udev-drop-print_kmsg.patch
  G 1074-udev-fix-copy-paste-error-in-log-message.patch
  G 1075-udev-timeout-increase-timeout.patch
  G 1076-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch
  G 1077-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch
  G 1078-udev-remove-userspace-firmware-loading-support.patch
  G 1079-udev-remove-userspace-firmware-loading-support.patch
  G 1080-udevd-parse_argv-warn-if-argumens-are-invalid.patch
  G 1081-udevd-check-return-of-various-functions.patch
  G 1082-udevadm-hwdb-check-return-value-of-fseeko.patch
  G 1083-udev-node-warn-if-chmod-chown-fails.patch
  G 1084-udev-ctrl-log-if-setting-SO_PASSCRED-fails.patch
  G 1085-udev-fix-typos.patch
  G 1086-udevd-don-t-fail-if-run-udev-exists.patch
  G 1089-fix-cgroup-device-controller.patch
  G 1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  G 1091-udev-path_id-update-comments.patch
  G 1092-libudev-do-not-accept-invalid-log-levels.patch
  G 1093-udev-Fix-parsing-of-udev.event-timeout-kernel-parame.patch
  G 1094-udev-avoid-magic-constants-in-kernel-cmdline-parsers.patch
  G 1098-udev-link_setup-respect-kernel-name-assign-policy.patch
* Wed Jan  7 2015 arvidjaar@gmail.com
- update set-and-use-default-logconsole.patch - fix comparison of
  console log facility that caused journald to skip output to console
  (boo#912030)
* Thu Dec 18 2014 werner@suse.de
- Use Robert's latest patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which drops NAMEPOLICY_KERNEL as this breaks all on current
  systems out there
* Wed Dec 17 2014 thomas.blume@suse.com
- remove 0022-systemd-tmpfiles-ownerkeep.patch since this is now
  implemented into the systemd-tmpfiles binary
- add user based ignore statements in tmpfiles removal directives
  (bnc#903009)
  add systemd-add-user-keep.patch
* Tue Dec 16 2014 thomas.blume@suse.com
- use --boot option in systemd-tmpfiles-setup-dev.service (bnc#908476)
  add upstream patches:
  0001-units-tmpfiles-setup-dev-allow-unsafe-file-creation-.patch
  0002-man-tmpfiles.d-recommend-using-b-and-c.patch (adapted)
* Tue Dec 16 2014 werner@suse.de
- Update patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  to Robert's version
* Mon Dec 15 2014 werner@suse.de
- Add upstream patches
  0001-selinux-access-fix-broken-ternary-operator.patch
  0002-systemctl-show-BindsTo-BoundBy-in-list-dependencies.patch
  0003-cryptsetup-default-to-no-hash-when-keyfile-is-specif.patch
  0004-core-fix-transaction-destructiveness-check-once-more.patch
- Avoid old net devices naming scheme on openSUSE 13.2 and less
  maybe caused by patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
* Thu Dec 11 2014 thomas.blume@suse.com
- fix systemd-nspawn network-veth support (bnc#906709)
  add 513-nspawn-veth.patch
* Fri Dec  5 2014 werner@suse.de
- Add upstream patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which may solve bsc#907318
* Fri Dec  5 2014 werner@suse.de
- Add upstream patches
  0001-units-make-sure-rfkill-service-is-bount-to-the-actua.patch
  0002-rfkill-rework-how-we-generate-file-names-from-rfkill.patch
* Fri Nov 28 2014 rmilasan@suse.com
- Change the maximum number of children from CPU_COUNT * 256 to
  CPU_COUNT * 64.
  Update 1097-udevd-increase-maximum-number-of-children.patch
* Thu Nov 27 2014 rmilasan@suse.com
- Increase number of children/workers to CPU_COUNT * 256 to avoid
  'maximum number of children reached' (bnc#907393).
  Add 1097-udevd-increase-maximum-number-of-children.patch
* Tue Nov 25 2014 rmilasan@suse.com
- Fix error return in rootsymlink_generator.c
  Update 1096-new-udev-root-symlink-generator.patch
* Fri Nov 21 2014 werner@suse.de
- Remove upstream patch
  0001-systemd-logind.service-set-Type-notify.patch
  as systemd-logind.service is already from DBus type, compare with
  upstream commit eab459bc0639b81b32735f36d3e929e4bfa2cb4b
* Thu Nov 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-logind.service-set-Type-notify.patch
  0002-core-watchdog-bus-properties-cannot-be-both-writable.patch
  0003-sd-bus-refuse-properties-that-claim-to-be-both-writa.patch
* Thu Nov 20 2014 werner@suse.de
- Re-add directory /usr/lib/systemd/system/basic.target.wants
* Wed Nov 19 2014 gber@opensuse.org
- remove pm-utils-hooks-compat.sh again, pm-utils built-in hooks
  partially duplicate hooks run by systemd which may potentially
  lead to problems, instead temporarily re-enable
  Forward-suspend-hibernate-calls-to-pm-utils.patch until
  boo#904828 can be addressed properly
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashisms in write_net_rules script
- update patches:
  * 1053-better-checks-in-write_net_rules.patch
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-let-list-units-unit-files-honour-type.patch
  0002-systemctl-obey-state-in-list-unit-files.patch
  which allows to use --type in the systemctl command list-units
  and list-unit-files.
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Add-support-for-IBM-ThinkPad-X41-Tablet.patch
  0002-keymap-Fix-special-keys-on-ThinkPad-X60-X61-Tablet.patch
* Thu Nov 13 2014 rmilasan@suse.com
- New root symlink rule generator
  Add 1096-new-udev-root-symlink-generator.patch
- Remove write_dev_root_rule and systemd-udev-root-symlink
* Thu Nov 13 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip hdflush as well as hddown but only use halt as fallback
  for poweroff as well as synch in systemctl before any reboot command
  (compare with commit 4a3ad39957399c4a30fc472a804e72907ecaa4f9)
* Thu Nov 13 2014 rmilasan@suse.com
- Create rule to set I/O scheduler to deadline if device attribute
  'rotational' equals 0, usually SSDs (bnc#904517).
  Add 1095-set-ssd-disk-to-use-deadline-scheduler.patch
* Thu Nov 13 2014 thomas.blume@suse.com
- fix systemd-fstab-generator crypttab parsing (bnc#903963)
* Tue Nov 11 2014 gber@opensuse.org
- Add pm-utils-hooks-compat.sh in order to run pm-utils sleep hooks
  from systemd (boo#904828)
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-login-rerun-vconsole-setup-when-switching-from-vgaco.patch
  0002-shutdown-fix-arguments-to-run-initramfs-shutdown.patch
  0003-utf8-when-looking-at-the-next-unichar-honour-the-siz.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-core-don-t-allow-enabling-if-unit-is-masked.patch
  0002-snapshot-return-error-when-snapshot-exists.patch
  0003-shared-install-avoid-prematurely-rejecting-missing-u.patch
  0004-Raise-level-of-Found-dependency.-lines.patch
  0005-units-order-sd-journal-flush-after-sd-remount-fs.patch
  0006-journald-fix-minor-memory-leak.patch
  0007-journald-also-check-journal-file-size-to-deduce-if-i.patch
  0008-journald-fix-memory-leak-on-error-path.patch
  0009-units-make-systemd-journald.service-Type-notify.patch
  0010-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  1092-libudev-do-not-accept-invalid-log-levels.patch
  1093-udev-Fix-parsing-of-udev.event-timeout-kernel-parame.patch
  1094-udev-avoid-magic-constants-in-kernel-cmdline-parsers.patch
* Fri Nov  7 2014 werner@suse.de
- Add patch watch_resolv.conf_for_become_changed.patch to add an
  inotify watch on /etc/resolv.conf which enables the reload of
  a changed resolver configuration on the fly (bsc#902901)
- Do not apply patch 0022-systemd-tmpfiles-ownerkeep.patch in case
  if the script /usr/bin/systemd-tmpfiles-keep is missed
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  0001-sd-bus-properly-handle-removals-of-non-existing-matc.patch
  0002-keymap-Ignore-brightness-keys-on-Dell-Inspiron-1520-.patch
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  1091-udev-path_id-update-comments.patch
  which will be applied if patch
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  is applied a this may fix the trouble with iSCSI (bnc#898233)
* Thu Oct 30 2014 werner@suse.de
- Add upstream patches
  0001-manager-Linux-on-hppa-has-fewer-rtsigs-hence-avoid-u.patch
  0002-time-also-support-infinity-syntax-in-parse_nsec.patch
  0003-time-earlier-exit-from-format_timestamp_relative-on-.patch
  0004-sd-bus-if-we-don-t-manage-to-properly-allocate-the-e.patch
  0005-journalctl-correct-help-text-for-until.patch
  0006-calendarspec-fix-typo-in-annually.patch
  0007-systemctl-do-not-ignore-errors-in-symlink-removal.patch
  0008-util-introduce-sethostname_idempotent.patch
  0009-util-fix-copy-paste-error-and-actually-set-the-new-h.patch
  0010-shutdown-do-final-unmounting-only-if-not-running-ins.patch
  0011-selinux-make-sure-we-do-not-try-to-print-missing-fie.patch
- Replace patch
  keep-crypt-password-prompt.patch as this with
  upstream patch
  0012-manager-do-not-print-anything-while-passwords-are-be.patch
* Fri Oct 24 2014 werner@suse.de
- Add upstream patch
  0002-shutdown-pass-own-argv-to-run-initramfs-shutdown.patch
- Add patch journald-advice-about-use-of-memory.patch to use mmap()
  flags as well as madvise(2) for journal files.
* Thu Oct 23 2014 werner@suse.de
- Add upstream patches
  0001-strv-add-an-additional-overflow-check-when-enlarging.patch
  0002-hwdb-Add-mapping-for-special-keys-on-compaq-ku-0133-.patch
  0003-journald-add-CAP_MAC_OVERRIDE-in-journald-for-SMACK-.patch
  0004-journal-do-server_vacuum-for-sigusr1.patch
  0005-cryptsetup-fix-an-OOM-check.patch
* Wed Oct 22 2014 werner@suse.de
- Add upstream patch 1089-fix-cgroup-device-controller.patch
  to avoid trouble on existing /dev/console with nspawn (bsc#902240)
* Tue Oct 21 2014 werner@suse.de
- Modify patch avoid-leaking-socket-descriptors.patch to close
  file descriptors for incomming connections in pam module in case
  of short memory.
* Mon Oct 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-continue-switch-root-even-if-umount-fails.patch
  0002-systemd-try-harder-to-bind-to-notify-socket.patch
- Add patch avoid-leaking-socket-descriptors.patch to close
  file descriptors if an incomming connection can not be handled
  due e.g. short memory. Could be related to bsc #901481
* Wed Oct 15 2014 werner@suse.de
- Add upstream patches
  0001-shell-completion-fix-completion-of-inactive-units.patch
  0002-shell-completion-propose-templates-for-disable-re-en.patch
  0003-man-we-don-t-have-Wanted-dependency.patch
  0004-selinux-fix-potential-double-free-crash-in-child-pro.patch
* Wed Oct 15 2014 werner@suse.de
- Adapt patch
  rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  to make it work even with patch #438 and #439
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-when-mangle-unit-names-for-the-isolate-suf.patch
  0001-tmpfiles-compare-return-against-correct-errno.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Fix-touchpad-toggle-on-Toshiba-Satellite-P75-.patch
  0001-units-introduce-network-pre.target-as-place-to-hook-.patch
  0002-keymap-Fix-touchpad-toggle-key-on-Asus-laptops.patch
  0003-sd-bus-check-return-value-of-vasprintf.patch
  0004-core-map-the-rescue-argument-to-rescue.target.patch
  0005-util-avoid-double-close-of-fd.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-virt-detect-that-we-are-running-inside-the-docker-co.patch
  0002-bootchart-use-n-a-if-PRETTY_NAME-is-not-found.patch
  0003-fileio-label-return-error-when-writing-fails.patch
  0001-sd-event-don-t-require-a-signal-event-source-to-be-e.patch
  0004-sd-event-check-the-value-of-received-signal.patch
  0005-sd-id128-do-stricter-checking-of-random-boot-id.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-core-swap-only-make-configured-units-part-of-swap.ta.patch
  0009-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-journalctl-do-not-output-reboot-markers-when-running.patch
  0002-udev-hwdb-New-Entry-for-Dell-XPS12-9Q33-keyboard.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-logind-add-support-for-Triton2-Power-Button.patch
  0002-logind-add-support-for-TPS65217-Power-Button.patch
- Add upstream patches
  0001-shutdownd-clean-up-initialization-of-struct.patch
  0003-bootchart-parse-userinput-with-safe_atoi.patch
  0004-bootchart-check-return-of-strftime.patch
  0005-bootchart-Do-not-try-to-access-data-for-non-existing.patch
* Thu Oct  2 2014 lduncan@suse.com
- Revert patch 1063, which incorrectly disallows
  /dev/disk/by-path links for iSCSI (and other)
  devices. Will be corrected and re-added once
  upstream is consulted. (bnc#898233).  Disable:
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patc
* Fri Sep 26 2014 werner@suse.de
- Add upstream patch
  0001-systemd-tmpfiles-Fix-IGNORE_DIRECTORY_PATH-age-handl.patch
  for bsc#893797
* Fri Sep 26 2014 rmilasan@suse.com
- Drop renaming virtual interfaces in a guest (bnc#898432).
  Add 1088-drop-renaming-of-virtual-interfaces-in-guest.patch
* Thu Sep 25 2014 werner@suse.de
- Rename patch 0001-infinit-timeout-for-kmod-loaded-modules.patch
  to patch 1087-infinit-timeout-for-kmod-loaded-modules.patch
  and apply this one
* Thu Sep 25 2014 werner@suse.de
- Change patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  to fix bsc#898240
* Thu Sep 25 2014 werner@suse.de
- Add upstream patches
  0001-Fix-warning-about-unused-variable-with-SELINUX.patch
  0002-bus-remove-unused-check.patch
* Wed Sep 24 2014 werner@suse.de
- Add patch 0001-infinit-timeout-for-kmod-loaded-modules.patch to
  be able to avoid killing a running kmod/modprobe (bnc#889297)
* Wed Sep 24 2014 werner@suse.de
- Update patch 0001-bnc888612-logind-polkit-acpi.patch
* Wed Sep 24 2014 werner@suse.de
- Add upstream patches
  0001-login-pause-devices-before-acknowledging-VT-switches.patch
  May help that history of the shell is saved
  0001-nspawn-don-t-try-to-create-veth-link-with-too-long-i.patch
  0001-socket-introduce-SELinuxContextFromNet-option.patch (bsc#897801)
  0002-util-avoid-non-portable-__WORDSIZE.patch
* Fri Sep 19 2014 werner@suse.de
- Add patch 0001-bnc888612-logind-polkit-acpi.patch from Frederic
  to solve bnc#888612 - AUDIT-0: Power button press at gdm login
  should not prompt for credentials
* Fri Sep 19 2014 werner@suse.de
- Add upstream bugfix patches
  0001-journal-Do-not-count-on-the-compiler-initializing-fo.patch
  0002-include-fcntl.h-rather-than-sys-fcntl.h.patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  0004-shared-wtmp-utmp-don-t-clear-store_wtmp-in-utmp_put_.patch
  0005-shared-label.h-add-missing-stdio.h-include.patch
  0006-shared-sparse-endian.h-add-missing-byteswap.h-includ.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patch
  1080-udevd-parse_argv-warn-if-argumens-are-invalid.patch
  1081-udevd-check-return-of-various-functions.patch
  1082-udevadm-hwdb-check-return-value-of-fseeko.patch
  1083-udev-node-warn-if-chmod-chown-fails.patch
  1084-udev-ctrl-log-if-setting-SO_PASSCRED-fails.patch
  1085-udev-fix-typos.patch
  1086-udevd-don-t-fail-if-run-udev-exists.patch
* Thu Sep 18 2014 werner@suse.de
- Add upstream bugfix patches
  0001-core-fix-resource-leak-in-manager_environment_add.patch
  0002-util-remove-a-unnecessary-check.patch
  0003-udev-event-explicitly-don-t-read-from-invalid-fd.patch
  0004-shared-conf-parser.patch
  0005-logind-fix-typo.patch
  0006-systemctl-fix-resource-leak-CID-1237747.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patc
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
- Remove 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch as
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
  is the upstream solution
* Wed Sep 17 2014 werner@suse.de
- Add patch 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch to
  fix for the size of the gcc builtin type bool also known as _Bool
  from the include header stdbool.h.
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches as real fixes
  0001-activate-fix-fd-leak-in-do_accept.patch
  0002-analyze-avoid-a-null-dereference.patch
  0003-analyze-fix-mem-leak.patch
  0004-backlight-Avoid-error-when-state-restore-is-disabled.patch
  0005-bus-avoid-using-m-kdbus-after-freeing-it.patch
  0006-bus-unref-buscreds-on-failure.patch
  0007-core-fix-a-potential-mem-leak.patch
  0008-core-smack-setup-Actually-allow-for-succesfully-load.patch
  0009-journal-do-not-leak-mmaps-on-OOM.patch
  0010-manager-use-correct-cleanup-function.patch
- Intergrate the work of Robert and rename the patch
  1068-udev-remove-userspace-firmware-loading-support.patch
  to 1078-udev-remove-userspace-firmware-loading-support.patch
  Also add patch
  1079-udev-remove-userspace-firmware-loading-support.patch
  to apply the same change for opensuse 13.2 and above
* Tue Sep 16 2014 werner@suse.de
- Add upstream patch
  0001-systemctl-allow-to-change-the-default-target-without.patch
  to allow to override default target without --force (bnc#896664)
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches for udev
  1068-udev-net_setup_link-export-the-.link-filename-applie.patch
  1069-rules-net-setup-link-preserve-ID_NET_LINK_FILE-and-I.patch
  1070-rules-net-setup-link-remove-stray-linebreak.patch
  1071-udev-import-the-full-db-on-MOVE-events-for-devices-w.patch
  1072-udev-netif_rename-don-t-log-to-kmsg.patch
  1073-udev-drop-print_kmsg.patch
  1074-udev-fix-copy-paste-error-in-log-message.patch
  1075-udev-timeout-increase-timeout.patch (bnc#889297)
  1076-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
  1077-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
* Tue Sep 16 2014 rmilasan@suse.com
- udev: remove userspace firmware loading support (bnc#889297).
  Add 1068-udev-remove-userspace-firmware-loading-support.patch
* Sat Sep 13 2014 rmilasan@suse.com
- udev: always resolve correctly database names on 'change' event (bnc#864745).
  Add 1067-udev-always-resolve-correctly-database-names-on-chan.patch
* Tue Sep  9 2014 werner@suse.de
- Add upstream patch 0009-hwdb-update.patch
* Mon Sep  8 2014 werner@suse.de
- Add upstream patches
  0001-initrd-parse-etc.service-ignore-return-code-of-daemo.patch
  0008-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Sep  4 2014 werner@suse.de
- Disable patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  for SLES-12 as well as for openSUSE-13.2 (bnc#895087)
* Tue Sep  2 2014 rmilasan@suse.com
- udev: add option to generate old 'buggy' serials (bnc#886852)
  Add 1066-udev-add-compatibility-links-for-truncated-by-id-links.patch
* Tue Sep  2 2014 werner@suse.de
- Add upstream patch
  0001-login-simplify-controller-handling.patch
* Mon Sep  1 2014 werner@suse.de
- Add upstream patches
  0001-completion-filter-templates-from-restartable-units.patch
  0002-systemd-fix-error-message.patch
  0003-Quote-unit-names-in-suggested-systemctl-commandlines.patch
  0004-config-parser-fix-mem-leak.patch
  0005-login-fix-mem-leak.patch
  1065-udev-bump-event-timeout-to-60-seconds.patch
* Fri Aug 29 2014 werner@suse.de
- Add upstream patch 0001-nspawn-fix-network-interface.patch to
  make option network-interface of systemd-nspawn work
* Thu Aug 28 2014 werner@suse.de
- Add upstream patches
  0001-login-fix-memory-leak-on-DropController.patch
  0002-util-fix-minimal-race-where-we-might-miss-SIGTERMs-w.patch
  0003-sd-journal-properly-convert-object-size-on-big-endia.patch
  0004-sd-journal-verify-that-object-start-with-the-field-n.patch
- Add upstream patch
  1064-udev-hwdb-do-not-look-at-usb_device-parents.patch
  to avoid that hwdb ID's for unrecognised USB device are taken
  from the USB hub.
* Wed Aug 27 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-Correct-error-message-printed-when-bus_pro.patch
  0002-units-order-systemd-fsck-.service-after-local-fs-pre.patch
  0003-keymap-Adjust-for-more-Samsung-900X4-series.patch
* Wed Aug 27 2014 werner@suse.de
- Add patch use-rndaddentropy-ioctl-to-load-random-seed.patch to
  use RNDADDENTROPY ioctl to load random-seed and to increase
  entropy count as well (bnc#892096)
* Tue Aug 26 2014 werner@suse.de
- Add upstream patches for hwdb
  0001-hwdb-keymaps-for-Samsung-900X3E-900X3F.patch
  0002-Add-hwdb-entry-for-Samsung-Series-7-Ultra.patch
  0003-keymap-Fix-HP-Pavillon-DV7.patch
  0004-hwdb-update-format-description-and-document-reloadin.patch
  0008-hwdb-update.patch
* Tue Aug 26 2014 werner@suse.de
- Port back and add the missed upstream patches from 2014/08/22
  0004-login-set_controller-should-fail-if-prepare_vt-fails.patch
  0006-login-share-VT-signal-handler-between-sessions.patch
* Fri Aug 22 2014 werner@suse.de
- Add upstream patches
  0001-nspawn-fix-truncation-of-machine-names-in-interface-.patch
  0002-switch-root-umount-the-old-root-correctly.patch
  0003-bootchart-it-s-not-OK-to-return-1-from-a-main-progra.patch
  0005-sd-resolve-fix-allocation-if-query-ids-never-reuse-t.patch
  0007-journald-also-increase-the-SendBuffer-of-dev-log-to-.patch
  0008-mount-setup-fix-counting-of-early-mounts-without-SMA.patch
  0009-journald-Fix-off-by-one-error-in-Missed-X-kernel-mes.patch
  0010-machine_kill-Don-t-kill-the-unit-when-killing-the-le.patch
  0011-units-fix-BindsTo-logic-when-applied-relative-to-ser.patch
  0012-util-try-to-be-a-bit-more-NFS-compatible-when-checki.patch
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patch
* Fri Aug 22 2014 crrodriguez@opensuse.org
- man pages from section 3 are developer docs, move them to
  the -devel package.
* Wed Aug 20 2014 werner@suse.de
- Add patch 0001-let-systemctl-completion-ignore-at-names.patch to
  remove error messages for tab completion for systemctl isolate (bnc#892162)
* Mon Aug 18 2014 werner@suse.de
- Disable the usage of the systemd groups wheel and adm (bnc#892300)
* Fri Aug  8 2014 rmilasan@suse.com
- Set default permissions for GenWQE device nodes to 0666 (bnc#890977).
  Add 1062-rules-set-default-permissions-for-GenWQE-devices.patch
* Fri Aug  1 2014 werner@suse.de
- Add upstream patches
  0007-hwdb-update.patch
  1061-rules-allow-systemd-to-manage-loop-device-partitions.patch
* Thu Jul 31 2014 rmilasan@suse.com
- Rename:
  udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
  to
  1060-udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 jeffm@suse.com
- udev: use device mapper target name for btrfs device ready (bnc#888215).
- Add udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tomcat6-var-lock-subsys-legacy.patch to add the
  compatibility directory /var/lock/subsys (bnc#889357)
* Wed Jul 30 2014 werner@suse.de
- Add portabiltiy patch
  1055-let-9719859c07aa13539ed2cd4b31972cd30f678543-apply.patch
* Wed Jul 30 2014 werner@suse.de
- Port and add upstream patch
  0001-sysv-order-initscripts-which-provide-network-before-.patch
  0002-keymap-Add-microphone-mute-keymap-for-Dell-Latitude.patch
  0003-keymap-Annotate-all-micmute-workarounds.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tty-ask-password-agent-on-console.patch that is for system
  console do ask passphrases on all devices of the console (bnc#886211)
* Wed Jul 30 2014 werner@suse.de
- Add former SUSE and/now upstream patches (bnc#889297)
  1056-udevd-add-event-timeout-commandline-option.patch
  1057-udev-unify-event-timeout-handling.patch
  1058-udev-unify-event-timeout-handling.patch (backport for
  compatibility if patch 1022 is not applied)
  1059-udev-fixup-commit-dd5eddd28a74a49607a8fffcaf960040db.patch
* Mon Jul 28 2014 werner@suse.de
- Add patch shut-up-rpmlint-on-var-log-journal.patch to avoid
  rpmlink warning
- Add upstream patches
  0001-bus-proxyd-fix-incorrect-comparison.patch
  0002-shell-completion-prevent-mangling-unit-names.patch
  0003-Always-check-asprintf-return-code.patch
  0004-bash-completion-use-list-unit-files-to-get-all-units.patch
  0005-core-only-set-the-kernel-s-timezone-when-the-RTC-run.patch
  0006-parse_boolean-require-exact-matches.patch
  0007-drop_duplicates-copy-full-BindMount-struct.patch
  0008-shell-completion-prevent-mangling-unit-names-bash.patch
  0009-journald-always-add-syslog-facility-for-messages-com.patch
* Fri Jul 25 2014 werner@suse.de
- Disable blkrrpart for SLES12 and below
* Fri Jul 25 2014 werner@suse.de
- Add upstream patch
  1054-udev-exclude-MD-from-block-device-ownership-event-lo.patch
- Add with condition blkrrpart to be able to disable the patches
  1025, 1027, 1029, 1030, 1031, 1032, 1033, 1034, 1037, and 1054
  which uses the BLKRRPART ioctl for e.g. synthesize change events
  which may interfere with other tools like parted.
* Thu Jul 24 2014 fcrozat@suse.com
- Update
  handle-disable_caplock-and-compose_table-and-kbd_rate.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch: read
  /etc/vconsole.conf after /etc/sysconfig/(keyboard,console)
  otherwise empty value in /etc/sysconfig/keyboard might override
  /etc/vconsole.conf values.
- Update :
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
  apply-ACL-for-nvidia-device-nodes.patch
  keep-crypt-password-prompt.patch
  log-target-null-instead-kmsg.patch
  parse-crypttab-for-noauto-option.patch
  set-and-use-default-logconsole.patch: fix all warnings in code
- Remove 0001-compress-fix-return-value.patch: not relevant to
  systemd v210 code.
* Thu Jul 24 2014 werner@suse.de
- Also change udev-generate-peristent-rule to udev-generate-persistent-rule
  in file list
* Thu Jul 24 2014 rmilasan@suse.com
- Rename (fix typo in script name):
  udev-generate-peristent-rule.sh to udev-generate-persistent-rule.sh
* Wed Jul 23 2014 rmilasan@suse.com
- Enable better checks in write_net_rules to skip adding duplicated
  entries in the generate rules (bnc#888178).
  Add 1053-better-checks-in-write_net_rules.patch
* Wed Jul 23 2014 werner@suse.de
- Change patch set-and-use-default-logconsole.patch to avoid to
  write security/authorization (private) messages to console
* Tue Jul 22 2014 werner@suse.de
- Add patch set-and-use-default-logconsole.patch to use and set
  the default logging console for both journald and kernel messages
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-bash-completion-p-option-for-journalctl.patch
  0002-journalctl-man-allow-only-between-terms.patch
  0003-systemd-use-pager-for-test-and-help.patch
* Mon Jul 21 2014 werner@suse.de
- Use verify scripts and add permission files for systemd logger
- Avoid useless warning about static systemd unit files
- Make pam file a config file
- Remove non-break-space from this changelog
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-compress-fix-return-value.patch
  0002-Be-more-verbose-when-bind-or-listen-fails.patch
  0003-Add-quotes-to-warning-message.patch
  0004-systemd-return-the-first-error-from-manager_startup.patch
* Mon Jul 21 2014 werner@suse.de
- Replace patch 0001-fix-only-discover-Xen-domU.patch with
  upstream patch 0001-detect-virt-Fix-Xen-domU-discovery.patch
- Replace patch 0001-detect-s390-virt.patch with upstream
  patch 0001-systemd-detect-virt-detect-s390-virtualization.patch
* Thu Jul 17 2014 werner@suse.de
- Add upstream patches
  0001-po-add-Ukrainian-translation.patch
  0002-man-document-yearly-and-annually-in-systemd.time-7.patch
  0003-core-nicer-message-when-inotify-watches-are-exhauste.patch
- Add patch 0001-fix-only-discover-Xen-domU.patch to fix upstream
  patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
* Thu Jul 17 2014 rmilasan@suse.com
- Check if NAME key has a value before going thru the rule (bnc#885232).
  Add 1051-check-if-NAME-has-a-value.patch
* Wed Jul 16 2014 werner@suse.de
- Add upstream patches
  0001-Clear-up-confusion-wrt.-ENTRY_SIZE_MAX-and-DATA_SIZE.patch
  0002-units-serial-getty-.service-use-the-default-RestartS.patch
  1052-rules-uaccess-add-ID_SOFTWARE_RADIO.patch
* Tue Jul 15 2014 rmilasan@suse.com
- Only rename SRIOV-VF devices if device name start with eth (bnc#885232).
  Add 1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch
* Tue Jul 15 2014 werner@suse.de
- Add patch vhangup-on-all-consoles.patch that is do a vhangup on
  lines (bnc#886599)
* Tue Jul 15 2014 jlee@suse.com
- Removed %%{_libexecdir}/modules-load.d/efivars.conf because the kernel
  patch of autoload efivars driver accepted by linux-efi upstream.
  (bnc#881559)
  https://git.kernel.org/cgit/linux/kernel/git/mfleming/efi.git/commit/?h=next&id=be756a5327fe3d4686d74d3e9b273010424e230c
* Mon Jul 14 2014 werner@suse.de
- Update patch
  1007-physical-hotplug-cpu-and-memory.patch (bnc#869603)
- Add script systemd-remount-tmpfs (bnc#869603) as helper script
  for the rule changed in patch 1007-physical-hotplug-cpu-and-memory.patch
* Mon Jul 14 2014 werner@suse.de
- Add upstream patch
  0001-event-pull-in-sd-event.h-from-event-util.h.patch
  0002-util-fix-has-cc-check-and-add-test.patch
  0003-sd-event-always-call-epoll_ctl-on-mask-updates-if-ed.patch
  0004-fileio-quote-more-shell-characters-in-envfiles.patch
* Fri Jul 11 2014 werner@suse.de
- Only on SLES12 seccomp is available on ppc64 and s390x
* Thu Jul 10 2014 werner@suse.de
- Port and add upstream patch
  0001-units-make-ExecStopPost-action-part-of-ExecStart.patch
* Wed Jul  9 2014 werner@suse.de
- Add patches
  0001-logind-allow-switching-to-unused-VTs-via-SwitchTo.patch
  0002-hostnamed-add-a-new-chassis-type-for-watches.patch
- Port and add upstream patches
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-journal-compress-improve-xz-compression-performance.patch
* Wed Jul  9 2014 meissner@suse.com
- enable seccomp also for ppc64 and s390x
* Tue Jul  8 2014 werner@suse.de
- Port and add upstream patches
  0001-util-consider-0x7F-a-control-chracter-which-it-is-DE.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0003-architecture-add-string-table-entries-for-mips-le-ar.patch
  0004-core-Added-support-for-ERRNO-NOTIFY_SOCKET-message-p.patch
  0005-service-don-t-accept-negative-ERRNO-notification-mes.patch
  0006-systemctl-show-StatusErrno-value-in-systemctl-status.patch
  0007-service-flush-status-text-and-errno-values-each-time.patch
* Tue Jul  8 2014 werner@suse.de
- Add upstream patch
  1049-udev-link_config-ignore-errors-due-to-missing-MAC-ad.patch
* Mon Jul  7 2014 werner@suse.de
- Add upstream patch
  0001-machine-don-t-return-uninitialized-variable.patch
- Port and add upstream patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
* Mon Jul  7 2014 rmilasan@suse.com
- Rename
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  to
  1048-udev-net_setup_link-add-a-bit-more-logging.patch
* Fri Jul  4 2014 werner@suse.de
- Port and add upstream patches
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch
  0002-namespace-fix-uninitialized-memory-access.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0001-architecture-Add-tilegx.patch
  0002-architecture-Add-cris.patch
  0003-arch-add-crisv32-to-uname-check.patch
  0004-architecture-remove-cris-from-uname-list.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0006-hwdb-update.patch
  0007-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Jul  3 2014 werner@suse.de
- Add upstream patches
  0001-parse_uid-return-ENXIO-for-1-uids.patch
  0002-util-when-unescaping-strings-don-t-allow-smuggling-i.patch
  0003-localed-consider-an-unset-model-as-a-wildcard.patch
  0004-sd-bus-when-an-event-loop-terminates-explicitly-clos.patch
  0005-bus-close-a-bus-that-failed-to-connect.patch
  1047-udev-net_setup_link-builtin-should-print-the-reason-.patch
* Wed Jul  2 2014 rmilasan@suse.com
- Fix duplicated rules when having layer3 interfaces (bnc#882714).
  Add 1046-fix-duplicated-rules-with-layer3-interfaces.patch
* Tue Jul  1 2014 werner@suse.de
- Require correct pam-config version overall even for scriptlets (bnc#885288)
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  0001-main-uid_to_name-might-fail-due-to-OOM-protect-again.patch
  0002-journald-make-MaxFileSec-really-default-to-1month.patch
  0003-units-remove-RefuseManualStart-from-units-which-are-.patch
  0004-util-refuse-considering-UID-0xFFFF-and-0xFFFFFFFF-va.patch
  0005-nspawn-block-open_by_handle_at-and-others-via-seccom.patch
  0006-tmpfiles-don-t-do-automatic-cleanup-in-XDG_RUNTIME_D.patch
  0007-units-skip-mounting-tmp-if-it-is-a-symlink.patch
* Tue Jul  1 2014 werner@suse.de
- Be aware that close_nointr_nofail() may fail whereas safe_close() not
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  1042-libudev-queue-provide-file-descriptor-to-watch-busy-.patch
  1043-libudev-queue-watch-entire-directory-to-allow-the-re.patch
  1044-rules-update-qemu-hid-rules.patch
  1045-rules-don-t-enable-usb-pm-for-Avocent-devices.patch
* Fri Jun 27 2014 werner@suse.de
- Add upstream bug fix patch
  1041-libudev-fix-udev_queue_get_queue_is_empty-logic.patch (bnc#882714)
* Fri Jun 27 2014 werner@suse.de
- Update of patch 0001-detect-s390-virt.patch (bnc#880438)
* Thu Jun 26 2014 werner@suse.de
- Shut up stupid check scripts crying for not mentioned systemd-mini-rpmlintrc
* Thu Jun 26 2014 werner@suse.de
- Add upstream patchs
  0001-core-use-correct-format-string-for-UIDs.patch
  0002-core-transaction-fix-cycle-break-attempts-outside-tr.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
* Thu Jun 26 2014 werner@suse.de
- Add upstream patch
  0001-units-order-network-online.target-after-network.targ.patch
  to make sure that etwork-online.target follows network.target
* Wed Jun 25 2014 rmilasan@suse.com
- rules: re-enable dev_id conditionally in persistent rules
  (bnc#884403 and bnc#882714).
  Add 1040-re-enable-dev_id-conditionally-in-persistent-rules.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patches
  0001-vconsole-also-copy-character-maps-not-just-fonts-fro.patch
  0002-core-make-sure-Environment-fields-passed-in-for-tran.patch
  0003-core-You-can-not-put-the-cached-result-of-use_smack-.patch
  0004-cryptsetup-don-t-add-unit-dependency-on-dev-null-dev.patch
  0005-man-fix-path-in-crypttab-5.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patch
  1039-udevadm-settle-fixed-return-code-for-empty-queue.patch it
  fixes udevadm settle exit code which may had broken dracut scripts
  (bnc#884271 comment#18)
* Wed Jun 25 2014 werner@suse.de
- Temporary disable patch 1022 (bnc#884271 and bnc#882714).
* Tue Jun 24 2014 rmilasan@suse.com
- Rename 0002-udev-fix-invalid-free-in-enable_name_policy.patch
  to 1038-udev-fix-invalid-free-in-enable_name_policy.patch
* Tue Jun 24 2014 werner@suse.de
- Replace patches
  0001-systemd-empty-sigmask-on-reexec.patch with
  upstream 0008-Reset-signal-mask-on-re-exec-to-init.patch
  ensure-sysctl-are-applied-after-modules-are-loaded.patch with
  upstream 0001-units-systemd-sysctl.service.in-run-after-load-modul.patch
  getty-generator-with-serial-3270-tty.patch with
  upstream 0004-getty-generator-properly-escape-instance-names.patch
- Add upstream patches
  0002-units-add-missing-caps-so-that-GetAddresses-can-work.patch
  0003-units-order-systemd-tmpfiles-clean.service-after-tim.patch
  0005-po-add-Greek-translation.patch
  0006-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0007-po-add-German-translation.patch
  0009-core-clean-up-signal-reset-logic-when-reexec.patch
  0010-util-treat-fuse.sshfs-as-a-network-filesystem.patch
  0011-build-sys-add-pthread-flag-for-libsystemd-shared.patch
  0012-core-transaction-avoid-misleading-error-message-when.patch
* Tue Jun 24 2014 werner@suse.de
- Invert of the boolean for locking scheme of fsck (bnc#881125)
- Remove the ghost entry /etc/hostname and require the netcfg
* Mon Jun 23 2014 arvidjaar@gmail.com
- make sure legacy services that depend on network are started after
  network is available (bnc#883565)
  * 0001-core-sysvcompat-network-should-be-equivalent-to-netw.patch
  * update insserv-generator.patch to translate $network into
    network-online.target
* Wed Jun 18 2014 werner@suse.de
- Add patch 0001-detect-s390-virt.patch from Thomas Blume (bnc#880438)
  to detect the virtualization layers on s390x as well
* Wed Jun 18 2014 werner@suse.de
- Do not generate synthesize change for cd/dvd (bnc#882714, comment #51)
  add patch 1037-udev-exclude-cd-dvd-from-block-device.patch from
  Roberts suggestion as well as readd
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue Jun 17 2014 werner@suse.de
- Add upstream patches
  0001-core-fix-invalid-free-in-killall.patch
  0002-udev-fix-invalid-free-in-enable_name_policy.patch
  0003-install-fix-invalid-free-in-unit_file_mask.patch
* Tue Jun 17 2014 rmilasan@suse.com
- rules: disable usage of dev_id in persistent rules (bnc#882714).
  add: 1036-rules-disable-usage-of-dev_id-in-persistent-rules.patch
- Disable patch (bnc#882714).
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Thu Jun 12 2014 werner@suse.de
- Add patch
  1035-99-systemd.rules-Ignore-devices-with-SYSTEMD_READY-0.patch
  from Hannes Reinecke to avoid a race condition between variable
  'SYSTEMD_READY=0' and 'systemd' tag within udev rules (bnc#881942)
* Thu Jun 12 2014 werner@suse.de
- Add workaround for bnc#882393 by adding the systemd update utmp
  runlevel service to the wanted unit of e.g. the graphical target
- Add some later on created files to our file list
* Thu Jun 12 2014 jlee@suse.com
- Generate %%{_libexecdir}/modules-load.d/efivars.conf so we load efivars
  module at boot time not from udev (bnc#881559).
* Wed Jun 11 2014 crrodriguez@opensuse.org
- Do not build EFI support code in architectures on which
  the kernel does not support CONFIG_EFI, it won't work.
  (ia64 also supports it, but that's dead so is not included)
* Wed Jun 11 2014 werner@suse.de
- Add patch tmpfiles-do-not-clean-for-mandb-index-files.patch
  there is no need to clean out all 30 days the index data base
  files nor the cachedir tags of mandb.  Those files are used
  for whatis(1) as well as for apropos(1).
* Wed Jun 11 2014 werner@suse.de
- Do not override predictable names for openSUSE
* Wed Jun 11 2014 werner@suse.de
- Remove systemd-detect-xendom.patch as it becomes obsolete with
  upstream patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
- Add upstream patches
  0001-umount-modernizations.patch
  0002-namespace-when-setting-up-an-inaccessible-mount-poin.patch
  0003-core-allow-transient-mount-units.patch
  0004-systemd-detect-virt-only-discover-Xen-domU.patch
  0005-backlight-Do-not-clamp-brightness-for-LEDs.patch
  0006-log-honour-the-kernel-s-quiet-cmdline-argument.patch
* Tue Jun 10 2014 rmilasan@suse.com
- Add upstream patches
  1033-udev-really-exclude-device-mapper-from-block-device.patch
  1034-udev-check-the-return-value-from-udev_enumerate_scan.patch
* Tue Jun 10 2014 werner@suse.de
- Change detection of new locking scheme of fsck
* Tue Jun 10 2014 werner@suse.de
- Change 1021-udev-re-add-persistent-net-rules.patch to use persistent
  rules as a default on SLES-12 and predictable rules as a default
  otherwise
- Add cflags shell function to check possible flags for the compiler
  as well as for the linker
* Mon Jun  9 2014 rmilasan@suse.com
- Add upstream patches
  1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
  1026-udevd-inotify-modernizations.patch
  1027-udev-synthesize-change-events-for-partitions-when-to.patch
  1028-udev-link-config-fix-mem-leak.patch
  1029-udev-try-first-re-reading-the-partition-table.patch
  1030-udev-guard-REREADP-logic-with-open-O_ECXL.patch
  1031-udev-make-sure-we-always-get-change-for-the-disk.patch
  1032-udev-guard-REREADPT-by-exclusive-lock-instead-of-O_E.patch
* Fri Jun  6 2014 werner@suse.de
- Add upstream patches
  0001-sd-event-restore-correct-timeout-behaviour.patch
  0002-bus-make-use-of-sd_bus_try_close-in-exit-on-idle-ser.patch
* Thu Jun  5 2014 werner@suse.de
- Add upstream patch 0001-hwdb-fix-case-sensitive-match.patch
* Thu Jun  5 2014 werner@suse.de
- Add dynamic detection of util-linux version to be able to
  disable the fsck option -l for version less than 2.25.0
* Thu Jun  5 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * The patches
    delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch and
    ensure-DM-and-LVM-are-started-before-local-fs-pre-target.patch
    indeed mention unit files which do not exist anymore.
- Make sure that systemd-ask-password-wall.service has a tty as
  it is not sure that a tty1 exists
- Avoid broken firmware loading on newer distributions as 13.1
* Thu Jun  5 2014 werner@suse.de
- Correct version check for the tcp-devel drop
- Use correct permissions for /var/log/journal
- Use ACLs for /var/log/journal as described in man:systemd-journald.service(8)
* Thu Jun  5 2014 crrodriguez@opensuse.org
- Correct the libseccomp distribution version test must be >= 13.1
-  In order to use unit directive AppArmorProfile= libapparmor-devel
  must be present in buildRequires.
* Tue Jun  3 2014 sndirsch@suse.com
- apply-ACL-for-nvidia-uvm-device-node.patch: set ACL on nvidia-uvm
  device (bnc#879767).
* Tue Jun  3 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * fix keep-crypt-password-prompt.patch which floods the system
    logs with bogus opendir failures, still the wrong thing to do however.
  * Use %%find_lang to collect locale files
  * systemd-no-libattr.patch: systemd does not require  libattr
    but just sys/xattr.h, therefore drop the dependency.
    (from upstream)
  * Again, drop tcp-devel from buildRequires, this time it is not a
    SUSE specific feature removal, tcpd supportdisappeared in systemd
    212 and we shouldn't keep it around.
- Add patch 0001-build-sys-use-glibc-s-xattr-support-instead-of-requi.patch
  that is rename systemd-no-libattr.patch to git format
- Drop tcp-devel only for *next* openSUSE and not for SLES-12 nor
  for openSUSE 13.1
* Tue Jun  3 2014 werner@suse.de
- Add upstream patches
  0001-virt-rework-container-detection-logic.patch
  0002-fsck-include-device-name-in-the-message-about-missin.patch
  0003-units-use-KillMode-mixed-for-systemd-nspawn-.service.patch
  0004-util-ignore_file-should-not-allow-files-ending-with.patch
  0006-tty-ask-password-agent-Do-tell-what-directory-we-fai.patch
- Add upstream patches to update keyboard data base
  0007-keyboard-add-Plantronics-.Audio-mute-button.patch
- Add upstream patches for udev
  1023-udev-builtin-keyboard-do-tell-on-which-device-EVIOCS.patch
  1024-udev-always-close-lock-file-descriptor.patch
* Tue Jun  3 2014 rmilasan@suse.com
- Fix enabling predictable rules when using net.ifnames=1.
  update: 1021-udev-re-add-persistent-net-rules.patch
* Fri May 30 2014 rmilasan@suse.com
- Re-add persistent rules as a default and make predictable rules as
  fallback (bnc#880732).
  add: 1021-udev-re-add-persistent-net-rules.patch
- udev: remove seqnum API and all assumptions about seqnums
  add: 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue May 27 2014 werner@suse.de
- Add upstream patches
  0001-Do-not-unescape-unit-names-in-Install-section.patch
  0002-analyze-run-use-bus_open_transport_systemd-instead-o.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patch
  1020-udev-keyboard-also-hook-into-change-events.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patches to update keyboard data base
  0001-keymap-Add-Lenovo-Enhanced-USB-Keyboard.patch
  0002-keymap-Asus-EeePC-touchpad-toggle-key.patch
- Add upstream patches
  0001-nspawn-allow-to-bind-mount-journal-on-top-of-a-non-e.patch
  0002-nspawn-restore-journal-directory-is-empty-check.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0004-socket-properly-handle-if-our-service-vanished-durin.patch
* Wed May 21 2014 coolo@suse.com
- fix file list of systemd.pc
* Wed May 21 2014 werner@suse.de
- Add a workaround for old distributions like 13.1 to avoid
  deadlocks due NFS shares stopped after network
* Wed May 21 2014 werner@suse.de
- Add upstream patches
  0001-journal-cleanup-up-error-handling-in-update_catalog.patch
  0002-journal-properly-detect-language-specified-in-line.patch
  0003-man-mention-XDG_CONFIG_HOME-in-systemd.unit.patch
* Wed May 21 2014 werner@suse.de
- Add upstream patches to update usb and pci company identifiers
  0001-hwdb-update.patch
  0002-hwdb-update.patch
  0003-hwdb-PCI-include-primary-model-string-in-subsystem-m.patch
  0004-hwdb-update.patch
  0005-hwdb-update.patch
* Wed May 21 2014 werner@suse.de
- Move systemd.pc and udev.pc to their main packages (bnc#876587)
* Tue May 20 2014 werner@suse.de
- Add upstream patches
  0001-conf-parser-silently-ignore-sections-starting-with-X.patch
  0002-man-note-that-entire-sections-can-now-be-ignored.patch
  0004-machined-make-sure-GetMachineAddresses-is-available-.patch
  0005-core-Filter-by-state-behind-the-D-Bus-API-not-in-the.patch
  0006-login-add-mir-to-the-list-of-session-types.patch
  0007-logind-fix-Display-property-of-user-objects.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to update BluTooth company identifiers
  0001-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0002-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0003-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0004-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0005-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to allow processes to serialize block device
  events, also do execute the RUN tag if rename of a network device
  fails:
  1016-udev-serialize-synchronize-block-device-event-handli.patch
  1017-udev-do-not-skip-the-execution-of-RUN-when-renaming-.patch
  1018-udev-avoid-use-of-uninitialized-err.patch
- Rename 0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  to 1016-udev-warn-when-name_to_handle_at-is-not-implemented.patch
* Mon May 19 2014 werner@suse.de
- Add upstream patches mainly for better lid handling (bnc#878525
  and bnc#868019)
  0001-logind-ignore-lid-switch-if-more-than-1-display-is-c.patch
  0002-logind-fix-printf-format.patch
  0003-logind-ignore-lid-switch-events-for-30s-after-each-s.patch
  0004-logind-Do-not-fail-display-count-if-a-device-has-no-.patch
  0005-logind-move-lid-switch-handling-from-logind-main-to-.patch
  0006-man-clarify-that-the-ExecReload-command-should-be-sy.patch
  0007-man-readahead-fix-cmdline-switch-inconsistency-betwe.patch
  0008-man-update-journald-rate-limit-defaults.patch
  0009-nspawn-properly-format-container_uuid-in-UUID-format.patch
  0010-logind-allow-suspending-if-there-are-no-displays.patch
* Fri May 16 2014 werner@suse.de
- Make baselibs.conf aware to use the appropiate %%post and %%postun
  scriptlets which includes pam-config (bnc#877674)
* Fri May 16 2014 werner@suse.de
- Add upstream patches
  0001-core-close-socket-fds-asynchronously.patch
  0002-logind-bring-polkit-policy-for-hibernate-in-line-wit.patch
  0003-core-make-sure-to-serialize-jobs-for-all-units.patch
* Wed May 14 2014 werner@suse.de
- Add upstream patches
  0001-replace-more-dup-by-F_DUPFD_CLOEXEC.patch
  0002-pam_systemd-use-F_DUPFD_CLOEXEC-when-dupping-session.patch
  to avoid that in pam session unwanted file descriptors are inherited
* Tue May 13 2014 werner@suse.de
- Add patch log-target-null-instead-kmsg.patch from Thomas Blume
  to enable the kernel developers to see a clean kmsg ring buffer
  without any systemd/udev messages included (bnc#877021)
* Mon May 12 2014 werner@suse.de
- Add upstream patches for backlight
  0001-backlight-Avoid-restoring-brightness-to-an-unreadabl.patch
  0002-backlight-do-nothing-if-max_brightness-is-0.patch
  0003-backlight-unify-error-messages.patch
  0004-backlight-warn-if-kernel-exposes-backlight-device-wi.patch
  0005-backlight-handle-saved-brightness-exceeding-max-brig.patch
* Mon May 12 2014 werner@suse.de
- Add upstream patches
  0001-errno-make-sure-to-handle-the-3-errnos-that-are-alia.patch
  0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  0003-analyze-fix-plot-with-bad-y-size.patch
  0004-job-add-waiting-jobs-to-run-queue-in-unit_coldplug.patch
  0005-job-always-add-waiting-jobs-to-run-queue-during-cold.patch
* Mon May 12 2014 rmilasan@suse.com
- Drop upstream-net_id-changes.patch and replace them with the correct
  patches from upstream and their commits:
  add: 1014-udev-update-net_id-comments.patch
  add: 1015-udev-persistent-naming-we-cannot-use-virtio-numbers-.patch
* Wed May  7 2014 werner@suse.de
- Add patch parse-crypttab-for-noauto-option.patch from Thomas Blume
  to handle the option 'noauto' in /etc/crypttab (bnc#742774)
* Wed May  7 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to have the correct terminal type used with agetty
- Add patch 0001-tmpfiles-fix-permissions-on-new-journal-files.patch
  to allow users to access systemd user journal (bnc#876694)
* Mon May  5 2014 werner@suse.de
- Port upstream patch
  0001-sd-rtnl-message-append-fix-uninitialized-memory.patch
  back to 210
- Add patch keep-crypt-password-prompt.patch from Thomas Blume
  to fix bnc#875502 - fails to boot when swap space is encrypted
- Port upstream patch set for net_id back in patch
  upstream-net_id-changes.patch
* Fri May  2 2014 werner@suse.de
- Add patch shut-up-annoying-assertion-monotonic-clock-message.patch
  to avoid annyoing messages on failing dual_timestamp_is_set in the
  kernel's message ring buffer
* Wed Apr 30 2014 werner@suse.de
- Update udev-generate-peristent-rule.sh from latest git
* Wed Apr 30 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to avoid also ANSI escape sequences for busy jobs on s390
* Mon Apr 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-bash-completion-fix-__get_startable_units.patch
  0002-sysctl-replaces-some-slashes-with-dots.patch
  0003-delta-do-not-use-unicode-chars-in-C-locale.patch
  0004-implement-a-union-to-pad-out-file_handle.patch
- Add patch respect-nfs-bg-option.patch from Thomas Blume:
  System fails to boot if nfs mounts get added to fstab (bnc#874665)
* Wed Apr 23 2014 oneukum@suse.com
- Do not use runtime PM for some IBM consoles (bnc#868931)
  1013-no-runtime-PM-for-IBM-consoles.patch
* Thu Apr 17 2014 werner@suse.de
- Extend avoid-divide-by-zero-sigtrap.patch to make the crash
  handler know about SIGTRAP and SIGSYS
* Thu Apr 17 2014 werner@suse.de
- Add avoid-divide-by-zero-sigtrap.patch which fixes bnc#867663
  that is a divide by zero on a jobless system
* Wed Apr 16 2014 werner@suse.de
- Use latest regenerate-initrd rpm macros (fate#313506)
- Add rescue-emergency-target-conflicts.patch to avoid that
  emergency and rescue sulogin are fighting on console
* Tue Apr 15 2014 werner@suse.de
- Modify systemd-sleep-grub to let hybrid-sleep.target work even
  on XEN, changes from Thomas Blume (bnc#873432)
* Mon Apr 14 2014 werner@suse.de
- Add backported upstream patch
  0001-reduce-the-amount-of-messages-logged-to-dev-kmsg-whe.patch
- Add patch systemd-detect-xendom.patch from Thomas Blume
  to be able to detect XEN dom0 as well as domU
- systemd conflicts with sysvinit, ven if the package systemd-sysvinit
  does already conflict with sysvinit-init (bnc#873444)
* Thu Apr 10 2014 werner@suse.de
- Add two patches from hare@suse.com
  1011-64-btrfs.rules-skip-btrfs-check-if-devices-are-not-r.patch
  1012-Skip-persistent-device-link-creation-on-multipath-de.patch
  to solve bnc#872929
* Wed Apr  9 2014 rmilasan@suse.com
- Increase result size for programs stdout (bnc#867840).
  add: 1010-udev-increase-result-size-for-programs.patch
- Update udev-generate-peristent-rule.sh to the latest version.
- Clean-up spec file, re-arange patch to suit the setup, all udev
  patches start with 1XXX-*.{patch,diff}.
- Rename: 0013-cdrom_id-use-the-old-MMC-fallback.patch to
  1009-cdrom_id-use-the-old-MMC-fallback.patch
- Rename: 1009-make-xsltproc-use-correct-ROFF-links.patch to
  0009-make-xsltproc-use-correct-ROFF-links.patch
- Rename: 1010-do-not-install-sulogin-unit-with-poweroff.patch to
  0010-do-not-install-sulogin-unit-with-poweroff.patch
- Rename: 1014-journald-with-journaling-FS.patch to
  0014-journald-with-journaling-FS.patch
- Rename: 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch to
  0018-Make-LSB-Skripts-know-about-Required-and-Should.patch
- Rename: 1019-make-completion-smart-to-be-able-to-redirect.patch to
  0019-make-completion-smart-to-be-able-to-redirect.patch
- Rename: 1022-systemd-tmpfiles-ownerkeep.patch to
  0022-systemd-tmpfiles-ownerkeep.patch
* Tue Apr  8 2014 werner@suse.de
- Add patch portmap-wants-rpcbind-socket.patch to make sure that
  rpcbind socket as well as service is up with the target
- Add or port upstream bugfix patches:
  0001-journal-fix-export-of-messages-containing-newlines.patch
  0002-systemctl-update-NAME-to-PATTERN-in-help.patch
  0003-tty-ask-password-agent-return-negative-errno.patch
  0004-systemd-python-use-.hex-instead-of-.get_hex.patch
  0005-systemd-python-fix-failing-assert.patch
* Fri Mar 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-cgroup-it-s-not-OK-to-invoke-alloca-in-loops.patch
  0002-machined-fix-Kill-bus-call-on-machine-objects-when-w.patch
  0003-sd-bus-don-t-use-assert_return-to-check-for-disconne.patch
  0004-core-don-t-try-to-relabel-mounts-before-we-loaded-th.patch
  0005-sd-daemon-fix-incorrect-variable-access.patch
  0006-sd-event-initialization-perturbation-value-right-bef.patch
  0007-sd-event-don-t-accidentally-turn-of-watchdog-timer-e.patch
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
  0009-ask-password-when-the-user-types-a-overly-long-passw.patch
- Modify patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to work together with
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
* Fri Mar 28 2014 werner@suse.de
- Use Robert's revised 1006-udev-always-rename-network.patch
* Tue Mar 25 2014 werner@suse.de
- Readd patch Forward-suspend-hibernate-calls-to-pm-utils.patch
  older code base as 13.1 only
- Add patch avoid-random-hangs-on-timeouts-due-lost-cwd.patch
  to be able to terminate the user manager even if cwd of the
  user is gone
* Tue Mar 25 2014 thomas.blume@suse.com
- add prepare-suspend-to-disk.patch
  enable suspend conditions check and preparation for systemd-sleep
  (fate#316824, bnc#856389, bnc#856392)
- remove Forward-suspend-hibernate-calls-to-pm-utils.patch since it is obsolete
  (bnc#856392#c20)
- add boot-local-start.patch
  fix startup for /etc/init.d/boot.local (bnc#869142)
* Mon Mar 24 2014 coolo@suse.com
- also autoreconf in systemd-mini to simplify spec file logic
  and fix build in staging:gcc49
  (obsoleting 0002-make-209-working-on-older-dist.patch)
* Wed Mar 19 2014 werner@suse.de
- Be sure that the refreshed manual pages are installed
* Wed Mar 19 2014 werner@suse.de
- Add patch systemctl-set-default-target.patch which explain how
  to override the default.target by using --force (bnc#868439)
* Tue Mar 18 2014 werner@suse.de
- Add Robert's udev-generate-peristent-rule shell script to
  udev's tool library
- Add or port upstream bugfix patches:
  0001-gpt-auto-generator-don-t-return-OOM-on-parentless-de.patch
  0002-bus-fix-memory-leak-when-kdbus-is-not-enabled.patch
  0006-Do-not-return-1-EINVAL-on-allocation-error.patch
  0007-networkd-fix-typo.patch
  0008-sd-bus-don-t-access-invalid-memory-if-a-signal-match.patch
  0009-sd-bus-don-t-choke-if-somebody-sends-us-a-message-wi.patch
  0012-journald-remove-stray-reset-of-error-return-value.patch
  0013-core-libsystemd-systemd-timedate-udev-spelling-fixes.patch
* Fri Mar 14 2014 werner@suse.de
- Add patch getty-generator-with-serial-3270-tty.patch to avoid
  harmless error messages on not existing getty@3270 files
* Fri Mar 14 2014 werner@suse.de
- Replace systemd-big-endian-reply-matching.patch with upstream
  0001-sd-bus-don-t-look-for-a-64bit-value-when-we-only-hav.patch
  to solve broken systemd communication with and over dbus (bnc#866732)
* Fri Mar 14 2014 werner@suse.de
- Readd patch 1008-add-msft-compability-rules.patch for
  older code base as 13.1
- Modify pre_checkin.sh to throw an error if a patch will be
  applied which modifies one of Makefile.am, Makefile.in, or
  configiure.ac as this breaks bootstrapping
- Add second version of make-209-working-on-older-dist.patch
  to be able to apply for bootstrapping version
* Thu Mar 13 2014 schwab@linux-m68k.org
- Don't require non-existing binutils-gold
* Thu Mar 13 2014 werner@suse.de
- Avoid file conflict between udev and systemd (bnc#868230)
* Wed Mar 12 2014 werner@suse.de
- Modify patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  to ignore if /etc/sysconfig/kernel does not exist (bnc#865834)
* Wed Mar 12 2014 werner@suse.de
- Add patch systemd-big-endian-reply-matching.patch
  make sure that systemd can talk with dbus-daemon even on big
  endian systems (bnc#866732)
* Tue Mar 11 2014 hrvoje.senjan@gmail.com
- Due to previous reason, resurrect systemd-dbus-system-bus-address.patch
- Removed pkgconfig(dbus-1) BuildRequires - with 209 and newer, itis only
  needed for quering default DBus directories, which we nowpass to configure.
  This also unbreaks libdbus <-> systemd-miniBuild Cycle
* Tue Mar 11 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-core-busname-add-lookup-string-for-BUSNAME_FAILURE_S.patch
  0002-manager-flush-memory-stream-before-using-the-buffer.patch
  0003-busname-don-t-drop-service-from-the-result-string.patch
  0004-fix-off-by-one-error-in-array-index-assertion.patch
  0005-logind-fix-policykit-checks.patch
  0006-rules-mark-loop-device-as-SYSTEMD_READY-0-if-no-file.patch
  0007-dbus-suppress-duplicate-and-misleading-messages.patch
  0008-man-multiple-sleep-modes-are-to-be-separated-by-whit.patch
* Tue Mar 11 2014 werner@suse.de
- Make compeletion file parser work (bnc#867664)
* Fri Mar  7 2014 hare@suse.de
- Integrate powerd handling in initctl service
  + Remove 1016-support-powerfail-with-powerstatus.patch
  + Remove systemd-powerfail
  + Add systemd-powerd-initctl-support.patch
- Remove 61-msft.rules; superseded by sg3_utils (bnc#866933)
- Persistent by-path links for ATA devices (FATE#317063)
  + Update 1001-re-enable-by_path-links-for-ata-devices.patch
* Fri Mar  7 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-Fix-systemd-stdio-bridge-symlink.patch
  0002-execute-free-directory-path-if-we-fail-to-remove-it-.patch
  0003-Do-not-print-invalid-UTF-8-in-error-messages.patch
  0004-man-document-missing-options-of-systemd-run.patch
  0005-systemd-run-add-some-extra-safety-checks.patch
  0006-journal-assume-that-next-entry-is-after-previous-ent.patch
  0007-journal-forget-file-after-encountering-an-error.patch
  0008-core-correctly-unregister-PIDs-from-PID-hashtables.patch
  0009-logind-fix-reference-to-systemd-user-sessions.servic.patch
  0010-man-update-link-to-LSB.patch
  0011-man-systemd-bootchart-fix-spacing-in-command.patch
  0012-man-add-missing-comma.patch
  0013-units-Do-not-unescape-instance-name-in-systemd-backl.patch
* Fri Mar  7 2014 werner@suse.de
- Add linker scripts as place holder of the old systemd shared
  libraries now all included in libsystemd.so  (bnc#867128)
* Tue Mar  4 2014 werner@suse.de
- Make patch 1006-udev-always-rename-network.patch work again
  and add it again.
* Mon Mar  3 2014 thomas.blume@suse.com
- address missing owner functionality in systemd-tmpfiles (fate#314974)
  1022-systemd-tmpfiles-ownerkeep.patch
* Mon Mar  3 2014 werner@suse.de
- Generate the bash completion files on the fly for the case of
  not having the package bash-completion around
- Add or port upstream bugfix patches:
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  0002-cdrom_id-use-the-old-MMC-fallback.patch
  0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  0004-logs-show-fix-corrupt-output-with-empty-messages.patch
  0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  0008-README-document-that-var-run-must-be-a-symlink-run.patch
  0010-Replace-var-run-with-run-in-remaining-places.patch
  0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  0014-login-fix-pos-array-allocation.patch
* Mon Mar  3 2014 werner@suse.de
- Update to Release v210
  + systemd will now relabel /dev after loading the SMACK policy
    according to SMACK rules.
  + A new unit file option AppArmoreProfile= has been added to
    set the AppArmor profile for the processes of a unit.
  + A new condition check ConditionArchitecture= has been added
    to conditionalize units based on the system architecture, as
    reported by uname()'s "machine" field.
  + systemd-networkd now supports matching on the system
    virtualization, architecture, kernel command line, host name
    and machine ID.
  + logind is now a lot more aggressive when suspending the
    machine due to a closed laptop lid.
  + logind will now watch SW_DOCK switches and inhibit reaction
    to the lid switch if it is pressed.
  + nspawn will now make use of the devices cgroup controller by
    default, and only permit creation of and access to the usual
    API device nodes like /dev/null or /dev/random, as well as
    access to (but not creation of) the pty devices.
  + systemd will now understand the usual M, K, G, T suffixes
    according to SI conventions (i.e. to the base 1000) when
    referring to throughput and hardware metrics.
  + The DeviceAllow= setting in unit files now supports a syntax
    to whitelist an entire group of devices node majors at once,
    based on the /proc/devices listing. For example, with the
    string "char-pts" it is now possible to whitelist all
    current and future pseudo-TTYs at once.
  + sd-event learned a new "post" event source. Event sources of
    this type are triggered by the dispatching of any event
    source of a type that is not "post". This is useful for
    implementing clean-up and check event sources that are
    triggered by other work being done in the program.
  + The compatibility libraries for libsystemd-journal.so,
    libsystem-id128.so, libsystemd-login.so and
    libsystemd-daemon.so do not make use of IFUNC
    anymore.
- Dropped systemd patches as those are fixed upstream:
  * 0001-units-serial-getty-.service-add-Install-section.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patchc
  * 0001-make-tests-with-libseccomp-work.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-units-serial-getty-.service-add-Install-section.patch
- Dropped patches as those do not work anymore
  * 1006-udev-always-rename-network.patch
- Renamed systemd patches as seen from git log:
  * 0001-cdrom_id-use-the-old-MMC-fallback.patch
    become 0002-cdrom_id-use-the-old-MMC-fallback.patch
  * 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
    become 0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  * 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
    become 0004-logs-show-fix-corrupt-output-with-empty-messages.patch
- Add several upstream bugfix patches which are missed:
  * 0001-build-sys-Add-setns-functions-if-not-in-the-C-librar.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  * 0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  * 0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  * 0008-README-document-that-var-run-must-be-a-symlink-run.patch
  * 0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  * 0010-Replace-var-run-with-run-in-remaining-places.patch
  * 0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  * 0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  * 0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  * 0014-login-fix-pos-array-allocation.patch
- Modified patches to make is build
  * 0001-add-network-device-after-NFS-mount-units.patch
- Reenable libseccomp for the architecture for which libseccomp exists
* Sun Mar  2 2014 ro@suse.de
- always install compat pkgconfig files, regardless if
  compat libs is enabled or not
* Sun Mar  2 2014 ro@suse.de
- disable use of libseccomp for sle12, library has not been ported
  to most architectures
- do not use binutils-gold on s390/s390x, does not exist there
- fix exclude statements for bootstrap case
* Fri Feb 28 2014 werner@suse.de
- Add upstream patches
  + 0001-cdrom_id-use-the-old-MMC-fallback.patch
  + 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
  + 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-systemd-empty-sigmask-on-reexec.patch
  which corrects sigmaks for reexec in initrd (bnc#864904)
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  to avoid error on not existing file /proc/self/loginuid
* Fri Feb 28 2014 werner@suse.de
- Make patch
  0001-make-209-working-on-older-dist.patch
  more smart that is make configure script les restrictive
- Make patch
  apply-ACL-for-nvidia-device-nodes.patch
  apply to v209
* Fri Feb 28 2014 werner@suse.de
- Update to Release v209 on the base of the work of Stefan Brüns
  from declined submit request 223602:
  + A new tool "systemd-socket-proxyd" has been added
  + Add a new tool to save/restore rfkill state on
    shutdown/boot.
  + Save/restore state of keyboard backlights in addition to
    display backlights on shutdown/boot.
  + udev learned a new SECLABEL{} construct to label device
    nodes with a specific security label when they appear. For
    now, only SECLABEL{selinux} is supported, but the syntax is
    prepared for additional security frameworks.
  + When the User= switch is used in a unit file, also
    initialize $SHELL= based on the user database entry.
  + systemd no longer depends on libdbus. All communication is
    now done with sd-bus, systemd's low-level bus library
    implementation.
  + sd-bus: add a light-weight vtable implementation that allows
    defining objects on the bus with a simple static const
    vtable array of its methods, signals and properties.
  + systemd will not generate or install static dbus
    introspection data anymore to /usr/share/dbus-1/interfaces,
    as the precise format of these files is unclear, and
    nothing makes use of it.
  + A proxy daemon is now provided to proxy clients connecting
    via classic D-Bus AF_UNIX sockets to kdbus, to provide full
    compatibility with classic D-Bus.
  + A bus driver implementation has been added that supports the
    classic D-Bus bus driver calls on kdbus, also for
    compatibility purposes.
  + A new API "sd-event.h" has been added that implements a
    minimal event loop API built around epoll.
  + A new API "sd-rntl.h" has been added that provides an API
    around the route netlink interface of the kernel, similar in
    style to "sd-bus.h".
  + A new API "sd-dhcp-client.h" has been added that provides a
    small DHCPv4 client-side implementation. This is used by
    "systemd-networkd".
  + There is a new kernel command line option
    "systemd.restore_state=0|1". When set to "0", none of the
    systemd tools will restore saved runtime state to hardware
    devices. More specifically, the rfkill and backlight states
    are not restored.
  + The FsckPassNo= compatibility option in mount/service units
    has been removed. The fstab generator will now add the
    necessary dependencies automatically, and does not require
    PID1's support for that anymore.
  + journalctl gained a new switch, --list-boots, that lists
    recent boots with their times and boot IDs.
  + The various tools like systemctl, loginctl, timedatectl,
    busctl, systemd-run, ... have gained a new switch "-M" to
    connect to a specific, local OS container (as direct
    connection, without requiring SSH).
  + systemd-run and systemd-analyze also gained support for "-H"
    to connect to remote hosts via SSH. This is particularly
    useful for systemd-run because it enables queuing of jobs
    onto remote systems.
  + machinectl gained a new command "login" to open a getty
    login in any local container. This works with any container
    that is registered with machined (such as those created by
    libvirt-lxc or nspawn), and which runs systemd inside.
  + machinectl gained a new "reboot" command that may be used to
    trigger a reboot on a specific container that is registered
    with machined. This works on any container that runs an init
    system of some kind.
  + systemctl gained a new "list-timers" command to print a nice
    listing of installed timer units with the times they elapse
    next.
  + Alternative reboot() parameters may now be specified on the
    "systemctl reboot" command line and are passed to the
    reboot() system call.
  + systemctl gained a new --job-mode= switch to configure the
    mode to queue a job with. This is a more generic version of
  - -fail, --irreversible, and --ignore-dependencies, which are
    still available but not advertised anymore.
  + /etc/systemd/system.conf gained new settings to configure
    various default timeouts of units, as well as the default
    start limit interval and burst. These may still be overridden
    within each Unit.
  + PID1 will now export on the bus profile data of the security
    policy upload process (such as the SELinux policy upload to
    the kernel).
  + journald: when forwarding logs to the console, include
    timestamps (following the setting in
    /sys/module/printk/parameters/time).
  + OnCalendar= in timer units now understands the special
    strings "yearly" and "annually". (Both are equivalent)
  + The accuracy of timer units is now configurable with the new
    AccuracySec= setting. It defaults to 1min.
  + A new dependency type JoinsNamespaceOf= has been added that
    allows running two services within the same /tmp and network
    namespace, if PrivateNetwork= or PrivateTmp= are used.
  + A new command "cat" has been added to systemctl. It outputs
    the original unit file of a unit, and concatenates the
    contents of additional "drop-in" unit file snippets, so that
    the full configuration is shown.
  + systemctl now supports globbing on the various "list-xyz"
    commands, like "list-units" or "list-sockets", as well as on
    those commands which take multiple unit names.
  + journalctl's --unit= switch gained support for globbing.
  + All systemd daemons now make use of the watchdog logic so
    that systemd automatically notices when they hang.
  + If the $container_ttys environment variable is set,
    getty-generator will automatically spawn a getty for each
    listed tty. This is useful for container managers to request
    login gettys to be spawned on as many ttys as needed.
  + %%h, %%s, %%U specifier support is not available anymore when
    used in unit files for PID 1. This is because NSS calls are
    not safe from PID 1. They stay available for --user
    instances of systemd, and as special case for the root user.
  + loginctl gained a new "--no-legend" switch to turn off output
    of the legend text.
  + The "sd-login.h" API gained three new calls:
    sd_session_is_remote(), sd_session_get_remote_user(),
    sd_session_get_remote_host() to query information about
    remote sessions.
  + The udev hardware database now also carries vendor/product
    information of SDIO devices.
  + The "sd-daemon.h" API gained a new sd_watchdog_enabled() to
    determine whether watchdog notifications are requested by
    the system manager.
  + Socket-activated per-connection services now include a
    short description of the connection parameters in the
    description.
  + tmpfiles gained a new "--boot" option. When this is not used,
    only lines where the command character is not suffixed with
    "!" are executed. When this option is specified, those
    options are executed too.
  + systemctl gained a new "import-environment" command which
    uploads the caller's environment (or parts thereof) into the
    service manager so that it is inherited by services started
    by the manager. This is useful to upload variables like
    $DISPLAY into the user service manager.
  + A new PrivateDevices= switch has been added to service units
    which allows running a service with a namespaced /dev
    directory that does not contain any device nodes for
    physical devices. More specifically, it only includes devices
    such as /dev/null, /dev/urandom, and /dev/zero which are API
    entry points.
  + logind has been extended to support behaviour like VT
    switching on seats that do not support a VT. This makes
    multi-session available on seats that are not the first seat
    (seat0), and on systems where kernel support for VTs has
    been disabled at compile-time.
  + If a process holds a delay lock for system sleep or shutdown
    and fails to release it in time, we will now log its
    identity. This makes it easier to identify processes that
    cause slow suspends or power-offs.
  + When parsing /etc/crypttab, support for a new key-slot=
    option as supported by Debian is added. It allows indicating
    which LUKS slot to use on disk, speeding up key loading.
  + The sd_journald_sendv() API call has been checked and
    officially declared to be async-signal-safe so that it may
    be invoked from signal handlers for logging purposes.
  + Boot-time status output is now enabled automatically after a
    short timeout if boot does not progress, in order to give
    the user an indication what she or he is waiting for.
  + The boot-time output has been improved to show how much time
    remains until jobs expire.
  + The KillMode= switch in service units gained a new possible
    value "mixed". If set, and the unit is shut down, then the
    initial SIGTERM signal is sent only to the main daemon
    process, while the following SIGKILL signal is sent to
    all remaining processes of the service.
  + logind will now also track a "Desktop" identifier for each
    session which encodes the desktop environment of it. This is
    useful for desktop environments that want to identify
    multiple running sessions of itself easily.
  + A new SELinuxContext= setting for service units has been
    added that allows setting a specific SELinux execution
    context for a service.
  + Most systemd client tools will now honour $SYSTEMD_LESS for
    settings of the "less" pager.
  + systemd's "seccomp" hook-up has been changed to make use of
    the libseccomp library instead of using its own
    implementation. This has benefits for portability among
    other things.
- Dropped systemd patches as those are fixed upstream:
  * 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch
  * 0002-fix-lingering-references-to-var-lib-backlight-random.patch
  * 0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch
  * 0004-systemctl-fix-name-mangling-for-sysv-units.patch
  * 0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch
  * 0006-journald-add-missing-error-check.patch
  * 0007-bus-fix-potentially-uninitialized-memory-access.patch
  * 0008-dbus-fix-return-value-of-dispatch_rqueue.patch
  * 0009-modules-load-fix-error-handling.patch
  * 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch
  * 0011-strv-don-t-access-potentially-NULL-string-arrays.patch
  * 0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch
  * 0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch
  * 0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch
  * 0001-gpt-auto-generator-exit-immediately-if-in-container.patch
  * 0001-manager-when-verifying-whether-clients-may-change-en.patch
  * 0001-logind-fix-bus-introspection-data-for-TakeControl.patch
  * 0001-mount-check-for-NULL-before-reading-pm-what.patch
  * 0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch
  * 0001-systemd-serialize-deserialize-forbid_restart-value.patch
  * 0001-core-unify-the-way-we-denote-serialization-attribute.patch
  * 0001-journald-fix-minor-memory-leak.patch
  * 0001-do-not-accept-garbage-from-acpi-firmware-performance.patch
  * 0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch
  * 0001-login-fix-invalid-free-in-sd_session_get_vt.patch
  * 0001-login-make-sd_session_get_vt-actually-work.patch
  * 0001-Never-call-qsort-on-potentially-NULL-arrays.patch
  * 0001-dbus-common-avoid-leak-in-error-path.patch
  * 0001-drop-ins-check-return-value.patch
  * 0001-shared-util-Fix-glob_extend-argument.patch
  * 0001-Fix-bad-assert-in-show_pid_array.patch
  * 0001-analyze-set-white-background.patch
  * 0001-analyze-set-text-on-side-with-most-space.patch
  * analyze-fix-crash-in-command-line-parsing.patch
  * 0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
  * U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * build-sys-make-multi-seat-x-optional.patch
  * 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Dropped backported systemd patches as those are fixed upstream
  * 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  * 1011-check-4-valid-kmsg-device.patch
  * 0001-logind-garbage-collect-stale-users.patch
- Dropped udev patches as those are fixed fixed upstream:
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
- Modified patches
  * 1006-udev-always-rename-network.patch
- Replaced patches
  * the patch
    1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    is upstream now but has to be replaced by patch
    0001-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    to fix an further issue similar to the upstream patch (bnc#852015)
  * the patch
    0001-upstream-systemctl-halt-reboot-error-handling.patch
    is upstream now, only the part with the halt after a failed poweroff
    has been added to the patch
    0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
* Thu Feb 27 2014 werner@suse.de
- Add patch 0001-make-209-working-on-older-dist.patch to make
  it usable on older distributions like 13.1
* Wed Feb 26 2014 werner@suse.de
- Add patch 0001-add-network-device-after-NFS-mount-units.patch to
  add "After" dependency to all NFS shares to the network interface
  device as this ensures at shutdown that the NFS share becomes
  unmounted before the interface is down (bnc#861489)
  +-------------------------------------------------------------------
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- enable compat-libs, BuildRequires binutils-gold
  ("old" ld fails on ifunc magic)
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- add network link configuration for udev
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch,
  move to core and link in directly to avoid libudev dep all over
- Disable networkd
- Disable compat-libs, adapt files section
- add and remove some entries in the files section
* Fri Feb 21 2014 werner@suse.de
- Modify patch 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to avoid WantedBy for Should-Start/Start-Before/Start-After SysVinit
  scripts (bnc#863217)
* Thu Feb 20 2014 werner@suse.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to do a final sync() and flush the disks
* Fri Feb 14 2014 werner@suse.de
- Add several upstream bugfix patches which are missed:
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Add patch 0001-Don-t-snprintf-a-potentially-NULL-pointer.patch
  to avoid potential NULL pointer
- Reorder patches to reflect udev/systemd usage
* Tue Feb 11 2014 coolo@suse.com
- don't build bash-completions for bootstrap package
* Tue Feb 11 2014 coolo@suse.com
- add more requires to this-is-only-for-build-envs to avoid
  problems in kiwi configs
* Mon Feb 10 2014 werner@suse.de
- Add patch 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  to be able to kill sessions (bnc#860574)
* Mon Feb 10 2014 werner@suse.de
- Do not return from main shell script but simply exit (bnc#862789)
* Sun Feb  9 2014 werner@suse.de
- ... as only the systemd-analyze completion depends on
  bash-completion I prefere a without which has to be defined
  for SLES 12
* Sun Feb  9 2014 coolo@suse.com
- avoid bootstrap cycle with libusb and systemd-mini
* Sat Feb  8 2014 coolo@suse.com
- split bash-completion support into its own package,
  no need for sles_version
* Fri Feb  7 2014 werner@suse.de
- Split off systemd-rpm-macros as a separate package to avoid
  a rebuild of all packages due new systemd package
- Define a sles_version 12 for suse_version 1315
* Wed Feb  5 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to disable the workaround to find /dev/3270/tty1 as this now
  should be done by a) the kernel patch
  http://lkml.indiana.edu/hypermail/linux/kernel/1402.0/02319.html
  and the changed udev rule 99-systemd.rules
* Sun Feb  2 2014 ohering@suse.com
- Remove PreReq pidof from udev, nothing in this pkg uses it
* Fri Jan 31 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to re-enable colouring if 3270 console was enforced on the kernel
  command line as 3270 cna handle colour ANSI escape sequences.
  Also let the serial getty generator find the /dev/3270/tty1
  character device (bnc#861316)
* Thu Jan 30 2014 werner@suse.de
- Add patch 0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to strip the colouring ANSI escape sequences from the console
  messages (bnc#860937)
* Thu Jan 30 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip already by the kernel managed devices
* Wed Jan 29 2014 arvidjaar@gmail.com
- fix timeout stopping user@.service (bnc#841544)
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
* Tue Jan 28 2014 werner@suse.de
- Add patch 0001-upstream-systemctl-halt-reboot-error-handling.patch
  to be able to detect if the sysctl reboot() returns.
- Add patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  A check for unmaintained disk like devices is added to be able to
  flush and maybe shut them down.  Also the missing sync() system
  call is added for the direct halt/reboot systemctl command. Then
  the system halt is used as fallback if poweroff fails for both
  the direct poweroff systemctl command as well as for the
  systemd-shutdown utility.
* Thu Jan 23 2014 werner@suse.de
- Make systemd-mini build
* Thu Jan 23 2014 werner@suse.de
- Make requires bash-completion a recommends
* Tue Jan 21 2014 werner@suse.de
- Add patch 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  to avoid that enabled boot scripts will be handled as unit files
  by systemctl status command (bnc#818044)
* Tue Jan 21 2014 werner@suse.de
- Drop patch 1017-enforce-sufficient-shutdown-warnings.patch
  as the original code behaves exactly as the shutdown code of
  the old SysVinit (bnc#750845)
- Rename support-powerfail-with-powerstatus.patch to
  1016-support-powerfail-with-powerstatus.patch
* Mon Jan 20 2014 fcrozat@suse.com
- Add analyze-fix-crash-in-command-line-parsing.patch: fix crash in
  systemd-analyze (bnc#859365)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to make redirections work with the bash command completions for
  for systemd command tools (bnc#856858, bnc#859072)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to support the "+" to tag wanted dependencies as well as make
  sure that required dependencies are handles as required ones.
  This should fix bnc#858864 and bnc#857204.
* Thu Jan 16 2014 lnussel@suse.de
- apply preset also to service files that are new in upgrade
* Wed Jan 15 2014 werner@suse.de
- Change support-powerfail-with-powerstatus.patch to use BindsTo
  instead of BindTo
* Wed Jan 15 2014 werner@suse.de
- Add patch 1017-enforce-sufficient-shutdown-warnings.patch
  Warn once per hour in the last 3 hours, then all 30 minutes in last
  hour, all 15 minutes in the last 45 minutes, all 10 minutes in the
  last 15 minutes, and then all minute in the last 10 minutes (bnc#750845)
* Tue Jan 14 2014 werner@suse.de
- Add patch support-powerfail-with-powerstatus.patch and source
  file systemd-powerfail to implement SIGPWR support with evaluation
  of the file /var/run/powerstatus (bnc#737690)
* Fri Dec 20 2013 werner@suse.de
- Adapt patch
  1011-check-4-valid-kmsg-device.patch
  to fit current upstream version maybe related to bnc#854884
- Change patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to check if XDG_RUNTIME_DIR is set before the call of pam_putenv()
  may fix bnc#855160
* Fri Dec 20 2013 lbsousajr@gmail.com
- Disable multi-seat-x build, since package xorg-x11-server
  currently in Factory no longer needs it.
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Added 0001-logind-garbage-collect-stale-users.patch: Don't stop a
  running user manager from garbage-collecting the user. Original
  behavior caused bnc#849870
* Mon Dec 16 2013 lbsousajr@gmail.com
- Add build-sys-make-multi-seat-x-optional.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=bd441fa27a22b7c6e11d9330560e0622fb69f297
  * Now systemd-multi-seat-x build can be disabled with configure option
  - -disable-multi-seat-x. It should be done when xorg-x11-server
    no longer needs it (work in progress).
* Mon Dec 16 2013 fcrozat@suse.com
- Update insserv-generator.patch: fix crash in insserv generator
  (bnc#854314).
- Update apply-ACL-for-nvidia-device-nodes.patch with latest fixes
  for Nvidia cards (bnc#808319).
* Fri Dec  6 2013 werner@suse.de
- Add patch
  1014-journald-with-journaling-FS.patch
  which now uses the file system ioctls for switching off atime,
  compression, and copy-on-write of the journal directory of the
  the systemd-journald (bnc#838475)
- Let us build require the package config for libpcre (bnc#853293)
* Sat Nov 30 2013 arvidjaar@gmail.com
- Add patch
  0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  Make sure emergency shell is not killed by attempt to start another unit
  (bnc#852021). Backported from d420282b28f50720e233ccb1c02547c562195653.
- Add patch
  make-emergency.service-conflict-with-syslog.socket.patch
  Previous patch did not fix problem if syslog connection request came
  after emergency shell was already started. So forcibly stop syslog.socket
  when starting emergency.service. (bnc#852232)
* Thu Nov 28 2013 lbsousajr@gmail.com
- Add U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=3fdb2494c1e24c0a020f5b54022d2c751fd26f50
* Tue Nov 26 2013 werner@suse.de
- Add patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to avoid (xdg-)su to set XDG_RUNTIME_DIR to the original user and
  avoid that e.g. pulseaudio will create /run/user/<pid>/pulse owned
  by root (bnc#852015)
* Thu Nov 21 2013 werner@suse.de
- Add patch
  1011-check-4-valid-kmsg-device.patch
  to avoid a busy systemd-journald (bnc#851393)
* Wed Nov  6 2013 werner@suse.de
- Add patch
  1010-do-not-install-sulogin-unit-with-poweroff.patch
  that is do not install console-shell.service in any system target
  as this will cause automatic poweroff at boot (bnc#849071)
* Mon Nov  4 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-text-on-side-with-most-space.patch
  to place the text on the side with most space
* Fri Oct 25 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-white-background.patch
  to make SVG output of systemd analyze readable
* Mon Oct 21 2013 werner@suse.de
- Add patch
  1009-make-xsltproc-use-correct-ROFF-links.patch
  to have valid ROFF links in manual pages working again (bnc#842844)
* Tue Oct 15 2013 fcrozat@suse.com
- Add
  0001-gpt-auto-generator-exit-immediately-if-in-container.patch:
  don't start gpt auto-generator in container (git).
- Add
  0001-manager-when-verifying-whether-clients-may-change-en.patch:
  fix reload check in selinux case (git).
- Add 0001-logind-fix-bus-introspection-data-for-TakeControl.patch:
  fix introspection for TakeControl (git).
- Add 0001-mount-check-for-NULL-before-reading-pm-what.patch: fix
  crash when parsing some incorrect unit (git).
- Add
  0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch:
  Fix udev rules parsing (git).
- Add
  0001-systemd-serialize-deserialize-forbid_restart-value.patch:
  Fix incorrect deserialization for forbid_restart (git).
- Add
  0001-core-unify-the-way-we-denote-serialization-attribute.patch:
  Ensure forbid_restart is named like other attributes (git).
- Add 0001-journald-fix-minor-memory-leak.patch: fix memleak in
  journald (git).
- Add
  0001-do-not-accept-garbage-from-acpi-firmware-performance.patch:
  Improve ACPI firmware performance parsing (git).
- Add
  0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch:
  Fix journal rotation (git).
- Add
  0001-login-fix-invalid-free-in-sd_session_get_vt.patch:
  Fix memory corruption in sd_session_get_vt (git).
- Add 0001-login-make-sd_session_get_vt-actually-work.patch: Ensure
  sd_session_get_vt returns correct value (git).
- Add 0001-Never-call-qsort-on-potentially-NULL-arrays.patch: Don't
  call qsort on NULL arrays (git).
- Add 0001-dbus-common-avoid-leak-in-error-path.patch: Fix memleak
  in dbus-common code (git).
- Add 0001-drop-ins-check-return-value.patch: Fix return value for
  drop-ins checks (git).
- Add 0001-shared-util-Fix-glob_extend-argument.patch: Fix
  glob_extend argument (git).
- Add 0001-Fix-bad-assert-in-show_pid_array.patch: Fix bad assert
  in show_pid_array (git).
* Thu Oct  3 2013 fcrozat@suse.com
- Add 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch:
  fix acpi memleak.
- Add
  0002-fix-lingering-references-to-var-lib-backlight-random.patch:
  fix invalid path in documentation.
- Add
  0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch:
  fix invalid memory free.
- Add 0004-systemctl-fix-name-mangling-for-sysv-units.patch: fix
  name mangling for sysv units.
- Add
  0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch:
  fix OOM handling.
- Add 0006-journald-add-missing-error-check.patch: add missing
  error check.
- Add 0007-bus-fix-potentially-uninitialized-memory-access.patch:
  fix uninitialized memory access.
- Add 0008-dbus-fix-return-value-of-dispatch_rqueue.patch: fix
  return value.
- Add 0009-modules-load-fix-error-handling.patch: fix error
  handling.
- Add 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch:
  fix incorrect memory access.
- Add 0011-strv-don-t-access-potentially-NULL-string-arrays.patch:
  fix incorrect memory access.
- Add
  0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch:
  fix invalid pointer.
- Add
  0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch:
  fix permission on /run/log/journal.
- Add
  0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch:
  order remote mount points properly before remote-fs.target.
* Wed Oct  2 2013 hrvoje.senjan@gmail.com
- Explicitly require pam-config for %%post of the main package
* Wed Oct  2 2013 fcrozat@suse.com
- Release v208:
  + logind gained support for facilitating privileged input and drm
    devices access for unprivileged clients (helps Wayland /
    kmscon).
  + New kernel command line luks.options= allows to specify LUKS
    options, when used with luks.uuid=
  + tmpfileS.d snippets can uses specifier expansion in path names
    (%%m, %%b, %%H, %%v).
  + New tmpfiles.d command "m" introduced to change
    owner/group/access mode of a file/directory only if it exists.
  + MemorySoftLimit= cgroup settings is no longer supported
    (underlying kernel cgroup attribute will disappear in the
    future).
  + memeory.use_hierarchy cgroup attribute is enabled for all
    cgroups systemd creates in memory cgroup hierarchy.
  + New filed _SYSTEMD_SLICE= is logged in journal messages related
    to a slice.
  + systemd-journald will no longer adjust the group of journal
    files it creates to "systemd-journal" group. Permissions and
    owernship is adjusted when package is upgraded.
  + Backlight and random seed files are now stored in
    /var/lib/systemd.
  + Boot time performance measurements included ACPI 5.0 FPDT
    informations if available.
- Drop merged patches:
  0001-cgroup-add-the-missing-setting-of-variable-s-value.patch,
  0002-cgroup-correct-the-log-information.patch,
  0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch,
  0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch,
  0005-core-cgroup-first-print-then-free.patch,
  0006-swap-fix-reverse-dependencies.patch,
  0008-swap-create-.wants-symlink-to-auto-swap-devices.patch,
  0009-polkit-Avoid-race-condition-in-scraping-proc.patch,
  Fix-timeout-when-stopping-Type-notify-service.patch,
  set-ignoreonisolate-noauto-cryptsetup.patch,
  0001-Fix-buffer-overrun-when-enumerating-files.patch,
  0007-libudev-fix-move_later-comparison.patch.
- Refresh patches
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch,
  handle-root_uses_lang-value-in-etc-sysconfig-language.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch.
- Own more ghost files.
- Do not run pam-config in systemd-mini %%post.
- Add after-local.service to run after.local late during the boot
  process (bnc#778715).
* Tue Oct  1 2013 fcrozat@suse.com
- Update Fix-timeout-when-stopping-Type-notify-service.patch with
  upstream fix.
- No longer start ask-password-wall, was causing too much spam on
  terminals (bnc#747783).
* Mon Sep 30 2013 fcrozat@suse.com
- Add set-ignoreonisolate-noauto-cryptsetup.patch: ensure noauto
  encrypted mounts survives runlevel changes (bnc#843085).
- Add 0001-Fix-buffer-overrun-when-enumerating-files.patch: fix
  logind crash when /run/systemd/sessions was too big (bnc#840055,
  initial fix from hpj@suse.com).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  only check for /boot/sysctl.conf-<uname -r> presence.
- Add service wrapper for after.local (bnc#778715).
* Fri Sep 27 2013 fcrozat@suse.com
- Update use-usr-sbin-sulogin-for-emergency-service.patch to apply
  to all services using sulogin and remove generated files from
  upstream tarball (bnc#841398).
* Mon Sep 23 2013 arvidjaar@gmail.com
- Fix-timeout-when-stopping-Type-notify-service.patch
  Make sure MAINPID is watched when it becomes known (bnc#841544)
* Mon Sep 23 2013 fcrozat@suse.com
- Remove output and error redirection to /dev/null in install
  script, it might help tracing pam related issue (bnc#841573).
* Thu Sep 19 2013 fcrozat@suse.com
- Move symlink migration trigger to post (bnc#821800).
* Wed Sep 18 2013 crrodriguez@opensuse.org
- 0009-polkit-Avoid-race-condition-in-scraping-proc.patch
  VUL-0: polkit: process subject race condition [bnc#835827]
  CVE-2013-4288
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-ima as the openSUSE kernel
  does not support IMA (CONFIG_IMA is not set)
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-smack as the openSUSE kernel
  does not support smack (CONFIG_SECURITY_SMACK is not set)
* Wed Sep 18 2013 fcrozat@suse.com
- Don't use a trigger to create symlink for sysctl.conf, always run
  the test on %%post (bnc#840864).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  ensure /boot is mounted before reading /boot/sysctl.conf-*
  (bnc#809420).
* Mon Sep 16 2013 crrodriguez@opensuse.org
- 0008-swap-create-.wants-symlink-to-auto-swap-devices.patch
  really fixes the swap unit problem mentioned in previous
  commit & the opensuse-factory mailing list.
* Sat Sep 14 2013 crrodriguez@opensuse.org
- 0001-cgroup-add-the-missing-setting-of-variable-s-value.patch
  missing important check on return value.
- 0002-cgroup-correct-the-log-information.patch fix misleading
  log information.
- 0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch fix
  setting memory cgroup
- 0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch
  should fail if write fails.
- 0005-core-cgroup-first-print-then-free.patch use-after-free
  will trigger if there is an error condition.
- 0006-swap-fix-reverse-dependencies.patch reported in
  opensuse-factory list, topic "swap isn't activated"
- 0007-libudev-fix-move_later-comparison.patch libudev
  invalid usage of "move_later".
* Sat Sep 14 2013 crrodriguez@opensuse.org
- while testing this new release I get in the logs ocassionally
  at boot "systemd[1]: Failed to open private bus connection:
  Failed to connect to socket /var/run/dbus/system_bus_socket:
  No such file or directory" indeed DBUS_SYSTEM_BUS_DEFAULT_ADDRESS
  is defined to /var/run/dbus/system_bus_socket instead of
  /run/dbus/system_bus_socket and that does not fly when /var/run
  is not yet available. (systemd-dbus-system-bus-address.patch)
* Fri Sep 13 2013 fcrozat@suse.com
- Enable Predictable Network interface names (bnc#829526).
* Fri Sep 13 2013 crrodriguez@opensuse.org
- version 207, distribution specific changes follow, for overall
  release notes see NEWS.
- Fixed:
  * Failed at step PAM spawning /usr/lib/systemd/systemd:
  Operation not permitted
  * Fix shutdown hang "a stop job is running for Session 1 of user root"
    that was reported in opensuse-factory list.
- systemd-sysctl no longer reads /etc/sysctl.conf however backward
  compatbility is to be provides by a symlink created at %%post.
- removed previously disabled upstream patches (merged):
  0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch,
  0004-disable-the-cgroups-release-agent-when-shutting-down.patch,
  0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch,
  0006-suppress-status-message-output-at-shutdown-when-quie.patch,
- removed upstream merged patches:
  exclude-dev-from-tmpfiles.patch,
  logind_update_state_file_after_generating_....patch
- Add systemd-pam_config.patch: use correct include name for PAM
  configuration on openSUSE.
* Mon Sep  9 2013 fcrozat@suse.com
- Add exclude-dev-from-tmpfiles.patch: allow to exclude /dev from
  tmpfiles (bnc#835813).
* Fri Sep  6 2013 fcrozat@suse.com
- Remove
  force-lvm-restart-after-cryptsetup-target-is-reached.patch and
  remove additional dependencies on LVM in other patches: LVM has
  now systemd support, no need to work around it anymore in
  systemd.
* Wed Aug 21 2013 idonmez@suse.com
- Add patch logind_update_state_file_after_generating_the_session_fifo_not_before.patch
  to fix https://bugs.freedesktop.org/show_bug.cgi?id=67273
* Tue Aug  6 2013 lnussel@suse.de
- explicitly enable getty@tty1.service instead of getty@.service as
  the tty1 alias has been removed from the file (bnc#833494)
* Thu Aug  1 2013 fcrozat@suse.com
- Ensure /usr/lib/systemd/system/shutdown.target.wants is created
  and owned by systemd package.
* Mon Jul 29 2013 fcrozat@suse.com
- Fix drop-in for getty@tty1.service
* Thu Jul 25 2013 fcrozat@suse.com
- Move systemd-journal-gateway to subpackage to lower dependencies
  in default install.
* Tue Jul 23 2013 crrodriguez@opensuse.org
- version 206 , highlights:
  * Unit files now understand the new %%v specifier which
  resolves to the kernel version string as returned by "uname-r".
  * "journalctl -b" may now be used to look for boot output of a
  specific boot. Try "journalctl -b -1"
  * Creation of "dead" device nodes has been moved from udev
  into kmod and tmpfiles.
  * The udev "keymap" data files and tools to apply keyboard
  specific mappings of scan to key codes, and force-release
  scan code lists have been entirely replaced by a udev
  "keyboard" builtin and a hwdb data file.
- remove patches now in upstream
- systemd now requires libkmod >=14 and cryptsetup >= 1.6.0
- systemd now require the kmod tool in addition to the library.
* Sun Jul 14 2013 arvidjaar@gmail.com
- use-usr-sbin-sulogin-for-emergency-service.patch
  emergency.service failed to start because sulogin is in /usr/sbin now
* Fri Jul 12 2013 mls@suse.de
- fix build with rpm-4.11.1: /etc/xdg/system/user is a symlink,
  not a directory
* Fri Jul  5 2013 crrodriguez@opensuse.org
- 0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch
  fix segfault at shutdown
- 0004-disable-the-cgroups-release-agent-when-shutting-down.patch
  disable the cgroups release agent when shutting down.
- 0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch
  remove ancient fallback code; turn connection error into warning
- 006-suppress-status-message-output-at-shutdown-when-quie.patch
  make shutdown honour "quiet" kernel cmdline.
* Fri Jul  5 2013 crrodriguez@opensuse.org
- fix broken symlink, service is called systemd-random-seed now.
* Thu Jul  4 2013 fcrozat@suse.com
- Update to release 205:
  + two new unit types have been introduced:
  - Scope units are very similar to service units, however, are
    created out of pre-existing processes -- instead of PID 1
    forking off the processes.
  - Slice units may be used to partition system resources in an
    hierarchial fashion and then assign other units to them. By
    default there are now three slices: system.slice (for all
    system services), user.slice (for all user sessions),
    machine.slice (for VMs and containers).
  + new concept of "transient" units, which are created at runtime
    using an API and not based on configuration from disk.
  + logind has been updated to make use of scope and slice units to
    manage user sessions. Logind will no longer create cgroups
    hierchies itself but will relying on PID 1.
  + A new mini-daemon "systemd-machined" has been added which
    may be used by virtualization managers to register local
    VMs/containers. machinectl tool has been added to query
    meta-data from systemd-machined.
  + Low-level cgroup configuration options ControlGroup=,
    ControlGroupModify=, ControlGroupPersistent=,
    ControlGroupAttribute= have been removed. High-level attribute
    settings or slice units should be used instead?
  + A new bus call SetUnitProperties() has been added to alter
    various runtime parameters of a unit, including cgroup
    parameters. systemctl gained set-properties command to wrap
    this call.
  + A new tool "systemd-run" has been added which can be used to
    run arbitrary command lines as transient services or scopes,
    while configuring a number of settings via the command
    line.
  + nspawn will now inform the user explicitly that kernels with
    audit enabled break containers, and suggest the user to turn
    off audit.
  + Support for detecting the IMA and AppArmor security
    frameworks with ConditionSecurity= has been added.
  + journalctl gained a new "-k" switch for showing only kernel
    messages, mimicking dmesg output; in addition to "--user"
    and "--system" switches for showing only user's own logs
    and system logs.
  + systemd-delta can now show information about drop-in
    snippets extending unit files.
  + systemd will now look for the "debug" argument on the kernel
    command line and enable debug logging, similar to
    "systemd.log_level=debug" already did before.
  + "systemctl set-default", "systemctl get-default" has been
    added to configure the default.target symlink, which
    controls what to boot into by default.
  + "systemctl set-log-level" has been added as a convenient
    way to raise and lower systemd logging threshold.
  + "systemd-analyze plot" will now show the time the various
    generators needed for execution, as well as information
    about the unit file loading.
  + libsystemd-journal gained a new sd_journal_open_files() call
    for opening specific journal files. journactl also gained a
    new switch to expose this new functionality (useful for
    debugging).
  + systemd gained the new DefaultEnvironment= setting in
    /etc/systemd/system.conf to set environment variables for
    all services.
  + If a privileged process logs a journal message with the
    OBJECT_PID= field set, then journald will automatically
    augment this with additional OBJECT_UID=, OBJECT_GID=,
    OBJECT_COMM=, OBJECT_EXE=, ... fields. This is useful if
    system services want to log events about specific client
    processes. journactl/systemctl has been updated to make use
    of this information if all log messages regarding a specific
    unit is requested.
- Remove 0001-journal-letting-interleaved-seqnums-go.patch,
  0002-journal-remember-last-direction-of-search-and-keep-o.patch,
  0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch,
  0006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch,
  0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch,
  0160-mount-when-learning-about-the-root-mount-from-mounti.patch,
  0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch,
  Start-ctrl-alt-del.target-irreversibly.patch,
  systemctl-does-not-expand-u-so-revert-back-to-I.patch: merged
  upstream.
- Regenerate patches 1007-physical-hotplug-cpu-and-memory.patch,
  1008-add-msft-compability-rules.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch,
  fix-support-for-boot-prefixed-initscript-bnc-746506.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch,
  insserv-generator.patch,
  optionally-warn-if-nss-myhostname-is-called.patch,
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  restore-var-run-and-var-lock-bind-mount-if-they-aren-t-sym.patch,
  service-flags-sysv-service-with-detected-pid-as-RemainAfte.patch.
- Update macros.systemd.upstream with latest upstream revision.
* Mon Jul  1 2013 fcrozat@suse.com
- Replace
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch
  patch with insserv-generator.patch: no longer patch systemd main
  binary but generate systemd drop-in files using a generator, for
  insserv.conf compatibility.
* Mon Jul  1 2013 coolo@suse.com
- systemd-mini doesn't need dbus-1, only dbus-1-devel
* Wed Jun 26 2013 rmilasan@suse.com
- Re-add fixed udev MSFT compability rules (bnc#805059, bnc#826528).
  add: 1008-add-msft-compability-rules.patch
* Wed Jun 26 2013 rmilasan@suse.com
- Drop 1007-add-msft-compability-rules.patch, breaks boot and links
  in /dev/disk/by-id, will need proper rework (bnc#826528).
* Mon Jun 24 2013 crrodriguez@opensuse.org
- 0160-mount-when-learning-about-the-root-mount-from-mounti.patch Another
  case where we are trying to umount the root directory at shutdown.
- 0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch
  only attempt to connect to a session bus if one likely exists
* Fri Jun 21 2013 rmilasan@suse.com
- Automatically online CPUs/Memory on CPU/Memory hotplug add events
  (bnc#703100, fate#311831).
  add: 1008-physical-hotplug-cpu-and-memory.patch
* Wed Jun 19 2013 mhrusecky@suse.com
- Dropped backward compatibility
- Added check for upstream rpm macros changes
* Tue Jun 18 2013 mhrusecky@suse.com
- Split out RPM macros into separate package to simplify dependencies
* Tue Jun 18 2013 crrodriguez@opensuse.org
- 0001-journal-letting-interleaved-seqnums-go.patch and
  0002-journal-remember-last-direction-of-search-and-keep-o.patch
  fix possible infinite loops in the journal code, related to
  bnc #817778
* Sun Jun 16 2013 jengelh@inai.de
- Explicitly list libattr-devel as BuildRequires
- More robust make install call. Remove redundant %%clean section.
* Thu Jun 13 2013 sbrabec@suse.cz
- Cleanup NumLock setting code
  (handle-numlock-value-in-etc-sysconfig-keyboard.patch).
* Wed Jun 12 2013 fcrozat@suse.com
- Only apply 1007-add-msft-compability-rules.patch when not
  building systemd-mini.
* Tue Jun 11 2013 rmilasan@suse.com
- Add udev MSFT compability rules (bnc#805059).
  add: 1007-add-msft-compability-rules.patch
- Add sg3_utils requires, need it by 61-msft.rules (bnc#805059).
- Clean-up spec file, put udev patches after systemd patches.
- Rebase patches so they would apply nicely.
* Tue Jun 11 2013 crrodriguez@opensuse.org
- 0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch
  fixes :
  * systemd-journald[347]: Failed to set ACL on
  /var/log/journal/11d90b1c0239b5b2e38ed54f513722e3/user-1000.journal,
  ignoring: Invalid argument
- 006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch
  systemctl disable should remove dangling symlinks.
- 0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch
  alien childs are reported as alive when they are really dead.
* Wed May 29 2013 fcrozat@suse.com
- Update to release 204:
  + systemd-nspawn creates etc/resolv.conf in container if needed.
  + systemd-nspawn will store metadata about container in container
    cgroup including its root directory.
  + cgroup hierarchy has been reworked, all objects are now suffxed
    (with .session for user sessions, .user for users, .nspawn for
    containers). All cgroup names are now escaped to preven
    collision of object names.
  + systemctl list-dependencies gained --plain, --reverse, --after
    and --before switches.
  + systemd-inhibit shows processes name taking inhibitor lock.
  + nss-myhostname will now resolve "localhost" implicitly.
  + .include is not allowed recursively anymore and only in unit
    files. Drop-in files should be favored in most cases.
  + systemd-analyze gained "critical-chain" command, to get slowest
    chain of units run during boot-up.
  + systemd-nspawn@.service has been added to easily run nspawn
    container for system services. Just start
    "systemd-nspawn@foobar.service" and container from
    /var/lib/container/foobar" will be booted.
  + systemd-cgls has new --machine parameter to list processes from
    one container.
  + ConditionSecurity= can now check for apparmor and SMACK.
  + /etc/systemd/sleep.conf has been introduced to configure which
    kernel operation will be execute when "suspend", "hibernate" or
    "hybrid-sleep" is requrested. It allow new kernel "freeze"
    state to be used too. (This setting won't have any effect if
    pm-utils is installed).
  + ENV{SYSTEMD_WANTS} in udev rules will now implicitly escape
    passed argument if applicable.
- Regenerate some patches for this new release.
- Rename hostname-setup-shortname.patch to
  ensure-shortname-is-set-as-hostname-bnc-820213.patch to  be git
  format-patch friendly.
- Update apply-ACL-for-nvidia-device-nodes.patch to apply ACL to
  /dev/nvidia* (bnc#808319).
- Remove Ensure-debugshell-has-a-correct-value.patch, doable with a
  configure option.
- Add systemctl-does-not-expand-u-so-revert-back-to-I.patch: avoids
  expansion errors.
- Add Start-ctrl-alt-del.target-irreversibly.patch: ctrl-alt-del
  should be irreversible for reliability.
* Tue May 28 2013 crrodriguez@opensuse.org
- Drop Add-bootsplash-handling-for-password-dialogs.patch bootsplash
  support has been removed from the kernel.
- Drop ensure-systemd-udevd-is-started-before-local-fs-pre-for-lo.patch
  fixed in systemd v199, commit 89d09e1b5c65a2d97840f682e0932c8bb499f166
- Apply rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  only on ARM, patch rejected upstream because is too generic.
- no such define TARGET_SUSE exists but it is used in
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch
  use HAVE_SYSV_COMPAT instead.
* Fri May 24 2013 fcrozat@suse.com
- Do no ship defaults for sysctl, they should be part of aaa_base
  (currently in procps).
- Add hostname-setup-shortname.patch: ensure shortname is set as
  hostname (bnc#820213).
* Fri May 17 2013 fcrozat@suse.com
- Rebase
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch to
  fix memory corruption (thanks to Michal Vyskocil) (bnc#820454).
* Fri May 17 2013 fcrozat@suse.com
- Add sysctl-handle-boot-sysctl.conf-kernel_release.patch: ensure
  /boot/sysctl.conf-<kernel_release> is handled (bnc#809420).
* Wed May 15 2013 fcrozat@suse.com
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch: don't
  free variable whose content is still be used (bnc#819970).
* Tue May 14 2013 fcrozat@suse.com
- Add configure flags to ensure boot.local/halt.local are run on
  startup/shutdown.
* Mon May 13 2013 rmilasan@suse.com
- Fix firmware loading by enabling --with-firmware-path (bnc#817551).
* Mon Apr 29 2013 dschung@cs.uni-kl.de
- Fix systemd-sysv-convert, so empty runlevel folders don't lead
  to "line 44: [: too many arguments"
* Fri Apr 26 2013 fcrozat@suse.com
- Fix handle-etc-HOSTNAME.patch to properly set hostname at startup
  when using /etc/HOSTNAME.
* Thu Apr 25 2013 rmilasan@suse.com
- Rename remaning udev patches (clean-up).
- Generate %%{_libexecdir}/modules-load.d/sg.conf so we load sg module at
  boot time not from udev (bnc#761109).
- Drop unused patches:
  1001-Reinstate-TIMEOUT-handling.patch
  1005-udev-fix-sg-autoload-regression.patch
  1026-re-add-persistent-net.patch
* Tue Apr 23 2013 fcrozat@suse.com
- Use drop-in file to fix bnc#804158.
* Tue Apr 23 2013 coolo@suse.com
- add some more conflicts to make bootstrap work
* Mon Apr 22 2013 fcrozat@suse.com
- Do not provide %%{release} for systemd-analyze
- Add more conflicts to -mini packages
- Disable Predictable Network interface names until it has been
  reviewed by network team, with /usr/lib/tmpfiles.d/network.conf.
- Don't package /usr/lib/firmware/update (not used)
* Sun Apr 21 2013 crrodriguez@opensuse.org
- Fix packaging error, there is no syslog.target anymore
  do not pretend there is one.
* Fri Apr 19 2013 fcrozat@suse.com
- Update to release 202:
  + 'systemctl list-jobs' got some polishing. '--type=' argument
    may now be passed more than once. 'systemctl list-sockets' has
    been added.
  + systemd gained a new unit 'systemd-static-nodes.service'
    that generates static device nodes earlier during boot, and
    can run in conjunction with udev.
  + systemd-nspawn now places all containers in the new /machine
    top-level cgroup directory in the name=systemd hierarchy.
  + bootchart can now store its data in the journal.
  + journactl can now take multiple --unit= and --user-unit=
    switches.
  + The cryptsetup logic now understands the "luks.key=" kernel
    line switch. If a configured key file is missing, it
    will fallback to prompting the user.
- Rebase some patches
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch to
  properly handle SYSTEMCTL_OPTIONS
* Fri Apr 19 2013 max@suse.com
- Fix regression in the default for tmp auto-deletion
  (systemd-tmp-safe-defaults.patch, FATE#314974).
* Fri Apr 12 2013 fcrozat@suse.com
- Update to release 201:
  + udev now supports different nameng policies for network
    interface for predictable names.
  + udev gained support for loading additional device properties
    from an indexed database. %%udev_hwdb_update macro should be
    used by packages adding entries to this database.
  + Journal gained support for "Message Catalog", indexed database
    to link up additional information with journal entries.
    %%journal_catalog_update macro should be used by packages adding
    %%entries to this database.
  + "age" field for tmpfiles entries can be set to 0, forcing
    removal of files matching this entry.
  + coredumpctl gained "gdb" verb to invoke gdb on selected
    coredump.
  + New rpm macros has been added: %%udev_rules_update(),
    %%_udevhwdbdir, %%_udevrulesdir, %%_journalcatalogdir,
    %%_tmpfilesdir, %%_sysctldir.
  + In service files, %%U can be used for configured user name of
    the service.
  + nspawn can be invoked without a controlling TTY.
  + systemd and nspawn can accept socket file descriptors when
    started for socket activation. This allow socket activated
    nspawn containers.
  + logind can now automatically suspend/hibernate/shutdown system
    on idle.
  + ConditionACPower can be used in unit file to detect if AC power
    source is connected or if system is on battery power.
  + EnvironmentFile= in unit files supports file globbing.
  + Behaviour of PrivateTmp=, ReadWriteDirectories=,
    ReadOnlyDirectories= and InaccessibleDirectories= has
    changed. The private /tmp and /var/tmp directories are now
    shared by all processes of a service (which means
    ExecStartPre= may now leave data in /tmp that ExecStart= of
    the same service can still access). When a service is
    stopped its temporary directories are immediately deleted
    (normal clean-up with tmpfiles is still done in addition to
    this though).
  + Resource limits (as exposed by cgroup controlers) can be
    controlled dynamically at runtime for all units, using
    "systemctl set-cgroup-attr foobar.server cgroup.attribute
    value". Those settings are stored persistenly on disk.
  + systemd-vconsole-setup will now copy all fonts settings to all
    allocated VTs.
  + timedated now exposes CanNTP property to indicate if a local
    NTP service is available.
  + pstore file system is mounted by default, if available.
  + SMACK policies are loaded at early boot, if available.
  + Timer units now support calendar time events.
  + systemd-detect-virt detect xen PVs.
  + Some distributions specific LSB targets has been dropped:
    $x-display-manager, $mail-transfer-agent,
    $mail-transport-agent, $mail-transfer-agent, $smtp, $null. As
    well mail-transfer-agent.target and syslog.target has been
    removed.
  + systemd-journal-gatewayd gained SSL support and now runs as
    unprivileged user/group
    "systemd-journal-gateway:systemd-journal-gateway"
  + systemd-analyze will read, when available, boot time
    performance from EFI variable from boot loader supporting it.
  + A new generator for automatically mounting EFI System Partition
    (ESP) to /boot (if empty and no other file system has been
    configured in fstab for it).
  + logind will now send out PrepareForSleep(false) out
    unconditionally, after coming back from suspend.
  + tmpfiles gained a new "X" line type, that allows
    configuration of files and directories (with wildcards) that
    shall be excluded from automatic cleanup ("aging").
  + udev default rules set the device node permissions now only
    at "add" events, and do not change them any longer with a
    later "change" event.
  + A new bootctl tool has been added that is an interface for
    certain EFI boot loader operations.
  + A new tool kernel-install has been added to install kernel
    images according to Boot Loader Specification.
  + A new tool systemd-activate can be used to test socket
    activation.
  + A new group "systemd-journal" is now owning journal files,
    replacing "adm" group.
  + journalctl gained "--reverse" to show output in reverse order,
    "--pager-end" to jump at the end of the journal in the
    pager (only less is supported) and "--user-unit" to filter for
    user units.
  + New unit files has been addedto ease for systemd usage in
    initrd.
  + "systemctl start" now supports "--irreversible" to queue
    operations which can be reserved. It is now used to make
    shutdown requests more robust.
  + Auke Kok's bootchart has been merged and relicensed to
    LGPLv2.1+.
  + nss-myhostname has been merged in systemd codebase.
  + some defaults sysctl values are now set by default: the safe
    sysrq options are turned on, IP route verification is turned
    on, and source routing disabled. The recently added hardlink
    and softlink protection of the kernel is turned on.
  + Add support for predictable network naming logic. It can be
    turned off with kernel command line switch: net.ifnames=0
  + journald will now explicitly flush journal files to disk at the
    latest 5 min after each write and will mark file offline until
    next read. This should increase reliability in case of crash.
  + remote-fs-setup.target target has been added to pull in
    specific services when at least one remote file system is to be
    mounted.
  + timers.target and paths.target have been added as canonical
    targets to pull user timer and path units, similar to
    sockets.targets.
  + udev daemon now sets default number of worker processes in
    parallel based on number of CPUs instead of RAM.
  + Most unit file settings which takes likst of items can now be
  reset by assigning empty string to them, using drop-in.
  + Add support for drop-in configuration file for units.
  + Most unit file settings which takes likst of items can now be
    reset by assigning empty string to them, using drop-in.
  + improve systemg-cgtop output.
  + improve 'systemctl status' output for socket, drop-in for units.
  + 'hostnamectl set-hostname' allows setting FQDN hostnames.
  + fractional time intervals are now parsed properly.
  + localectl can list available X11 keymaps.
  + systemd-analyze dot can filter for specific units and has been
    rewritten in C.
  + systemctl gained "list-dependencies" command.
  + Inhibitors are now honored no only in GNOME.
- Many patches has been dropped, being merged upstream.
- Many patches has been renamed and regenerated with git, to have
  consistent naming, authorship and comments embedded.
- Add
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch:
  re-add support for boot.* initscripts until they are all migrated
  to systemd unit files.
- Merge patches for nss-myhostname package to this package.
* Fri Apr 12 2013 rschweikert@suse.com
- Add chromebook lid switch as a power switch to logind rule to
  enable suspend on lid close
* Mon Apr  8 2013 fcrozat@suse.com
- Add improve-readahead-spinning.patch: improve readahead
  performance on spinning media with ext4.
- Add fix-journal-vacuum-logic.patch: fix vacuum logic in journal
  (bnc#789589).
- Add fix-lsb-provides.patch: ensure LSB provides are correctly
  handled if also referenced as dependencies (bnc#809646).
- Add fix-loopback-mount.patch: ensure udevd is started (and
  therefore static devices are created) before mounting
  (bnc#809820).
- Update systemd-sysv-convert to search services files in new
  location (bnc#809695).
- Add logind-nvidia-acl.diff: set ACL on nvidia devices
  (bnc#808319).
- Add do-no-isolate-on-fsck-failure.patch: do not turn off services
  if fsck fails (bnc#812874)
- Add wait-for-processes-killed.patch: wait for processes killed by
  SIGTERM before killing them with SIGKILL.
- Update systemctl-options.patch to only apply SYSTEMCTL_OPTIONS to
  systemctl command (bnc#801878).
* Tue Apr  2 2013 sbrabec@suse.cz
- Fixed disabling CapsLock and enabling NumLock (bnc#746595,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  systemd-numlock-suse.patch).
- Explicitly require libgcrypt-devel to fix build failure.
* Thu Mar 28 2013 rmilasan@suse.com
- udev: ensure that the network interfaces are renamed even if they
  exist (bnc#809843).
  add: 1027-udev-always-rename-network.patch
* Wed Mar 20 2013 rmilasan@suse.com
- udev: re-add persistent network rules (bnc#809843).
  add: 1026-re-add-persistent-net.patch
- rebase all patches, ensure that they apply properly.
* Thu Feb 21 2013 fcrozat@suse.com
- Add rbind-mount.patch: handle rbind mount points correctly
  (bnc#804575).
* Tue Feb 19 2013 fcrozat@suse.com
- Ensure journal is flushed on disk when systemd-logger is
  installed for the first time.
- Add improve-journal-perf.patch: improve journal performance on
  query.
- Add support-hybrid-suspend.patch: add support for hybrid suspend.
- Add forward-to-pmutils.patch: forward suspend/hibernation calls
  to pm-utils, if installed (bnc#790157).
* Tue Feb 19 2013 rmilasan@suse.com
- udev: usb_id: parse only 'size' bytes of the 'descriptors' buffer
  add: 1024-udev-usb_id-parse-only-size-bytes-of-the-descriptors.patch
- udev: expose new ISO9660 properties from libblkid
  add: 1025-udev-expose-new-ISO9660-properties-from-libblkid.patch
* Mon Feb 18 2013 jengelh@inai.de
- Create getty@tty1.service to restore traditional SUSE behavior
  of not clearing tty1. (bnc#804158)
- Better use of find -exec
* Fri Feb 15 2013 fcrozat@suse.com
- Add early-sync-shutdown.patch: start sync just when
  shutdown.target is beginning
- Update parse-multiline-env-file.patch to better handle continuing
  lines.
- Add handle-HOSTNAME.patch: handle /etc/HOSTNAME (bnc#803653).
- Add systemctl-print-wall-on-if-successful.patch: only print on
  wall if successful.
- Add improve-bash-completion.patch: improve bash completion.
* Fri Feb 15 2013 lnussel@suse.de
- disable nss-myhostname warning (bnc#783841)
  => disable-nss-myhostname-warning-bnc-783841.diff
* Wed Feb 13 2013 rmilasan@suse.com
- rework patch:
  1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- udev: use unique names for temporary files created in /dev.
  add: 1022-udev-use-unique-names-for-temporary-files-created-in.patch
- cdrom_id: add data track count for bad virtual drive.
  add: 1023-cdrom_id-add-data-track-count-for-bad-virtual-drive.patch
* Tue Feb 12 2013 rmilasan@suse.com
- usb_id: ensure we have a valid serial number as a string (bnc#779493).
  add: 1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- cdrom_id: created links for the default cd/dvd drive (bnc#783054).
  add: 1021-create-default-links-for-primary-cd_dvd-drive.patch
* Fri Feb  1 2013 fcrozat@suse.com
- Add cryptsetup-accept-read-only.patch: accept "read-only" in
  addition to "readonly" in crypttab
- Update parse-multiline-env-file.patch to correctly handle
  commented lines (bnc#793411)
* Tue Jan 29 2013 rmilasan@suse.com
- udev: Fix device matching in the accelerometer
  add: 1019-udev-Fix-device-matching-in-the-accelerometer.patch
- keymap: add aditional support for some keyboard keys
  add: 1018-keymap-add-aditional-support.patch
- journalctl: require argument for --priority
  add: journalctl-require-argument-for-priority
- dropped useless patches:
  libudev-validate-argument-udev_enumerate_new.patch
  kmod-fix-builtin-typo.patch
- rename udev-root-symlink.service to systemd-udev-root-symlink.service.
- fix in udev package missing link in basic.target.wants for
  systemd-udev-root-symlink.service
* Mon Jan 28 2013 fcrozat@suse.com
- Add tmpfiles-X-type.patch: allow to clean directories with
  removing them.
- Add systemd-fix-merge-ignore-dependencies.patch: fix merging with
  - -ignore-dependencies waiting for dependencies (bnc#800365).
- Update systemd-numlock-suse.patch: udev-trigger.service is now
  called systemd-udev-trigger.service.
- Add improve-man-environment.patch: improve manpage regarding
  Environment value.
* Tue Jan 22 2013 fcrozat@suse.com
- Add systemctl-options.patch: handle SYSTEMCTL_OPTIONS internaly
  (bnc#798620).
- Update crypt-loop-file.patch to correctly detect crypto loop
  files (bnc#799514).
- Add journalctl-remove-leftover-message.patch: remove debug
  message in systemctl.
- Add job-avoid-recursion-when-cancelling.patch: prevent potential
  recursion when cancelling a service.
- Add sysctl-parse-all-keys.patch: ensure sysctl file is fully
  parsed.
- Add journal-fix-cutoff-max-date.patch: fix computation of cutoff
  max date for journal.
- Add reword-rescue-mode-hints.patch: reword rescue prompt.
- Add improve-overflow-checks.patch: improve time overflow checks.
- Add fix-swap-behaviour-with-symlinks.patch: fix swap behaviour
  with symlinks.
- Add hostnamectl-fix-set-hostname-with-no-argument.patch: ensure
  hostnamectl requires an argument when called with set-hostname
  option.
- Add agetty-overrides-term.patch: pass correctly terminal type to
  agetty.
- Add check-for-empty-strings-in-strto-conversions.patch: better
  check for empty strings in strto* conversions.
- Add strv-cleanup-error-path-loops.patch: cleanup strv on error
  path.
- Add cryptsetup-handle-plain.patch: correctly handle "plain"
  option in cryptsetup.
- Add fstab-generator-improve-error-message.patch: improve error
  message in fstab-generator.
- Add delta-accept-t-option.patch: accept -t option in
  systemd-delta.
- Add highlight-ordering-cycle-deletions.patch: highlight ordering
  cycle deletions in logs.
- Add core-interpret-escaped-semicolon-as-escaped.patch: accept \;
  in ExecStart.
- Add hostnamectl-fix-parsing-no-ask-password.patch: accept
  no-ask-password in hostnamectl.
- Add systemd-cgls-fix-piping-output.patch: fix piping output of
  systemd-cgls.
- Add core-load-fragment-improve-error-message.patch: improve error
  message when parsing fragments.
- Add fix-potential-bad-mem-access.patch: fix potential bad memory
  access.
- Add socket-improve-error-message.patch: improve error message in
  socket handling.
- Add journal-send-always-send-syslog_identifier.patch: always send
  syslog_identifier if available for journal.
- Add crypsetup-handle-nofail.patch: handle nofail in cryptsetup.
- Add crypsetup-generator-state-file-name-in-error-message.patch:
  add filename in error message from crypsetup-generator.
- Add fstab-generator-error-message-on-duplicates.patch: improve
  error message on duplicate in fstab-generator.
- Add systemctl-verbose-message-on-missing-install.patch: reword
  missing install error message in systemctl.
- Add shutdown-improvements.patch: various improvements at
  shutdown.
- Add localectl-fix-assertion.patch: fix assertion in localectl.
- Add path-util-fix-potential-crash.patch: fix potential crash in
  path-util.
- Add coredumpctl-fix-crash.patch: fix crash in coredumpctl.
- Add socket-verbose-error-message.patch: add more verbose error
  message in socket handling.
- Add pam-properly-handle-ssh-logins-without-pam-tty-field.patch:
  handle properly ssh-logins without pam tty field.
- Add fstab-generator-properly-detect-bind-mounts.patch: properly
  detect bind-mounts in fstab-generator.
- Add localectl-support-systems-without-locale-archive.patch:
  localectl now supports systemd without locale-archive file.
- Add logind-capability-making-seats-without-fb.patch: allows
  capability of making seats without fb.
- Add service-forking-ignore-exit-status-main-process.patch: ignore
  exit-statis of main process when forking, if specified in unit
  file.
- Add systemctl-no-assert-on-reboot-without-dbus.patch: don't
  assert on reboot if dbus isn't there.
- Add logind-ignore-non-tty-non-x11-session-on-shutdown.patch:
  ignore non tty non-x11 session on shutdown.
- Add journalctl-quit-on-io-error.patch: fix journalctl quit on io
  error.
- Add do-not-make-sockets-dependent-on-lo.patch: do not make
  sockets dependent on lo interface.
- Add shutdown-dont-force-mnt-force-on-final-umount.patch: don't
  force MNT_FORCE on final umount at shutdown.
- Add shutdown-ignore-loop-devices-without-backing-file.patch:
  ignore loop devices without backing file at shutdown.
- Add fix-bad-mem-access.patch: fix bad memory access
- Add parse-multiline-env-file.patch: correctly parse multiline
  environment files (bnc#793411).
* Thu Jan 10 2013 fcrozat@suse.com
- Add multiple-sulogin.patch: allows multiple sulogin instance
  (bnc#793182).
* Wed Jan  9 2013 rmilasan@suse.com
- udev: path_id - handle Hyper-V devices
  add: 1008-udev-path_id-handle-Hyper-V-devices.patch
- keymap: Update the list of Samsung Series 9 models
  add: 1009-keymap-Update-the-list-of-Samsung-Series-9-models.patch
- keymap: Add Samsung 700T
  add: 1010-keymap-Add-Samsung-700T.patch
- libudev: avoid leak during realloc failure
  add: 1011-libudev-avoid-leak-during-realloc-failure.patch
- libudev: do not resolve $attr{device} symlinks
  add: 1012-libudev-do-not-resolve-attr-device-symlinks.patch
- libudev: validate 'udev' argument to udev_enumerate_new()
  add: 1013-libudev-validate-udev-argument-to-udev_enumerate_new.patch
- udev: fix whitespace
  add: 1014-udev-fix-whitespace.patch
- udev: properly handle symlink removal by 'change' event
  add: 1015-udev-properly-handle-symlink-removal-by-change-event.patch
- udev: builtin - do not fail builtin initialization if one of
  them returns an error
  add: 1016-udev-builtin-do-not-fail-builtin-initialization-if-o.patch
- udev: use usec_t and now()
  add: 1017-udev-use-usec_t-and-now.patch
* Tue Jan  8 2013 rmilasan@suse.com
- udevd: add missing ':' to getopt_long 'e'.
  add: 1007-udevd-add-missing-to-getopt_long-e.patch
- clean up systemd.spec, make it easy to see which are udev and
  systemd patches.
- make 'reload' and 'force-reload' LSB compliant (bnc#793936).
* Tue Dec 11 2012 crrodriguez@opensuse.org
- detect-btrfs-ssd.patch: Fix btrfs detection on SSD.
- timedated-donot-close-bogus-dbus-connection.patch: Avoid
  closing an non-existent dbus connection and getting assertion
  failures.
* Mon Dec 10 2012 coolo@suse.com
- add conflicts between udev-mini and udev-mini-devel to libudev1
* Thu Dec  6 2012 crrodriguez@opensuse.org
- revert-of-9279749b84cc87c7830280b7895a48bed03c9429.patch:
  do not consider failure to umount / and /usr an error.
* Wed Dec  5 2012 fcrozat@suse.com
- Add fix-devname-prefix.patch: fix modules.devname path, it isn't
  in /usr.
- Move post script to fix symlinks in /etc/systemd/system to a
  trigger to run it after old systemd is uninstalled.
* Tue Dec  4 2012 fcrozat@suse.com
- Add fix-debugshell.patch: use /bin/bash if sushell isn't
  installed (bnc#789052).
- Add handle-root-uses-lang.patch: handle ROOT_USES_LANG=ctype
  (bnc#792182).
- Ensure libudev1 and libudev-mini1 conflicts.
* Thu Nov 22 2012 rmilasan@suse.com
- Fix creation of /dev/root link.
* Tue Nov 20 2012 fcrozat@suse.com
- Add remount-ro-before-unmount.patch: always remount read-only
  before unmounting in final shutdown loop.
- Add switch-root-try-pivot-root.patch: try pivot_root before
  overmounting /
* Tue Nov 20 2012 fcrozat@suse.com
- links more manpages for migrated tools (from Christopher
  Yeleighton).
- disable boot.localnet service, ypbind service will do the right
  thing now (bnc#716746)
- add xdm-display-manager.patch: pull xdm.service instead of
  display-manager.service (needed until xdm initscript is migrated
  to native systemd service).
- Add fix-permissions-btmp.patch: ensure btmp is owned only by root
  (bnc#777405).
- Have the udev package create a tape group, as referenced by
  50-udev-default.rules and 60-persistent-storage-tape.rules
  (DimStar).
- Add fix-bad-memory-access.patch: fix crash in journal rotation.
- Add fix-dbus-crash.patch: fix D-Bus caused crash.
- Add sync-on-shutdown.patch: ensure sync is done when initiating
  shutdown.
- Add mount-efivars.patch: mount efivars if booting on UEFI.
* Thu Nov 15 2012 fcrozat@suse.com
- Ship a empty systemd-journald initscript in systemd-logger to
  stop insserv to complain about missing syslog dependency.
- Update
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch
  with bug fixes from Debian.
* Wed Nov 14 2012 fcrozat@suse.com
- /var/log/journal is now only provided by systemd-logger (journal
  won't be persistent for people using another syslog
  implementation).
- install README in /var/log (in systemd-logger) and /etc/init.d
- create adm group when installing systemd.
- fix path in udev-root-symlink.systemd.
- Enforce Requires(post) dependency on libudev in main systemd
  package (help upgrade).
- Ensure configuration is reloaded when upgrading and save random
  seed when installing.
- Create /lib/udev symlink, if we do a fresh install.
- Add fix-build-glibc217.patch: fix build with latest glibc.
- Add libgcrypt.m4: copy of autoconf macro from libgcrypt, only
  used to bootstrap systemd-mini.
* Tue Nov  6 2012 coolo@suse.com
- adding a package systemd-logger that blocks syslog implementations
  from installation to make an installation that only uses the journal
* Mon Nov  5 2012 fcrozat@suse.com
- Don't hardcode path for systemctl in udev post script.
- Ensure systemd-udevd.service is shadowing boot.udev when booting
  under systemd.
- Fix udev daemon upgrade under both systemd and sysvinit.
- Add fix-logind-pty-seat.patch: fix logind complaining when doing
  su/sudo in X terminal.
* Sat Nov  3 2012 coolo@suse.com
- add libudev1 to baselibs.conf
* Fri Nov  2 2012 coolo@suse.com
- udev is GPL-2.0, the rest remains LGPL-2.1+ (bnc#787824)
* Mon Oct 29 2012 fcrozat@suse.com
- Add var-run-lock.patch: make sure /var/run and /var/lock are
  handled as bind mount if they aren't symlinks.
- Update storage-after-cryptsetup.patch with new systemctl path.
- Migrate broken symlinks in /etc/systemd/system due to new systemd
  location.
* Fri Oct 26 2012 fcrozat@suse.com
- Update to release 195:
  + journalctl agained --since and --until, as well as filtering
    for units with --unit=/-u.
  + allow ExecReload properly for Type=oneshot (needed for
    iptables.service, rpc-nfsd.service).
  + journal daemon supports time-based rotation and vaccuming.
  + journalctl -F allow to list all values of a certain field in
    journal database.
  + new commandline clients for timedated, locald and hostnamed
  + new tool systemd-coredumpctl to list and extract coredumps from
    journal.
  + improve gatewayd: follow mode, filtering, support for
    HTML5/JSON Server-Sent-Events.
  + reload support in SysV initscripts is now detected when file is
    parted.
  + "systemctl status --follow" as been removed, use "journalctl -fu
    instead"
  + journald.conf RuntimeMinSize and PersistentMinSize settings
    have been removed.
- Add compatibility symlink for systemd-ask-password and systemctl
  in /bin.
* Thu Oct 18 2012 fcrozat@suse.com
- Create and own more systemd drop-in directories.
* Tue Oct 16 2012 fcrozat@suse.com
- Improve mini packages for bootstrapping.
- do not mount /tmp as tmpfs by default.
* Tue Oct 16 2012 fcrozat@suse.com
- Fix install script when there is no inittab
* Mon Oct 15 2012 fcrozat@suse.com
- Create a systemd-mini specfile to prevent cycle in bootstrapping
* Thu Oct  4 2012 fcrozat@suse.com
- udev and its subpackages are now generated by systemd source
  package.
- migrate udev and systemd to /usr
- Update to version 194:
  + if /etc/vconsole.conf is non-existent or empty and if
    /etc/sysconfig/console:CONSOLE_FONT (resp
    /etc/sysconfig/keyboard:KEYTABLE) set, console font (resp
    keymap) is not modified.
- Changes from version 44 to 193:
  + journalctl gained --cursor= to show entries starting from a
    specified location in journal.
  + Size limit enforced to 4K for fields exported with "-o json" in
    journalctl. Use --all to disable this behavior.
  + Optional journal gateway daemon
    (systemd-journal-gatewayd.service) to access journal via HTTP
    and JSON. Use "wget http://localhost:19531/entries" to get
    /var/log/messages compatible format and
    'curl -H"Accept: application/json"
    http://localhost:19531/entries' for JSON formatted content.
    HTML5 static page is also available as explained on
    http://0pointer.de/public/journal-gatewayd
  + do not mount cpuset controler, doesn't work well by default
    ATM.
  + improved nspawn behaviour with /etc/localtime
  + journald logs its maximize size on disk
  + multi-seat X wrapper (partially merged in upstream X server).
  + HandleSleepKey has been splitted into HandleSuspendKey and
    HandleHibernateKey.
  + systemd and logind now handle system sleep states, in
    particular suspending and hibernating.
  + new cgroups are mounted by default (cpu, cpuacct,
    net_cls, net_pri)
  + sync at shutdown is now handled by kernel
  + imported journalctl output (colors, filtering, pager, bash
    completion).
  + suffix ".service" may now be ommited on most systemctl command
    involving service unit names.
  + much improved nspawn containers support.
  + new conditions added : ConditionFileNotEmpty, ConditionHost,
    ConditionPathIsReadWrite
  + tmpfiles "w" supports file globbing
  + logind handles lid switch, power and sleep keys all the time,
    unless systemd-inhibit
  - -what=handle-power-key:handle-sleep-key:handle-lid-switch is
    run by Desktop Environments.
  + support for reading structured kernel message is used by
    default (need kernel >= 3.5). /proc/kmsg is now used only by
    classic syslog daemons.
  + Forward Secure Sealing is now support for Journal files.
  + RestartPrevenExitStatus and SuccessExitStatus allow configure
    of exit status (exit code or signal).
  + handles keyfile-size and keyfile-offset in /etc/crypttab.
  + TimeoutSec settings has been splitted into TimeoutStartSec and
    TimeoutStopSec.
  + add SystemCallFilters option to add blacklist/whitelist to
    system calls, using SECCOMP mode 2 of kernel >= 3.5.
  + systemctl udevadm info now takes a /dev or /sys path as argument:
  - udevadm info /dev/sda
  + XDG_RUNTIME_DIR now uses numeric UIDs instead of usernames.
  + systemd-loginctl and systemd-journalctl have been renamed
    to loginctl and journalctl to match systemctl.
  + udev: RUN+="socket:..."  and udev_monitor_new_from_socket() is
    no longer supported. udev_monitor_new_from_netlink() needs to
    be used to subscribe to events.
  + udev: when udevd is started by systemd, processes which are left
    behind by forking them off of udev rules, are unconditionally
    cleaned up and killed now after the event handling has finished.
    Services or daemons must be started as systemd services.
    Services can be pulled-in by udev to get started, but they can
    no longer be directly forked by udev rules.
  + For almost all files, license is now LGPL2.1+ (from previous
    GPL2.0+). Exception are some minor stuff in udev (will be
    changed to LGPL2.1 eventually) and MIT license sd-daemon.[ch]
    library.
  + var-run.mount and var-lock.mount are no longer provided
    (should be converted to symlinks).
  + A new service type Type=idle to avoid ugly interleaving of
    getty output and boot status messages.
  + systemd-delta has been added, a tool to explore differences
    between user/admin configuration and vendor defaults.
  + /tmp mouted as tmpfs by default.
  + /media is now longer mounted as tmpfs
  + GTK tool has been split off to systemd-ui package.
  + much improved documentation.
- Merge BuildRequires from udev package:
  gobject-introspection-devel, gtk-doc, libsepol-devel,
  libusb-devel, pkgconfig(blkid), pkgconfig-glib-2.0),
  pjgconfig(libcryptsetup), pkgconfig(libpci),
  pkgconfig(libqrencode), pkgconfig(libselinux),
  pkgconfig(usbutils).
- Add pkgconfig(libqrencode) and pkgconfig(libmicrohttpd)
- Merge sources from udev package: boot.udev, write_dev_root.rules,
  udev-root-symlink.systemd.
- Merge patches from udev package: numbered started from 1000):
  0001-Reinstate-TIMEOUT-handling.patch,
  0013-re-enable-by_path-links-for-ata-devices.patch,
  0014-rules-create-by-id-scsi-links-for-ATA-devices.patch,
  0026-udev-netlink-null-rules.patch,
  0027-udev-fix-sg-autoload-regression.patch.
- Remove following patches, merged upstream:
  0001-util-never-follow-symlinks-in-rm_rf_children.patch,
  fixppc.patch, logind-logout.patch, fix-getty-isolate.patch,
  fix-swap-priority.patch, improve-restart-behaviour.patch,
  fix-dir-noatime-tmpfiles.patch, journal-bugfixes.patch,
  ulimit-support.patch, change-terminal.patch,
  fix-tty-startup.patch, fix-write-user-state-file.patch,
  fix-analyze-exception.patch, use_localtime.patch,
  journalctl-pager-improvement.patch,
  avoid-random-seed-cycle.patch,
  0001-add-sparse-support-to-detect-endianness-bug.patch,
  drop-timezone.patch.
- Rebase the following patches:
  0001-Add-bootsplash-handling-for-password-dialogs.patch,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch,
  0001-service-flags-sysv-service-with-detected-pid-as-Rema.patch,
  crypt-loop-file.patch,
  delay-fsck-cryptsetup-after-md-lvm-dmraid.patch,
  dm-lvm-after-local-fs-pre-target.patch, fastboot-forcefsck.patch,
  fix-enable-disable-boot-initscript.patch, modules_on_boot.patch,
  new-lsb-headers.patch, storage-after-cryptsetup.patch,
  support-suse-clock-sysconfig.patch, support-sysvinit.patch,
  sysctl-modules.patch, systemd-numlock-suse.patch, tty1.patch.
* Thu Aug 23 2012 fcrozat@suse.com
- Add use_localtime.patch: use /etc/localtime instead of
  /etc/timezone (bnc#773491)
- Add support-suse-clock-sysconfig.patch: read SUSE
  /etc/sysconfig/clock file.
- Add drop-timezone.patch: drop support for /etc/timezone, never
  supported on openSUSE.
- Add journalctl-pager-improvement.patch: better handle output when
  using pager.
- Add fix-enable-disable-boot-initscript.patch: support boot.*
  initscripts for systemctl enable /disable (bnc#746506).
* Mon Jul 30 2012 fcrozat@suse.com
- Ensure systemd macros never fails (if systemd isn't install)
* Mon Jul 23 2012 fcrozat@suse.com
- Add fix-analyze-exception.patch: prevent exception if running
  systemd-analyze before boot is complete (bnc#772506)
* Fri Jul 20 2012 sbrabec@suse.cz
- Fix NumLock detection/set race condition (bnc#746595#c47).
* Wed Jul 18 2012 fcrozat@suse.com
- Move systemd-analyse to a subpackage, to remove any python
  dependencies from systemd main package (bnc#772039).
* Tue Jul 10 2012 fcrozat@suse.com
- Add fastboot-forcefsck.patch: ensure fastboot and forcefsck on
  kernel commandline are handled.
- Add fix-write-user-state-file.patch: write logind state file
  correctly.
- Disable logind-logout.patch: cause too many issues (bnc#769531).
* Mon Jul  9 2012 fcrozat@suse.com
- Add fix-tty-startup.patch: don't limit tty VT to 12 (bnc#770182).
* Tue Jul  3 2012 sbrabec@suse.cz
- Fix SUSE specific sysconfig numlock logic for 12.2 (bnc#746595).
* Tue Jul  3 2012 fcrozat@suse.com
- Add fix-dir-noatime-tmpfiles.patch: do not modify directory
  atime, which was preventing removing empty directories
  (bnc#751253, rh#810257).
- Add improve-restart-behaviour.patch: prevent deadlock during
  try-restart (bnc#743218).
- Add journal-bugfixes.patch: don't crash when rotating journal
  (bnc#768953) and prevent memleak at rotation time too.
- Add ulimit-support.patch: add support for system wide ulimit
  (bnc#744818).
- Add change-terminal.patch: use vt102 instead of vt100 as terminal
  for non-vc tty.
- Package various .wants directories, which were no longer packaged
  due to plymouth units being removed from systemd package.
- Fix buildrequires for manpages build.
* Mon Jul  2 2012 fcrozat@suse.com
- Do not ship plymouth units, they are shipped by plymouth package
  now (bnc#769397).
- Fix module loading (bnc#769462)
* Thu Jun  7 2012 fcrozat@suse.com
- Add fix-swap-priority: fix default swap priority (bnc#731601).
* Fri May 25 2012 fcrozat@suse.com
- Re-enable logind-logout.patch, fix in xdm-np PAM file is the real
  fix.
* Thu May 24 2012 fcrozat@suse.com
- Update new-lsb-headers.patch to handle entries written after
  description tag (bnc#727771, bnc#747931).
* Thu May  3 2012 fcrozat@suse.com
- Disable logind-logout.patch: it crashes sudo session (if called
  after su -l) (bnc#746704).
* Tue Apr 24 2012 fcrozat@suse.com
- Add fix-getty-isolate.patch: don't quit getty when changing
  runlevel (bnc#746594)
* Fri Apr 20 2012 sbrabec@suse.cz
- Implemented SUSE specific sysconfig numlock logic (bnc#746595).
* Thu Apr 19 2012 fcrozat@suse.com
- Add dbus-1 as BuildRequires to fix build.
* Tue Apr  3 2012 dvaleev@suse.com
- apply ppc patch to systemd-gtk too (fixes build)
* Thu Mar 22 2012 fcrozat@suse.com
- Update fixppc.patch with upstream patches
- Add comments from upstream in
  0001-util-never-follow-symlinks-in-rm_rf_children.patch.
- Add logind-logout.patch: it should fix sudo / su with pam_systemd
  (bnc#746704).
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-add-sparse-support-to-detect-endianness-bug.patch: fix
  endianness error, preventing journal to work properly on ppc.
- Add fixppc.patch: fix build and warnings on ppc.
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-util-never-follow-symlinks-in-rm_rf_children.patch: fix
  CVE-2012-1174 (bnc#752281).
* Fri Mar 16 2012 fcrozat@suse.com
- Update to version 43:
  + Support optional initialization of the machine ID from the KVM
    or container configured UUID.
  + Support immediate reboots with "systemctl reboot -ff"
  + Show /etc/os-release data in systemd-analyze output
  + Many bugfixes for the journal, including endianess fixes and
    ensuring that disk space enforcement works
  + non-UTF8 strings are refused if used in configuration and unit
    files.
  + Register Mimo USB Screens as suitable for automatic seat
    configuration
  + Reorder configuration file lookup order. /etc now always
    overrides /run.
  + manpages for journal utilities.
- Drop fix-c++-compat.patch, no-tmpfs-fsck.patch,
  systemd-journald-fix-endianess-bug.patch.
- Requires util-linux >= 2.21 (needed to fix fsck on tmpfs).
* Mon Mar 12 2012 fcrozat@suse.com
- Add fix-c++-compat.patch: fix C++ compatibility error in header.
* Wed Feb 29 2012 fcrozat@suse.com
- Add systemd-journald-fix-endianess-bug.patch: fix journald not
  starting on ppc architecture.
- Add correct_plymouth_paths_and_conflicts.patch: ensure plymouth
  is correctly called and conflicts with bootsplash.
* Tue Feb 21 2012 fcrozat@suse.com
- Remove rsyslog listen.conf, handled directly by rsyslog now
  (bnc#747871).
* Mon Feb 20 2012 fcrozat@suse.com
- Update to version 43:
  + requires /etc/os-release, support for /etc/SuSE-release is no
    longer present.
  + Track class of PAM logins to distinguish greeters from normal
    user logins.
  + Various bug fixes.
* Sun Feb 19 2012 jengelh@medozas.de
- Use pkgconfig symbols for BuildRequires and specify version
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Enable Plymouth integration.
  * Bootsplash related files will be moved to the bootsplash
    package
* Mon Feb 13 2012 fcrozat@suse.com
- Update to version 42:
  + Various bug fixes
  + Watchdog support for supervising services is now usable
  + Service start rate limiting is now configurable and can be
    turned off per service.
  + New CanReboot(), CanPowerOff() bus calls in systemd-logind
- Dropped fix-kmod-build.patch, fix-message-after-chkconfig.patch,
  is-enabled-non-existing-service.patch (merged upstream)
- Add libxslt1 / docbook-xsl-stylesheets as BuildRequires for
  manpage generation
* Thu Feb  9 2012 fcrozat@suse.com
- Update to version 41:
  + systemd binary is now installed in /lib/systemd (symlink for
  /bin/systemd is available now)
  + kernel modules are now loaded through libkmod
  + Watchdog support is now useful (not complete)
  + new kernel command line available to set system wide
    environment variable: systemd.setenv
  + journald capabilities set is now limited
  + SIGPIPE is ignored by default. This can be disabled with
    IgnoreSIGPIPE=no in unit files.
- Add fix-kmod-build.patch: fix build with libkmod
- Drop remote-fs-after-network.patch (merged upstream)
- Add dm-lvm-after-local-fs-pre-target.patch: ensure md / lvm
  /dmraid is started before mounting partitions, if fsck was
  disabled for them (bnc#733283).
- Update lsb-header patch to correctly disable heuristic if
  X-Systemd-RemainAfterExit is specified (whatever its value)
- Add fix-message-after-chkconfig.patch: don't complain if only
  sysv services are called in systemctl.
- Add is-enabled-non-existing-service.patch: fix error message when
  running is-enabled on non-existing service.
* Tue Feb  7 2012 fcrozat@suse.com
- Update to version 40:
  + reason why a service failed is now exposed in the"Result" D-Bus
    property.
  + Rudimentary service watchdog support (not complete)
  + Improve bootcharts, by immediatly changing argv[0] after
    forking to to reflect which process will be executed.
  + Various bug fixes.
- Add remote-fs-after-network.patch and update insserv patch:
  ensure remote-fs-pre.target is enabled and started before network
  mount points (bnc#744293).
- Ensure journald doesn't prevent syslogs to read from /proc/kmsg.
* Tue Jan 31 2012 fcrozat@suse.com
- Ensure systemd show service status when started behind bootsplash
  (bnc#736225).
- Disable core dump redirection to journal, not stable atm.
* Thu Jan 26 2012 fcrozat@suse.com
- Update modules_on_boot.patch to not cause failed state for
  systemd-modules-load.service (bnc#741481).
* Wed Jan 25 2012 fcrozat@suse.com
- Update to version 39:
  + New systemd-cgtop tool to show control groups by their resource
    usage.
  + Linking against libacl for ACLs is optional again.
  + If a group "adm" exists, journal files are automatically owned
    by them, thus allow members of this group full access to the
    system journal as well as all user journals.
  + The journal now stores the SELinux context of the logging
    client for all entries.
  + Add C++ inclusion guards to all public headers.
  + New output mode "cat" in the journal to print only text
    messages, without any meta data like date or time.
  + Include tiny X server wrapper as a temporary stop-gap to teach
    XOrg udev display enumeration (until XOrg supports udev
    hotplugging for display devices).
  + Add new systemd-cat tool for executing arbitrary programs with
    STDERR/STDOUT connected to the journal. Can also act as BSD
    logger replacement, and does so by default.
  + Optionally store all locally generated coredumps in the journal
    along with meta data.
  + systemd-tmpfiles learnt four new commands: n, L, c, b, for
    writing short strings to files (for usage for /sys), and for
    creating symlinks, character and block device nodes.
  + New unit file option ControlGroupPersistent= to make cgroups
    persistent.
  + Support multiple local RTCs in a sane way.
  + No longer monopolize IO when replaying readahead data on
    rotating disks.
  + Don't show kernel threads in systemd-cgls anymore, unless
    requested with new -k switch.
- Drop systemd-syslog_away_early_on_shutdown.patch: fixed upstream.
- Add fdupes to BuildRequires and use it at build time.
* Thu Jan 19 2012 tittiatcoke@gmail.com
- Make the systemd journal persistent by creating the
  /var/log/journal directory
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 38 :
  - Bugfixes
  - Implementation of a Journal Utility Library
  - Implementation of a 128 Bit ID Utility Library
- 11 Patches integrated upstream
- Add systemd-syslog_away_early_on_shutdown.patch: make sure
  syslog socket goes away early during shutdown.
- Add listen.conf for rsyslog. This will ensure that it will still
  work fine with rsyslog and the new journal.
* Mon Jan  9 2012 fcrozat@suse.com
- Add fix-is-enabled.patch: ensure systemctl is-enabled work
  properly when systemd isn't running.
- Add logind-console.patch: do not bail logind if /dev/tty0 doesn't
  exist (bnc#733022, bnc#735047).
- Add sysctl-modules.patch: ensure sysctl is started after modules
  are loaded (bnc#725412).
- Fix warning in insserv patch.
- Update avoid-random-seed-cycle.patch with better upstream
  approach.
- Update storage-after-cryptsetup.patch to restart lvm before
  local-fs.target, not after it (bnc#740106).
- Increase pam-config dependency (bnc#713319).
* Wed Dec  7 2011 fcrozat@suse.com
- Remove storage-after-cryptsetup.service, add
  storage-after-cryptsetup.patch instead to prevent dependency
  cycle (bnc#722539).
- Add delay-fsck-cryptsetup-after-md-lvm-dmraid.patch: ensure
  fsck/cryptsetup is run after lvm/md/dmraid have landed
  (bnc#724912).
- Add cron-tty-pam.patch: Fix cron filling logs (bnc#731358).
- Add do_not_warn_pidfile.patch: Fix PID warning in logs
  (bnc#732912).
- Add mount-swap-log.patch: Ensure swap and mount output is
  redirected to default log target (rhb#750032).
- Add color-on-boot.patch: ensure colored status are displayed at
  boot time.
- Update modules_on_boot.patch to fix bnc#732041.
- Replace private_tmp_crash.patch with log_on_close.patch, better
  upstream fix for bnc#699829 and fix bnc#731719.
- Update vconsole patch to fix memleaks and crash (bnc#734527).
- Add handle-racy-daemon.patch: fix warnings with sendmail
  (bnc#732912).
- Add new-lsb-headers.patch: support PIDFile: and
  X-Systemd-RemainAfterExit: header in initscript (bnc#727771).
- Update bootsplash services to not start if vga= is missing from
  cmdline (bnc#727771)
- Add lock-opensuse.patch: disable /var/lock/{subsys,lockdev} and
  change default permissions on /var/lock (bnc#733523).
- Add garbage_collect_units: ensure error units are correctly
  garbage collected (rhb#680122).
- Add crypt-loop-file.patch: add support for crypt file loop
  (bnc#730496).
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 fcrozat@suse.com
- Fix rpm macros to only call presets on initial install
  (bnc#728104).
* Thu Oct 27 2011 fcrozat@suse.com
- Add no-tmpfs-fsck.patch: don't try to fsck tmpfs mountpoint
  (bnc#726791).
* Wed Oct 19 2011 fcrozat@suse.com
- Add avoid-random-seed-cycle.patch: fix dependency cycle between
  cryptsetup and random-seed-load (bnc#721666).
- Add crash-isolating.patch: fix crash when isolating a service.
- Fix bootsplash being killed too early.
- Fix some manpages not being redirected properly.
- Add storage-after-cryptsetup.service to restart lvm after
  cryptsetup. Fixes lvm on top of LUKS (bnc#724238).
* Fri Oct 14 2011 fcrozat@suse.com
- Recommends dbus-1-python, do not requires python (bnc#716939)
- Add private_tmp_crash.patch: prevent crash in debug mode
  (bnc#699829).
- Add systemctl-completion-fix.patch: fix incorrect bash completion
  with some commands (git).
* Wed Oct 12 2011 fcrozat@suse.com
- Shadow single sysv service, it was breaking runlevel 1.
- Add modules_on_boot.patch to handle /etc/sysconfig/kernel
  MODULES_ON_BOOT variable (bnc#721662).
* Wed Oct 12 2011 fcrozat@suse.com
- Update to release 37:
  - many bugfixes
  - ConditionCapability added, useful for containers.
  - locale mechanism got extend to kbd configuration for
    both X and the console
  - don't try to guess PID for SysV services anymore (bnc#723194)
- Drop detect-non-running.patch, logind-warning.patch.
- Rewrite systemd-sysv-convert in bash (bnc#716939)
* Tue Oct 11 2011 coolo@suse.com
- make sure updaters get in the /sbin/init from here - the sub package
  of the split package will decide which init wins in update case
* Tue Oct 11 2011 coolo@suse.com
- under openSUSE if it's not systemd, chances are good it's
  sysvinit
* Tue Oct 11 2011 coolo@suse.com
- do not list specific sbin_init providers
* Wed Oct  5 2011 fcrozat@suse.com
- Add logind-warning.patch: fix pam warning (bnc#716384)
* Fri Sep 30 2011 fcrozat@suse.com
- Update to version 36 :
  - many bugfixes
  - systemd now requires socket-activated syslog implementations
  - After=syslog.target is no longer needed in .service files
  - X-Interactive is ignored in LSB headers (was not working)
- Enable back insserv.conf parsing in systemd core and fix added
  dependencies (bnc#721428).
- Fix detection of LSB services status when running daemon
  (bnc#721426).
- Drop 0001-execute-fix-bus-serialization-for-commands.patch,
  fix-reload.patch
* Thu Sep 29 2011 fcrozat@suse.com
- Add services to stop bootsplash at end of startup and start it at
  beginning of shutdown.
- Fix bootsplash call and ensure dependencies are set right.
* Thu Sep 29 2011 fcrozat@suse.com
- Add detect-non-running.patch: fix assertion when running
  systemctl under non systemd system (git).
- Requires presets branding package.
- Improve macros a little bit.
* Mon Sep 26 2011 fcrozat@suse.com
- Merge migration rpm macros into service_add/service_del macros.
- Use systemd presets in rpm macros
- Add fix-reload.patch: handle daemon-reload and start condition
  properly (bnc#719221).
* Fri Sep 23 2011 fcrozat@suse.com
- Add systemd-splash / bootsplash-startup.service: enable
  bootsplash at startup.
* Fri Sep 16 2011 fcrozat@suse.com
- Create -32bit package (bnc#713319)
* Mon Sep 12 2011 fcrozat@suse.com
- Do not mask localnet service, it is not yet handled by systemd.
  (bnc#716746)
* Fri Sep  9 2011 fcrozat@suse.com
- Add revert_insserv_conf_parsing.patch and systemd-insserv_conf:
  remove insserv.conf parsing from systemd and use generator
  instead.
- put back default.target creation at package install and remove
  inittab generator, Yast2 is now able to create it.
* Thu Sep  1 2011 fcrozat@novell.com
- Update to version 34:
  * Bugfixes
  * optionaly apply cgroup attributes to cgroups systemd creates
  * honour sticky bit when trimming cgroup trees
  * improve readahead
- Add libacl-devel as BuildRequires (needed for systemd-uaccess)
- Add some %%{nil} to systemd.macros to fix some build issues.
- Fix dbus assertion
- move gtk part to its own package, to reduce bootstrapping
  (bnc#713981).
* Fri Aug 26 2011 fcrozat@suse.com
- Update compose_table patch to use two separate loadkeys call,
  compose table overflows otherwise (spotted by Werner Fink).
* Wed Aug 24 2011 fcrozat@novell.com
- Add tty1.patch: ensure passphrase are handled before starting
  gettty on tty1.
- Add inittab generator, creating default.target at startup based
  on /etc/inittab value.
- No longer try to create /etc/systemd/system/default.target at
  initial package install (bnc#707418)
- Fix configuration path used for systemd user manager.
- Ensure pam-config output is no display in install script.
- Remove buildrequires on vala, no longer needed.
* Fri Aug 19 2011 fcrozat@suse.com
- Handle disable_capslock, compose table and kbd_rate
- Add rpm macros.systemd file.
- Do not disable klogd, it has its own service now.
- Handle kexec correctly (bnc#671673).
- Disable preload services, they are conflicting with systemd.
* Fri Aug 19 2011 fcrozat@suse.com
- enable pam_systemd module, using pam-config.
* Thu Aug 18 2011 aj@suse.de
- Fix crash with systemctl enable.
* Tue Aug 16 2011 fcrozat@suse.com
- Fix localfs.service to no cause cycle and starts it after
  local-fs.target.
* Thu Aug  4 2011 fcrozat@suse.com
- Remove root-fsck.patch, mkinitrd will use the same path as
  dracut.
- Add systemd-cryptsetup.patch: don't complain on "none" option in
  crypttab.
- Add systemd-cryptsetup-query.patch: block boot until passphrase
  is typed.
* Wed Aug  3 2011 fcrozat@suse.com
- Add root-fsck.patch: do not run fsck on / if it is rw
- Ship a non null localfs.service, fixes static mount points not
  being mounted properly.
* Wed Aug  3 2011 aj@suse.de
- Update to version 33:
  * optimizations and bugfixes.
  * New PrivateNetwork= service setting which allows you to shut off
    networking for a specific service (i.e. all routable network
    interfaces will disappear for that service).
  * Merged insserv-parsing.patch and bash-completion-restart.patch
    patches.
* Tue Aug  2 2011 fcrozat@suse.com
- Add insserv-parsing.patch: read/parse insserv.conf.
- Add bash-completion-restart.patch: fix restart service list
  (bnc#704782).
* Mon Aug  1 2011 aj@suse.de
- Split up devel package.
- restart logind after upgrade.
- Adjust rpmlintrc for changes.
* Fri Jul 29 2011 aj@suse.de
- Update to version 32:
  * bugfixes
  * improve selinux setup
* Thu Jul 28 2011 aj@suse.de
- Update to version 31:
  * rewrite of enable/disable code: New features systemctl --runtime,
    systemctl mask, systemctl link and presets.
  * sd-daemon is now shared library.
* Tue Jul 19 2011 aj@suse.de
- Update to version 30:
  + Logic from pam_systemd has been moved to new systemd-login.
  + VT gettys are autospawn only when needed
  + Handle boot.local/halt.local on SUSE distribution
  + add support for systemctl --root
* Wed Jun 29 2011 fcrozat@suse.com
- Make sure to not start kbd initscript, it is handled by systemd
  natively.
* Fri Jun 17 2011 fcrozat@novell.com
- version 29:
  + enable chkconfig support in systemctl for openSUSE.
  + systemctl: plug a leak upon create_symlink mismatch
  + mount /run without MS_NOEXEC
  + dbus: fix name of capability property
  + systemctl: fix double unref of a dbus message
  + cryptsetup-generator: fix /etc/cryptsetup options
  + selinux: selinuxfs can be mounted on /sys/fs/selinux
  + readahead-common: fix total memory size detection
  + systemctl: fix 'is-enabled' for native units under /lib
  + systemctl: fix a FILE* leak
  + pam-module: add debug= parameter
  + remote-fs.target: do not order after network.target
- update tarball url.
* Wed Jun 15 2011 saschpe@suse.de
- Use RPM macros instead of $RPM_FOO variables
- Don't require %%{version}-%%{release} of the base package,
  %%{version} is sufficient
* Tue Jun 14 2011 kay.sievers@novell.com
- new snapshot
  - mount /run without MS_NOEXEC
  - readahead-common: fix total memory size detection
  - enable chkconfig support in systemctl for openSUSE
  - selinux: selinuxfs can be mounted on /sys/fs/selinux
  - cryptsetup-generator: fix /etc/cryptsetup options
  - systemctl: fix double unref of a dbus message
- drop merged chkconfig patch
* Tue Jun 14 2011 fcrozat@novell.com
- Add sysv chkconfig patch to be able to enable / disable sysv
  initscripts with systemctl.
- Ensure plymouth support is buildable conditionnally.
* Thu May 26 2011 kay.sievers@novell.com
- version 28
  - drop hwclock-save.service
  - fix segfault when a DBus message has no interface
  - man: update the list of unit search locations
  - readahead-collect: ignore EACCES for fanotify
  - rtc in localtime: use settimeofday(NULL, tz)
    instead of hwclock(8)
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - fix crash in D-Bus code
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - socket: always use SO_{RCV,SND}BUFFORCE to allow larger values
  - util: use new VT ESC sequence to clear scrollback buffer
  - sd-daemon: move _sd_hidden_ from .h to .c file
  - missing: add IP_TRANSPARENT
* Sat May 21 2011 kay.sievers@novell.com
- version 27
  - util: use open_terminal() in chvt() too
  - socket: expose SO_BROADCAST
  - git: add .mailmap
  - exec: expose tty reset options in dbus introspection data
  - socket: expose IP_TRANSPARENT
  - exec: hangup/reset/deallocate VTs in gettys
  - socket: use 666 socket mode by default since neither fifos,
    nor sockets, nor mqueues need to be executable
  - socket: add POSIX mqueue support
  - README: document relation to nss-myhostname
  - hostnamed: check that nss-myhostname is installed
* Tue May 17 2011 kay.sievers@novell.com
- new snapshot
  - sysctl: apply /etc/sysctl.conf last
  - systemd-analyze: print hostname, kernelversion and arch at
    the top of the plot
  - pam: downgrade a few log msgs
  - hostnamed: SetPrettyHostname() should check PK action
    org.freedesktop.hostname1.set-static-hostname
  - user-sessions: ignore EROFS when unlinking /etc/nologin if
    the file doesn't exist anyway
  - unit: make ignoring in snapshots a per unit property,
    instead of a per unit type property
  - vconsole: use open_terminal() instead of open()
  - units: enable automount units only if the kernel supports them
* Thu May  5 2011 coolo@opensuse.org
- remove policy filter
* Thu May  5 2011 meissner@suse.de
- add missing buildrequires dbus-1-devel, vala, libxslt-devel
- touch vala files for rebuilding to unbreak Factory
* Mon May  2 2011 kay.sievers@novell.com
- also delete plymouth files
* Mon May  2 2011 kay.sievers@novell.com
- disable plymouth sub-package until plymouth gets into Factory
* Sun May  1 2011 kay.sievers@novell.com
- new snapshot
  - binfmt, modules-load, sysctl, tmpfiles: add missing
    ConditionDirectoryNotEmpty=
  - binfmt, modules-load, sysctl, tmpfiles: read /usr/local/lib
    and where appropriate /lib directories
* Sat Apr 30 2011 kay.sievers@novell.com
- version 26
  - plymouth: introduce plymouth.enable=0 kernel command line
  - util: don't AND cx with cx
  - man: typo in sd_daemon reference
  - util: conf_files_list() return list as parameter
  - dbus: make daemon reexecution synchronous
* Thu Apr 28 2011 kay.sievers@novell.com
- new snapshot
  - service: properly notice when services with a main process
    that isn't a child of init die
  - unit: fix assert when trying to load unit instances for
    uninstanciable types
  - def: lower default timeout to 90s
  - manager: fix serialization counter
* Wed Apr 27 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't hit assert when dumping properties
  - cryptsetup: fix keyfile size option processing
  - socket: improve warning message when we get POLLHUP
  - mount: failure to mount cgroup hierarchies should not be fatal
  - configure: add AC_SYS_LARGEFILE
* Mon Apr 25 2011 kay.sievers@novell.com
- new snapshot
  - tmpfiles.d: switch to stacked config dirs in /lib, /etc, /run
  - sysctl.d, binfmt.d, modules-load.d: switch to stacked config
    dirs in /lib, /etc, /run
  - manager: mkdir /run/systemd/system when starting up
  - man: Spelling fixes
* Thu Apr 21 2011 kay.sievers@novell.com
- version 25
  - mount: Allow creating mount units for /var/lib/nfs/rpc_pipefs
    and /proc/fs/nfsd.
  - socket: support ListeSpecial= sockets
  - vconsole: don't set console font/keymap if settings are empty
  - nspawn: don't fail when we receive SIGCHLD
  - cgroup: don't accidentaly trim on reload
  - units: set capability bounding set for syslog services
  - socket: log more information about invalid poll events
  - man: fix specification of default timeouts
  - mount,crypto: rework meaning of noauto/nofail
  - fsck: don't fsck against basic.target in order to properly
    allow automount /home
  - manager: when running in test mode, do not write generated
    unit files to /run/systemd/generator
  - mount: properly parse timeouts options in the middle of
    the string
  - hostnamed: drop all caps but CAP_SYS_ADMIN
  - execute: when we run as PID 1 the kernel doesn't give us
    CAP_SETPCAP by default. Get that temporarily when dropping
    capabilities for good
  - mount: make device timeout configurable
  - cryptsetup: do not order crypto DM devices against the
    cryptsetup service
  - socket: reuse existing FIFOs
  - socket: guarantee order in which sockets are passed to be
    the one of the configuration file
  - systemctl: always consider unit files with no
    [Install] section but stored in /lib enabled
  - job: also print status messages when we successfully started
    a unit
  - hostnamed: add reference to SMBIOS specs
  - man: runlevel 5 is usually more comprehensive, so use it
    instead of 3 to detect whether a sysv service is enabled
  - polkit: follow the usual syntax for polkit actions
  - hostnamed: introduce systemd-hostnamed
  - units: order quotacheck after remount-rootfs
  - hostname: split out hostname validation into util.c
  - dbus: split out object management code into dbus-common,
    and simplify it
  - strv: properly override settings in env_append()
  - strv: detect non-assignments in env blocks properly in
    env_append()
  - strv: handle empty lists in strv_copy() properly
  - util: truncate newline inside of read_one_line_file()
  - util: modernize get_parent_of_pid() a bit
  - crypto: let the cryptsetup binary handles its own
    configurable timeouts
  - logger,initctl: use global exit timeout
  - ask-password: use default timeout
  - manager: drop all pending jobs when isolating
  - manager: introduce IgnoreOnIsolate flag so that we can keep
    systemd-logger around when isolating
  - units: never pull in sysinit from utmp, so that we can
    shutdown from emergency mode without pulling in sysinit
  - manager: downgrade a few log messages
  - units: require syslog.socket from the logger because we
    simply fail if we don't have it
  - logger: adjust socket description to match service
  - units: set stdout of kmsg syslogd to /dev/null
  - units: add --no-block when starting normal service after
    shell exited
  - ask-password: use kill(PID, 0) before querying a password
  - ask-password: support passwords without timeouts
  - ask-password: always send final NUL char
  - ask-password: properly accept empty passwords from agent
  - unit: skip default cgroup setup if we have no hierarchy
  - units: isolate emergency.target instead of emergency.service
    when we fail to mount all file systems
  - mount: don't pull in stdio logger for root mount unit
  - cgroup: be nice to Ingo Molnar
  - pam: use /proc/self/sessionid only with CAP_AUDIT_CONTROL
  - pam: use /proc/self/loginuid only with CAP_AUDIT_CONTROL
  - socket: try creating a socket under our own identity if we
    have no perms to consult the selinux database
  - socket: fix check for SEQPACKET
  - execute: don't fail if we cannot fix OOM in a container
  - unit: fix dump output
  - socket: be a bit more verbose when refusing to start a
    socket unit
  - socket: support netlink sockets
  - local-fs: invoke emergency.service mounting at boot fails
  - path: optionally, create watched directories in .path units
  - tmpfiles: don't warn if two identical lines are configured
  - man: add man page for ask-password
  - dbus: expose monotonic timestamps on the bus
  - manager: no need to use randomized generator dir when running
    as system manager
  - don't make up buffer sizes, use standard LINE_MAX instead
  - unit: disallow configuration of more than one on_failure
    dependencies if OnFailureIsolate= is on
  - unit: pull in logger unit only when running in system mode
  - manager: serialize/deserialize max job id and /usr taint flag
  - manager: don't garbage collect jobs when isolating, to change
    global state
  - unit: introduce OnFailureIsolate=
  - mount: relabel both before and after a mount, just in case
  - cmdline: we actually want to parse the kernel cmdline in VMs,
    just not in containers
  - units: rename rtc-set.target to time-sync.target and pull it
    in by hwclock-load.service
  - job: fix deserialization of jobs: do not ignore ordering
  - systemctl: properly parse JobNew signals
  - service: fix units with more than one socket
  - systemctl: make most operations NOPs in a chroot
  - manager: don't show PID for incoming signals if it is 0
  - man: fix description of systemctl reload-or-try-restart
  - mount: block creation of mount units for API file systems
  - units: call the logger a bridge too
  - build-sys: always place user units in /usr/lib/systemd
  - pkgconfig: update .pc file accordingly
  - lookup: always also look into /usr/lib for units
  - exec: support unlimited resources
  - selinux: relabel /run the same way as /dev after loading
    the policy since they both come pre-filled and unlabelled
  - manager: fd must be int, not char
  - change remaining /var/run to /run
  - units: move user units from /usr/share to /usr/lib since
    they might be arch-dependent
  - man: document /etc/sysctl.d/
  - binfmt: add binfmt tool to set up binfmt_misc at boot
  - tmpfiles: create leading directories for d/D instructions
  - condition: add ConditionSecurity
  - load-fragment: unify config_parse_condition_{kernel, virt}
  - condition: fix dumping of conditions
  - initctl: /dev/initctl is a named pipe, not a socket
  - kmsg-syslogd: pass facility value into kmsg
  - move /var/lock to HAVE_SYSV_COMPAT
  - tmpfiles: split off rules for legacy systems into legacy.conf
  - general: replace a few uses of /var/run by /run
  - tmpfiles: enforce new /var/lock semantics
  - man: document ConditionPathIsDirectory=
  - mount: also relabel pre-mounted API dirs
  - log: don't strip facility when writing to kmsg
  - build-sys: create a number of drop-in config dirs
  - random: do not print warning if random seed doesn't exist
  - plymouth: use PID file to detect whether ply is running
  - build-sys: install systemd-analyze by default
  - analyze: improve output
  - analyze: add plotter
  - unit: when deserializing do reconnect to dbus/syslog when
    they show up
  - analyze: beautify output a bit
  - add systemd-analyze tool
  - unit: don't override timestamps due to state changes when
    deserializing
  - plymouth: don't explicitly enable status message when
    plymouth is up
  - status: show status messages unconditionally if plymouth
    is around
  - taint: add missing cgroups taint flag
  - locale: don't access misinitialized variable
  - quota: do not pull in quota tools for mounts that do not
    originate in neither /etc/fstab nor fragment files
  - manager: fix taint check for /usr
  - unit: never apply /etc/rcN.d/ priority to native services
  - unit: fix parsing of condition-result
  - unit: don't complain about failed units when deserializing
  - exec: drop process group kill mode since it has little use
    and confuses the user
  - cgroup: explain when we cannot initialize the cgroup stuff
  - systemctl: don't truncate description when using pager
  - ask-password: also accept Backspace as first keypress as
    silent mode switch
  - unit: when deserializing jobs, don't pull in dependencies
  - locale: fix LC_MESSAGES variable name
  - plymouth: Remove the calls to plymouth message
  - udev: systemd-tag all ttys
  - tmpfiles fix /run/lock permissions
  - ask-password: use TAB to disable asterisk password echo
  - execute: socket isn't abstract anymore
  - use /run instead of /dev/.run
  - man: explain a couple of default dependencies
  - mount: pull in quota services from local mountpoints with
    usr/grpquota options
  - service: pull in sysv facility targets from the sysv units,
    not the other way round
  - units: pull in syslog.target from syslog.socket
  - units: don't ever pull in SysV targets from other SysV
    targets
  - units: document that some targets exists only for compat
    with SysV
  - man: document pidns containers
  - units: deemphesize Names= settings, and explain why nobody
    whould use them
  - units: on mandriva/fedora create single.service alias via
    symlink, not Names=
  - units: get rid of runlevel Names=, the symlinks in
    /lib/systemd/system are much more useful
  - rework syslog detection so that we need no compile-time
    option what the name of the syslog implementation is
  - man: document .requires/ directories
  - special: get rid of dbus.target
  - exec: properly apply capability bounding set, add inverted
    bounding sets
  - dbus: add service D-Bus property "Sockets"
  - dbus: consolidate service SysV conditionals
  - unit: serialize condition test results
  - def: centralize definition of default timeout in one place
  - chkconfig: check against runlevel 5 instead of 3, since it is
    a superset of the latter
  - systemctl: accept condstop as alias for stop
  - dbus: allow LoadUnit to unprivileged users
  - umount: make sure skip_ro is always correctly initialized
- create /run (link it to /var/run)
- refresh splash password patch
- conflict with old mkinitrd version (we need /run)
- conflict with old udev (we need /run)
* Wed Mar 16 2011 kay.sievers@novell.com
- new snapshot
  - man: fix systemctl try-restart description
  - Add Frugalware display-manager service
  - main: revert recognition of "b" argument
  - main: interpret all argv[] arguments unconditionally when
    run in a container
  - loopback: downgrade an error to warning
  - nspawn: bind mount /etc/localtime
  - nspawn: make tty code more robust against closed/reopened
    /dev/console
  - util: make touched files non-writable by default
  - nspawn: allocate a new pty instead of passing ours through
    to avoid terminal settings chaos
  - main: parse the whole arv[] as kernel command line
  - main: check if we have a valid PID before getting the name
  - ask-password: reset signal mask after we are done
  - cgroup: don't recheck all the time whether the systemd
    hierarchy is mounted, to make strace outputs nicer and save
    a few stat()s
  - man: document systemd-nspawn
  - cgls: don't strip user processes and kernel threads from
    default output
  - umount: don't try to remount bind mounts ro during shutdown
  - getty: move automatic serial getty logic into generator
  - container: skip a few things when we are run in a container
    such as accessing /proc/cmdline
  - cgls: by default start with group of PID 1
  - pam: determine user cgroup tree from cgroup of PID 1
  - nspawn: move container into its own name=systemd cgroup
  - manager: don't show kernel boot-up time for containers
  - manager: show who killed us
  - units: add console-shell.service which can be used insted of
    the gettys to get a shell on /dev/console
* Mon Mar 14 2011 kay.sievers@novell.com
- new snapshot
  - build-sys: move remaining tools from sbin/ to bin/ since they
    might eventually be useful for user execution
  - hostname: don't override the hostname with localhost if it
    is already set and /etc/hostname unset
  - audit: give up sending auditing messages when it failed due
    to EPERM
  - nspawn: don't require selinux on if it is compiled in
  - main: remove AF_UNIX sockets before binding
  - shutdown: print a nice message when terminating a container
  - nspawn: mount /selinux if needed
  - shutdown: just call exit() if we are in a container
  - umount: assume that a non-existing /dev/loop device means it
    is already detached
  - socket: use 777 as default mode for sockets
  - main: log to the console in a container
  - main: don't parse /proc/cmdline in containers
  - util: add detect_container()
  - nspawn: reset environment and load login shell
  - core: move abstract namespace sockets to /dev/.run
  - nspawn: add simple chroot(1) like tool to execute commands
    in a namespace container
  - util: return exit status in wait_for_terminate_and_warn()
  - util: properly identify pty devices by their major
* Sat Mar 12 2011 kay.sievers@novell.com
- new snapshot
  - polkit: autogenerate polkit policy with correct paths
  - systemctl: support remote and privileged systemctl access
    via SSH and pkexec
  - gnome-ask-password-agent: fix path to watch
* Fri Mar 11 2011 kay.sievers@novell.com
- fix broken sysctl.service linking
* Fri Mar 11 2011 kay.sievers@novell.com
- new snapshot
  - units: move the last flag files to /dev/.run
  - util: close all fds before freezing execution
  - dbus: timeout connection setup
  - main: properly handle -b boot option
  - pam: do not leak file descriptor if flock fails
- disable sysv services natively provided by systemd
* Thu Mar 10 2011 kay.sievers@novell.com
- new snapshot
  - main: refuse system to be started in a chroot
  - main: don't check if /usr really is a mount point, since it is
    fine if it is passed pre-mounted to us from the initrd
  - condition: take a timestamp and store last result of conditions
  - dev: use /dev/.run/systemd as runtime directory, instead of
    /dev/.systemd
  - machine-id: move machine-id-setup to /sbin
  - pkconfig: export full search path as .pc variable
  - selinux: bump up error level when in non-enforcing mode
  - dbus: fix dbus assert due to uninitialized error
  - dbus: properly generate UnknownInterface, UnknownProperty
    and PropertyReadOnly errors
  - mount: use /dev/.run as an early boot alias for /var/run
* Tue Mar  8 2011 kay.sievers@novell.com
- version 20
  - service: prefix description with LSB only if script has LSB header,
    use 'SysV:' otherwise
  - unit: don't accidently create ordering links to targets when
    default deps are off for either target and unit
  - mount: support less cumbersome x-systemd-xxx mount options
  - unit: distuingish mandatory from triggering conditions
  - dbus: return DBUS_ERROR_UNKNOWN_OBJECT when an object
    is unknown
  - systemctl: when forwarding is-enabled to chkconfig
    hardcode runlevel 3
  - job: introduce new job result code 'skipped' to use when pre
    conditions of job did not apply
  - job: convert job type as early as we can, to simplify things
  - Keep emacs configuration in one configuration file.
  - syslog: make sure the kmsg bridge is always pulled in and
    never terminated automatically
  - mount: make /media a tmpfs
* Mon Mar  7 2011 kay.sievers@novell.com
- new snapshot
  - add org.freedesktop.DBus.Properies.Set method
  - main: introduce /etc/machine-id
  - systemctl: fix exit code when directing is-enabled
    to chkconfig
  - dbus: add 'Tainted' property to Manager object
  - dbus: expose distribution name and features on manager
    object as properties
  - man: document changed EnvironmentFile= behaviour
  - main: add link to wiki page with longer explanation of the
    /usr madness
  - execute: load environment files at time of execution, not
    when we load the service configuration
  - path: after installing inotify watches, recheck file again
    to fix race
  - path: don't use IN_ATTRIB on parent dirs when watching a
    file, since those cannot be removed without emptying the dir
    first anyway and we need IN_ATTRIB only to detect the link
    count dropping to 0
  - kill: always send SIGCONT after SIGTERM
  - readahead: disable collector automatically on read-only media
  - sysctl: use scandir() instead of nftw() to guarantee
    systematic ordering
  - support DT_UNKNOWN where necessary for compat with reiserfs
  - systemctl: always null-terminate the password
- call systemd-machine-id-setup at installation
* Tue Mar  1 2011 kay.sievers@novell.com
- version 19
  - udev: don't ignore non-encrypted block devices with no
    superblock
  - udev: expose ttyUSB devices too
  - udev: mark hvc devices for exposure in systemd
  - cryptsetup: add a terse help
  - agent: don't print warnings if a password was removed or
    timed out
  - systemctl: shutdown agent explicitly so that it can reset
    the tty properly
  - never clean up a service that still has a process in it
  - label: udev might be making changes in /dev while we
    iterate through it
  - systemctl: properly handle job results
  - job: also trigger on-failure dependencies when jobs faile
    due to dependencies, timeout
  - job: when cancelling jobs, make sure to propagate this
    properly to depending jobs
  - job: start job timeout on enqueuing not when we start to
    process a job
  - unit: increase default timeout to 3min
  - logger: leave the logger longer around and allow it do
    handle more connections
  - dbus: pass along information why a job failed when it
    failed (dbus api change!)
  - general: unify error code we generate on timeout
  - units: synchronize gettys to plymouth even if plymouth is
    killed by gdm
  - job: start job timer when we begin running the job, not
    already when we add it to the queue of jobs
  - cryptsetup: try to show the mount point for a crypto disk
    if we can
  - rescue: terminate plymouth entirely when going into
    rescue mode
  - ask-password: fix handling of timeouts when waiting
    for password
  - ask-password: supported plymouth cached passwords
  - main: print warning if /usr is on a seperate partition
  - ensure we start not a single getty before plymouth is
    gone because we never know which ttys plymouth still controls
  - unit: introduce ConditionVirtualization=
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't rely that timer/path units have an initialized
    unit field (bnc#671561)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - order network mounts after network.target (bnc#672855)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - kmsg-syslogd: increase terminate timeout to 5min to generte
    less debug spew
  - shutdown(8) - call kexec if kexec kernel is loaded (bnc#671673)
  - unit: don't timeout fsck
  - man: fixed typo in SyslogIdentifier=
  - tmpfiles: never clean up block devices
  - main: refuse --test as root
* Fri Feb 18 2011 kay.sievers@novell.com
- new snapshot
  - units: order fsck@.service before basic.target
    instead of local-fs.target to relax things a little
  - readahead: remove misleading error messages
  - man: don't do more reloads than necessary in spec files
  - util: retry opening a TTY on EIO
  - util: beef up logic to find ctty name
  - tmpfiles: kill double slashes in unix socket names
- drop vhangup patch, it is fixed in login(3) by forwarding the
  SIGHUP to the child process
* Fri Feb 18 2011 coolo@novell.com
- revert back to conflicts: sysvinit
* Thu Feb 17 2011 werner@suse.de
- Add temporary workaround for bnc#652633, that is do a vhangup
  to all processes on a tty line used for a getty
* Wed Feb 16 2011 kay.sievers@novell.com
- version 18
  - systemctl: introduce --ignore-dependencies
  - systemctl: introduce --failed to show only failed services
  - systemctl: introduce --failed to show only failed services
  - rescue: make 'systemctl default' fail if there is already
    something running when the shell exited
  - util: seperate welcome line from other output by empty lines
  - manager: don't consider transaction jobs conflicting with
    queued jobs redundant
  - udev: ignore block devices which no known contents, to avoid
    trying of mounts/swapons when devices aren't set up full yet
  - swap: handle "nofail" from fstab
  - mount,swap: properly add dependencies to logger if needed
  - service: change default std output to inherit
  - exec: introduce global defaults for the standard output
    of services
  - udev: use SYSTEMD_READY to mask uninitialized DM devices
  - fsck: output to /dev/console by default in addition to syslog
  - execute: optionally forward program output to /dev/console in
    addition to syslog/kmsg
  - socket: refuse socket activation for SysV services
  - fsck: do not fail boot if fsck returns with an error code that
    hasn't 2 or 6 set
  - shutdown: execute all binaries in /lib/systemd/system-shutdown
    as last step before invoking reboot()
  - job: make status message printing more verbose
  - cryptsetup: fix unit file description
  - tmpfiles: never delete AF_UNIX sockets that are alive
  - getty: don't parse console= anymore, use
    /sys/class/tty/console/active instead
  - properly resolve /dev/console if more than once console=
    argument was passed on the kernel command line
  - getty: do not auto-spawn getty's on VC ttys if console=ttyN
  - fsck: skip root fsck if dracut already did it
  - util: when determining the right TERM for /dev/console
    consult /sys/class/tty/console/active
  - pam: introduce whitelist and blacklist user list feature
  - systemctl: minor optimizations
  - systemctl: don't unnecessarily close stdin/stdout/stderr for
    tty agent so that locking by tty works
  - readahead: disable readahead in virtual machines
  - tmpfiles: move binary to /bin to make it publicly available
  - tmpfiles: take names of tmpfiles configuration files on the
    command line
  - tmpfiles: log to stderr if possible
  - tmpfiles: support globs
  - units: introduce and hook up sound.target
  - dbus: allow all clients access to org.freedesktop.DBus.Peer
  - consider udev devices with SYSTEMD_READY=0 as unplugged
  - systemctl: don't start agent for --user
  - systemctl: make sure the tty agent does not retain a copy
    of stdio
* Tue Feb  8 2011 kay.sievers@novell.com
- new snapshot
  - plymouth: move plymouth out of TARGET_FEDORA
  - build-sys: fix AC_COMPILE_IFELSE tests
  - build-sys: ensure selinux configure check follows logic of
    other optional features
  - build-sys: autodetect and use pkg-config for libselinux
  - dbus: use ControlGroup as property name to match config option
  - pam: optionally reset cgroup memberships for login sessions
  - load-fragment: properly parse Nice= value
  - automount: use unit_pending_inactive() where appropriate
* Tue Feb  8 2011 jeffm@suse.de
- Removed unecessary workaround for plymouth startup.
* Fri Feb  4 2011 jeffm@suse.de
- Split plymouth support into systemd-plymouth package.
* Sat Jan 22 2011 kay.sievers@novell.com
- new snapshot
  - clang: fix some issues found with clang-analyzer
  - gcc: make gcc shut up
* Sat Jan 22 2011 kay.sievers@novell.com
- version 17
  - vala 0.10 seem to work fine
  - cryptsetup: fix ordering loop when dealing with encrypted
    swap devices
  - main: don't warn if /etc/mtab is a symlink to /proc/mounts
  - socket: don't crash if the .service unit for a .socket unit
    is not found
  - mount: ignore if an fsck is requested for a bind mount,
    so that we don't wait for the bind 'device' to show up
  - automount: fix segfault when shutting down
  - man: give an example for vconsole.conf
  - dbus: don't try to connect to the system bus before it is
    actually up
  - service: make chain of main commands and control commands
    independent of each other, so that both can be executed
    simultaneously and independently
  - service: don't allow reload operations for oneshot services
  - vala: convert from dbus-glib to gdbus
  - systemctl: highlight failed processes in systemctl status
  - systemctl: show process type along process exit codes
  - service: when reloading a service fails don't fail the entire
    service but just the reload job
* Wed Jan 19 2011 kay.sievers@novell.com
- new snapshot
  - shutdown: use correct kexec options
  - serial-getty: do not invoke /sbin/securetty; recent
    pam_securetty looks for console= in /proc/cmdline
  - systemctl: before spawning pager cache number of columns
  - pam: optionally keep processes of root user around
  - service: if a reload operation fails, don't shut down
    the service
  - execute: make sending of SIGKILL on shutdown optional
  - mount: do not translate uuids to lowercase
  - man: document missing KillSignal= and swap options
- require recent util-linux
- drop mtab symlink creation which is done in util-linux
* Sat Jan  8 2011 kay.sievers@novell.com
- version 16
  - device: don't warn if we cannot bump the udev socket buffer
  - logger: when passing on PID info, fall back to our own if
    originating process is already gone
  - service: don't hit an assert if information in LSB headers is
    incorrectly formatted
  - execute,util: fix two small memory leaks
  - getty: unset locale before execution
  - execute: drop empty assignments from env blocks on execution
    but keep them around otherwise to make them visible
  - umount: don't try to detach the dm device the root dir is on,
    to minimize warning messages
  - locale: fix variable names
  - fragment: allow prefixing of the EnvironmentFile=
    path with - to ignore errors
  - util: don't pass invalid fd to fdopendir() on error to avoid
    corruption of errno
  - tmpfiles: nicer message when two or more conflicting lines
    are configured for the same file
  - fragment: properly handle quotes in assignments in
    EnvironmentFile= files
  - sysctl: don't warn if sysctls are gone
  - readahead: ignore if files are removed during collection or
    before replay
  - serial: use TERM=vt100 instead of TERM=vt100-nav
  - cryptsetup: call mkswap on dm device, not on source device
  - mount-setup: mount /dev/pts with mode=620,gid=5 by default
    and make GID overridable via configure switch
  - systemctl: implement auto-pager a la git
  - shutdown: drop redundant sync() invocation
  - util: invoke sync() implicitly on freeze()
  - tmpfiles: do no follow symlinks when cleaning up dirs
* Tue Dec 28 2010 jeffm@suse.de
- Add support for building plymouth support with openSUSE
* Mon Dec 27 2010 kay.sievers@novell.com
- new snapshot
  - pam: do not sort user sessions into their own cgroups in
    the 'cpu' hierarchy
  - mount-setup: drop noexec flag from default mount options
    for /dev/shm
  - systemd.pc: change 'session' to 'user'
* Thu Dec 16 2010 kay.sievers@novell.com
- new snapshot
  - ifdef suse-only sysv script lookup code
* Thu Dec 16 2010 seife@opensuse.org
- add bootsplash handling patch to be able to enter e.g.
  crypto passphrases (bnc#659885)
* Thu Dec  9 2010 kay.sievers@novell.com
- new snapshot
  - add LSB 'smtp' alias for mail-transport-agent.target
* Wed Dec  8 2010 kay.sievers@novell.com
- new snapshot
  - path: fix watching the root directory
  - update README
* Fri Nov 26 2010 kay.sievers@novell.com
- new snapshot
  - gnome-ask-password-agent: also support libnotify < 0.7 for now
  - udev: increase event buffer size
- require fsck -l
* Thu Nov 25 2010 kay.sievers@novell.com
- version 15
  - dbus: use the right data slot allocator
  - manager: bump up max number of units to 128K
  - build-sys: allow cross-compilation
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Tue Nov 23 2010 kay.sievers@novell.com
- new snapshot
  - units: simplify shutdown scripts
  - logger: fix error handling
  - swap: order file-based swap devices after remount-rootfs
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Mon Nov 22 2010 kay.sievers@novell.com
- new snapshot
  - systemctl: don't return LSB status error codes for 'show'
  - mount: do not try to mount disabled cgroup controllers
  - man: document /etc/modules-load.d/, /etc/os-release,
    locale.conf, /etc/vconsole.conf, /etc/hostname
  - units: move a couple of units from base.target to
    sysinit.target
  - man: reorder things to follow the same order everywhere
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Sat Nov 20 2010 kay.sievers@novell.com
- version 13
  - cryptsetup: actually show disk name
  - cryptsetup: show udev device name when asking for password
  - sysctl: implement native tool and support /etc/sysctl.d
  - units: enable console ask-password agent by default
  - introduce /etc/os-release distro description
  - job: make sure we don't fail umount.target if a mount unit
    failed to stop
  - cgroup: after killing cgroup processes, ensure the group is
    really dead gone. wait for 3s at max
  - cgroup: if we couldn't remove a cgroup after killing
    evertyhing in it then it's fine
  - cryptsetup: automatically order crypt partitions before
    cryptsetup.target
  - man: trivial BindTo description fix
  - manager: make list of default controllers configurable
  - build: expose libcryptsetup dependency in build string
  - pam: document controllers= switch
  - cgroup: by default, duplicate service cgroup in the cpu hierarchy
  - pam: duplicate cgroup tree in the cpu hierarchy by default,
    optionally more
- enable native crypto handling instead of boot.crypto
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Wed Nov 17 2010 kay.sievers@novell.com
- version 12
  - ask-password: add --console mode to ask /dev/console
- revert too new libnotify code/requirement
* Tue Nov 16 2010 kay.sievers@novell.com
- new snapshot
  - cryptsetup: reword questions a little
  - units: order hwclock after readahead
  - path: don't mention too many inotify msgs
  - cryptsetup: include device name in password question
  - cryptsetup: lock ourselves into memory as long as we deal
    with passwords
  - plymouth: use updated socket name
  - units: set TERM for gettys again, since they acquire a TTY
  - units: allow start-up of plymouth ask-password agent very early
  - units: enable ask-paswword .path units early enough to be useful
    for early mounts
  - units: delay getty until logins are allowed
  - pam: always rely on loginuid instead of uid to determine cgroup
    and XDG_RUNTIME_DIR name
  - cgroup: call root cgroup system instead of systemd-1
  - exec: determine right TERM= setting based on tty name
  - pam: rename master user cgroup to 'master'
  - drop support for MANAGER_SESSION, introduce MANAGER_USER
  - units: use ConditionDirectoryNotEmpty= where applicable
  - unit: introduce ConditionDirectoryNotEmpty=
  - delete tmp.mount which may conflict with an unrelated fstab
    entry
- revert too new libnotify code/requirement
- disable native crypto handling
* Mon Nov 15 2010 kay.sievers@novell.com
- new snapshot
  - load-dropin: add support for .requires directories
  - manager: consider jobs already installed as redundant when
    reducing new transactions
  - manager: always pull 'following' units into transaction
  - util: always highlight distro name
  - units: make use of agetty mandatory
  - manager: don't fail transaction if adding CONFLICTED_BY job fails
  - job: make it possible to wait for devices to be unplugged
  - tmpfiles: ignore files marked with the sticky bit
  - cryptsetup: handle password=none properly
  - cryptsetup: properly parse cipher= switch
  - cryptsetup: support non-LUKS crypto partitions
  - ask-password: enable password agent
  - automatically start cryptsetup when looking for mount source
  - log: add automatic log target
  - cryptsetup: hook up tool with ask-password
  - manager: hookup generators
  - split mount_point_is_api() and mount_point_ignore()
- replace boot.crypto job with systemd native crypto handling
- enable readahead (requires 2.6.37+ kernel's fanotify to work)
* Thu Nov 11 2010 kay.sievers@novell.com
- new snapshot
  - tmpfiles: include reference to man page in tmpfiles files
  - vconsole: support additional keymap for toggling layouts
  - main: warn if /etc/mtab is not a symlink
  - add bash completion for systemctl --system
  - man: minor tmpfiles(5) updates and reindenting
  - main: rename process on startup to 'systemd' to avoid confusion
  - unit: add ConditionNull= condition
  - ac-power: make ac-power a proper binary that scripts can call
  - manager: parse RD_TIMESTAMP passed from initrd
  - modules-load: fix minor race
  - label: use internal utility functions wher epossible
  - cryptsetup: minimal cryptsetup unit generator
  - selinux: relabel /dev after loading policy
  - log: downgrade syslog connection failure message
  - service: delay automatic restart if job is pending
  - manager: when isolating undo all pending jobs, too
  - manager: only minimize impact if we are in fail mode
- replace /etc/mtab with link to /proc/self/mounts
* Thu Nov  4 2010 kay.sievers@novell.com
- new snapshot
  - man/tmpfiles.d.xml: add a manpage for tmpfiles
  - do not overwrite other udev tags
  - readahead: shortcut replay if /.readahead doesn't exist
* Fri Oct 29 2010 kay.sievers@novell.com
- new snapshot
  - fsck: return SUCCESS when we skip the check
  - fsck: skip checking / if it is writable
  - units: fix variable expansion
  - mount: don't pull in nofail mounts by default, but use them
    if they are around
  - job: recursively fail BoundBy dependencies
  - fsck: fix target name to check for
  - units: rename fedora/single.service to rescue.service
  - units: introduce plymouth-start and plymouth-kexec
  - unit: get rid of IgnoreDependencyFailure=
  - use util-linux:agetty instead of mingetty
  - unit: replace StopRetroactively= by BindTo= dependencies
  - automount: show who's triggering an automount
  - units: run sysctl only if /etc/sysctl.conf exists
  - systemctl: always show what and where for mount units
  - shutdown: reword a few messages a little
  - manager: show which jobs are actually installed after a transaction
  - timer: when deserializing timer state stay elapsed
  - device: set recursive_stop=true by default
  - unit: suppress incorrect deserialization errors
  - swap: there's no reason not order swap after sysinit
  - socket: fix IPv6 availability detection
* Wed Oct 27 2010 kay.sievers@novell.com
- new snapshot
  - create /dev/stderr and friends early on boot
  - run sysv related scripts with TERM=linux
  - add only swaps listed in /etc/fstab automatically to swap.target
  - errors: refer to systemctl status when useful
  - swap: add default cgroup to swap exec env
  - readahead: bump a device's request_nr when enabling readahead
  - shutdown: properly handle sigtimedwait() timing out
  - main: fix typo in kernel cmdline parameters help
  - ord-tty: properly handle SIGINT/SIGTERM
  - systemctl: automatically spawn temporary password agent
  - ask-password: properly handle multiple pending passwords
  - ask-password: enable plymouth agent by default
  - ask-password: add minimal plymouth password agent
* Tue Oct 26 2010 kay.sievers@novell.com
- new snapshot
  - make sure to pass TERM=linux to all sysv scripts
  - don't unset HOME/TERM when run in session mode
  - mount: add nosuid,nodev,noexec switches to /var/lock and /var/run
  - tmpfiles: Don't clean /var/lock/subsys
  - tmpfiles: Make wtmp match utmp perms, and add btmp
  - umount: Make sure / is remounted ro on shutdown
  - unset HOME and TERM set from the kernel
  - activate wall agent automatically
  - ask-password: add basic tty agent
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - rename ask-password-agent to gnome-ask-password-agent
  - fsck: suppress error message if we cannot change into single
    user mode since
  - dbus: epose FsckPassNo property for service objects
  - man: document systemctl --force
  - introduce 'systemctl kill'
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - syslog: enable kmsg bridge by default
  - fsck: add initial version of fsck and quotacheck wrappers
  - tmpfiles: remove forcefsck/fastboot flag files after boot
  - swap: listen for POLLPRI events on /proc/swaps if availabled
  - tmpfiles: integrate native tmpwatch
  - shutdown: loop only as long as we manage to unmount/detach devices
  - umount: disable dm devices by devnode, not by path name
  - introduce final.target
  - replace distro-specific shutdown scripts with native services
  - try to get rid of DM devices
  - log to console by default
  - introduce kexec.service, kexec.target and exit.target
  - hook in fsck@.service instance for all mount points with passno > 0
  - systemctl: warn if user enables unit with no installation instructions
  - dbus: add introspection to midlevel paths
  - look for dynamic throw-away units in /dev/.systemd/system
  - major rework, use /sbin/swapon for setting up swaps
  - introduce Restart=on-failure and Restart=on-abort
  - units: enable utmp for serial gettys too
  - rename 'banned' load state to 'masked'
  - optionally, create INIT_PROCESS/DEAD_PROCESS entries for a service
- use systemd-native fsck/mount
- use systemd-native tmpfiles.d/ instead of tmpwatch
* Fri Oct  8 2010 kay.sievers@novell.com
  new snapshot
  - fix 'systemctl enable getty@.service'
  - properly support 'banning' of services
  - handle nologin
  - add native reboot/shutdown implementation
* Thu Oct  7 2010 kay.sievers@novell.com
- version 11
* Wed Oct  6 2010 kay.sievers@novell.com
- new snapshot
  - readahead fixes
* Sun Oct  3 2010 aj@suse.de
- /etc/modules.d was renamed to modules-load.d
- only include tmpfiles.d/*conf files
* Wed Sep 29 2010 kay.sievers@novell.com
- don't create sysv order deps on merged units
- fix Provides: handling in LSB headers (network.target)
- native (optional) readahead
* Sun Sep 26 2010 aj@suse.de
- Do not package man pages twice.
* Wed Sep 22 2010 kay.sievers@novell.com
- new snapshot
  - basic services are enabled by default now
* Tue Sep 21 2010 kay.sievers@novell.com
- new snapshot
  - vconsole and locale setup
  - hook up tmpwatch
* Fri Sep 17 2010 kay.sievers@novell.com
- new snapshot
  - add new utility to initialize the virtual console
  - initialize locale from /etc/locale by default
  - ask-password: allow services query SSL/harddisk passphrases
* Fri Sep 17 2010 kay.sievers@novell.com
- version 10
  - logger: support SOCK_STREAM /dev/log sockets
  - make sure the file system is writable before we write utmp data
  - systemctl: use isolate when called as telinit for a runlevel
  - initctl: properly use isolate when activating runlevels
  - set HOME=/root when running shells
  - make sure we don't crash if there's an automount unit without
    mount unit
  - start logger only after syslog is up
* Fri Sep  3 2010 kay.sievers@novell.com
- version 9
  - units: don't add shutdown conflicts dep to umount.target
  - dbus: don't send cgroup agent messages directly to system bus
  - dbus: don't accept activation requests anymore if we are going
    down anyway
  - systemctl: fix return value of systemctl start and friends
  - service: wait for process exit only if we actually killed
    somebody
* Thu Aug 26 2010 kay.sievers@novell.com
- version 8
  - KERNEL 2.6.36+ REQUIRED!
  - mount cgroup file systems to /sys/fs/cgroup instead of /cgroup
  - invoke sulogin instead of /bin/sh
  - systemctl: show timestamps for state changes
  - add global configuration options for handling of auto mounts
* Fri Aug 20 2010 kay.sievers@novell.com
- apply /etc/fstab mount options to all api mounts
- properly handle LABEL="" in fstab
- do not consider LSB exit codes 5 and 6 as failure
* Tue Aug 17 2010 kay.sievers@novell.com
- prefix sysv job descriptions with LSB:
- add native sysctl + hwclock + random seed service files
- properly fallback to rescue.target if default.target is hosed
- rename ValidNoProcess= to RemainAfterExit=
- add systemd-modules-load tool to handle /etc/modules.d/
* Tue Aug 17 2010 kay.sievers@novell.com
- add support for delayed shutdown, similar to sysv in style
- rename Type=finish to Type=oneshot and allow multiple ExecStart=
- don't show ENOENT for non exitent configuration files
- log build time features on startup
- rearrange structs to make them smaller
- move runlevel[2-5] links to /lib
- create default.target link to /lib not /etc
- handle random-seed
- write utmp record before we kill all processes
- create /var/lock/subsys, /var/run/utmp
* Wed Aug 11 2010 kay.sievers@novell.com
- add audit messages for service changes
- update utmp with external program
- all to refuse manual service starting/stopping
* Tue Aug 10 2010 kay.sievers@novell.com
- version 7
  - hide output if quiet is passed on the kernel cmdline
  - fix auto restarting of units after a configuration reload
  - don't call bus_path_escape() with NULL unit name
* Fri Aug  6 2010 kay.sievers@novell.com
- version 6
  - man page update
* Fri Aug  6 2010 kay.sievers@novell.com
- new snapshot
  - downgrade a few log messages
  - properly handle devices which are referenced before they exist
* Thu Aug  5 2010 kay.sievers@novell.com
- new snapshot
  - fix dependency cycle of boot.* by splitting fsck.target
  - sort boot.* before other sysv services
    from sysinint.target
  - start getty for serial console
* Thu Aug  5 2010 kay.sievers@novell.com
- add licence to subpackages
* Wed Aug  4 2010 kay.sievers@novell.com
- version 5
  - selinux fixes
- fix hanging 'reboot' started from vc
* Mon Aug  2 2010 kay.sievers@novell.com
- enable getty.target by default
* Sat Jul 24 2010 kay.sievers@novell.com
- at install, read old inittab for the defaul target/runlevel
- disable services on package uninstall
* Sat Jul 24 2010 kay.sievers@novell.com
- version 4
  - merge systemd-install into systemctl
* Fri Jul 23 2010 kay.sievers@novell.com
- create config files in /etc in %%post
- mark files in /etc as config
- remove nodev from /dev/pts
- add selinux support
* Thu Jul 22 2010 kay.sievers@novell.com
- version 4 (pre)
  - require newer vala
  - add [Install] section to getty.target and remote-fs.target
- re-enable post-build check
* Wed Jul 21 2010 kay.sievers@novell.com
- do not add sysv services that are not enabled in /etc/rcN.d/
- allow symlinking unit files to /dev/null
- remove only pam sessions we ourselves created
- unit files in /etc/ always take precedence, even over link targets
* Tue Jul 20 2010 kay.sievers@novell.com
- fix access mode verification of FIFOs
* Sun Jul 18 2010 kay.sievers@novell.com
- fix default mode of /var/run and /var/lock
- force /var/run and /var/lock to be on tmpfs
* Wed Jul 14 2010 kay.sievers@novell.com
- always enable udev and dbus until we can require systemd from
  packages providing systemd service files
* Tue Jul 13 2010 kay.sievers@novell.com
- drop systemd-units.rpm
* Tue Jul 13 2010 kay.sievers@novell.com
- version 3
  - treat non-existing cgroups like empty ones, to deal with races
  - replace --running-as= by --session and --system
  - always allow stopping of units that failed to load
* Tue Jul 13 2010 kay.sievers@novell.com
- update
* Mon Jul 12 2010 kay.sievers@novell.com
- drop libcgroup
* Mon Jul 12 2010 kay.sievers@novell.com
- trim cgroups for services that are "active" but "exited"
- drop /bin/init hack and require now fixed mkinitrd
* Sun Jul 11 2010 kay.sievers@novell.com
- fix reboot issue
- fix abstract namespace name handling (needs udev update)
- prefer private D-Bus socket wherever possible
* Sat Jul 10 2010 kay.sievers@novell.com
- D-Bus 1.3.2 support
- use COLD_BOOT=1 on reboot to skip sysv boot.d/ handling
* Fri Jul  9 2010 kay.sievers@novell.com
- fix typo in spec file
* Fri Jul  9 2010 kay.sievers@novell.com
- provide /bin/init to be found by 'too simple' mkinitrd, and work
  around mindless relinking of relative links in the buildsystem
- add rpmlintrc to silent warnings about intentional behavior
* Fri Jul  9 2010 kay.sievers@novell.com
- version 2
* Thu Jul  8 2010 kay.sievers@novell.com
- fix 'reboot -w' to skip the actual reboot
- fix segfault in D-Bus code
- use unique instead of multiple keys in config file
- support continuation lines in config files
- support multiple commands in a single key in config files
- adapt log level of some messages
* Wed Jul  7 2010 kay.sievers@novell.com
- version 1
  - default log level to INFO
  - show welcome message
* Tue Jul  6 2010 kay.sievers@novell.com
- add systemd-install --start option
- add more documentation
* Mon Jul  5 2010 kay.sievers@novell.com
- new snapshot with extended D-Bus support
* Sun Jul  4 2010 kay.sievers@novell.com
- new snapshot with default unit dependency handling
* Sat Jul  3 2010 kay.sievers@novell.com
- new snapshot
* Fri Jul  2 2010 kay.sievers@novell.com
- add more documentation
* Thu Jul  1 2010 kay.sievers@novell.com
- new snapshot
* Thu Jun 24 2010 kay.sievers@novell.com
- split off systemd-units.rpm which can be pulled-in by other
  packages without further dependencies
* Thu Jun 24 2010 kay.sievers@novell.com
- add more documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- more man pages and documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- conflict with upstart
- include all installed doc files
* Tue Jun 22 2010 kay.sievers@novell.com
- provide pam module
* Mon Jun 21 2010 kay.sievers@novell.com
- use private D-Bus connection
- properly handle replacing a running upstart
* Fri Jun 18 2010 kay.sievers@novell.com
- implement wall message in halt/reboot/...
- speak /dev/initctl to old /sbin/init after installing
* Thu Jun 17 2010 kay.sievers@novell.com
- drop no longer needed -fno-strict-aliasing
- add README and examples
* Thu Jun 17 2010 kay.sievers@novell.com
- enable pam and libwrap
* Thu Jun 17 2010 kay.sievers@novell.com
- provide systemd-sysvinit.rpm with /sbin/init and friends
* Thu Jun 17 2010 kay.sievers@novell.com
- libwrap / pam support
* Wed Jun 16 2010 kay.sievers@novell.com
- initial packaging of experimental version 0
